#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# This file is generated, DO NOT EDIT!
# For more details, see:
#    - https://github.com/zoranbosnjak/asterix-lib-generator
#    - https://github.com/zoranbosnjak/asterix-specs
"""Asterix data manipulation routines, generic code.
"""

from dataclasses import dataclass
from typing import *
import sys
if sys.version_info < (3, 10):
    from typing_extensions import TypeAlias
from functools import reduce, total_ordering, partial
import math
from abc import *
from binascii import hexlify, unhexlify
import re

Raw : TypeAlias = int
ItemName : TypeAlias = str

@dataclass
class ParsingOptions:
    no_check_spare : bool       # do not check spare bits value (zero)

    @classmethod
    def default(cls) -> 'ParsingOptions':
        return ParsingOptions(
            no_check_spare = False,
        )

class AsterixError(Exception):
    """Base class for asterix related errors."""
    def __init__(self, msg : Optional[str]=None):
        if msg is None:
            msg = self.__class__.__name__
        super().__init__(msg)

class AsterixOverflow(AsterixError):
    """Raised when no sufficient data is available."""

@dataclass
class RawDatablock:
    """Size verified raw datablock."""
    bs : bytes

    @classmethod
    def parse_single(cls, s : bytes) -> Tuple['RawDatablock', bytes]:
        """Parse the first level of asterix and the remaining, that is:
        [cat|len|records...|cat|len|records...|...]
        -------------------|-----------------------
            ^--result           ^--remaining
        """
        if len(s) < 3:
            raise AsterixOverflow('datablock header')
        n = int.from_bytes(s[1:3], 'big')
        if n < 3:
            raise AsterixError('datablock length < 3')
        if len(s) < n:
            raise AsterixOverflow('datablock records')
        (a,b) = (s[0:n], s[n:])
        return(cls(a), b)

    @classmethod
    def parse(cls, s : bytes) -> List['RawDatablock']:
        """Parse the first level of asterix to the list of results."""
        def go(acc : List['RawDatablock'], val : bytes) -> Tuple[List['RawDatablock'], bytes]:
            if len(val) == 0:
                return (acc, val)
            (db, rest) = cls.parse_single(val)
            return go(acc+[db], rest)
        return go([], s)[0]

    def unparse(self) -> bytes:
        return self.bs

    @property
    def category(self) -> int:
        return self.bs[0]

    @property
    def length(self) -> int:
        return int.from_bytes(self.bs[1:3], 'big')

    @property
    def raw_records(self) -> bytes:
        return self.bs[3:]

@dataclass
class Bits:
    """Bit string, a wrapper around bytes (bytes, offset, size)."""
    bs          : bytes
    bit_offset  : int
    bit_size    : int

    @classmethod
    def empty(cls) -> 'Bits':
        return cls(b'', 0, 0)

    @classmethod
    def from_bytes(cls, val : bytes) -> 'Bits':
        return cls(val, 0, len(val)*8)

    @classmethod
    def from_uinteger(cls, raw : int, o : int, n : int) -> 'Bits':
        (a,b) = divmod(o+n, 8)
        rem = 8-b if b else 0
        if b:
            a += 1
            raw *= pow(2, rem)
        raw = raw % pow(2, a*8)
        bs = raw.to_bytes(a, 'big')
        return Bits(bs, o, n)

    @classmethod
    def fx(cls, val : bool) -> 'Bits':
        return cls.from_uinteger(1 if val else 0, 7, 1)

    def __len__(self) -> int:
        return self.bit_size

    def __iter__(self) -> Iterator[bool]:
        o = self.bit_offset
        n = self.bit_size
        (a,b) = divmod(o, 8)
        m = math.ceil(n/8)
        bs = self.bs[a:a+m]
        s2 = ''.join([bin(i)[2:].zfill(8) for i in bs])
        o2 = o%8
        s3 = s2[o2:o2+n]
        for i in s3:
            yield False if i=='0' else True

    def __eq__(self, other : Any) -> bool:
        return list(self) == list(other)

    def _compact(self) -> bytes:
        (a, b) = divmod(self.bit_offset, 8)
        n = self.bit_offset + self.bit_size
        (c, d) = divmod(n, 8)
        if d: c += 1
        return self.bs[a:c]

    def __str__(self) -> str:
        bs = self._compact()
        o = self.bit_offset % 8
        mask = [i >= o and i < (o + self.bit_size) for i in range(len(bs)*8)]
        bits = ''.join([bin(i)[2:].zfill(8) for i in bs])
        out = ''.join([b if m else '.' for (b,m) in zip(bits, mask)])
        return ' '.join(re.findall('........', out))

    def split_at(self, n : int) -> Tuple['Bits', 'Bits']:
        assert n >= 0
        if n > self.bit_size:
            raise AsterixOverflow
        a = self.__class__(self.bs, self.bit_offset, n)
        b = self.__class__(self.bs, self.bit_offset + n, self.bit_size - n)
        return (a,b)

    def take(self, x : int) -> 'Bits':
        return self.split_at(x)[0]

    def drop(self, x : int) -> 'Bits':
        return self.split_at(x)[1]

    def __add__(self, other : 'Bits') -> 'Bits':
        o = other.bit_offset % 8
        assert ((self.bit_offset + self.bit_size) % 8) == o, "Bits alignment error"
        n1 = self.bit_size
        n2 = other.bit_size
        bs1 = self._compact()
        bs2 = other._compact()
        if o:
            (a1, x1) = bs1[:-1], bs1[-1]
            (x2, b2) = bs2[0], bs2[1:]
            mask2 = 0xff >> o
            mask1 = 0xff - mask2
            x = (x1 & mask1) | (x2 & mask2)
            bs = a1 + x.to_bytes(1, 'big') + b2
            return self.__class__(bs, self.bit_offset % 8, n1+n2)
        else:
            return self.__class__(bs1 + bs2, self.bit_offset % 8, n1+n2)

    def to_bytes(self) -> bytes:
        (a,o) = divmod(self.bit_offset, 8)
        assert o == 0
        (b,o) = divmod(self.bit_size, 8)
        assert o == 0
        return self.bs[a:a+b]

    def to_uinteger(self) -> int:
        (a,o) = divmod(self.bit_offset, 8)
        bs = self.bs[a:]
        if o != 0:
            x = bs[0] & (0xff >> o)
            bs = x.to_bytes(1, 'big') + bs[1:]
        (c,d) = divmod(o + self.bit_size, 8)
        if d == 0:
            return int.from_bytes(bs[0:c], 'big')
        else:
            return (int.from_bytes(bs[0:(c+1)], 'big') >> (8-d))

    @classmethod
    def join(cls, lst : List['Bits']) -> 'Bits':
        if len(lst) == 0: return Bits.empty()
        if len(lst) == 1: return lst[0]
        # TODO: optimize...
        #   - try to avoid bytes concatination
        #   - create groups of the same 'bs'
        #   - use b''.join(...) instead if (+)
        return reduce(lambda a,b: a+b, lst)

def mk_item(t : Any, val : Any) -> Any:
    """Helper function to create item, either by
        - using t(val)
        - or val itself if it's of the correct type already.
    """
    if not isinstance(val, t):
        val = t(val)
    return val

@dataclass
class Spare:
    """Spare bits."""
    bit_offset8 : int
    bit_size : int

    def parse_bits(self, s : Bits, opt : ParsingOptions) -> Any:
        n = self.bit_size
        if not opt.no_check_spare:
            if s.take(n).to_uinteger() != 0:
                raise AsterixError('unexpected non-zero spare item')
        return n

    def unparse_bits(self) -> Bits:
        return Bits.from_uinteger(0, self.bit_offset8, self.bit_size)

class StringType:
    """Baseclass for 'String' types"""
    n : int

    @classmethod
    @abstractmethod
    def from_char(cls, ch : str) -> Raw: ...

    @classmethod
    @abstractmethod
    def to_char(cls, x : Raw) -> str: ...

    @classmethod
    def from_string(cls, s : str) -> Raw:
        p = pow(2, cls.n)
        acc = 0
        for (ix, ch) in enumerate(reversed(s)):
            acc += cls.from_char(ch) * pow(p, ix)
        return acc

    @classmethod
    def to_string(cls, x : Raw, bit_size : int) -> str:
        p = pow(2, cls.n)
        n = bit_size // cls.n
        acc = ''
        for i in range(n):
            (x, i) = divmod(x, p)
            acc = cls.to_char(i) + acc
        return acc

class StringAscii(StringType):
    """Ascii string."""

    n = 8

    @classmethod
    def from_char(cls, ch : str) -> Raw:
        return ord(ch)

    @classmethod
    def to_char(cls, x : Raw) -> str:
        return chr(x)

class StringICAO(StringType):
    """
    Valid range is:
        - 'A'..'Z'  -> [0x01..]
        - space     -> 0x20
        - '0'..'9'  -> [0x30..]
    """

    n = 6

    @classmethod
    def from_char(cls, ch : str) -> Raw:
        if ch >= 'A' and ch <= 'Z':
            return 0x01 + ord(ch) - ord('A')
        if ch == ' ':
            return 0x20
        if ch >= '0' and ch <= '9':
            return 0x30 + ord(ch) - ord('0')
        return 0

    @classmethod
    def to_char(cls, x : Raw) -> str:
        if x >= 0x01 and x <= 0x1A:
            return chr(ord('A') + x - 0x01)
        if x == 0x20:
            return ' '
        if x >= 0x30 and x <= 0x39:
            return chr(ord('0') + x - 0x30)
        return ''

class StringOctal(StringType):
    """Valid character range: ['0'..'7']"""
    n = 3

    @classmethod
    def from_char(cls, ch : str) -> Raw:
        return ord(ch) - ord('0')

    @classmethod
    def to_char(cls, x : Raw) -> str:
        return chr(ord('0') + x)

class Quantity:
    """Quantity helper class."""
    def __init__(self, sig : Literal['Signed', 'Unsigned'], lsb : float, unit : str):
        self.sig = sig
        self.lsb = lsb
        self.unit = unit

class Variation:
    """Baseclass for all variations."""
    variation : str

    def __init__(self, val : Bits):
        self._val = val

    def unparse_bits(self) -> Bits:
        return self._val

    def __eq__(self, other : object) -> bool:
        if not isinstance(other, Variation):
            return NotImplemented
        return self._val == other._val

    def to_uinteger(self) -> int:
        return self._val.to_uinteger()

class Element(Variation):
    bit_offset8 : int
    bit_size : int
    string_type : StringType
    quantity : Quantity

    @classmethod
    def parse_bits(cls, s : Bits, opt : ParsingOptions) -> Any:
        n = cls.bit_size
        (a,b) = s.split_at(n)
        return (cls(a), b)

    def _from_raw(self, raw : Raw) -> Bits:
        o = self.__class__.bit_offset8
        n = self.__class__.bit_size
        assert (o >= 0) and (o < 8)
        assert n > 0
        return Bits.from_uinteger(raw, o, n)

    def _from_string(self, s : str) -> Bits:
        st = self.__class__.string_type
        return self._from_raw(st.from_string(s))

    def _sig(self, x : int) -> int:
        sig = self.__class__.quantity.sig
        if sig == 'Signed':
            half = pow(2, self.__class__.bit_size-1)
            if x < half:
                return x
            else:
                return (x - int(2*half))
        if sig == 'Unsigned':
            return x
        assert_never(sig)

    def _from_float(self, val : float) -> Bits:
        x = round(val/self.quantity.lsb)
        return self._from_raw(x)

    def _to_string(self) -> str:
        st = self.__class__.string_type
        x = self.to_uinteger()
        return st.to_string(x, self.__class__.bit_size)

    def _to_quantity(self) -> float:
        x = self._sig(self.to_uinteger())
        return (x * self.quantity.lsb)

def _items_to_group(lst : List[Union[Spare, Tuple[ItemName, Any]]], args : Any, fx : Optional[bool]) -> Tuple[Bits, Dict[ItemName, Element]]:
    """Helper function for 'Group' and 'Extended'."""
    bits : List[Bits] = []
    items : Dict[ItemName, Element] = {}
    for x in lst:
        if isinstance(x, Spare):
            bits.append(x.unparse_bits())
            continue
        if isinstance(x, tuple):
            name, t = x
            i = mk_item(t, args[name])
            items[name] = i
            bits.append(i.unparse_bits())
            continue
        assert_never(x)
    if fx is not None:
        bits.append(Bits.fx(fx))
    return (Bits.join(bits), items)

def _raw_to_items(lst : List[Union[Spare, Tuple[ItemName, Any]]], raw : Raw) -> Dict[ItemName, Element]:
    """Helper function for 'Group' and 'Extended'."""
    items : Dict[ItemName, Element] = {}
    for x in reversed(lst):
        if isinstance(x, Spare):
            raw, ignore = divmod(raw, pow(2, x.bit_size))
            continue
        if isinstance(x, tuple):
            name, t = x
            raw, val = divmod(raw, pow(2, t.bit_size))
            items[name] = val
            continue
        assert_never(x)
    return items

def _parse_group(s, lst, opt):   # type: ignore
    """Helper function for 'Group' and 'Extended'."""
    reminder = s
    items = {}
    n = 0
    for i in lst:
        if isinstance(i, Spare):
            result = i.parse_bits(reminder, opt)
            reminder = reminder.drop(result)
            n += result
        else:
            (item, reminder) = i[1].parse_bits(reminder, opt)
            items[i[0]] = item
            n += len(item.unparse_bits())
    return (n, items)

class Group(Variation):
    subitems_list : List[Union[Spare, Tuple[ItemName, Any]]]
    subitems_dict : Dict[ItemName, Tuple[str, Any, int, int]]

    @classmethod
    def parse_bits(cls, s : Bits, opt : ParsingOptions) -> Any:
        (n, items) = _parse_group(s, cls.subitems_list, opt) # type: ignore
        (a, b) = s.split_at(n)
        return (cls((a, items)), b) # type: ignore

    def __init__(self, val : Bits, items : Dict[ItemName, Any]):
        self._val = val
        self._items = items

    def _from_items(self, args : Any) -> Tuple[Bits, Dict[ItemName, Element]]:
        return _items_to_group(self.__class__.subitems_list, args, fx=None)

    def _from_raw(self, raw : Raw) -> Tuple[Bits, Dict[ItemName, Element]]:
        return self._from_items(_raw_to_items(self.__class__.subitems_list, raw))

    def _get_item(self, name : Any) -> Any:
        return self._items[name]

    def _set_item(self, name : Any, val : Any) -> Any:
        items = self._items.copy()
        items[name] = val
        return self.__class__(items) # type: ignore

    def _modify_item(self, name : Any, f : Any) -> Any:
        x = self._get_item(name)
        return self._set_item(name, f(x))

class Extended(Variation):
    no_trailing_fx : bool
    groups_bit_sizes : List[int]
    subitems_list : List[List[Union[Spare, Tuple[ItemName, Any]]]]
    subitems_dict : Dict[ItemName, Tuple[str, Any, int, int]]

    @classmethod
    def parse_bits(cls, s : Bits, opt : ParsingOptions) -> Any:
        def is_last(grp : List[Any]) -> bool:
            return grp == cls.subitems_list[-1]
        reminder = s
        items = {}
        n = 0
        for grp in cls.subitems_list:
            (m, sub) = _parse_group(reminder, grp, opt) # type: ignore
            reminder = reminder.drop(m)
            items.update(sub)
            if is_last(grp) and cls.no_trailing_fx:
                n += m
                break
            else:
                (fx,reminder) = reminder.split_at(1)
                n += (m+1)
                if fx.to_uinteger() == 0:
                    break
                if is_last(grp) and fx.to_uinteger() == 1:
                    raise AsterixError('unexpected fx bit set')
        (a,b) = s.split_at(n)
        return (cls((a, items)), b) # type: ignore

    def __init__(self, val : Bits, items : Dict[ItemName, Element]):
        self._val = val
        self._items = items

    def _concat(self, lst : List[Any]) -> Tuple[Any, Any]:
        bits = Bits.join([a for (a,_b) in lst])
        items = {}
        for (_a,b) in lst:
            items.update(b)
        return (bits, items)

    def _from_single_int(self, ix: int, val : int, fx : Optional[bool]) -> Tuple[Bits, Dict[ItemName, Element]]:
        lst = self.__class__.subitems_list[ix]
        items = _raw_to_items(lst, val)
        return _items_to_group(lst, items, fx)

    def _fx_absent(self, group_list : List[Any]) -> bool:
        return all ([
            self.__class__.no_trailing_fx,
            len(group_list) >= len(self.__class__.subitems_list) ])

    def _from_tuple_int(self, val : Any) -> Tuple[Bits, Dict[ItemName, Element]]:
        val = list(enumerate(val))
        a = val[:-1] # fx=True
        b = val[-1]  # fx=False or absent

        result = [self._from_single_int(ix, x, fx=True) for (ix, x) in a]
        trailing_fx = None if self._fx_absent(val) else False
        result += [self._from_single_int(b[0], b[1], fx=trailing_fx)]

        return self._concat(result)

    def _from_dict(self, n : int, arg : Any) -> Tuple[Bits, Dict[ItemName, Element]]:
        def mk_names(lst : List[Any]) -> Any:
            for i in lst:
                if not isinstance(i, Spare):
                    yield i[0]
        subitems = [mk_names(lst) for lst in self.__class__.subitems_list]
        def mk_group(lst : Any) -> Any:
            return {k: arg[k] for k in lst}
        groups = list(map(mk_group, subitems[0:n]))
        trailing_fx = None if self._fx_absent(groups) else False
        a = groups[:-1]    # fx=True
        b = groups[-1]     # fx=False
        groups = [(x, True) for x in a]
        groups.append((b, trailing_fx))
        result = []
        for (ix, (items, fx)) in enumerate(groups):
            lst = self.__class__.subitems_list[ix]
            result.append(_items_to_group(lst, items, fx))
        return self._concat(result)

    def _get_item(self, name : Any) -> Any:
        return self._items.get(name)

    def _set_item(self, name : Any, val : Any) -> Any:
        items = self._items.copy()
        items[name] = val
        return self.__class__(items) # type: ignore

    def _modify_item(self, name : Any, f : Any) -> Any:
        x = self._items.get(name)
        if x is None:
            return self
        return self._set_item(name, f(x))

class Repetitive(Variation):
    rep_byte_size : Optional[int]
    variation_bit_size : int
    variation_type : Any

    @classmethod
    def parse_bits(cls, s : Bits, opt : ParsingOptions) -> Any:
        bs = cls.rep_byte_size
        items = []
        # parsing with FX
        if bs is None:
            n = 0
            reminder = s
            while True:
                (item, reminder) = cls.variation_type.parse_bits(reminder, opt)
                (fx, reminder) = reminder.split_at(1)
                items.append(item)
                n += len(item.unparse_bits()) + 1
                if fx.to_uinteger() == 0:
                    break
        # parsing as regular repetitive
        else:
            rbs = bs * 8
            n = rbs
            (m,reminder) = s.split_at(rbs)
            for i in range(m.to_uinteger()):
                (item, reminder) = cls.variation_type.parse_bits(reminder, opt)
                items.append(item)
                n += len(item.unparse_bits())

        (a,b) = s.split_at(n)
        return (cls((a, items)), b) # type: ignore

    def __init__(self, val : Bits, items : List[Variation]):
        self._val = val
        self._items = items

    def _from_list(self, lst : List[Any]) -> Tuple[Bits, Any]:
        cls = self.__class__.variation_type
        items = [mk_item(cls,arg) for arg in lst]
        bs = self.__class__.rep_byte_size
        if bs is None:
            blist = []
            for (ix, i) in enumerate(items):
                fx = Bits.fx(True if ((ix+1) < len(items)) else False)
                blist.append(i.unparse_bits() + fx)
            return (Bits.join(blist), items)
        else:
            bits = Bits.join([i.unparse_bits() for i in items])
            n = Bits.from_uinteger(len(lst), 0, bs*8)
            return(n+bits, items)

    def __len__(self) -> Any:
        return len(self._items)

    def __iter__(self) -> Any:
        return iter(self._items)

    def __getitem__(self, ix : int) -> Any:
        return self._items[ix]

    def _append_item(self, arg : Any) -> Any:
        items = self._items.copy()
        return self.__class__(items + [arg]) # type: ignore

    def _prepend_item(self, arg : Any) -> Any:
        items = self._items.copy()
        return self.__class__([arg] + items) # type: ignore

class Explicit(Variation):
    explicit_type : Optional[str]

    @classmethod
    def parse_bits(cls, s : Bits, opt : ParsingOptions) -> Any:
        (a,b) = s.split_at(8)
        n = a.to_uinteger() * 8
        (a,b) = s.split_at(n)
        raw = a.drop(8).to_bytes()
        return (cls((a, raw)), b) # type: ignore

    def __init__(self, val : Bits, raw : bytes):
        self._val = val
        self._raw = raw

    def _from_bytes(self, arg : bytes) -> Tuple[Bits, bytes]:
        n = len(arg) + 1
        bits = Bits.from_uinteger(n, 0, 8) + Bits.from_bytes(arg)
        return (bits, arg)

    @property
    def raw(self) -> bytes:
        return self._raw

class Compound(Variation):
    fspec_fx : bool
    fspec_max_bytes : int
    subitems_list : List[Optional[Tuple[ItemName, Any]]]
    subitems_dict : Dict[ItemName, Tuple[str, Any, int]]

    @classmethod
    def _parse_fspec(cls, s : Bits, opt : ParsingOptions) -> Any:
        reminder = s
        if cls.fspec_fx:
            cnt = 0
            flags = []
            while True:
                if cnt >= cls.fspec_max_bytes:
                    raise AsterixError('fspec max bytes exceeded')
                cnt += 1
                (a, reminder) = reminder.split_at(8)
                flags.extend(list(a.take(7)))
                fx = a.drop(7).take(1).to_uinteger()
                if fx == 0:
                    break
            return (cnt*8, flags)
        else:
            n = cls.fspec_max_bytes * 8
            return (n, list(s.take(n)))

    @classmethod
    def parse_bits(cls, s : Bits, opt : ParsingOptions) -> Any:
        result = cls._parse_fspec(s, opt)
        (n,fspec) = result
        items = {}
        reminder = s.drop(n)
        for (flag, i) in zip(fspec, cls.subitems_list):
            if not flag:
                continue
            if i is None:
                raise AsterixError('fx bit set for non-defined item')
            (subname, subcls) = i
            result = subcls.parse_bits(reminder, opt)
            (subitem, reminder) = result
            items[subname] = subitem
            n += len(subitem.unparse_bits())
        return (cls((s.take(n), items)), reminder) # type: ignore

    def __init__(self, val : Bits = Bits.empty(), items : Dict[ItemName, Variation] = {}) -> None:
        self._val = val
        self._items = items

    def __bool__(self) -> bool:
        return bool(self._items)

    def _fspec(self, parts : List[ItemName]) -> Bits:
        d = self.__class__.subitems_dict
        fspec = reduce(lambda a,b: a|b, [d[name][2] for name in parts], 0)
        n = self.__class__.fspec_max_bytes
        if self.__class__.fspec_fx:
            while (((fspec % 256) == 0) and (n>0)):
                fspec = fspec // 256
                n -= 1
        return Bits.from_bytes(fspec.to_bytes(n, 'big'))

    def _recreate(self, items : Any) -> Any:
        bits : List[Bits] = []
        fspec = self._fspec(list(items.keys()))
        bits.append(fspec)
        for x in self.__class__.subitems_list:
            if isinstance(x, tuple):
                name, ignore = x
                i = items.get(name)
                if i is not None:
                    bits.append(i.unparse_bits())
        obj = self.__class__()
        obj._val = Bits.join(bits)
        obj._items = items
        return obj

    def _set_item(self, name : ItemName, val : Any) -> Any:
        _title, t, fspec_bit = self.__class__.subitems_dict[name]
        i = mk_item(t, val)
        items = self._items.copy()
        items[name] = i
        return self._recreate(items)

    def _update(self, args : Any) -> Any:
        obj = self
        for name, val in args.items():
            obj = obj._set_item(name, val)
        self._val = obj._val
        self._items = obj._items

    def _del_item(self, name : ItemName) -> Any:
        items = self._items.copy()
        items.pop(name, None)
        return self._recreate(items)

    def _get_item(self, name : ItemName) -> Any:
        return self._items.get(name)

    def _modify_item(self, name : Any, f : Any) -> Any:
        x = self._items.get(name)
        if x is None:
            return self
        return self._set_item(name, f(x))

T = TypeVar('T')
class Datablock(Generic[T]):
    """Correctly constructed/parsed datablock."""
    def __init__(self, cat : int, lst : Union[T, List[T]], val : Optional[bytes] = None):
        self.cat = cat
        if not isinstance(lst, list):
            lst = [lst]
        self.lst = lst
        raw = b''.join([rec.unparse_bits().to_bytes() for rec in lst]) # type: ignore
        if val is None:
            val = b''.join([
                cat.to_bytes(1, 'big'),             # CAT
                (3 + len(raw)).to_bytes(2, 'big'),  # LEN
                raw])
        self.val = val

    def unparse(self) -> bytes:
        return self.val

    def __eq__(self, other : Any) -> bool:
        return self.val == other.val # type: ignore

    @property
    def records(self) -> List[T]:
        return self.lst

class AsterixSpec:
    """Asterix base class."""
    cat : int

class Basic(AsterixSpec):
    variation : Any
    uaps : Any
    uap_selector_item : Any
    uap_selector_table : Any

    @classmethod
    def _parse(cls, raw_db : RawDatablock, opt : ParsingOptions, uap : Optional[str] = None) -> Any:
        if raw_db.category != cls.cat:
            raise AsterixError('Wrong category')
        s = Bits.from_bytes(raw_db.raw_records)
        records = []
        while len(s) > 0:
            if hasattr(cls, 'variation'):
                (rec, s) = cls.variation.parse_bits(s, opt)
            elif hasattr(cls, 'uaps'):
                result = None
                errors = {}
                # UAP is not specified, try each in sequence
                if uap is None:
                    for (name, var) in cls.uaps.items():
                        try:
                            (rec, s2) = var.parse_bits(s, opt)
                            # parsing alone is not sufficient,
                            # need to confirm UAP selector
                            if cls._is_valid(rec):
                                (result, s) = (rec, s2)
                                break
                        except AsterixError as e:
                            errors[name] = e
                    if result is None:
                        raise AsterixError('unable to parse with any UAP, {}'.format(errors))
                # use specified UAP
                else:
                    var = cls.uaps[uap]
                    (rec, s) = var.parse_bits(s, opt)
                    # if selector is available, validate
                    if not cls.uap_selector_item is None:
                        if not cls._is_valid(rec):
                            raise AsterixError('incompatible UAP')
            else:
                raise RuntimeError('should not be here')
            records.append(rec)
        return Datablock(cls.cat, records, raw_db.bs)

    @classmethod
    def _is_valid(cls, rec : Any) -> bool:
        i = rec
        for subitem in cls.uap_selector_item:
            i = i.get_item(subitem)
            if i is None:
                return False
        val = i.to_uinteger()
        uap_name = cls.uap_selector_table[val]
        actual_var = cls.uaps[uap_name]
        return actual_var == rec.__class__ # type: ignore

class Expansion(AsterixSpec):
    variation : Any
# --- Generated code ---

Variation_0_Arg : TypeAlias = Raw
class Variation_0(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8

    def __init__(self, arg : Variation_0_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_1_Arg_Group = TypedDict('Variation_1_Arg_Group', {
    'SAC': Union[Variation_0, Variation_0_Arg],
    'SIC': Union[Variation_0, Variation_0_Arg],
})
Variation_1_Arg : TypeAlias = Union[Raw, Variation_1_Arg_Group]
class Variation_1(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('SAC', Variation_0),
        ('SIC', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SAC': ('System Area Code', Variation_0, 0, 8),
        'SIC': ('System Identification Code', Variation_0, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SAC']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIC']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SAC'], Literal['SIC']]) -> Union[Type['Variation_0'], Type['Variation_0']]:
        if key == 'SAC':
            return Variation_0
        if key == 'SIC':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_1_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SAC']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SIC']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['SAC'], Literal['SIC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SAC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1':
        ...

    @overload
    def set_item(self, name : Literal['SIC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SAC'], f : Any) -> 'Variation_1':
        ...

    @overload
    def modify_item(self, name : Literal['SIC'], f : Any) -> 'Variation_1':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_2_Arg : TypeAlias = Raw
class Variation_2(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Plot',
        1: 'Track',
    }

    def __init__(self, arg : Variation_2_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_3_Arg : TypeAlias = Raw
class Variation_3(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Actual plot or track',
        1: 'Simulated plot or track',
    }

    def __init__(self, arg : Variation_3_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_4_Arg : TypeAlias = Raw
class Variation_4(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'No detection',
        1: 'Sole primary detection',
        2: 'Sole secondary detection',
        3: 'Combined primary and secondary detection',
    }

    def __init__(self, arg : Variation_4_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_5_Arg : TypeAlias = Raw
class Variation_5(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Target report from antenna 1',
        1: 'Target report from antenna 2',
    }

    def __init__(self, arg : Variation_5_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_6_Arg : TypeAlias = Raw
class Variation_6(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Special Position Identification',
    }

    def __init__(self, arg : Variation_6_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_7_Arg : TypeAlias = Raw
class Variation_7(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Plot or track from a fixed transponder',
    }

    def __init__(self, arg : Variation_7_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_8_Arg : TypeAlias = Raw
class Variation_8(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Test target indicator',
    }

    def __init__(self, arg : Variation_8_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_9_Arg : TypeAlias = Raw
class Variation_9(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'Default',
        1: 'Unlawful interference (code 7500)',
        2: 'Radio-communication failure (code 7600)',
        3: 'Emergency (code 7700)',
    }

    def __init__(self, arg : Variation_9_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_10_Arg : TypeAlias = Raw
class Variation_10(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Military emergency',
    }

    def __init__(self, arg : Variation_10_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_11_Arg : TypeAlias = Raw
class Variation_11(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Military identification',
    }

    def __init__(self, arg : Variation_11_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_12_Arg_Group_1 = TypedDict('Variation_12_Arg_Group_1', {
    'TYP': Union[Variation_2, Variation_2_Arg],
    'SIM': Union[Variation_3, Variation_3_Arg],
    'SSRPSR': Union[Variation_4, Variation_4_Arg],
    'ANT': Union[Variation_5, Variation_5_Arg],
    'SPI': Union[Variation_6, Variation_6_Arg],
    'RAB': Union[Variation_7, Variation_7_Arg],
})
Variation_12_Arg_Group_2 = TypedDict('Variation_12_Arg_Group_2', {
    'TYP': Union[Variation_2, Variation_2_Arg],
    'SIM': Union[Variation_3, Variation_3_Arg],
    'SSRPSR': Union[Variation_4, Variation_4_Arg],
    'ANT': Union[Variation_5, Variation_5_Arg],
    'SPI': Union[Variation_6, Variation_6_Arg],
    'RAB': Union[Variation_7, Variation_7_Arg],
    'TST': Union[Variation_8, Variation_8_Arg],
    'DS1DS2': Union[Variation_9, Variation_9_Arg],
    'ME': Union[Variation_10, Variation_10_Arg],
    'MI': Union[Variation_11, Variation_11_Arg],
})
Variation_12_Arg : TypeAlias = Union[
    int,
    Variation_12_Arg_Group_1,
    Tuple[int],
    Variation_12_Arg_Group_2,
    Tuple[int,int],
]
class Variation_12(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('TYP', Variation_2),
            ('SIM', Variation_3),
            ('SSRPSR', Variation_4),
            ('ANT', Variation_5),
            ('SPI', Variation_6),
            ('RAB', Variation_7),
        ],
        [
            ('TST', Variation_8),
            ('DS1DS2', Variation_9),
            ('ME', Variation_10),
            ('MI', Variation_11),
            Spare(5, 2),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('', Variation_2, 0, 1),
        'SIM': ('', Variation_3, 1, 1),
        'SSRPSR': ('Radar Detection in Last Antenna Scan', Variation_4, 2, 2),
        'ANT': ('', Variation_5, 4, 1),
        'SPI': ('', Variation_6, 5, 1),
        'RAB': ('', Variation_7, 6, 1),
        'TST': ('', Variation_8, 0, 1),
        'DS1DS2': ('Radar Detection in Last Antenna Scan', Variation_9, 1, 2),
        'ME': ('', Variation_10, 3, 1),
        'MI': ('', Variation_11, 4, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_2]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_3]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSRPSR']) -> Type[Variation_4]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ANT']) -> Type[Variation_5]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_6]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_7]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_8]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DS1DS2']) -> Type[Variation_9]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ME']) -> Type[Variation_10]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MI']) -> Type[Variation_11]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['SIM'], Literal['SSRPSR'], Literal['ANT'], Literal['SPI'], Literal['RAB'], Literal['TST'], Literal['DS1DS2'], Literal['ME'], Literal['MI']]) -> Union[Type['Variation_2'], Type['Variation_3'], Type['Variation_4'], Type['Variation_5'], Type['Variation_6'], Type['Variation_7'], Type['Variation_8'], Type['Variation_9'], Type['Variation_10'], Type['Variation_11']]:
        if key == 'TYP':
            return Variation_2
        if key == 'SIM':
            return Variation_3
        if key == 'SSRPSR':
            return Variation_4
        if key == 'ANT':
            return Variation_5
        if key == 'SPI':
            return Variation_6
        if key == 'RAB':
            return Variation_7
        if key == 'TST':
            return Variation_8
        if key == 'DS1DS2':
            return Variation_9
        if key == 'ME':
            return Variation_10
        if key == 'MI':
            return Variation_11
        assert_never(key)

    def __init__(self, arg : Variation_12_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_12_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_12_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_2:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_3:
        ...

    @overload
    def get_item(self, name : Literal['SSRPSR']) -> Variation_4:
        ...

    @overload
    def get_item(self, name : Literal['ANT']) -> Variation_5:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_6:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_7:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_8:
        ...

    @overload
    def get_item(self, name : Literal['DS1DS2']) -> Variation_9:
        ...

    @overload
    def get_item(self, name : Literal['ME']) -> Variation_10:
        ...

    @overload
    def get_item(self, name : Literal['MI']) -> Variation_11:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['SIM'], Literal['SSRPSR'], Literal['ANT'], Literal['SPI'], Literal['RAB'], Literal['TST'], Literal['DS1DS2'], Literal['ME'], Literal['MI']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_2, Variation_2_Arg]) -> 'Variation_12':
        ...

    @overload
    def set_item(self, name : Literal['SIM'], val : Union[Variation_3, Variation_3_Arg]) -> 'Variation_12':
        ...

    @overload
    def set_item(self, name : Literal['SSRPSR'], val : Union[Variation_4, Variation_4_Arg]) -> 'Variation_12':
        ...

    @overload
    def set_item(self, name : Literal['ANT'], val : Union[Variation_5, Variation_5_Arg]) -> 'Variation_12':
        ...

    @overload
    def set_item(self, name : Literal['SPI'], val : Union[Variation_6, Variation_6_Arg]) -> 'Variation_12':
        ...

    @overload
    def set_item(self, name : Literal['RAB'], val : Union[Variation_7, Variation_7_Arg]) -> 'Variation_12':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_12':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_12':
        ...

    @overload
    def modify_item(self, name : Literal['SSRPSR'], f : Any) -> 'Variation_12':
        ...

    @overload
    def modify_item(self, name : Literal['ANT'], f : Any) -> 'Variation_12':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_12':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_12':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_12':
        ...

    @overload
    def modify_item(self, name : Literal['DS1DS2'], f : Any) -> 'Variation_12':
        ...

    @overload
    def modify_item(self, name : Literal['ME'], f : Any) -> 'Variation_12':
        ...

    @overload
    def modify_item(self, name : Literal['MI'], f : Any) -> 'Variation_12':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_13_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_13(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 7.8125e-3, 'NM')

    def __init__(self, arg : Variation_13_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_14_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_14(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 5.4931640625e-3, '°')

    def __init__(self, arg : Variation_14_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_15_Arg_Group = TypedDict('Variation_15_Arg_Group', {
    'RHO': Union[Variation_13, Variation_13_Arg],
    'THETA': Union[Variation_14, Variation_14_Arg],
})
Variation_15_Arg : TypeAlias = Union[Raw, Variation_15_Arg_Group]
class Variation_15(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('RHO', Variation_13),
        ('THETA', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RHO': ('', Variation_13, 0, 16),
        'THETA': ('', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RHO']) -> Type[Variation_13]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['THETA']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RHO'], Literal['THETA']]) -> Union[Type['Variation_13'], Type['Variation_14']]:
        if key == 'RHO':
            return Variation_13
        if key == 'THETA':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_15_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RHO']) -> Variation_13:
        ...

    @overload
    def get_item(self, name : Literal['THETA']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['RHO'], Literal['THETA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RHO'], val : Union[Variation_13, Variation_13_Arg]) -> 'Variation_15':
        ...

    @overload
    def set_item(self, name : Literal['THETA'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_15':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RHO'], f : Any) -> 'Variation_15':
        ...

    @overload
    def modify_item(self, name : Literal['THETA'], f : Any) -> 'Variation_15':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_16_Arg : TypeAlias = Raw
class Variation_16(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Code validated',
        1: 'Code not validated',
    }

    def __init__(self, arg : Variation_16_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_17_Arg : TypeAlias = Raw
class Variation_17(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Garbled code',
    }

    def __init__(self, arg : Variation_17_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_18_Arg : TypeAlias = Raw
class Variation_18(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode-3/A code derived from the reply of the transponder',
        1: 'Smoothed Mode-3/A code as provided by a local tracker',
    }

    def __init__(self, arg : Variation_18_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_19_Arg : TypeAlias = Union[Raw,str]
class Variation_19(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 12
    string_type = StringOctal()

    def __init__(self, arg : Variation_19_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, str):
            super().__init__(self._from_string(arg)); return
        assert_never(arg)


    def to_string(self) -> str:
        return self._to_string()


Variation_20_Arg_Group = TypedDict('Variation_20_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_18, Variation_18_Arg],
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_20_Arg : TypeAlias = Union[Raw, Variation_20_Arg_Group]
class Variation_20(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_18),
        Spare(3, 1),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'L': ('', Variation_18, 2, 1),
        'MODE3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_18]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_18'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_18
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_20_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_18:
        ...

    @overload
    def get_item(self, name : Literal['MODE3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_20':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_20':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_18, Variation_18_Arg]) -> 'Variation_20':
        ...

    @overload
    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_20':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_20':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_20':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_20':
        ...

    @overload
    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_20':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_21_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['FL']]]
class Variation_21(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 14
    quantity = Quantity('Signed', 0.25, 'FL')

    def __init__(self, arg : Variation_21_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_22_Arg_Group = TypedDict('Variation_22_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'HGT': Union[Variation_21, Variation_21_Arg],
})
Variation_22_Arg : TypeAlias = Union[Raw, Variation_22_Arg_Group]
class Variation_22(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('HGT', Variation_21),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'HGT': ('Mode-C HEIGHT', Variation_21, 2, 14),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HGT']) -> Type[Variation_21]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['HGT']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_21']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'HGT':
            return Variation_21
        assert_never(key)

    def __init__(self, arg : Variation_22_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['HGT']) -> Variation_21:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['HGT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_22':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_22':
        ...

    @overload
    def set_item(self, name : Literal['HGT'], val : Union[Variation_21, Variation_21_Arg]) -> 'Variation_22':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_22':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_22':
        ...

    @overload
    def modify_item(self, name : Literal['HGT'], f : Any) -> 'Variation_22':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_23_Arg : TypeAlias = Raw
class Variation_23(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7

    def __init__(self, arg : Variation_23_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_24_Arg : TypeAlias = Union[Variation_23, Variation_23_Arg]
class Variation_24(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = None
    variation_bit_size = 7
    variation_type = Variation_23

    @classmethod
    def spec(cls) -> Type[Variation_23]:
        return Variation_23

    def __init__(self, arg : List[Union[Variation_23, Variation_23_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_23, Variation_23_Arg]) -> 'Variation_24':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_23, Variation_23_Arg]) -> 'Variation_24':
        return self._prepend_item(arg) # type: ignore

Variation_25_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_25(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 7.8125e-3, 's')

    def __init__(self, arg : Variation_25_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_26_Arg : TypeAlias = Raw
class Variation_26(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode-2 code as derived from the reply of the transponder',
        1: 'Smoothed Mode-2 code as provided by a local tracker',
    }

    def __init__(self, arg : Variation_26_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_27_Arg_Group = TypedDict('Variation_27_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_26, Variation_26_Arg],
    'MODE2': Union[Variation_19, Variation_19_Arg],
})
Variation_27_Arg : TypeAlias = Union[Raw, Variation_27_Arg_Group]
class Variation_27(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_26),
        Spare(3, 1),
        ('MODE2', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'L': ('', Variation_26, 2, 1),
        'MODE2': ('Mode-2 Code in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_26]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE2']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE2']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_26'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_26
        if key == 'MODE2':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_27_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_26:
        ...

    @overload
    def get_item(self, name : Literal['MODE2']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE2']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_27':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_27':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_26, Variation_26_Arg]) -> 'Variation_27':
        ...

    @overload
    def set_item(self, name : Literal['MODE2'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_27':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_27':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_27':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_27':
        ...

    @overload
    def modify_item(self, name : Literal['MODE2'], f : Any) -> 'Variation_27':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_28_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM/s']]]
class Variation_28(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 3.90625e-3, 'NM/s')

    def __init__(self, arg : Variation_28_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_29_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['dBm']]]
class Variation_29(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 1.0, 'dBm')

    def __init__(self, arg : Variation_29_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_30_Arg : TypeAlias = Raw
class Variation_30(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'High quality pulse A4',
        1: 'Low quality pulse A4',
    }

    def __init__(self, arg : Variation_30_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_31_Arg : TypeAlias = Raw
class Variation_31(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'High quality pulse A2',
        1: 'Low quality pulse A2',
    }

    def __init__(self, arg : Variation_31_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_32_Arg : TypeAlias = Raw
class Variation_32(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'High quality pulse A1',
        1: 'Low quality pulse A1',
    }

    def __init__(self, arg : Variation_32_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_33_Arg : TypeAlias = Raw
class Variation_33(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'High quality pulse B4',
        1: 'Low quality pulse B4',
    }

    def __init__(self, arg : Variation_33_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_34_Arg : TypeAlias = Raw
class Variation_34(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'High quality pulse B2',
        1: 'Low quality pulse B2',
    }

    def __init__(self, arg : Variation_34_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_35_Arg : TypeAlias = Raw
class Variation_35(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'High quality pulse B1',
        1: 'Low quality pulse B1',
    }

    def __init__(self, arg : Variation_35_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_36_Arg : TypeAlias = Raw
class Variation_36(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'High quality pulse C4',
        1: 'Low quality pulse C4',
    }

    def __init__(self, arg : Variation_36_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_37_Arg : TypeAlias = Raw
class Variation_37(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'High quality pulse C2',
        1: 'Low quality pulse C2',
    }

    def __init__(self, arg : Variation_37_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_38_Arg : TypeAlias = Raw
class Variation_38(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'High quality pulse C1',
        1: 'Low quality pulse C1',
    }

    def __init__(self, arg : Variation_38_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_39_Arg : TypeAlias = Raw
class Variation_39(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'High quality pulse D4',
        1: 'Low quality pulse D4',
    }

    def __init__(self, arg : Variation_39_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_40_Arg : TypeAlias = Raw
class Variation_40(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'High quality pulse D2',
        1: 'Low quality pulse D2',
    }

    def __init__(self, arg : Variation_40_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_41_Arg : TypeAlias = Raw
class Variation_41(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'High quality pulse D1',
        1: 'Low quality pulse D1',
    }

    def __init__(self, arg : Variation_41_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_42_Arg_Group = TypedDict('Variation_42_Arg_Group', {
    'QA4': Union[Variation_30, Variation_30_Arg],
    'QA2': Union[Variation_31, Variation_31_Arg],
    'QA1': Union[Variation_32, Variation_32_Arg],
    'QB4': Union[Variation_33, Variation_33_Arg],
    'QB2': Union[Variation_34, Variation_34_Arg],
    'QB1': Union[Variation_35, Variation_35_Arg],
    'QC4': Union[Variation_36, Variation_36_Arg],
    'QC2': Union[Variation_37, Variation_37_Arg],
    'QC1': Union[Variation_38, Variation_38_Arg],
    'QD4': Union[Variation_39, Variation_39_Arg],
    'QD2': Union[Variation_40, Variation_40_Arg],
    'QD1': Union[Variation_41, Variation_41_Arg],
})
Variation_42_Arg : TypeAlias = Union[Raw, Variation_42_Arg_Group]
class Variation_42(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('QA4', Variation_30),
        ('QA2', Variation_31),
        ('QA1', Variation_32),
        ('QB4', Variation_33),
        ('QB2', Variation_34),
        ('QB1', Variation_35),
        ('QC4', Variation_36),
        ('QC2', Variation_37),
        ('QC1', Variation_38),
        ('QD4', Variation_39),
        ('QD2', Variation_40),
        ('QD1', Variation_41),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'QA4': ('', Variation_30, 4, 1),
        'QA2': ('', Variation_31, 5, 1),
        'QA1': ('', Variation_32, 6, 1),
        'QB4': ('', Variation_33, 7, 1),
        'QB2': ('', Variation_34, 8, 1),
        'QB1': ('', Variation_35, 9, 1),
        'QC4': ('', Variation_36, 10, 1),
        'QC2': ('', Variation_37, 11, 1),
        'QC1': ('', Variation_38, 12, 1),
        'QD4': ('', Variation_39, 13, 1),
        'QD2': ('', Variation_40, 14, 1),
        'QD1': ('', Variation_41, 15, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['QA4']) -> Type[Variation_30]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA2']) -> Type[Variation_31]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA1']) -> Type[Variation_32]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB4']) -> Type[Variation_33]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB2']) -> Type[Variation_34]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB1']) -> Type[Variation_35]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QC4']) -> Type[Variation_36]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QC2']) -> Type[Variation_37]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QC1']) -> Type[Variation_38]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QD4']) -> Type[Variation_39]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QD2']) -> Type[Variation_40]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QD1']) -> Type[Variation_41]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['QA4'], Literal['QA2'], Literal['QA1'], Literal['QB4'], Literal['QB2'], Literal['QB1'], Literal['QC4'], Literal['QC2'], Literal['QC1'], Literal['QD4'], Literal['QD2'], Literal['QD1']]) -> Union[Type['Variation_30'], Type['Variation_31'], Type['Variation_32'], Type['Variation_33'], Type['Variation_34'], Type['Variation_35'], Type['Variation_36'], Type['Variation_37'], Type['Variation_38'], Type['Variation_39'], Type['Variation_40'], Type['Variation_41']]:
        if key == 'QA4':
            return Variation_30
        if key == 'QA2':
            return Variation_31
        if key == 'QA1':
            return Variation_32
        if key == 'QB4':
            return Variation_33
        if key == 'QB2':
            return Variation_34
        if key == 'QB1':
            return Variation_35
        if key == 'QC4':
            return Variation_36
        if key == 'QC2':
            return Variation_37
        if key == 'QC1':
            return Variation_38
        if key == 'QD4':
            return Variation_39
        if key == 'QD2':
            return Variation_40
        if key == 'QD1':
            return Variation_41
        assert_never(key)

    def __init__(self, arg : Variation_42_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['QA4']) -> Variation_30:
        ...

    @overload
    def get_item(self, name : Literal['QA2']) -> Variation_31:
        ...

    @overload
    def get_item(self, name : Literal['QA1']) -> Variation_32:
        ...

    @overload
    def get_item(self, name : Literal['QB4']) -> Variation_33:
        ...

    @overload
    def get_item(self, name : Literal['QB2']) -> Variation_34:
        ...

    @overload
    def get_item(self, name : Literal['QB1']) -> Variation_35:
        ...

    @overload
    def get_item(self, name : Literal['QC4']) -> Variation_36:
        ...

    @overload
    def get_item(self, name : Literal['QC2']) -> Variation_37:
        ...

    @overload
    def get_item(self, name : Literal['QC1']) -> Variation_38:
        ...

    @overload
    def get_item(self, name : Literal['QD4']) -> Variation_39:
        ...

    @overload
    def get_item(self, name : Literal['QD2']) -> Variation_40:
        ...

    @overload
    def get_item(self, name : Literal['QD1']) -> Variation_41:
        ...

    def get_item(self, name : Union[Literal['QA4'], Literal['QA2'], Literal['QA1'], Literal['QB4'], Literal['QB2'], Literal['QB1'], Literal['QC4'], Literal['QC2'], Literal['QC1'], Literal['QD4'], Literal['QD2'], Literal['QD1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['QA4'], val : Union[Variation_30, Variation_30_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QA2'], val : Union[Variation_31, Variation_31_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QA1'], val : Union[Variation_32, Variation_32_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QB4'], val : Union[Variation_33, Variation_33_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QB2'], val : Union[Variation_34, Variation_34_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QB1'], val : Union[Variation_35, Variation_35_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QC4'], val : Union[Variation_36, Variation_36_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QC2'], val : Union[Variation_37, Variation_37_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QC1'], val : Union[Variation_38, Variation_38_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QD4'], val : Union[Variation_39, Variation_39_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QD2'], val : Union[Variation_40, Variation_40_Arg]) -> 'Variation_42':
        ...

    @overload
    def set_item(self, name : Literal['QD1'], val : Union[Variation_41, Variation_41_Arg]) -> 'Variation_42':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['QA4'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QA2'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QA1'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QB4'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QB2'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QB1'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QC4'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QC2'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QC1'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QD4'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QD2'], f : Any) -> 'Variation_42':
        ...

    @overload
    def modify_item(self, name : Literal['QD1'], f : Any) -> 'Variation_42':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_43_Arg : TypeAlias = Raw
class Variation_43(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 12

    def __init__(self, arg : Variation_43_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_44_Arg : TypeAlias = Raw
class Variation_44(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'High quality pulse A1',
        1: 'Low quality pulse A1',
    }

    def __init__(self, arg : Variation_44_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_45_Arg : TypeAlias = Raw
class Variation_45(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'High quality pulse C2',
        1: 'Low quality pulse C2',
    }

    def __init__(self, arg : Variation_45_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_46_Arg : TypeAlias = Raw
class Variation_46(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'High quality pulse A2',
        1: 'Low quality pulse A2',
    }

    def __init__(self, arg : Variation_46_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_47_Arg : TypeAlias = Raw
class Variation_47(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'High quality pulse C4',
        1: 'Low quality pulse C4',
    }

    def __init__(self, arg : Variation_47_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_48_Arg : TypeAlias = Raw
class Variation_48(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'High quality pulse A4',
        1: 'Low quality pulse A4',
    }

    def __init__(self, arg : Variation_48_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_49_Arg : TypeAlias = Raw
class Variation_49(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'High quality pulse B1',
        1: 'Low quality pulse B1',
    }

    def __init__(self, arg : Variation_49_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_50_Arg : TypeAlias = Raw
class Variation_50(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'High quality pulse D1',
        1: 'Low quality pulse D1',
    }

    def __init__(self, arg : Variation_50_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_51_Arg : TypeAlias = Raw
class Variation_51(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'High quality pulse B2',
        1: 'Low quality pulse B2',
    }

    def __init__(self, arg : Variation_51_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_52_Arg : TypeAlias = Raw
class Variation_52(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'High quality pulse D2',
        1: 'Low quality pulse D2',
    }

    def __init__(self, arg : Variation_52_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_53_Arg : TypeAlias = Raw
class Variation_53(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'High quality pulse B4',
        1: 'Low quality pulse B4',
    }

    def __init__(self, arg : Variation_53_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_54_Arg : TypeAlias = Raw
class Variation_54(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'High quality pulse D4',
        1: 'Low quality pulse D4',
    }

    def __init__(self, arg : Variation_54_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_55_Arg_Group = TypedDict('Variation_55_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'MODEC': Union[Variation_43, Variation_43_Arg],
    'QC1': Union[Variation_38, Variation_38_Arg],
    'QA1': Union[Variation_44, Variation_44_Arg],
    'QC2': Union[Variation_45, Variation_45_Arg],
    'QA2': Union[Variation_46, Variation_46_Arg],
    'QC4': Union[Variation_47, Variation_47_Arg],
    'QA4': Union[Variation_48, Variation_48_Arg],
    'QB1': Union[Variation_49, Variation_49_Arg],
    'QD1': Union[Variation_50, Variation_50_Arg],
    'QB2': Union[Variation_51, Variation_51_Arg],
    'QD2': Union[Variation_52, Variation_52_Arg],
    'QB4': Union[Variation_53, Variation_53_Arg],
    'QD4': Union[Variation_54, Variation_54_Arg],
})
Variation_55_Arg : TypeAlias = Union[Raw, Variation_55_Arg_Group]
class Variation_55(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        Spare(2, 2),
        ('MODEC', Variation_43),
        Spare(0, 4),
        ('QC1', Variation_38),
        ('QA1', Variation_44),
        ('QC2', Variation_45),
        ('QA2', Variation_46),
        ('QC4', Variation_47),
        ('QA4', Variation_48),
        ('QB1', Variation_49),
        ('QD1', Variation_50),
        ('QB2', Variation_51),
        ('QD2', Variation_52),
        ('QB4', Variation_53),
        ('QD4', Variation_54),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'MODEC': ('Mode-C Reply in Gray Notation', Variation_43, 4, 12),
        'QC1': ('', Variation_38, 20, 1),
        'QA1': ('', Variation_44, 21, 1),
        'QC2': ('', Variation_45, 22, 1),
        'QA2': ('', Variation_46, 23, 1),
        'QC4': ('', Variation_47, 24, 1),
        'QA4': ('', Variation_48, 25, 1),
        'QB1': ('', Variation_49, 26, 1),
        'QD1': ('', Variation_50, 27, 1),
        'QB2': ('', Variation_51, 28, 1),
        'QD2': ('', Variation_52, 29, 1),
        'QB4': ('', Variation_53, 30, 1),
        'QD4': ('', Variation_54, 31, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODEC']) -> Type[Variation_43]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QC1']) -> Type[Variation_38]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA1']) -> Type[Variation_44]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QC2']) -> Type[Variation_45]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA2']) -> Type[Variation_46]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QC4']) -> Type[Variation_47]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA4']) -> Type[Variation_48]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB1']) -> Type[Variation_49]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QD1']) -> Type[Variation_50]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB2']) -> Type[Variation_51]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QD2']) -> Type[Variation_52]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB4']) -> Type[Variation_53]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QD4']) -> Type[Variation_54]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['MODEC'], Literal['QC1'], Literal['QA1'], Literal['QC2'], Literal['QA2'], Literal['QC4'], Literal['QA4'], Literal['QB1'], Literal['QD1'], Literal['QB2'], Literal['QD2'], Literal['QB4'], Literal['QD4']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_43'], Type['Variation_38'], Type['Variation_44'], Type['Variation_45'], Type['Variation_46'], Type['Variation_47'], Type['Variation_48'], Type['Variation_49'], Type['Variation_50'], Type['Variation_51'], Type['Variation_52'], Type['Variation_53'], Type['Variation_54']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'MODEC':
            return Variation_43
        if key == 'QC1':
            return Variation_38
        if key == 'QA1':
            return Variation_44
        if key == 'QC2':
            return Variation_45
        if key == 'QA2':
            return Variation_46
        if key == 'QC4':
            return Variation_47
        if key == 'QA4':
            return Variation_48
        if key == 'QB1':
            return Variation_49
        if key == 'QD1':
            return Variation_50
        if key == 'QB2':
            return Variation_51
        if key == 'QD2':
            return Variation_52
        if key == 'QB4':
            return Variation_53
        if key == 'QD4':
            return Variation_54
        assert_never(key)

    def __init__(self, arg : Variation_55_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['MODEC']) -> Variation_43:
        ...

    @overload
    def get_item(self, name : Literal['QC1']) -> Variation_38:
        ...

    @overload
    def get_item(self, name : Literal['QA1']) -> Variation_44:
        ...

    @overload
    def get_item(self, name : Literal['QC2']) -> Variation_45:
        ...

    @overload
    def get_item(self, name : Literal['QA2']) -> Variation_46:
        ...

    @overload
    def get_item(self, name : Literal['QC4']) -> Variation_47:
        ...

    @overload
    def get_item(self, name : Literal['QA4']) -> Variation_48:
        ...

    @overload
    def get_item(self, name : Literal['QB1']) -> Variation_49:
        ...

    @overload
    def get_item(self, name : Literal['QD1']) -> Variation_50:
        ...

    @overload
    def get_item(self, name : Literal['QB2']) -> Variation_51:
        ...

    @overload
    def get_item(self, name : Literal['QD2']) -> Variation_52:
        ...

    @overload
    def get_item(self, name : Literal['QB4']) -> Variation_53:
        ...

    @overload
    def get_item(self, name : Literal['QD4']) -> Variation_54:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['MODEC'], Literal['QC1'], Literal['QA1'], Literal['QC2'], Literal['QA2'], Literal['QC4'], Literal['QA4'], Literal['QB1'], Literal['QD1'], Literal['QB2'], Literal['QD2'], Literal['QB4'], Literal['QD4']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['MODEC'], val : Union[Variation_43, Variation_43_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QC1'], val : Union[Variation_38, Variation_38_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QA1'], val : Union[Variation_44, Variation_44_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QC2'], val : Union[Variation_45, Variation_45_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QA2'], val : Union[Variation_46, Variation_46_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QC4'], val : Union[Variation_47, Variation_47_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QA4'], val : Union[Variation_48, Variation_48_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QB1'], val : Union[Variation_49, Variation_49_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QD1'], val : Union[Variation_50, Variation_50_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QB2'], val : Union[Variation_51, Variation_51_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QD2'], val : Union[Variation_52, Variation_52_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QB4'], val : Union[Variation_53, Variation_53_Arg]) -> 'Variation_55':
        ...

    @overload
    def set_item(self, name : Literal['QD4'], val : Union[Variation_54, Variation_54_Arg]) -> 'Variation_55':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['MODEC'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QC1'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QA1'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QC2'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QA2'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QC4'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QA4'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QB1'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QD1'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QB2'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QD2'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QB4'], f : Any) -> 'Variation_55':
        ...

    @overload
    def modify_item(self, name : Literal['QD4'], f : Any) -> 'Variation_55':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_56_Arg : TypeAlias = Raw
class Variation_56(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    table = {
        0: 'No warning nor error condition',
        1: 'Garbled reply',
        2: 'Reflection',
        3: 'Sidelobe reply',
        4: 'Split plot',
        5: 'Second time around reply',
        6: 'Angels',
        7: 'Terrestrial vehicles',
        64: 'Possible wrong code in Mode-3/A',
        65: 'Possible wrong altitude information, transmitted when the Code C credibility check fails together with the Mode-C code in binary notation',
        66: 'Possible phantom MSSR plot',
        80: 'Fixed PSR plot',
        81: 'Slow PSR plot',
        82: 'Low quality PSR plot',
    }

    def __init__(self, arg : Variation_56_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_57_Arg : TypeAlias = Union[Variation_56, Variation_56_Arg]
class Variation_57(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = None
    variation_bit_size = 7
    variation_type = Variation_56

    @classmethod
    def spec(cls) -> Type[Variation_56]:
        return Variation_56

    def __init__(self, arg : List[Union[Variation_56, Variation_56_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_56, Variation_56_Arg]) -> 'Variation_57':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_56, Variation_56_Arg]) -> 'Variation_57':
        return self._prepend_item(arg) # type: ignore

Variation_58_Arg : TypeAlias = Raw
class Variation_58(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'X-pulse received in Mode-3/A reply',
    }

    def __init__(self, arg : Variation_58_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_59_Arg : TypeAlias = Raw
class Variation_59(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'X-pulse received in Mode-C reply',
    }

    def __init__(self, arg : Variation_59_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_60_Arg : TypeAlias = Raw
class Variation_60(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'X-pulse received in Mode-2 reply',
    }

    def __init__(self, arg : Variation_60_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_61_Arg_Group = TypedDict('Variation_61_Arg_Group', {
    'XA': Union[Variation_58, Variation_58_Arg],
    'XC': Union[Variation_59, Variation_59_Arg],
    'X2': Union[Variation_60, Variation_60_Arg],
})
Variation_61_Arg : TypeAlias = Union[Raw, Variation_61_Arg_Group]
class Variation_61(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('XA', Variation_58),
        Spare(1, 1),
        ('XC', Variation_59),
        Spare(3, 2),
        ('X2', Variation_60),
        Spare(6, 2),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'XA': ('', Variation_58, 0, 1),
        'XC': ('', Variation_59, 2, 1),
        'X2': ('', Variation_60, 5, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['XA']) -> Type[Variation_58]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XC']) -> Type[Variation_59]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X2']) -> Type[Variation_60]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['XA'], Literal['XC'], Literal['X2']]) -> Union[Type['Variation_58'], Type['Variation_59'], Type['Variation_60']]:
        if key == 'XA':
            return Variation_58
        if key == 'XC':
            return Variation_59
        if key == 'X2':
            return Variation_60
        assert_never(key)

    def __init__(self, arg : Variation_61_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['XA']) -> Variation_58:
        ...

    @overload
    def get_item(self, name : Literal['XC']) -> Variation_59:
        ...

    @overload
    def get_item(self, name : Literal['X2']) -> Variation_60:
        ...

    def get_item(self, name : Union[Literal['XA'], Literal['XC'], Literal['X2']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['XA'], val : Union[Variation_58, Variation_58_Arg]) -> 'Variation_61':
        ...

    @overload
    def set_item(self, name : Literal['XC'], val : Union[Variation_59, Variation_59_Arg]) -> 'Variation_61':
        ...

    @overload
    def set_item(self, name : Literal['X2'], val : Union[Variation_60, Variation_60_Arg]) -> 'Variation_61':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['XA'], f : Any) -> 'Variation_61':
        ...

    @overload
    def modify_item(self, name : Literal['XC'], f : Any) -> 'Variation_61':
        ...

    @overload
    def modify_item(self, name : Literal['X2'], f : Any) -> 'Variation_61':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_62_Arg : TypeAlias = bytes
class Variation_62(Explicit):
    variation = 'Explicit'

    explicit_type = "SpecialPurpose"

    def __init__(self, arg : bytes) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, bytes):
            super().__init__(*self._from_bytes(arg)); return
        assert_never(arg)

Variation_63_Arg = TypedDict('Variation_63_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '020': Union[Variation_12, Variation_12_Arg],
    '040': Union[Variation_15, Variation_15_Arg],
    '070': Union[Variation_20, Variation_20_Arg],
    '090': Union[Variation_22, Variation_22_Arg],
    '130': Union[Variation_24, Variation_24_Arg],
    '141': Union[Variation_25, Variation_25_Arg],
    '050': Union[Variation_27, Variation_27_Arg],
    '120': Union[Variation_28, Variation_28_Arg],
    '131': Union[Variation_29, Variation_29_Arg],
    '080': Union[Variation_42, Variation_42_Arg],
    '100': Union[Variation_55, Variation_55_Arg],
    '060': Union[Variation_42, Variation_42_Arg],
    '030': Union[Variation_57, Variation_57_Arg],
    '150': Union[Variation_61, Variation_61_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_63(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 3

    subitems_list = [
        ('010', Variation_1),
        ('020', Variation_12),
        ('040', Variation_15),
        ('070', Variation_20),
        ('090', Variation_22),
        ('130', Variation_24),
        ('141', Variation_25),
        ('050', Variation_27),
        ('120', Variation_28),
        ('131', Variation_29),
        ('080', Variation_42),
        ('100', Variation_55),
        ('060', Variation_42),
        ('030', Variation_57),
        ('150', Variation_61),
        None,
        None,
        None,
        None,
        ('SP', Variation_62),
        None,
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x800000),
        '020': ('Target Report Descriptor', Variation_12, 0x400000),
        '040': ('Measured Position in Polar Co-ordinates', Variation_15, 0x200000),
        '070': ('Mode-3/A Code in Octal Representation', Variation_20, 0x100000),
        '090': ('Mode-C Code in Binary Representation', Variation_22, 0x080000),
        '130': ('Radar Plot Characteristics', Variation_24, 0x040000),
        '141': ('Truncated Time of Day', Variation_25, 0x020000),
        '050': ('Mode-2 Code in Octal Representation', Variation_27, 0x018000),
        '120': ('Measured Radial Doppler Speed', Variation_28, 0x014000),
        '131': ('Received Power', Variation_29, 0x012000),
        '080': ('Mode-3/A Code Confidence Indicator', Variation_42, 0x011000),
        '100': ('Mode-C Code and Code Confidence Indicator', Variation_55, 0x010800),
        '060': ('Mode-2 Code Confidence Indicator', Variation_42, 0x010400),
        '030': ('Warning/Error Conditions', Variation_57, 0x010200),
        '150': ('Presence of X-Pulse', Variation_61, 0x010180),
        'SP': ('Special Purpose Field', Variation_62, 0x010104),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_12]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_15]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_20]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_22]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_24]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['141']) -> Type[Variation_25]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_27]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_28]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['131']) -> Type[Variation_29]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_55]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_57]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_61]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['020'], Literal['040'], Literal['070'], Literal['090'], Literal['130'], Literal['141'], Literal['050'], Literal['120'], Literal['131'], Literal['080'], Literal['100'], Literal['060'], Literal['030'], Literal['150'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_12'], Type['Variation_15'], Type['Variation_20'], Type['Variation_22'], Type['Variation_24'], Type['Variation_25'], Type['Variation_27'], Type['Variation_28'], Type['Variation_29'], Type['Variation_42'], Type['Variation_55'], Type['Variation_42'], Type['Variation_57'], Type['Variation_61'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '020':
            return Variation_12
        if key == '040':
            return Variation_15
        if key == '070':
            return Variation_20
        if key == '090':
            return Variation_22
        if key == '130':
            return Variation_24
        if key == '141':
            return Variation_25
        if key == '050':
            return Variation_27
        if key == '120':
            return Variation_28
        if key == '131':
            return Variation_29
        if key == '080':
            return Variation_42
        if key == '100':
            return Variation_55
        if key == '060':
            return Variation_42
        if key == '030':
            return Variation_57
        if key == '150':
            return Variation_61
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_63_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_12, Variation_12_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_15, Variation_15_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_20, Variation_20_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_22, Variation_22_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_24, Variation_24_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['141'], val : Union[Variation_25, Variation_25_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_27, Variation_27_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_28, Variation_28_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['131'], val : Union[Variation_29, Variation_29_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_55, Variation_55_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_57, Variation_57_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_61, Variation_61_Arg]) -> 'Variation_63':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_63':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['141']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['131']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_63':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_63':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_12:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_15:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_20:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_22:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_24:
        ...

    @overload
    def get_item(self, name : Literal['141']) -> Variation_25:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_27:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_28:
        ...

    @overload
    def get_item(self, name : Literal['131']) -> Variation_29:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_55:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_57:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_61:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['141'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['131'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_63':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_63':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_64_Arg : TypeAlias = Raw
class Variation_64(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16

    def __init__(self, arg : Variation_64_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_65_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_65(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 1.5625e-2, 'NM')

    def __init__(self, arg : Variation_65_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_66_Arg_Group = TypedDict('Variation_66_Arg_Group', {
    'X': Union[Variation_65, Variation_65_Arg],
    'Y': Union[Variation_65, Variation_65_Arg],
})
Variation_66_Arg : TypeAlias = Union[Raw, Variation_66_Arg_Group]
class Variation_66(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('X', Variation_65),
        ('Y', Variation_65),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('X-Component', Variation_65, 0, 16),
        'Y': ('Y-Component', Variation_65, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_65]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_65]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_65'], Type['Variation_65']]:
        if key == 'X':
            return Variation_65
        if key == 'Y':
            return Variation_65
        assert_never(key)

    def __init__(self, arg : Variation_66_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_65:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_65:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_65, Variation_65_Arg]) -> 'Variation_66':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_65, Variation_65_Arg]) -> 'Variation_66':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_66':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_66':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_67_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM/s']]]
class Variation_67(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 6.103515625e-5, 'NM/s')

    def __init__(self, arg : Variation_67_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_68_Arg_Group = TypedDict('Variation_68_Arg_Group', {
    'GSP': Union[Variation_67, Variation_67_Arg],
    'HDG': Union[Variation_14, Variation_14_Arg],
})
Variation_68_Arg : TypeAlias = Union[Raw, Variation_68_Arg_Group]
class Variation_68(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('GSP', Variation_67),
        ('HDG', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'GSP': ('Calculated Groundspeed', Variation_67, 0, 16),
        'HDG': ('Calculated Heading', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['GSP']) -> Type[Variation_67]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HDG']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['GSP'], Literal['HDG']]) -> Union[Type['Variation_67'], Type['Variation_14']]:
        if key == 'GSP':
            return Variation_67
        if key == 'HDG':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_68_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['GSP']) -> Variation_67:
        ...

    @overload
    def get_item(self, name : Literal['HDG']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['GSP'], Literal['HDG']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['GSP'], val : Union[Variation_67, Variation_67_Arg]) -> 'Variation_68':
        ...

    @overload
    def set_item(self, name : Literal['HDG'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_68':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['GSP'], f : Any) -> 'Variation_68':
        ...

    @overload
    def modify_item(self, name : Literal['HDG'], f : Any) -> 'Variation_68':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_69_Arg : TypeAlias = Raw
class Variation_69(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Confirmed Track',
        1: 'Track in initialisation phase',
    }

    def __init__(self, arg : Variation_69_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_70_Arg : TypeAlias = Raw
class Variation_70(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Primary track',
        1: 'SSR/Combined track',
    }

    def __init__(self, arg : Variation_70_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_71_Arg : TypeAlias = Raw
class Variation_71(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Aircraft manoeuvring',
    }

    def __init__(self, arg : Variation_71_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_72_Arg : TypeAlias = Raw
class Variation_72(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Doubtful plot to track association',
    }

    def __init__(self, arg : Variation_72_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_73_Arg : TypeAlias = Raw
class Variation_73(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'RDP Chain 1',
        1: 'RDP Chain 2',
    }

    def __init__(self, arg : Variation_73_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_74_Arg : TypeAlias = Raw
class Variation_74(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Ghost track',
    }

    def __init__(self, arg : Variation_74_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_75_Arg : TypeAlias = Raw
class Variation_75(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Last report for a track',
    }

    def __init__(self, arg : Variation_75_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_76_Arg_Group_1 = TypedDict('Variation_76_Arg_Group_1', {
    'CON': Union[Variation_69, Variation_69_Arg],
    'RAD': Union[Variation_70, Variation_70_Arg],
    'MAN': Union[Variation_71, Variation_71_Arg],
    'DOU': Union[Variation_72, Variation_72_Arg],
    'RDPC': Union[Variation_73, Variation_73_Arg],
    'GHO': Union[Variation_74, Variation_74_Arg],
})
Variation_76_Arg_Group_2 = TypedDict('Variation_76_Arg_Group_2', {
    'CON': Union[Variation_69, Variation_69_Arg],
    'RAD': Union[Variation_70, Variation_70_Arg],
    'MAN': Union[Variation_71, Variation_71_Arg],
    'DOU': Union[Variation_72, Variation_72_Arg],
    'RDPC': Union[Variation_73, Variation_73_Arg],
    'GHO': Union[Variation_74, Variation_74_Arg],
    'TRE': Union[Variation_75, Variation_75_Arg],
})
Variation_76_Arg : TypeAlias = Union[
    int,
    Variation_76_Arg_Group_1,
    Tuple[int],
    Variation_76_Arg_Group_2,
    Tuple[int,int],
]
class Variation_76(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('CON', Variation_69),
            ('RAD', Variation_70),
            ('MAN', Variation_71),
            ('DOU', Variation_72),
            ('RDPC', Variation_73),
            Spare(5, 1),
            ('GHO', Variation_74),
        ],
        [
            ('TRE', Variation_75),
            Spare(1, 6),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CON': ('', Variation_69, 0, 1),
        'RAD': ('', Variation_70, 1, 1),
        'MAN': ('', Variation_71, 2, 1),
        'DOU': ('', Variation_72, 3, 1),
        'RDPC': ('Radar Data Processing Chain', Variation_73, 4, 1),
        'GHO': ('', Variation_74, 6, 1),
        'TRE': ('', Variation_75, 0, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CON']) -> Type[Variation_69]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAD']) -> Type[Variation_70]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAN']) -> Type[Variation_71]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DOU']) -> Type[Variation_72]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RDPC']) -> Type[Variation_73]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GHO']) -> Type[Variation_74]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRE']) -> Type[Variation_75]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CON'], Literal['RAD'], Literal['MAN'], Literal['DOU'], Literal['RDPC'], Literal['GHO'], Literal['TRE']]) -> Union[Type['Variation_69'], Type['Variation_70'], Type['Variation_71'], Type['Variation_72'], Type['Variation_73'], Type['Variation_74'], Type['Variation_75']]:
        if key == 'CON':
            return Variation_69
        if key == 'RAD':
            return Variation_70
        if key == 'MAN':
            return Variation_71
        if key == 'DOU':
            return Variation_72
        if key == 'RDPC':
            return Variation_73
        if key == 'GHO':
            return Variation_74
        if key == 'TRE':
            return Variation_75
        assert_never(key)

    def __init__(self, arg : Variation_76_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_76_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_76_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CON']) -> Variation_69:
        ...

    @overload
    def get_item(self, name : Literal['RAD']) -> Variation_70:
        ...

    @overload
    def get_item(self, name : Literal['MAN']) -> Variation_71:
        ...

    @overload
    def get_item(self, name : Literal['DOU']) -> Variation_72:
        ...

    @overload
    def get_item(self, name : Literal['RDPC']) -> Variation_73:
        ...

    @overload
    def get_item(self, name : Literal['GHO']) -> Variation_74:
        ...

    @overload
    def get_item(self, name : Literal['TRE']) -> Variation_75:
        ...

    def get_item(self, name : Union[Literal['CON'], Literal['RAD'], Literal['MAN'], Literal['DOU'], Literal['RDPC'], Literal['GHO'], Literal['TRE']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CON'], val : Union[Variation_69, Variation_69_Arg]) -> 'Variation_76':
        ...

    @overload
    def set_item(self, name : Literal['RAD'], val : Union[Variation_70, Variation_70_Arg]) -> 'Variation_76':
        ...

    @overload
    def set_item(self, name : Literal['MAN'], val : Union[Variation_71, Variation_71_Arg]) -> 'Variation_76':
        ...

    @overload
    def set_item(self, name : Literal['DOU'], val : Union[Variation_72, Variation_72_Arg]) -> 'Variation_76':
        ...

    @overload
    def set_item(self, name : Literal['RDPC'], val : Union[Variation_73, Variation_73_Arg]) -> 'Variation_76':
        ...

    @overload
    def set_item(self, name : Literal['GHO'], val : Union[Variation_74, Variation_74_Arg]) -> 'Variation_76':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CON'], f : Any) -> 'Variation_76':
        ...

    @overload
    def modify_item(self, name : Literal['RAD'], f : Any) -> 'Variation_76':
        ...

    @overload
    def modify_item(self, name : Literal['MAN'], f : Any) -> 'Variation_76':
        ...

    @overload
    def modify_item(self, name : Literal['DOU'], f : Any) -> 'Variation_76':
        ...

    @overload
    def modify_item(self, name : Literal['RDPC'], f : Any) -> 'Variation_76':
        ...

    @overload
    def modify_item(self, name : Literal['GHO'], f : Any) -> 'Variation_76':
        ...

    @overload
    def modify_item(self, name : Literal['TRE'], f : Any) -> 'Variation_76':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_77_Arg = TypedDict('Variation_77_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '020': Union[Variation_12, Variation_12_Arg],
    '161': Union[Variation_64, Variation_64_Arg],
    '040': Union[Variation_15, Variation_15_Arg],
    '042': Union[Variation_66, Variation_66_Arg],
    '200': Union[Variation_68, Variation_68_Arg],
    '070': Union[Variation_20, Variation_20_Arg],
    '090': Union[Variation_22, Variation_22_Arg],
    '141': Union[Variation_25, Variation_25_Arg],
    '130': Union[Variation_24, Variation_24_Arg],
    '131': Union[Variation_29, Variation_29_Arg],
    '120': Union[Variation_28, Variation_28_Arg],
    '170': Union[Variation_76, Variation_76_Arg],
    '210': Union[Variation_24, Variation_24_Arg],
    '050': Union[Variation_27, Variation_27_Arg],
    '080': Union[Variation_42, Variation_42_Arg],
    '100': Union[Variation_55, Variation_55_Arg],
    '060': Union[Variation_42, Variation_42_Arg],
    '030': Union[Variation_57, Variation_57_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    '150': Union[Variation_61, Variation_61_Arg],
}, total=False)
class Variation_77(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('020', Variation_12),
        ('161', Variation_64),
        ('040', Variation_15),
        ('042', Variation_66),
        ('200', Variation_68),
        ('070', Variation_20),
        ('090', Variation_22),
        ('141', Variation_25),
        ('130', Variation_24),
        ('131', Variation_29),
        ('120', Variation_28),
        ('170', Variation_76),
        ('210', Variation_24),
        ('050', Variation_27),
        ('080', Variation_42),
        ('100', Variation_55),
        ('060', Variation_42),
        ('030', Variation_57),
        ('SP', Variation_62),
        None,
        ('150', Variation_61),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '020': ('Target Report Descriptor', Variation_12, 0x40000000),
        '161': ('Track Plot Number', Variation_64, 0x20000000),
        '040': ('Measured Position in Polar Co-ordinates', Variation_15, 0x10000000),
        '042': ('Calculated Position in Cartesian Co-ordinates', Variation_66, 0x08000000),
        '200': ('Calculated Track Velocity in Polar Co-ordinates', Variation_68, 0x04000000),
        '070': ('Mode-3/A Code in Octal Representation', Variation_20, 0x02000000),
        '090': ('Mode-C Code in Binary Representation', Variation_22, 0x01800000),
        '141': ('Truncated Time of Day', Variation_25, 0x01400000),
        '130': ('Radar Plot Characteristics', Variation_24, 0x01200000),
        '131': ('Received Power', Variation_29, 0x01100000),
        '120': ('Measured Radial Doppler Speed', Variation_28, 0x01080000),
        '170': ('Track Status', Variation_76, 0x01040000),
        '210': ('Track Quality', Variation_24, 0x01020000),
        '050': ('Mode-2 Code in Octal Representation', Variation_27, 0x01018000),
        '080': ('Mode-3/A Code Confidence Indicator', Variation_42, 0x01014000),
        '100': ('Mode-C Code and Code Confidence Indicator', Variation_55, 0x01012000),
        '060': ('Mode-2 Code Confidence Indicator', Variation_42, 0x01011000),
        '030': ('Warning/Error Conditions', Variation_57, 0x01010800),
        'SP': ('Special Purpose Field', Variation_62, 0x01010400),
        '150': ('Presence of X-Pulse', Variation_61, 0x01010180),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_12]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_15]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_66]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_68]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_20]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_22]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['141']) -> Type[Variation_25]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_24]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['131']) -> Type[Variation_29]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_28]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_76]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_24]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_27]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_55]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_57]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_61]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['020'], Literal['161'], Literal['040'], Literal['042'], Literal['200'], Literal['070'], Literal['090'], Literal['141'], Literal['130'], Literal['131'], Literal['120'], Literal['170'], Literal['210'], Literal['050'], Literal['080'], Literal['100'], Literal['060'], Literal['030'], Literal['SP'], Literal['150']]) -> Union[Type['Variation_1'], Type['Variation_12'], Type['Variation_64'], Type['Variation_15'], Type['Variation_66'], Type['Variation_68'], Type['Variation_20'], Type['Variation_22'], Type['Variation_25'], Type['Variation_24'], Type['Variation_29'], Type['Variation_28'], Type['Variation_76'], Type['Variation_24'], Type['Variation_27'], Type['Variation_42'], Type['Variation_55'], Type['Variation_42'], Type['Variation_57'], Type['Variation_62'], Type['Variation_61']]:
        if key == '010':
            return Variation_1
        if key == '020':
            return Variation_12
        if key == '161':
            return Variation_64
        if key == '040':
            return Variation_15
        if key == '042':
            return Variation_66
        if key == '200':
            return Variation_68
        if key == '070':
            return Variation_20
        if key == '090':
            return Variation_22
        if key == '141':
            return Variation_25
        if key == '130':
            return Variation_24
        if key == '131':
            return Variation_29
        if key == '120':
            return Variation_28
        if key == '170':
            return Variation_76
        if key == '210':
            return Variation_24
        if key == '050':
            return Variation_27
        if key == '080':
            return Variation_42
        if key == '100':
            return Variation_55
        if key == '060':
            return Variation_42
        if key == '030':
            return Variation_57
        if key == 'SP':
            return Variation_62
        if key == '150':
            return Variation_61
        assert_never(key)

    def __init__(self, arg : Optional[Variation_77_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_12, Variation_12_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_15, Variation_15_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_66, Variation_66_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_68, Variation_68_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_20, Variation_20_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_22, Variation_22_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['141'], val : Union[Variation_25, Variation_25_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_24, Variation_24_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['131'], val : Union[Variation_29, Variation_29_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_28, Variation_28_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_76, Variation_76_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_24, Variation_24_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_27, Variation_27_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_55, Variation_55_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_57, Variation_57_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_77':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_61, Variation_61_Arg]) -> 'Variation_77':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['141']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['131']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_77':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_77':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_12:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_15:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_66:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_68:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_20:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_22:
        ...

    @overload
    def get_item(self, name : Literal['141']) -> Variation_25:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_24:
        ...

    @overload
    def get_item(self, name : Literal['131']) -> Variation_29:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_28:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_76:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_24:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_27:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_55:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_57:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_61:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['141'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['131'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_77':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_77':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_78_Arg : TypeAlias = Raw
class Variation_78(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'North marker message',
        2: 'Sector crossing message',
        3: 'South marker message',
        8: 'Activation of blind zone filtering',
        9: 'Stop of blind zone filtering',
    }

    def __init__(self, arg : Variation_78_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_79_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_79(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 1.40625, '°')

    def __init__(self, arg : Variation_79_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_80_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_80(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Unsigned', 7.8125e-3, 's')

    def __init__(self, arg : Variation_80_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_81_Arg : TypeAlias = Raw
class Variation_81(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Counter for antenna 1',
        1: 'Counter for antenna 2',
    }

    def __init__(self, arg : Variation_81_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_82_Arg : TypeAlias = Raw
class Variation_82(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 5
    table = {
        1: 'Sole primary plots',
        2: 'Sole SSR plots',
        3: 'Combined plots',
    }

    def __init__(self, arg : Variation_82_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_83_Arg : TypeAlias = Raw
class Variation_83(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 10

    def __init__(self, arg : Variation_83_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_84_Arg_Group = TypedDict('Variation_84_Arg_Group', {
    'A': Union[Variation_81, Variation_81_Arg],
    'IDENT': Union[Variation_82, Variation_82_Arg],
    'COUNTER': Union[Variation_83, Variation_83_Arg],
})
Variation_84_Arg : TypeAlias = Union[Raw, Variation_84_Arg_Group]
class Variation_84(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('A', Variation_81),
        ('IDENT', Variation_82),
        ('COUNTER', Variation_83),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'A': ('Aerial Identification', Variation_81, 0, 1),
        'IDENT': ('', Variation_82, 1, 5),
        'COUNTER': ('', Variation_83, 6, 10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['A']) -> Type[Variation_81]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IDENT']) -> Type[Variation_82]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COUNTER']) -> Type[Variation_83]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['A'], Literal['IDENT'], Literal['COUNTER']]) -> Union[Type['Variation_81'], Type['Variation_82'], Type['Variation_83']]:
        if key == 'A':
            return Variation_81
        if key == 'IDENT':
            return Variation_82
        if key == 'COUNTER':
            return Variation_83
        assert_never(key)

    def __init__(self, arg : Variation_84_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['A']) -> Variation_81:
        ...

    @overload
    def get_item(self, name : Literal['IDENT']) -> Variation_82:
        ...

    @overload
    def get_item(self, name : Literal['COUNTER']) -> Variation_83:
        ...

    def get_item(self, name : Union[Literal['A'], Literal['IDENT'], Literal['COUNTER']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['A'], val : Union[Variation_81, Variation_81_Arg]) -> 'Variation_84':
        ...

    @overload
    def set_item(self, name : Literal['IDENT'], val : Union[Variation_82, Variation_82_Arg]) -> 'Variation_84':
        ...

    @overload
    def set_item(self, name : Literal['COUNTER'], val : Union[Variation_83, Variation_83_Arg]) -> 'Variation_84':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['A'], f : Any) -> 'Variation_84':
        ...

    @overload
    def modify_item(self, name : Literal['IDENT'], f : Any) -> 'Variation_84':
        ...

    @overload
    def modify_item(self, name : Literal['COUNTER'], f : Any) -> 'Variation_84':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_85_Arg : TypeAlias = Union[Variation_84, Variation_84_Arg]
class Variation_85(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_84

    @classmethod
    def spec(cls) -> Type[Variation_84]:
        return Variation_84

    def __init__(self, arg : List[Union[Variation_84, Variation_84_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_84, Variation_84_Arg]) -> 'Variation_85':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_84, Variation_84_Arg]) -> 'Variation_85':
        return self._prepend_item(arg) # type: ignore

Variation_86_Arg_Group = TypedDict('Variation_86_Arg_Group', {
    'RS': Union[Variation_13, Variation_13_Arg],
    'RE': Union[Variation_13, Variation_13_Arg],
    'TS': Union[Variation_14, Variation_14_Arg],
    'TE': Union[Variation_14, Variation_14_Arg],
})
Variation_86_Arg : TypeAlias = Union[Raw, Variation_86_Arg_Group]
class Variation_86(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('RS', Variation_13),
        ('RE', Variation_13),
        ('TS', Variation_14),
        ('TE', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RS': ('Rho Start', Variation_13, 0, 16),
        'RE': ('Rho End', Variation_13, 16, 16),
        'TS': ('Theta Start', Variation_14, 32, 16),
        'TE': ('Theta End', Variation_14, 48, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RS']) -> Type[Variation_13]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_13]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TS']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TE']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RS'], Literal['RE'], Literal['TS'], Literal['TE']]) -> Union[Type['Variation_13'], Type['Variation_13'], Type['Variation_14'], Type['Variation_14']]:
        if key == 'RS':
            return Variation_13
        if key == 'RE':
            return Variation_13
        if key == 'TS':
            return Variation_14
        if key == 'TE':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_86_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RS']) -> Variation_13:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_13:
        ...

    @overload
    def get_item(self, name : Literal['TS']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['TE']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['RS'], Literal['RE'], Literal['TS'], Literal['TE']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RS'], val : Union[Variation_13, Variation_13_Arg]) -> 'Variation_86':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_13, Variation_13_Arg]) -> 'Variation_86':
        ...

    @overload
    def set_item(self, name : Literal['TS'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_86':
        ...

    @overload
    def set_item(self, name : Literal['TE'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_86':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RS'], f : Any) -> 'Variation_86':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_86':
        ...

    @overload
    def modify_item(self, name : Literal['TS'], f : Any) -> 'Variation_86':
        ...

    @overload
    def modify_item(self, name : Literal['TE'], f : Any) -> 'Variation_86':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_87_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_87(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 7.8125e-3, 'NM')

    def __init__(self, arg : Variation_87_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_88_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_88(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 2.197265625e-2, '°')

    def __init__(self, arg : Variation_88_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_89_Arg_Group = TypedDict('Variation_89_Arg_Group', {
    'RE': Union[Variation_87, Variation_87_Arg],
    'AE': Union[Variation_88, Variation_88_Arg],
})
Variation_89_Arg : TypeAlias = Union[Raw, Variation_89_Arg_Group]
class Variation_89(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('RE', Variation_87),
        ('AE', Variation_88),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RE': ('Range Error', Variation_87, 0, 8),
        'AE': ('Azimuth Error', Variation_88, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_87]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AE']) -> Type[Variation_88]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RE'], Literal['AE']]) -> Union[Type['Variation_87'], Type['Variation_88']]:
        if key == 'RE':
            return Variation_87
        if key == 'AE':
            return Variation_88
        assert_never(key)

    def __init__(self, arg : Variation_89_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_87:
        ...

    @overload
    def get_item(self, name : Literal['AE']) -> Variation_88:
        ...

    def get_item(self, name : Union[Literal['RE'], Literal['AE']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_87, Variation_87_Arg]) -> 'Variation_89':
        ...

    @overload
    def set_item(self, name : Literal['AE'], val : Union[Variation_88, Variation_88_Arg]) -> 'Variation_89':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_89':
        ...

    @overload
    def modify_item(self, name : Literal['AE'], f : Any) -> 'Variation_89':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_90_Arg = TypedDict('Variation_90_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_78, Variation_78_Arg],
    '020': Union[Variation_79, Variation_79_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '041': Union[Variation_25, Variation_25_Arg],
    '050': Union[Variation_24, Variation_24_Arg],
    '060': Union[Variation_24, Variation_24_Arg],
    '070': Union[Variation_85, Variation_85_Arg],
    '100': Union[Variation_86, Variation_86_Arg],
    '090': Union[Variation_89, Variation_89_Arg],
    '080': Union[Variation_24, Variation_24_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_90(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_78),
        ('020', Variation_79),
        ('030', Variation_80),
        ('041', Variation_25),
        ('050', Variation_24),
        ('060', Variation_24),
        ('070', Variation_85),
        ('100', Variation_86),
        ('090', Variation_89),
        ('080', Variation_24),
        None,
        ('SP', Variation_62),
        None,
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Message Type', Variation_78, 0x4000),
        '020': ('Sector Number', Variation_79, 0x2000),
        '030': ('Time of Day', Variation_80, 0x1000),
        '041': ('Antenna Rotation Speed', Variation_25, 0x0800),
        '050': ('Station Configuration Status', Variation_24, 0x0400),
        '060': ('Station Processing Mode', Variation_24, 0x0200),
        '070': ('Plot Count Values', Variation_85, 0x0180),
        '100': ('Dynamic Window Type 1', Variation_86, 0x0140),
        '090': ('Collimation Error', Variation_89, 0x0120),
        '080': ('Warning/Error Conditions', Variation_24, 0x0110),
        'SP': ('Special Purpose Field', Variation_62, 0x0104),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_78]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_79]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_25]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_24]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_24]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_85]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_86]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_89]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_24]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['020'], Literal['030'], Literal['041'], Literal['050'], Literal['060'], Literal['070'], Literal['100'], Literal['090'], Literal['080'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_78'], Type['Variation_79'], Type['Variation_80'], Type['Variation_25'], Type['Variation_24'], Type['Variation_24'], Type['Variation_85'], Type['Variation_86'], Type['Variation_89'], Type['Variation_24'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_78
        if key == '020':
            return Variation_79
        if key == '030':
            return Variation_80
        if key == '041':
            return Variation_25
        if key == '050':
            return Variation_24
        if key == '060':
            return Variation_24
        if key == '070':
            return Variation_85
        if key == '100':
            return Variation_86
        if key == '090':
            return Variation_89
        if key == '080':
            return Variation_24
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_90_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_78, Variation_78_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_79, Variation_79_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_25, Variation_25_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_24, Variation_24_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_24, Variation_24_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_85, Variation_85_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_86, Variation_86_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_89, Variation_89_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_24, Variation_24_Arg]) -> 'Variation_90':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_90':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_90':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_90':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_78:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_79:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_25:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_24:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_24:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_85:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_86:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_89:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_24:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_90':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_90':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_91_Arg : TypeAlias = Raw
class Variation_91(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Alive Message (AM)',
        2: 'Route Adherence Monitor Longitudinal Deviation (RAMLD)',
        3: 'Route Adherence Monitor Heading Deviation (RAMHD)',
        4: 'Minimum Safe Altitude Warning (MSAW)',
        5: 'Area Proximity Warning (APW)',
        6: 'Clearance Level Adherence Monitor (CLAM)',
        7: 'Short Term Conflict Alert (STCA)',
        8: 'Approach Path Monitor (APM)',
        9: 'RIMCAS Arrival / Landing Monitor (ALM)',
        10: 'RIMCAS Arrival / Departure Wrong Runway Alert (WRA)',
        11: 'RIMCAS Arrival / Departure Opposite Traffic Alert (OTA)',
        12: 'RIMCAS Departure Monitor (RDM)',
        13: 'RIMCAS Runway / Taxiway Crossing Monitor (RCM)',
        14: 'RIMCAS Taxiway Separation Monitor (TSM)',
        15: 'RIMCAS Unauthorized Taxiway Movement Monitor(UTMM)',
        16: 'RIMCAS Stop Bar Overrun Alert (SBOA)',
        17: 'End Of Conflict (EOC)',
        18: 'ACAS Resolution Advisory (ACASRA)',
        19: 'Near Term Conflict Alert (NTCA)',
        20: 'Downlinked Barometric Pressure Setting Monitor (DBPSM)',
        21: 'Speed Adherence Monitor (SAM)',
        22: 'Outside Controlled Airspace Tool (OCAT)',
        23: 'Vertical Conflict Detection (VCD)',
        24: 'Vertical Rate Adherence Monitor (VRAM)',
        25: 'Cleared Heading Adherence Monitor (CHAM)',
        26: 'Downlinked Selected Altitude Monitor (DSAM)',
        27: 'Holding Adherence Monitor (HAM)',
        28: 'Vertical Path Monitor (VPM)',
        29: 'RIMCAS Taxiway Traffic Alert (TTA)',
        30: 'RIMCAS Arrival/Departure Close Runway Alert (CRA)',
        31: 'RIMCAS Arrival/Departure Aircraft Separation Monitor (ASM)',
        32: 'RIMCAS ILS Area Violation Monitor (IAVM)',
        33: 'Final Target Distance Indicator (FTD)',
        34: 'Initial Target Distance Indicator (ITD)',
        35: 'Wake Vortex Indicator Infringement Alert (IIA)',
        36: 'Sequence Warning (SQW)',
        37: 'Catch Up Warning (CUW)',
        38: 'Conflicting ATC Clearances (CATC)',
        39: 'No ATC Clearance (NOCLR)',
        40: 'Aircraft Not Moving despite ATC Clearance (NOMOV)',
        41: 'Aircraft leaving/entering the aerodrome area without proper handover (NOH)',
        42: 'Wrong Runway or Taxiway Type (WRTY)',
        43: 'Stand Occupied (STOCC)',
        44: 'Ongoing Alert (ONGOING)',
        97: 'Lost Track Warning (LTW)',
        98: 'Holding Volume Infringement (HVI)',
        99: 'Airspace Infringement Warning (AIW)',
    }

    def __init__(self, arg : Variation_91_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_92_Arg : TypeAlias = Union[Variation_1, Variation_1_Arg]
class Variation_92(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_1

    @classmethod
    def spec(cls) -> Type[Variation_1]:
        return Variation_1

    def __init__(self, arg : List[Union[Variation_1, Variation_1_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1, Variation_1_Arg]) -> 'Variation_92':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1, Variation_1_Arg]) -> 'Variation_92':
        return self._prepend_item(arg) # type: ignore

Variation_93_Arg : TypeAlias = Raw
class Variation_93(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 3

    def __init__(self, arg : Variation_93_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_94_Arg_Group = TypedDict('Variation_94_Arg_Group', {
    'STAT': Union[Variation_93, Variation_93_Arg],
})
Variation_94_Arg : TypeAlias = Union[Raw, Variation_94_Arg_Group]
class Variation_94(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 4),
        ('STAT', Variation_93),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STAT': ('Status of the Alert', Variation_93, 4, 3),
    }


    @classmethod
    def spec(cls, key : Union[Literal['STAT']]) -> Union[Type['Variation_93']]:
        if key == 'STAT':
            return Variation_93
        assert_never(key)

    def __init__(self, arg : Variation_94_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['STAT']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['STAT'], val : Union[Variation_93, Variation_93_Arg]) -> 'Variation_94':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_94':
        return self._modify_item(name, f) # type: ignore

Variation_95_Arg : TypeAlias = Raw
class Variation_95(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'MRVA function',
    }

    def __init__(self, arg : Variation_95_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_96_Arg : TypeAlias = Raw
class Variation_96(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'RAMLD function',
    }

    def __init__(self, arg : Variation_96_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_97_Arg : TypeAlias = Raw
class Variation_97(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'RAMHD function',
    }

    def __init__(self, arg : Variation_97_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_98_Arg : TypeAlias = Raw
class Variation_98(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'MSAW function',
    }

    def __init__(self, arg : Variation_98_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_99_Arg : TypeAlias = Raw
class Variation_99(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'APW function',
    }

    def __init__(self, arg : Variation_99_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_100_Arg : TypeAlias = Raw
class Variation_100(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'CLAM function',
    }

    def __init__(self, arg : Variation_100_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_101_Arg : TypeAlias = Raw
class Variation_101(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'STCA function',
    }

    def __init__(self, arg : Variation_101_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_102_Arg : TypeAlias = Raw
class Variation_102(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'APM function',
    }

    def __init__(self, arg : Variation_102_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_103_Arg : TypeAlias = Raw
class Variation_103(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'RIMCA function',
    }

    def __init__(self, arg : Variation_103_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_104_Arg : TypeAlias = Raw
class Variation_104(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'ACAS RA function',
    }

    def __init__(self, arg : Variation_104_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_105_Arg : TypeAlias = Raw
class Variation_105(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'NTCA function',
    }

    def __init__(self, arg : Variation_105_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_106_Arg : TypeAlias = Raw
class Variation_106(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'System degraded',
    }

    def __init__(self, arg : Variation_106_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_107_Arg : TypeAlias = Raw
class Variation_107(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Overflow error',
    }

    def __init__(self, arg : Variation_107_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_108_Arg : TypeAlias = Raw
class Variation_108(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Overload error',
    }

    def __init__(self, arg : Variation_108_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_109_Arg : TypeAlias = Raw
class Variation_109(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'AIW function',
    }

    def __init__(self, arg : Variation_109_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_110_Arg : TypeAlias = Raw
class Variation_110(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'PAIW function',
    }

    def __init__(self, arg : Variation_110_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_111_Arg : TypeAlias = Raw
class Variation_111(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'OCAT function',
    }

    def __init__(self, arg : Variation_111_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_112_Arg : TypeAlias = Raw
class Variation_112(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'SAM function',
    }

    def __init__(self, arg : Variation_112_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_113_Arg : TypeAlias = Raw
class Variation_113(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'VCD function',
    }

    def __init__(self, arg : Variation_113_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_114_Arg : TypeAlias = Raw
class Variation_114(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'CHAM function',
    }

    def __init__(self, arg : Variation_114_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_115_Arg : TypeAlias = Raw
class Variation_115(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'DSAM function',
    }

    def __init__(self, arg : Variation_115_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_116_Arg : TypeAlias = Raw
class Variation_116(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'DBPSM ARR sub-function',
    }

    def __init__(self, arg : Variation_116_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_117_Arg : TypeAlias = Raw
class Variation_117(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'DBPSM DEP sub-function',
    }

    def __init__(self, arg : Variation_117_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_118_Arg : TypeAlias = Raw
class Variation_118(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'DBPSM TL sub-function',
    }

    def __init__(self, arg : Variation_118_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_119_Arg : TypeAlias = Raw
class Variation_119(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'VRAM CRM sub-function',
    }

    def __init__(self, arg : Variation_119_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_120_Arg : TypeAlias = Raw
class Variation_120(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'VRAM VTM sub-function',
    }

    def __init__(self, arg : Variation_120_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_121_Arg : TypeAlias = Raw
class Variation_121(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'VRAM VRM sub-function',
    }

    def __init__(self, arg : Variation_121_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_122_Arg : TypeAlias = Raw
class Variation_122(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'HAM HD sub-function',
    }

    def __init__(self, arg : Variation_122_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_123_Arg : TypeAlias = Raw
class Variation_123(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'HAM RD sub-function',
    }

    def __init__(self, arg : Variation_123_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_124_Arg : TypeAlias = Raw
class Variation_124(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'HAM VD sub-function',
    }

    def __init__(self, arg : Variation_124_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_125_Arg : TypeAlias = Raw
class Variation_125(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'HVI function',
    }

    def __init__(self, arg : Variation_125_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_126_Arg : TypeAlias = Raw
class Variation_126(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'LTW function',
    }

    def __init__(self, arg : Variation_126_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_127_Arg : TypeAlias = Raw
class Variation_127(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'VPM function',
    }

    def __init__(self, arg : Variation_127_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_128_Arg : TypeAlias = Raw
class Variation_128(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'TTA function',
    }

    def __init__(self, arg : Variation_128_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_129_Arg : TypeAlias = Raw
class Variation_129(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'CRA function',
    }

    def __init__(self, arg : Variation_129_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_130_Arg : TypeAlias = Raw
class Variation_130(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'ASM sub-function',
    }

    def __init__(self, arg : Variation_130_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_131_Arg : TypeAlias = Raw
class Variation_131(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'IAVM sub-function',
    }

    def __init__(self, arg : Variation_131_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_132_Arg : TypeAlias = Raw
class Variation_132(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'FTD Function',
    }

    def __init__(self, arg : Variation_132_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_133_Arg : TypeAlias = Raw
class Variation_133(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'ITD function',
    }

    def __init__(self, arg : Variation_133_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_134_Arg : TypeAlias = Raw
class Variation_134(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'IIA function',
    }

    def __init__(self, arg : Variation_134_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_135_Arg : TypeAlias = Raw
class Variation_135(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'SQW function',
    }

    def __init__(self, arg : Variation_135_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_136_Arg : TypeAlias = Raw
class Variation_136(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'CUW function',
    }

    def __init__(self, arg : Variation_136_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_137_Arg : TypeAlias = Raw
class Variation_137(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'CATC function',
    }

    def __init__(self, arg : Variation_137_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_138_Arg : TypeAlias = Raw
class Variation_138(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'NOCLR sub-function',
    }

    def __init__(self, arg : Variation_138_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_139_Arg : TypeAlias = Raw
class Variation_139(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'NOMOV Function',
    }

    def __init__(self, arg : Variation_139_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_140_Arg : TypeAlias = Raw
class Variation_140(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'NOH function',
    }

    def __init__(self, arg : Variation_140_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_141_Arg : TypeAlias = Raw
class Variation_141(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'WRTY function',
    }

    def __init__(self, arg : Variation_141_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_142_Arg : TypeAlias = Raw
class Variation_142(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'STOCC function',
    }

    def __init__(self, arg : Variation_142_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_143_Arg : TypeAlias = Raw
class Variation_143(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'ONGOING function',
    }

    def __init__(self, arg : Variation_143_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_144_Arg_Group_1 = TypedDict('Variation_144_Arg_Group_1', {
    'MRVA': Union[Variation_95, Variation_95_Arg],
    'RAMLD': Union[Variation_96, Variation_96_Arg],
    'RAMHD': Union[Variation_97, Variation_97_Arg],
    'MSAW': Union[Variation_98, Variation_98_Arg],
    'APW': Union[Variation_99, Variation_99_Arg],
    'CLAM': Union[Variation_100, Variation_100_Arg],
    'STCA': Union[Variation_101, Variation_101_Arg],
})
Variation_144_Arg_Group_2 = TypedDict('Variation_144_Arg_Group_2', {
    'MRVA': Union[Variation_95, Variation_95_Arg],
    'RAMLD': Union[Variation_96, Variation_96_Arg],
    'RAMHD': Union[Variation_97, Variation_97_Arg],
    'MSAW': Union[Variation_98, Variation_98_Arg],
    'APW': Union[Variation_99, Variation_99_Arg],
    'CLAM': Union[Variation_100, Variation_100_Arg],
    'STCA': Union[Variation_101, Variation_101_Arg],
    'APM': Union[Variation_102, Variation_102_Arg],
    'RIMCA': Union[Variation_103, Variation_103_Arg],
    'ACASRA': Union[Variation_104, Variation_104_Arg],
    'NTCA': Union[Variation_105, Variation_105_Arg],
    'DG': Union[Variation_106, Variation_106_Arg],
    'OF': Union[Variation_107, Variation_107_Arg],
    'OL': Union[Variation_108, Variation_108_Arg],
})
Variation_144_Arg_Group_3 = TypedDict('Variation_144_Arg_Group_3', {
    'MRVA': Union[Variation_95, Variation_95_Arg],
    'RAMLD': Union[Variation_96, Variation_96_Arg],
    'RAMHD': Union[Variation_97, Variation_97_Arg],
    'MSAW': Union[Variation_98, Variation_98_Arg],
    'APW': Union[Variation_99, Variation_99_Arg],
    'CLAM': Union[Variation_100, Variation_100_Arg],
    'STCA': Union[Variation_101, Variation_101_Arg],
    'APM': Union[Variation_102, Variation_102_Arg],
    'RIMCA': Union[Variation_103, Variation_103_Arg],
    'ACASRA': Union[Variation_104, Variation_104_Arg],
    'NTCA': Union[Variation_105, Variation_105_Arg],
    'DG': Union[Variation_106, Variation_106_Arg],
    'OF': Union[Variation_107, Variation_107_Arg],
    'OL': Union[Variation_108, Variation_108_Arg],
    'AIW': Union[Variation_109, Variation_109_Arg],
    'PAIW': Union[Variation_110, Variation_110_Arg],
    'OCAT': Union[Variation_111, Variation_111_Arg],
    'SAM': Union[Variation_112, Variation_112_Arg],
    'VCD': Union[Variation_113, Variation_113_Arg],
    'CHAM': Union[Variation_114, Variation_114_Arg],
    'DSAM': Union[Variation_115, Variation_115_Arg],
})
Variation_144_Arg_Group_4 = TypedDict('Variation_144_Arg_Group_4', {
    'MRVA': Union[Variation_95, Variation_95_Arg],
    'RAMLD': Union[Variation_96, Variation_96_Arg],
    'RAMHD': Union[Variation_97, Variation_97_Arg],
    'MSAW': Union[Variation_98, Variation_98_Arg],
    'APW': Union[Variation_99, Variation_99_Arg],
    'CLAM': Union[Variation_100, Variation_100_Arg],
    'STCA': Union[Variation_101, Variation_101_Arg],
    'APM': Union[Variation_102, Variation_102_Arg],
    'RIMCA': Union[Variation_103, Variation_103_Arg],
    'ACASRA': Union[Variation_104, Variation_104_Arg],
    'NTCA': Union[Variation_105, Variation_105_Arg],
    'DG': Union[Variation_106, Variation_106_Arg],
    'OF': Union[Variation_107, Variation_107_Arg],
    'OL': Union[Variation_108, Variation_108_Arg],
    'AIW': Union[Variation_109, Variation_109_Arg],
    'PAIW': Union[Variation_110, Variation_110_Arg],
    'OCAT': Union[Variation_111, Variation_111_Arg],
    'SAM': Union[Variation_112, Variation_112_Arg],
    'VCD': Union[Variation_113, Variation_113_Arg],
    'CHAM': Union[Variation_114, Variation_114_Arg],
    'DSAM': Union[Variation_115, Variation_115_Arg],
    'DBPSMARR': Union[Variation_116, Variation_116_Arg],
    'DBPSMDEP': Union[Variation_117, Variation_117_Arg],
    'DBPSMTL': Union[Variation_118, Variation_118_Arg],
    'VRAMCRM': Union[Variation_119, Variation_119_Arg],
    'VRAMVTM': Union[Variation_120, Variation_120_Arg],
    'VRAMVRM': Union[Variation_121, Variation_121_Arg],
    'HAMHD': Union[Variation_122, Variation_122_Arg],
})
Variation_144_Arg_Group_5 = TypedDict('Variation_144_Arg_Group_5', {
    'MRVA': Union[Variation_95, Variation_95_Arg],
    'RAMLD': Union[Variation_96, Variation_96_Arg],
    'RAMHD': Union[Variation_97, Variation_97_Arg],
    'MSAW': Union[Variation_98, Variation_98_Arg],
    'APW': Union[Variation_99, Variation_99_Arg],
    'CLAM': Union[Variation_100, Variation_100_Arg],
    'STCA': Union[Variation_101, Variation_101_Arg],
    'APM': Union[Variation_102, Variation_102_Arg],
    'RIMCA': Union[Variation_103, Variation_103_Arg],
    'ACASRA': Union[Variation_104, Variation_104_Arg],
    'NTCA': Union[Variation_105, Variation_105_Arg],
    'DG': Union[Variation_106, Variation_106_Arg],
    'OF': Union[Variation_107, Variation_107_Arg],
    'OL': Union[Variation_108, Variation_108_Arg],
    'AIW': Union[Variation_109, Variation_109_Arg],
    'PAIW': Union[Variation_110, Variation_110_Arg],
    'OCAT': Union[Variation_111, Variation_111_Arg],
    'SAM': Union[Variation_112, Variation_112_Arg],
    'VCD': Union[Variation_113, Variation_113_Arg],
    'CHAM': Union[Variation_114, Variation_114_Arg],
    'DSAM': Union[Variation_115, Variation_115_Arg],
    'DBPSMARR': Union[Variation_116, Variation_116_Arg],
    'DBPSMDEP': Union[Variation_117, Variation_117_Arg],
    'DBPSMTL': Union[Variation_118, Variation_118_Arg],
    'VRAMCRM': Union[Variation_119, Variation_119_Arg],
    'VRAMVTM': Union[Variation_120, Variation_120_Arg],
    'VRAMVRM': Union[Variation_121, Variation_121_Arg],
    'HAMHD': Union[Variation_122, Variation_122_Arg],
    'HAMRD': Union[Variation_123, Variation_123_Arg],
    'HAMVD': Union[Variation_124, Variation_124_Arg],
    'HVI': Union[Variation_125, Variation_125_Arg],
    'LTW': Union[Variation_126, Variation_126_Arg],
    'VPM': Union[Variation_127, Variation_127_Arg],
    'TTA': Union[Variation_128, Variation_128_Arg],
    'CRA': Union[Variation_129, Variation_129_Arg],
})
Variation_144_Arg_Group_6 = TypedDict('Variation_144_Arg_Group_6', {
    'MRVA': Union[Variation_95, Variation_95_Arg],
    'RAMLD': Union[Variation_96, Variation_96_Arg],
    'RAMHD': Union[Variation_97, Variation_97_Arg],
    'MSAW': Union[Variation_98, Variation_98_Arg],
    'APW': Union[Variation_99, Variation_99_Arg],
    'CLAM': Union[Variation_100, Variation_100_Arg],
    'STCA': Union[Variation_101, Variation_101_Arg],
    'APM': Union[Variation_102, Variation_102_Arg],
    'RIMCA': Union[Variation_103, Variation_103_Arg],
    'ACASRA': Union[Variation_104, Variation_104_Arg],
    'NTCA': Union[Variation_105, Variation_105_Arg],
    'DG': Union[Variation_106, Variation_106_Arg],
    'OF': Union[Variation_107, Variation_107_Arg],
    'OL': Union[Variation_108, Variation_108_Arg],
    'AIW': Union[Variation_109, Variation_109_Arg],
    'PAIW': Union[Variation_110, Variation_110_Arg],
    'OCAT': Union[Variation_111, Variation_111_Arg],
    'SAM': Union[Variation_112, Variation_112_Arg],
    'VCD': Union[Variation_113, Variation_113_Arg],
    'CHAM': Union[Variation_114, Variation_114_Arg],
    'DSAM': Union[Variation_115, Variation_115_Arg],
    'DBPSMARR': Union[Variation_116, Variation_116_Arg],
    'DBPSMDEP': Union[Variation_117, Variation_117_Arg],
    'DBPSMTL': Union[Variation_118, Variation_118_Arg],
    'VRAMCRM': Union[Variation_119, Variation_119_Arg],
    'VRAMVTM': Union[Variation_120, Variation_120_Arg],
    'VRAMVRM': Union[Variation_121, Variation_121_Arg],
    'HAMHD': Union[Variation_122, Variation_122_Arg],
    'HAMRD': Union[Variation_123, Variation_123_Arg],
    'HAMVD': Union[Variation_124, Variation_124_Arg],
    'HVI': Union[Variation_125, Variation_125_Arg],
    'LTW': Union[Variation_126, Variation_126_Arg],
    'VPM': Union[Variation_127, Variation_127_Arg],
    'TTA': Union[Variation_128, Variation_128_Arg],
    'CRA': Union[Variation_129, Variation_129_Arg],
    'ASM': Union[Variation_130, Variation_130_Arg],
    'IAVM': Union[Variation_131, Variation_131_Arg],
    'FTD': Union[Variation_132, Variation_132_Arg],
    'ITD': Union[Variation_133, Variation_133_Arg],
    'IIA': Union[Variation_134, Variation_134_Arg],
    'SQW': Union[Variation_135, Variation_135_Arg],
    'CUW': Union[Variation_136, Variation_136_Arg],
})
Variation_144_Arg_Group_7 = TypedDict('Variation_144_Arg_Group_7', {
    'MRVA': Union[Variation_95, Variation_95_Arg],
    'RAMLD': Union[Variation_96, Variation_96_Arg],
    'RAMHD': Union[Variation_97, Variation_97_Arg],
    'MSAW': Union[Variation_98, Variation_98_Arg],
    'APW': Union[Variation_99, Variation_99_Arg],
    'CLAM': Union[Variation_100, Variation_100_Arg],
    'STCA': Union[Variation_101, Variation_101_Arg],
    'APM': Union[Variation_102, Variation_102_Arg],
    'RIMCA': Union[Variation_103, Variation_103_Arg],
    'ACASRA': Union[Variation_104, Variation_104_Arg],
    'NTCA': Union[Variation_105, Variation_105_Arg],
    'DG': Union[Variation_106, Variation_106_Arg],
    'OF': Union[Variation_107, Variation_107_Arg],
    'OL': Union[Variation_108, Variation_108_Arg],
    'AIW': Union[Variation_109, Variation_109_Arg],
    'PAIW': Union[Variation_110, Variation_110_Arg],
    'OCAT': Union[Variation_111, Variation_111_Arg],
    'SAM': Union[Variation_112, Variation_112_Arg],
    'VCD': Union[Variation_113, Variation_113_Arg],
    'CHAM': Union[Variation_114, Variation_114_Arg],
    'DSAM': Union[Variation_115, Variation_115_Arg],
    'DBPSMARR': Union[Variation_116, Variation_116_Arg],
    'DBPSMDEP': Union[Variation_117, Variation_117_Arg],
    'DBPSMTL': Union[Variation_118, Variation_118_Arg],
    'VRAMCRM': Union[Variation_119, Variation_119_Arg],
    'VRAMVTM': Union[Variation_120, Variation_120_Arg],
    'VRAMVRM': Union[Variation_121, Variation_121_Arg],
    'HAMHD': Union[Variation_122, Variation_122_Arg],
    'HAMRD': Union[Variation_123, Variation_123_Arg],
    'HAMVD': Union[Variation_124, Variation_124_Arg],
    'HVI': Union[Variation_125, Variation_125_Arg],
    'LTW': Union[Variation_126, Variation_126_Arg],
    'VPM': Union[Variation_127, Variation_127_Arg],
    'TTA': Union[Variation_128, Variation_128_Arg],
    'CRA': Union[Variation_129, Variation_129_Arg],
    'ASM': Union[Variation_130, Variation_130_Arg],
    'IAVM': Union[Variation_131, Variation_131_Arg],
    'FTD': Union[Variation_132, Variation_132_Arg],
    'ITD': Union[Variation_133, Variation_133_Arg],
    'IIA': Union[Variation_134, Variation_134_Arg],
    'SQW': Union[Variation_135, Variation_135_Arg],
    'CUW': Union[Variation_136, Variation_136_Arg],
    'CATC': Union[Variation_137, Variation_137_Arg],
    'NOCLR': Union[Variation_138, Variation_138_Arg],
    'NOMOV': Union[Variation_139, Variation_139_Arg],
    'NOH': Union[Variation_140, Variation_140_Arg],
    'WRTY': Union[Variation_141, Variation_141_Arg],
    'STOCC': Union[Variation_142, Variation_142_Arg],
    'ONGOING': Union[Variation_143, Variation_143_Arg],
})
Variation_144_Arg : TypeAlias = Union[
    int,
    Variation_144_Arg_Group_1,
    Tuple[int],
    Variation_144_Arg_Group_2,
    Tuple[int,int],
    Variation_144_Arg_Group_3,
    Tuple[int,int,int],
    Variation_144_Arg_Group_4,
    Tuple[int,int,int,int],
    Variation_144_Arg_Group_5,
    Tuple[int,int,int,int,int],
    Variation_144_Arg_Group_6,
    Tuple[int,int,int,int,int,int],
    Variation_144_Arg_Group_7,
    Tuple[int,int,int,int,int,int,int],
]
class Variation_144(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
        7,
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('MRVA', Variation_95),
            ('RAMLD', Variation_96),
            ('RAMHD', Variation_97),
            ('MSAW', Variation_98),
            ('APW', Variation_99),
            ('CLAM', Variation_100),
            ('STCA', Variation_101),
        ],
        [
            ('APM', Variation_102),
            ('RIMCA', Variation_103),
            ('ACASRA', Variation_104),
            ('NTCA', Variation_105),
            ('DG', Variation_106),
            ('OF', Variation_107),
            ('OL', Variation_108),
        ],
        [
            ('AIW', Variation_109),
            ('PAIW', Variation_110),
            ('OCAT', Variation_111),
            ('SAM', Variation_112),
            ('VCD', Variation_113),
            ('CHAM', Variation_114),
            ('DSAM', Variation_115),
        ],
        [
            ('DBPSMARR', Variation_116),
            ('DBPSMDEP', Variation_117),
            ('DBPSMTL', Variation_118),
            ('VRAMCRM', Variation_119),
            ('VRAMVTM', Variation_120),
            ('VRAMVRM', Variation_121),
            ('HAMHD', Variation_122),
        ],
        [
            ('HAMRD', Variation_123),
            ('HAMVD', Variation_124),
            ('HVI', Variation_125),
            ('LTW', Variation_126),
            ('VPM', Variation_127),
            ('TTA', Variation_128),
            ('CRA', Variation_129),
        ],
        [
            ('ASM', Variation_130),
            ('IAVM', Variation_131),
            ('FTD', Variation_132),
            ('ITD', Variation_133),
            ('IIA', Variation_134),
            ('SQW', Variation_135),
            ('CUW', Variation_136),
        ],
        [
            ('CATC', Variation_137),
            ('NOCLR', Variation_138),
            ('NOMOV', Variation_139),
            ('NOH', Variation_140),
            ('WRTY', Variation_141),
            ('STOCC', Variation_142),
            ('ONGOING', Variation_143),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MRVA': ('', Variation_95, 0, 1),
        'RAMLD': ('', Variation_96, 1, 1),
        'RAMHD': ('', Variation_97, 2, 1),
        'MSAW': ('', Variation_98, 3, 1),
        'APW': ('', Variation_99, 4, 1),
        'CLAM': ('', Variation_100, 5, 1),
        'STCA': ('', Variation_101, 6, 1),
        'APM': ('', Variation_102, 0, 1),
        'RIMCA': ('', Variation_103, 1, 1),
        'ACASRA': ('', Variation_104, 2, 1),
        'NTCA': ('', Variation_105, 3, 1),
        'DG': ('', Variation_106, 4, 1),
        'OF': ('', Variation_107, 5, 1),
        'OL': ('', Variation_108, 6, 1),
        'AIW': ('', Variation_109, 0, 1),
        'PAIW': ('', Variation_110, 1, 1),
        'OCAT': ('', Variation_111, 2, 1),
        'SAM': ('', Variation_112, 3, 1),
        'VCD': ('', Variation_113, 4, 1),
        'CHAM': ('', Variation_114, 5, 1),
        'DSAM': ('', Variation_115, 6, 1),
        'DBPSMARR': ('', Variation_116, 0, 1),
        'DBPSMDEP': ('', Variation_117, 1, 1),
        'DBPSMTL': ('', Variation_118, 2, 1),
        'VRAMCRM': ('', Variation_119, 3, 1),
        'VRAMVTM': ('', Variation_120, 4, 1),
        'VRAMVRM': ('', Variation_121, 5, 1),
        'HAMHD': ('', Variation_122, 6, 1),
        'HAMRD': ('', Variation_123, 0, 1),
        'HAMVD': ('', Variation_124, 1, 1),
        'HVI': ('', Variation_125, 2, 1),
        'LTW': ('', Variation_126, 3, 1),
        'VPM': ('', Variation_127, 4, 1),
        'TTA': ('', Variation_128, 5, 1),
        'CRA': ('', Variation_129, 6, 1),
        'ASM': ('', Variation_130, 0, 1),
        'IAVM': ('', Variation_131, 1, 1),
        'FTD': ('', Variation_132, 2, 1),
        'ITD': ('', Variation_133, 3, 1),
        'IIA': ('', Variation_134, 4, 1),
        'SQW': ('', Variation_135, 5, 1),
        'CUW': ('', Variation_136, 6, 1),
        'CATC': ('', Variation_137, 0, 1),
        'NOCLR': ('', Variation_138, 1, 1),
        'NOMOV': ('', Variation_139, 2, 1),
        'NOH': ('', Variation_140, 3, 1),
        'WRTY': ('', Variation_141, 4, 1),
        'STOCC': ('', Variation_142, 5, 1),
        'ONGOING': ('', Variation_143, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MRVA']) -> Type[Variation_95]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAMLD']) -> Type[Variation_96]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAMHD']) -> Type[Variation_97]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSAW']) -> Type[Variation_98]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['APW']) -> Type[Variation_99]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CLAM']) -> Type[Variation_100]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STCA']) -> Type[Variation_101]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['APM']) -> Type[Variation_102]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RIMCA']) -> Type[Variation_103]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ACASRA']) -> Type[Variation_104]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NTCA']) -> Type[Variation_105]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DG']) -> Type[Variation_106]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OF']) -> Type[Variation_107]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OL']) -> Type[Variation_108]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AIW']) -> Type[Variation_109]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PAIW']) -> Type[Variation_110]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OCAT']) -> Type[Variation_111]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAM']) -> Type[Variation_112]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VCD']) -> Type[Variation_113]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHAM']) -> Type[Variation_114]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DSAM']) -> Type[Variation_115]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DBPSMARR']) -> Type[Variation_116]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DBPSMDEP']) -> Type[Variation_117]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DBPSMTL']) -> Type[Variation_118]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VRAMCRM']) -> Type[Variation_119]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VRAMVTM']) -> Type[Variation_120]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VRAMVRM']) -> Type[Variation_121]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HAMHD']) -> Type[Variation_122]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HAMRD']) -> Type[Variation_123]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HAMVD']) -> Type[Variation_124]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HVI']) -> Type[Variation_125]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LTW']) -> Type[Variation_126]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VPM']) -> Type[Variation_127]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TTA']) -> Type[Variation_128]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CRA']) -> Type[Variation_129]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ASM']) -> Type[Variation_130]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAVM']) -> Type[Variation_131]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FTD']) -> Type[Variation_132]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ITD']) -> Type[Variation_133]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IIA']) -> Type[Variation_134]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SQW']) -> Type[Variation_135]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CUW']) -> Type[Variation_136]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CATC']) -> Type[Variation_137]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOCLR']) -> Type[Variation_138]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOMOV']) -> Type[Variation_139]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOH']) -> Type[Variation_140]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WRTY']) -> Type[Variation_141]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STOCC']) -> Type[Variation_142]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ONGOING']) -> Type[Variation_143]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MRVA'], Literal['RAMLD'], Literal['RAMHD'], Literal['MSAW'], Literal['APW'], Literal['CLAM'], Literal['STCA'], Literal['APM'], Literal['RIMCA'], Literal['ACASRA'], Literal['NTCA'], Literal['DG'], Literal['OF'], Literal['OL'], Literal['AIW'], Literal['PAIW'], Literal['OCAT'], Literal['SAM'], Literal['VCD'], Literal['CHAM'], Literal['DSAM'], Literal['DBPSMARR'], Literal['DBPSMDEP'], Literal['DBPSMTL'], Literal['VRAMCRM'], Literal['VRAMVTM'], Literal['VRAMVRM'], Literal['HAMHD'], Literal['HAMRD'], Literal['HAMVD'], Literal['HVI'], Literal['LTW'], Literal['VPM'], Literal['TTA'], Literal['CRA'], Literal['ASM'], Literal['IAVM'], Literal['FTD'], Literal['ITD'], Literal['IIA'], Literal['SQW'], Literal['CUW'], Literal['CATC'], Literal['NOCLR'], Literal['NOMOV'], Literal['NOH'], Literal['WRTY'], Literal['STOCC'], Literal['ONGOING']]) -> Union[Type['Variation_95'], Type['Variation_96'], Type['Variation_97'], Type['Variation_98'], Type['Variation_99'], Type['Variation_100'], Type['Variation_101'], Type['Variation_102'], Type['Variation_103'], Type['Variation_104'], Type['Variation_105'], Type['Variation_106'], Type['Variation_107'], Type['Variation_108'], Type['Variation_109'], Type['Variation_110'], Type['Variation_111'], Type['Variation_112'], Type['Variation_113'], Type['Variation_114'], Type['Variation_115'], Type['Variation_116'], Type['Variation_117'], Type['Variation_118'], Type['Variation_119'], Type['Variation_120'], Type['Variation_121'], Type['Variation_122'], Type['Variation_123'], Type['Variation_124'], Type['Variation_125'], Type['Variation_126'], Type['Variation_127'], Type['Variation_128'], Type['Variation_129'], Type['Variation_130'], Type['Variation_131'], Type['Variation_132'], Type['Variation_133'], Type['Variation_134'], Type['Variation_135'], Type['Variation_136'], Type['Variation_137'], Type['Variation_138'], Type['Variation_139'], Type['Variation_140'], Type['Variation_141'], Type['Variation_142'], Type['Variation_143']]:
        if key == 'MRVA':
            return Variation_95
        if key == 'RAMLD':
            return Variation_96
        if key == 'RAMHD':
            return Variation_97
        if key == 'MSAW':
            return Variation_98
        if key == 'APW':
            return Variation_99
        if key == 'CLAM':
            return Variation_100
        if key == 'STCA':
            return Variation_101
        if key == 'APM':
            return Variation_102
        if key == 'RIMCA':
            return Variation_103
        if key == 'ACASRA':
            return Variation_104
        if key == 'NTCA':
            return Variation_105
        if key == 'DG':
            return Variation_106
        if key == 'OF':
            return Variation_107
        if key == 'OL':
            return Variation_108
        if key == 'AIW':
            return Variation_109
        if key == 'PAIW':
            return Variation_110
        if key == 'OCAT':
            return Variation_111
        if key == 'SAM':
            return Variation_112
        if key == 'VCD':
            return Variation_113
        if key == 'CHAM':
            return Variation_114
        if key == 'DSAM':
            return Variation_115
        if key == 'DBPSMARR':
            return Variation_116
        if key == 'DBPSMDEP':
            return Variation_117
        if key == 'DBPSMTL':
            return Variation_118
        if key == 'VRAMCRM':
            return Variation_119
        if key == 'VRAMVTM':
            return Variation_120
        if key == 'VRAMVRM':
            return Variation_121
        if key == 'HAMHD':
            return Variation_122
        if key == 'HAMRD':
            return Variation_123
        if key == 'HAMVD':
            return Variation_124
        if key == 'HVI':
            return Variation_125
        if key == 'LTW':
            return Variation_126
        if key == 'VPM':
            return Variation_127
        if key == 'TTA':
            return Variation_128
        if key == 'CRA':
            return Variation_129
        if key == 'ASM':
            return Variation_130
        if key == 'IAVM':
            return Variation_131
        if key == 'FTD':
            return Variation_132
        if key == 'ITD':
            return Variation_133
        if key == 'IIA':
            return Variation_134
        if key == 'SQW':
            return Variation_135
        if key == 'CUW':
            return Variation_136
        if key == 'CATC':
            return Variation_137
        if key == 'NOCLR':
            return Variation_138
        if key == 'NOMOV':
            return Variation_139
        if key == 'NOH':
            return Variation_140
        if key == 'WRTY':
            return Variation_141
        if key == 'STOCC':
            return Variation_142
        if key == 'ONGOING':
            return Variation_143
        assert_never(key)

    def __init__(self, arg : Variation_144_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_144_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_144_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_144_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            if Variation_144_Arg_Group_4.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(4, arg)); return
            if Variation_144_Arg_Group_5.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(5, arg)); return
            if Variation_144_Arg_Group_6.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(6, arg)); return
            if Variation_144_Arg_Group_7.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(7, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MRVA']) -> Variation_95:
        ...

    @overload
    def get_item(self, name : Literal['RAMLD']) -> Variation_96:
        ...

    @overload
    def get_item(self, name : Literal['RAMHD']) -> Variation_97:
        ...

    @overload
    def get_item(self, name : Literal['MSAW']) -> Variation_98:
        ...

    @overload
    def get_item(self, name : Literal['APW']) -> Variation_99:
        ...

    @overload
    def get_item(self, name : Literal['CLAM']) -> Variation_100:
        ...

    @overload
    def get_item(self, name : Literal['STCA']) -> Variation_101:
        ...

    @overload
    def get_item(self, name : Literal['APM']) -> Variation_102:
        ...

    @overload
    def get_item(self, name : Literal['RIMCA']) -> Variation_103:
        ...

    @overload
    def get_item(self, name : Literal['ACASRA']) -> Variation_104:
        ...

    @overload
    def get_item(self, name : Literal['NTCA']) -> Variation_105:
        ...

    @overload
    def get_item(self, name : Literal['DG']) -> Variation_106:
        ...

    @overload
    def get_item(self, name : Literal['OF']) -> Variation_107:
        ...

    @overload
    def get_item(self, name : Literal['OL']) -> Variation_108:
        ...

    @overload
    def get_item(self, name : Literal['AIW']) -> Variation_109:
        ...

    @overload
    def get_item(self, name : Literal['PAIW']) -> Variation_110:
        ...

    @overload
    def get_item(self, name : Literal['OCAT']) -> Variation_111:
        ...

    @overload
    def get_item(self, name : Literal['SAM']) -> Variation_112:
        ...

    @overload
    def get_item(self, name : Literal['VCD']) -> Variation_113:
        ...

    @overload
    def get_item(self, name : Literal['CHAM']) -> Variation_114:
        ...

    @overload
    def get_item(self, name : Literal['DSAM']) -> Variation_115:
        ...

    @overload
    def get_item(self, name : Literal['DBPSMARR']) -> Variation_116:
        ...

    @overload
    def get_item(self, name : Literal['DBPSMDEP']) -> Variation_117:
        ...

    @overload
    def get_item(self, name : Literal['DBPSMTL']) -> Variation_118:
        ...

    @overload
    def get_item(self, name : Literal['VRAMCRM']) -> Variation_119:
        ...

    @overload
    def get_item(self, name : Literal['VRAMVTM']) -> Variation_120:
        ...

    @overload
    def get_item(self, name : Literal['VRAMVRM']) -> Variation_121:
        ...

    @overload
    def get_item(self, name : Literal['HAMHD']) -> Variation_122:
        ...

    @overload
    def get_item(self, name : Literal['HAMRD']) -> Variation_123:
        ...

    @overload
    def get_item(self, name : Literal['HAMVD']) -> Variation_124:
        ...

    @overload
    def get_item(self, name : Literal['HVI']) -> Variation_125:
        ...

    @overload
    def get_item(self, name : Literal['LTW']) -> Variation_126:
        ...

    @overload
    def get_item(self, name : Literal['VPM']) -> Variation_127:
        ...

    @overload
    def get_item(self, name : Literal['TTA']) -> Variation_128:
        ...

    @overload
    def get_item(self, name : Literal['CRA']) -> Variation_129:
        ...

    @overload
    def get_item(self, name : Literal['ASM']) -> Variation_130:
        ...

    @overload
    def get_item(self, name : Literal['IAVM']) -> Variation_131:
        ...

    @overload
    def get_item(self, name : Literal['FTD']) -> Variation_132:
        ...

    @overload
    def get_item(self, name : Literal['ITD']) -> Variation_133:
        ...

    @overload
    def get_item(self, name : Literal['IIA']) -> Variation_134:
        ...

    @overload
    def get_item(self, name : Literal['SQW']) -> Variation_135:
        ...

    @overload
    def get_item(self, name : Literal['CUW']) -> Variation_136:
        ...

    @overload
    def get_item(self, name : Literal['CATC']) -> Variation_137:
        ...

    @overload
    def get_item(self, name : Literal['NOCLR']) -> Variation_138:
        ...

    @overload
    def get_item(self, name : Literal['NOMOV']) -> Variation_139:
        ...

    @overload
    def get_item(self, name : Literal['NOH']) -> Variation_140:
        ...

    @overload
    def get_item(self, name : Literal['WRTY']) -> Variation_141:
        ...

    @overload
    def get_item(self, name : Literal['STOCC']) -> Variation_142:
        ...

    @overload
    def get_item(self, name : Literal['ONGOING']) -> Variation_143:
        ...

    def get_item(self, name : Union[Literal['MRVA'], Literal['RAMLD'], Literal['RAMHD'], Literal['MSAW'], Literal['APW'], Literal['CLAM'], Literal['STCA'], Literal['APM'], Literal['RIMCA'], Literal['ACASRA'], Literal['NTCA'], Literal['DG'], Literal['OF'], Literal['OL'], Literal['AIW'], Literal['PAIW'], Literal['OCAT'], Literal['SAM'], Literal['VCD'], Literal['CHAM'], Literal['DSAM'], Literal['DBPSMARR'], Literal['DBPSMDEP'], Literal['DBPSMTL'], Literal['VRAMCRM'], Literal['VRAMVTM'], Literal['VRAMVRM'], Literal['HAMHD'], Literal['HAMRD'], Literal['HAMVD'], Literal['HVI'], Literal['LTW'], Literal['VPM'], Literal['TTA'], Literal['CRA'], Literal['ASM'], Literal['IAVM'], Literal['FTD'], Literal['ITD'], Literal['IIA'], Literal['SQW'], Literal['CUW'], Literal['CATC'], Literal['NOCLR'], Literal['NOMOV'], Literal['NOH'], Literal['WRTY'], Literal['STOCC'], Literal['ONGOING']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MRVA'], val : Union[Variation_95, Variation_95_Arg]) -> 'Variation_144':
        ...

    @overload
    def set_item(self, name : Literal['RAMLD'], val : Union[Variation_96, Variation_96_Arg]) -> 'Variation_144':
        ...

    @overload
    def set_item(self, name : Literal['RAMHD'], val : Union[Variation_97, Variation_97_Arg]) -> 'Variation_144':
        ...

    @overload
    def set_item(self, name : Literal['MSAW'], val : Union[Variation_98, Variation_98_Arg]) -> 'Variation_144':
        ...

    @overload
    def set_item(self, name : Literal['APW'], val : Union[Variation_99, Variation_99_Arg]) -> 'Variation_144':
        ...

    @overload
    def set_item(self, name : Literal['CLAM'], val : Union[Variation_100, Variation_100_Arg]) -> 'Variation_144':
        ...

    @overload
    def set_item(self, name : Literal['STCA'], val : Union[Variation_101, Variation_101_Arg]) -> 'Variation_144':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MRVA'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['RAMLD'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['RAMHD'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['MSAW'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['APW'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['CLAM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['STCA'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['APM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['RIMCA'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['ACASRA'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['NTCA'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['DG'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['OF'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['OL'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['AIW'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['PAIW'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['OCAT'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['SAM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['VCD'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['CHAM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['DSAM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['DBPSMARR'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['DBPSMDEP'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['DBPSMTL'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['VRAMCRM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['VRAMVTM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['VRAMVRM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['HAMHD'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['HAMRD'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['HAMVD'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['HVI'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['LTW'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['VPM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['TTA'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['CRA'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['ASM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['IAVM'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['FTD'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['ITD'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['IIA'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['SQW'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['CUW'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['CATC'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['NOCLR'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['NOMOV'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['NOH'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['WRTY'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['STOCC'], f : Any) -> 'Variation_144':
        ...

    @overload
    def modify_item(self, name : Literal['ONGOING'], f : Any) -> 'Variation_144':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_145_Arg : TypeAlias = Union[Raw,str]
class Variation_145(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 56
    string_type = StringAscii()

    def __init__(self, arg : Variation_145_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, str):
            super().__init__(self._from_string(arg)); return
        assert_never(arg)


    def to_string(self) -> str:
        return self._to_string()


Variation_146_Arg_Group = TypedDict('Variation_146_Arg_Group', {
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_146_Arg : TypeAlias = Union[Raw, Variation_146_Arg_Group]
class Variation_146(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MODE3A': ('Mode-3/A Code (Converted Into Octal Representation) of Aircraft 1 Involved in the Conflict', Variation_19, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['MODE3A']]) -> Union[Type['Variation_19']]:
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_146_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['MODE3A']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_146':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_146':
        return self._modify_item(name, f) # type: ignore

Variation_147_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_147(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 32
    quantity = Quantity('Signed', 5.364418029785156e-6, '°')

    def __init__(self, arg : Variation_147_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_148_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft']]]
class Variation_148(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 25.0, 'ft')

    def __init__(self, arg : Variation_148_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_149_Arg_Group = TypedDict('Variation_149_Arg_Group', {
    'LAT': Union[Variation_147, Variation_147_Arg],
    'LON': Union[Variation_147, Variation_147_Arg],
    'ALT': Union[Variation_148, Variation_148_Arg],
})
Variation_149_Arg : TypeAlias = Union[Raw, Variation_149_Arg_Group]
class Variation_149(Group):
    variation = 'Group'

    bit_size = 80

    subitems_list = [
        ('LAT', Variation_147),
        ('LON', Variation_147),
        ('ALT', Variation_148),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('In WGS-84 in Two’s Complement', Variation_147, 0, 32),
        'LON': ('In WGS-84 in Two’s Complement', Variation_147, 32, 32),
        'ALT': ('Altitude of Predicted Conflict', Variation_148, 64, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_147]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_147]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_148]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON'], Literal['ALT']]) -> Union[Type['Variation_147'], Type['Variation_147'], Type['Variation_148']]:
        if key == 'LAT':
            return Variation_147
        if key == 'LON':
            return Variation_147
        if key == 'ALT':
            return Variation_148
        assert_never(key)

    def __init__(self, arg : Variation_149_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_147:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_147:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_148:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON'], Literal['ALT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_147, Variation_147_Arg]) -> 'Variation_149':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_147, Variation_147_Arg]) -> 'Variation_149':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_148, Variation_148_Arg]) -> 'Variation_149':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_149':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_149':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_149':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_150_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_150(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Signed', 0.5, 'm')

    def __init__(self, arg : Variation_150_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_151_Arg_Group = TypedDict('Variation_151_Arg_Group', {
    'X': Union[Variation_150, Variation_150_Arg],
    'Y': Union[Variation_150, Variation_150_Arg],
    'Z': Union[Variation_148, Variation_148_Arg],
})
Variation_151_Arg : TypeAlias = Union[Raw, Variation_151_Arg_Group]
class Variation_151(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('X', Variation_150),
        ('Y', Variation_150),
        ('Z', Variation_148),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('Starting X-position of the Conflict', Variation_150, 0, 24),
        'Y': ('Starting Y-position of the Conflict', Variation_150, 24, 24),
        'Z': ('Starting Z-position of the Conflict', Variation_148, 48, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_150]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_150]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Z']) -> Type[Variation_148]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y'], Literal['Z']]) -> Union[Type['Variation_150'], Type['Variation_150'], Type['Variation_148']]:
        if key == 'X':
            return Variation_150
        if key == 'Y':
            return Variation_150
        if key == 'Z':
            return Variation_148
        assert_never(key)

    def __init__(self, arg : Variation_151_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_150:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_150:
        ...

    @overload
    def get_item(self, name : Literal['Z']) -> Variation_148:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y'], Literal['Z']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_150, Variation_150_Arg]) -> 'Variation_151':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_150, Variation_150_Arg]) -> 'Variation_151':
        ...

    @overload
    def set_item(self, name : Literal['Z'], val : Union[Variation_148, Variation_148_Arg]) -> 'Variation_151':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_151':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_151':
        ...

    @overload
    def modify_item(self, name : Literal['Z'], f : Any) -> 'Variation_151':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_152_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_152(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 0.5, 'm')

    def __init__(self, arg : Variation_152_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_153_Arg : TypeAlias = Raw
class Variation_153(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'General Air Traffic',
        2: 'Operational Air Traffic',
        3: 'Not applicable',
    }

    def __init__(self, arg : Variation_153_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_154_Arg : TypeAlias = Raw
class Variation_154(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'Instrument Flight Rules',
        1: 'Visual Flight rules',
        2: 'Not applicable',
        3: 'Controlled Visual Flight Rules',
    }

    def __init__(self, arg : Variation_154_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_155_Arg : TypeAlias = Raw
class Variation_155(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Approved',
        2: 'Exempt',
        3: 'Not Approved',
    }

    def __init__(self, arg : Variation_155_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_156_Arg : TypeAlias = Raw
class Variation_156(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Normal Priority Flight',
        1: 'High Priority Flight',
    }

    def __init__(self, arg : Variation_156_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_157_Arg : TypeAlias = Raw
class Variation_157(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Maintaining',
        1: 'Climbing',
        2: 'Descending',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_157_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_158_Arg : TypeAlias = Raw
class Variation_158(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Non primary target',
        1: 'Primary target',
    }

    def __init__(self, arg : Variation_158_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_159_Arg : TypeAlias = Raw
class Variation_159(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Ground Vehicle',
    }

    def __init__(self, arg : Variation_159_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_160_Arg_Group_1 = TypedDict('Variation_160_Arg_Group_1', {
    'GATOAT': Union[Variation_153, Variation_153_Arg],
    'FR1FR2': Union[Variation_154, Variation_154_Arg],
    'RVSM': Union[Variation_155, Variation_155_Arg],
    'HPR': Union[Variation_156, Variation_156_Arg],
})
Variation_160_Arg_Group_2 = TypedDict('Variation_160_Arg_Group_2', {
    'GATOAT': Union[Variation_153, Variation_153_Arg],
    'FR1FR2': Union[Variation_154, Variation_154_Arg],
    'RVSM': Union[Variation_155, Variation_155_Arg],
    'HPR': Union[Variation_156, Variation_156_Arg],
    'CDM': Union[Variation_157, Variation_157_Arg],
    'PRI': Union[Variation_158, Variation_158_Arg],
    'GV': Union[Variation_159, Variation_159_Arg],
})
Variation_160_Arg : TypeAlias = Union[
    int,
    Variation_160_Arg_Group_1,
    Tuple[int],
    Variation_160_Arg_Group_2,
    Tuple[int,int],
]
class Variation_160(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('GATOAT', Variation_153),
            ('FR1FR2', Variation_154),
            ('RVSM', Variation_155),
            ('HPR', Variation_156),
        ],
        [
            ('CDM', Variation_157),
            ('PRI', Variation_158),
            ('GV', Variation_159),
            Spare(4, 3),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'GATOAT': ('Identification of Conflict Categories Definition Table', Variation_153, 0, 2),
        'FR1FR2': ('Flight Rules', Variation_154, 2, 2),
        'RVSM': ('', Variation_155, 4, 2),
        'HPR': ('', Variation_156, 6, 1),
        'CDM': ('Climbing/Descending Mode', Variation_157, 0, 2),
        'PRI': ('', Variation_158, 2, 1),
        'GV': ('', Variation_159, 3, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['GATOAT']) -> Type[Variation_153]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FR1FR2']) -> Type[Variation_154]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RVSM']) -> Type[Variation_155]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HPR']) -> Type[Variation_156]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CDM']) -> Type[Variation_157]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PRI']) -> Type[Variation_158]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GV']) -> Type[Variation_159]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['RVSM'], Literal['HPR'], Literal['CDM'], Literal['PRI'], Literal['GV']]) -> Union[Type['Variation_153'], Type['Variation_154'], Type['Variation_155'], Type['Variation_156'], Type['Variation_157'], Type['Variation_158'], Type['Variation_159']]:
        if key == 'GATOAT':
            return Variation_153
        if key == 'FR1FR2':
            return Variation_154
        if key == 'RVSM':
            return Variation_155
        if key == 'HPR':
            return Variation_156
        if key == 'CDM':
            return Variation_157
        if key == 'PRI':
            return Variation_158
        if key == 'GV':
            return Variation_159
        assert_never(key)

    def __init__(self, arg : Variation_160_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_160_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_160_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['GATOAT']) -> Variation_153:
        ...

    @overload
    def get_item(self, name : Literal['FR1FR2']) -> Variation_154:
        ...

    @overload
    def get_item(self, name : Literal['RVSM']) -> Variation_155:
        ...

    @overload
    def get_item(self, name : Literal['HPR']) -> Variation_156:
        ...

    @overload
    def get_item(self, name : Literal['CDM']) -> Variation_157:
        ...

    @overload
    def get_item(self, name : Literal['PRI']) -> Variation_158:
        ...

    @overload
    def get_item(self, name : Literal['GV']) -> Variation_159:
        ...

    def get_item(self, name : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['RVSM'], Literal['HPR'], Literal['CDM'], Literal['PRI'], Literal['GV']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['GATOAT'], val : Union[Variation_153, Variation_153_Arg]) -> 'Variation_160':
        ...

    @overload
    def set_item(self, name : Literal['FR1FR2'], val : Union[Variation_154, Variation_154_Arg]) -> 'Variation_160':
        ...

    @overload
    def set_item(self, name : Literal['RVSM'], val : Union[Variation_155, Variation_155_Arg]) -> 'Variation_160':
        ...

    @overload
    def set_item(self, name : Literal['HPR'], val : Union[Variation_156, Variation_156_Arg]) -> 'Variation_160':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['GATOAT'], f : Any) -> 'Variation_160':
        ...

    @overload
    def modify_item(self, name : Literal['FR1FR2'], f : Any) -> 'Variation_160':
        ...

    @overload
    def modify_item(self, name : Literal['RVSM'], f : Any) -> 'Variation_160':
        ...

    @overload
    def modify_item(self, name : Literal['HPR'], f : Any) -> 'Variation_160':
        ...

    @overload
    def modify_item(self, name : Literal['CDM'], f : Any) -> 'Variation_160':
        ...

    @overload
    def modify_item(self, name : Literal['PRI'], f : Any) -> 'Variation_160':
        ...

    @overload
    def modify_item(self, name : Literal['GV'], f : Any) -> 'Variation_160':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_161_Arg : TypeAlias = Union[Raw,str]
class Variation_161(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 48
    string_type = StringAscii()

    def __init__(self, arg : Variation_161_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, str):
            super().__init__(self._from_string(arg)); return
        assert_never(arg)


    def to_string(self) -> str:
        return self._to_string()


Variation_162_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['']]]
class Variation_162(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 27
    quantity = Quantity('Unsigned', 1.0, '')

    def __init__(self, arg : Variation_162_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_163_Arg_Group = TypedDict('Variation_163_Arg_Group', {
    'NBR': Union[Variation_162, Variation_162_Arg],
})
Variation_163_Arg : TypeAlias = Union[Raw, Variation_163_Arg_Group]
class Variation_163(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        Spare(0, 5),
        ('NBR', Variation_162),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NBR': ('', Variation_162, 5, 27),
    }


    @classmethod
    def spec(cls, key : Union[Literal['NBR']]) -> Union[Type['Variation_162']]:
        if key == 'NBR':
            return Variation_162
        assert_never(key)

    def __init__(self, arg : Variation_163_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['NBR']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['NBR'], val : Union[Variation_162, Variation_162_Arg]) -> 'Variation_163':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['NBR'], f : Any) -> 'Variation_163':
        return self._modify_item(name, f) # type: ignore

Variation_164_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['FL']]]
class Variation_164(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 0.25, 'FL')

    def __init__(self, arg : Variation_164_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_165_Arg = TypedDict('Variation_165_Arg', {
    'AI1': Union[Variation_145, Variation_145_Arg],
    'M31': Union[Variation_146, Variation_146_Arg],
    'CPW': Union[Variation_149, Variation_149_Arg],
    'CPC': Union[Variation_151, Variation_151_Arg],
    'TT1': Union[Variation_80, Variation_80_Arg],
    'DT1': Union[Variation_152, Variation_152_Arg],
    'AC1': Union[Variation_160, Variation_160_Arg],
    'MS1': Union[Variation_161, Variation_161_Arg],
    'FP1': Union[Variation_163, Variation_163_Arg],
    'CF1': Union[Variation_164, Variation_164_Arg],
}, total=False)
class Variation_165(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('AI1', Variation_145),
        ('M31', Variation_146),
        ('CPW', Variation_149),
        ('CPC', Variation_151),
        ('TT1', Variation_80),
        ('DT1', Variation_152),
        ('AC1', Variation_160),
        ('MS1', Variation_161),
        ('FP1', Variation_163),
        ('CF1', Variation_164),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'AI1': ('Aircraft Identifier (in 7 Characters) of Aircraft 1 Involved in the Conflict', Variation_145, 0x8000),
        'M31': ('Mode 3/A Code Aircraft 1', Variation_146, 0x4000),
        'CPW': ('Predicted Conflict Position Target 1 in WGS-84 Coordinates', Variation_149, 0x2000),
        'CPC': ('Predicted Conflict Position for the Aircraft 1 Involved in the Conflict', Variation_151, 0x1000),
        'TT1': ('Time to Runway Threshold for First Approaching Aircraft in a RIMCA', Variation_80, 0x0800),
        'DT1': ('Distance to Runway Threshold for Aircraft 1 Involved in a RIMCA', Variation_152, 0x0400),
        'AC1': ('Characteristics of Aircraft 1 Involved in the Conflict', Variation_160, 0x0200),
        'MS1': ('Aircraft Identification Downloaded from Aircraft 1 Involved in the Conflict If Equipped with a Mode-S Transponder', Variation_161, 0x0180),
        'FP1': ('Number of the Flight Plan Correlated to Aircraft 1 Involved in the Conflict', Variation_163, 0x0140),
        'CF1': ('Cleared Flight Level for Aircraft 1 Involved in the Conflict', Variation_164, 0x0120),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AI1']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M31']) -> Type[Variation_146]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CPW']) -> Type[Variation_149]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CPC']) -> Type[Variation_151]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TT1']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DT1']) -> Type[Variation_152]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AC1']) -> Type[Variation_160]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MS1']) -> Type[Variation_161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FP1']) -> Type[Variation_163]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CF1']) -> Type[Variation_164]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AI1'], Literal['M31'], Literal['CPW'], Literal['CPC'], Literal['TT1'], Literal['DT1'], Literal['AC1'], Literal['MS1'], Literal['FP1'], Literal['CF1']]) -> Union[Type['Variation_145'], Type['Variation_146'], Type['Variation_149'], Type['Variation_151'], Type['Variation_80'], Type['Variation_152'], Type['Variation_160'], Type['Variation_161'], Type['Variation_163'], Type['Variation_164']]:
        if key == 'AI1':
            return Variation_145
        if key == 'M31':
            return Variation_146
        if key == 'CPW':
            return Variation_149
        if key == 'CPC':
            return Variation_151
        if key == 'TT1':
            return Variation_80
        if key == 'DT1':
            return Variation_152
        if key == 'AC1':
            return Variation_160
        if key == 'MS1':
            return Variation_161
        if key == 'FP1':
            return Variation_163
        if key == 'CF1':
            return Variation_164
        assert_never(key)

    def __init__(self, arg : Optional[Variation_165_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['AI1'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_165':
        ...

    @overload
    def set_item(self, name : Literal['M31'], val : Union[Variation_146, Variation_146_Arg]) -> 'Variation_165':
        ...

    @overload
    def set_item(self, name : Literal['CPW'], val : Union[Variation_149, Variation_149_Arg]) -> 'Variation_165':
        ...

    @overload
    def set_item(self, name : Literal['CPC'], val : Union[Variation_151, Variation_151_Arg]) -> 'Variation_165':
        ...

    @overload
    def set_item(self, name : Literal['TT1'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_165':
        ...

    @overload
    def set_item(self, name : Literal['DT1'], val : Union[Variation_152, Variation_152_Arg]) -> 'Variation_165':
        ...

    @overload
    def set_item(self, name : Literal['AC1'], val : Union[Variation_160, Variation_160_Arg]) -> 'Variation_165':
        ...

    @overload
    def set_item(self, name : Literal['MS1'], val : Union[Variation_161, Variation_161_Arg]) -> 'Variation_165':
        ...

    @overload
    def set_item(self, name : Literal['FP1'], val : Union[Variation_163, Variation_163_Arg]) -> 'Variation_165':
        ...

    @overload
    def set_item(self, name : Literal['CF1'], val : Union[Variation_164, Variation_164_Arg]) -> 'Variation_165':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['AI1']) -> 'Variation_165':
        ...

    @overload
    def del_item(self, name : Literal['M31']) -> 'Variation_165':
        ...

    @overload
    def del_item(self, name : Literal['CPW']) -> 'Variation_165':
        ...

    @overload
    def del_item(self, name : Literal['CPC']) -> 'Variation_165':
        ...

    @overload
    def del_item(self, name : Literal['TT1']) -> 'Variation_165':
        ...

    @overload
    def del_item(self, name : Literal['DT1']) -> 'Variation_165':
        ...

    @overload
    def del_item(self, name : Literal['AC1']) -> 'Variation_165':
        ...

    @overload
    def del_item(self, name : Literal['MS1']) -> 'Variation_165':
        ...

    @overload
    def del_item(self, name : Literal['FP1']) -> 'Variation_165':
        ...

    @overload
    def del_item(self, name : Literal['CF1']) -> 'Variation_165':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['AI1']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['M31']) -> Variation_146:
        ...

    @overload
    def get_item(self, name : Literal['CPW']) -> Variation_149:
        ...

    @overload
    def get_item(self, name : Literal['CPC']) -> Variation_151:
        ...

    @overload
    def get_item(self, name : Literal['TT1']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['DT1']) -> Variation_152:
        ...

    @overload
    def get_item(self, name : Literal['AC1']) -> Variation_160:
        ...

    @overload
    def get_item(self, name : Literal['MS1']) -> Variation_161:
        ...

    @overload
    def get_item(self, name : Literal['FP1']) -> Variation_163:
        ...

    @overload
    def get_item(self, name : Literal['CF1']) -> Variation_164:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['AI1'], f : Any) -> 'Variation_165':
        ...

    @overload
    def modify_item(self, name : Literal['M31'], f : Any) -> 'Variation_165':
        ...

    @overload
    def modify_item(self, name : Literal['CPW'], f : Any) -> 'Variation_165':
        ...

    @overload
    def modify_item(self, name : Literal['CPC'], f : Any) -> 'Variation_165':
        ...

    @overload
    def modify_item(self, name : Literal['TT1'], f : Any) -> 'Variation_165':
        ...

    @overload
    def modify_item(self, name : Literal['DT1'], f : Any) -> 'Variation_165':
        ...

    @overload
    def modify_item(self, name : Literal['AC1'], f : Any) -> 'Variation_165':
        ...

    @overload
    def modify_item(self, name : Literal['MS1'], f : Any) -> 'Variation_165':
        ...

    @overload
    def modify_item(self, name : Literal['FP1'], f : Any) -> 'Variation_165':
        ...

    @overload
    def modify_item(self, name : Literal['CF1'], f : Any) -> 'Variation_165':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_166_Arg : TypeAlias = Raw
class Variation_166(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Conflict not predicted to occur in military airspace',
        1: 'Conflict predicted to occur in military airspace',
    }

    def __init__(self, arg : Variation_166_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_167_Arg : TypeAlias = Raw
class Variation_167(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Conflict not predicted to occur in civil airspace',
        1: 'Conflict predicted to occur in civil airspace',
    }

    def __init__(self, arg : Variation_167_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_168_Arg : TypeAlias = Raw
class Variation_168(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Aircraft are not fast diverging laterally at current time',
        1: 'Aircraft are fast diverging laterally at current time',
    }

    def __init__(self, arg : Variation_168_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_169_Arg : TypeAlias = Raw
class Variation_169(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Aircraft are not fast diverging vertically at current time',
        1: 'Aircraft are fast diverging vertically at current time',
    }

    def __init__(self, arg : Variation_169_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_170_Arg : TypeAlias = Raw
class Variation_170(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Minor separation infringement',
        1: 'Major separation infringement',
    }

    def __init__(self, arg : Variation_170_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_171_Arg : TypeAlias = Raw
class Variation_171(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Aircraft have not crossed at starting time of conflict',
        1: 'Aircraft have crossed at starting time of conflict',
    }

    def __init__(self, arg : Variation_171_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_172_Arg : TypeAlias = Raw
class Variation_172(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Aircraft are not diverging at starting time of conflict',
        1: 'Aircraft are diverging at starting time of conflict',
    }

    def __init__(self, arg : Variation_172_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_173_Arg : TypeAlias = Raw
class Variation_173(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Runway/Runway Crossing',
    }

    def __init__(self, arg : Variation_173_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_174_Arg : TypeAlias = Raw
class Variation_174(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Runway/Taxiway Crossing',
    }

    def __init__(self, arg : Variation_174_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_175_Arg : TypeAlias = Raw
class Variation_175(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 4 (MSAW) indicates MRVA',
    }

    def __init__(self, arg : Variation_175_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_176_Arg : TypeAlias = Raw
class Variation_176(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 25 (VRAM) indicates CRM',
    }

    def __init__(self, arg : Variation_176_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_177_Arg : TypeAlias = Raw
class Variation_177(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 25 (VRAM) indicates VRM',
    }

    def __init__(self, arg : Variation_177_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_178_Arg : TypeAlias = Raw
class Variation_178(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 25 (VRAM) indicates VTM',
    }

    def __init__(self, arg : Variation_178_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_179_Arg : TypeAlias = Raw
class Variation_179(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 29 (HAM) indicates HD',
    }

    def __init__(self, arg : Variation_179_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_180_Arg : TypeAlias = Raw
class Variation_180(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 29 (HAM) indicates RD',
    }

    def __init__(self, arg : Variation_180_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_181_Arg : TypeAlias = Raw
class Variation_181(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 29 (HAM) indicates VD',
    }

    def __init__(self, arg : Variation_181_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_182_Arg : TypeAlias = Raw
class Variation_182(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 20 (DBPSM) indicates ARR',
    }

    def __init__(self, arg : Variation_182_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_183_Arg : TypeAlias = Raw
class Variation_183(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 20 (DBPSM) indicates DEP',
    }

    def __init__(self, arg : Variation_183_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_184_Arg : TypeAlias = Raw
class Variation_184(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 20 (DBPSM) indicates above TL',
    }

    def __init__(self, arg : Variation_184_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_185_Arg : TypeAlias = Raw
class Variation_185(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Msg Type 99 (AIW) indicates pAIW Alert',
    }

    def __init__(self, arg : Variation_185_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_186_Arg_Group_1 = TypedDict('Variation_186_Arg_Group_1', {
    'MAS': Union[Variation_166, Variation_166_Arg],
    'CAS': Union[Variation_167, Variation_167_Arg],
    'FLD': Union[Variation_168, Variation_168_Arg],
    'FVD': Union[Variation_169, Variation_169_Arg],
    'TYPE': Union[Variation_170, Variation_170_Arg],
    'CROSS': Union[Variation_171, Variation_171_Arg],
    'DIV': Union[Variation_172, Variation_172_Arg],
})
Variation_186_Arg_Group_2 = TypedDict('Variation_186_Arg_Group_2', {
    'MAS': Union[Variation_166, Variation_166_Arg],
    'CAS': Union[Variation_167, Variation_167_Arg],
    'FLD': Union[Variation_168, Variation_168_Arg],
    'FVD': Union[Variation_169, Variation_169_Arg],
    'TYPE': Union[Variation_170, Variation_170_Arg],
    'CROSS': Union[Variation_171, Variation_171_Arg],
    'DIV': Union[Variation_172, Variation_172_Arg],
    'RRC': Union[Variation_173, Variation_173_Arg],
    'RTC': Union[Variation_174, Variation_174_Arg],
    'MRVA': Union[Variation_175, Variation_175_Arg],
    'VRAMCRM': Union[Variation_176, Variation_176_Arg],
    'VRAMVRM': Union[Variation_177, Variation_177_Arg],
    'VRAMVTM': Union[Variation_178, Variation_178_Arg],
    'HAMHD': Union[Variation_179, Variation_179_Arg],
})
Variation_186_Arg_Group_3 = TypedDict('Variation_186_Arg_Group_3', {
    'MAS': Union[Variation_166, Variation_166_Arg],
    'CAS': Union[Variation_167, Variation_167_Arg],
    'FLD': Union[Variation_168, Variation_168_Arg],
    'FVD': Union[Variation_169, Variation_169_Arg],
    'TYPE': Union[Variation_170, Variation_170_Arg],
    'CROSS': Union[Variation_171, Variation_171_Arg],
    'DIV': Union[Variation_172, Variation_172_Arg],
    'RRC': Union[Variation_173, Variation_173_Arg],
    'RTC': Union[Variation_174, Variation_174_Arg],
    'MRVA': Union[Variation_175, Variation_175_Arg],
    'VRAMCRM': Union[Variation_176, Variation_176_Arg],
    'VRAMVRM': Union[Variation_177, Variation_177_Arg],
    'VRAMVTM': Union[Variation_178, Variation_178_Arg],
    'HAMHD': Union[Variation_179, Variation_179_Arg],
    'HAMRD': Union[Variation_180, Variation_180_Arg],
    'HAMVD': Union[Variation_181, Variation_181_Arg],
    'DBPSMARR': Union[Variation_182, Variation_182_Arg],
    'DBPSMDEP': Union[Variation_183, Variation_183_Arg],
    'DBPSMTL': Union[Variation_184, Variation_184_Arg],
    'AIW': Union[Variation_185, Variation_185_Arg],
})
Variation_186_Arg : TypeAlias = Union[
    int,
    Variation_186_Arg_Group_1,
    Tuple[int],
    Variation_186_Arg_Group_2,
    Tuple[int,int],
    Variation_186_Arg_Group_3,
    Tuple[int,int,int],
]
class Variation_186(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('MAS', Variation_166),
            ('CAS', Variation_167),
            ('FLD', Variation_168),
            ('FVD', Variation_169),
            ('TYPE', Variation_170),
            ('CROSS', Variation_171),
            ('DIV', Variation_172),
        ],
        [
            ('RRC', Variation_173),
            ('RTC', Variation_174),
            ('MRVA', Variation_175),
            ('VRAMCRM', Variation_176),
            ('VRAMVRM', Variation_177),
            ('VRAMVTM', Variation_178),
            ('HAMHD', Variation_179),
        ],
        [
            ('HAMRD', Variation_180),
            ('HAMVD', Variation_181),
            ('DBPSMARR', Variation_182),
            ('DBPSMDEP', Variation_183),
            ('DBPSMTL', Variation_184),
            ('AIW', Variation_185),
            Spare(6, 1),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MAS': ('Conflict Location in Military Airspace', Variation_166, 0, 1),
        'CAS': ('Conflict Location in Civil Airspace', Variation_167, 1, 1),
        'FLD': ('Fast Lateral Divergence', Variation_168, 2, 1),
        'FVD': ('Fast Vertical Divergence', Variation_169, 3, 1),
        'TYPE': ('Type of Separation Infringement', Variation_170, 4, 1),
        'CROSS': ('Crossing Test', Variation_171, 5, 1),
        'DIV': ('Divergence Test', Variation_172, 6, 1),
        'RRC': ('Runway/Runway Crossing in RIMCAS', Variation_173, 0, 1),
        'RTC': ('Runway/Taxiway Crossing in RIMCAS', Variation_174, 1, 1),
        'MRVA': ('', Variation_175, 2, 1),
        'VRAMCRM': ('', Variation_176, 3, 1),
        'VRAMVRM': ('', Variation_177, 4, 1),
        'VRAMVTM': ('', Variation_178, 5, 1),
        'HAMHD': ('', Variation_179, 6, 1),
        'HAMRD': ('', Variation_180, 0, 1),
        'HAMVD': ('', Variation_181, 1, 1),
        'DBPSMARR': ('', Variation_182, 2, 1),
        'DBPSMDEP': ('', Variation_183, 3, 1),
        'DBPSMTL': ('', Variation_184, 4, 1),
        'AIW': ('', Variation_185, 5, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MAS']) -> Type[Variation_166]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CAS']) -> Type[Variation_167]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FLD']) -> Type[Variation_168]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FVD']) -> Type[Variation_169]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TYPE']) -> Type[Variation_170]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CROSS']) -> Type[Variation_171]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DIV']) -> Type[Variation_172]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RRC']) -> Type[Variation_173]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RTC']) -> Type[Variation_174]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MRVA']) -> Type[Variation_175]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VRAMCRM']) -> Type[Variation_176]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VRAMVRM']) -> Type[Variation_177]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VRAMVTM']) -> Type[Variation_178]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HAMHD']) -> Type[Variation_179]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HAMRD']) -> Type[Variation_180]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HAMVD']) -> Type[Variation_181]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DBPSMARR']) -> Type[Variation_182]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DBPSMDEP']) -> Type[Variation_183]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DBPSMTL']) -> Type[Variation_184]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AIW']) -> Type[Variation_185]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MAS'], Literal['CAS'], Literal['FLD'], Literal['FVD'], Literal['TYPE'], Literal['CROSS'], Literal['DIV'], Literal['RRC'], Literal['RTC'], Literal['MRVA'], Literal['VRAMCRM'], Literal['VRAMVRM'], Literal['VRAMVTM'], Literal['HAMHD'], Literal['HAMRD'], Literal['HAMVD'], Literal['DBPSMARR'], Literal['DBPSMDEP'], Literal['DBPSMTL'], Literal['AIW']]) -> Union[Type['Variation_166'], Type['Variation_167'], Type['Variation_168'], Type['Variation_169'], Type['Variation_170'], Type['Variation_171'], Type['Variation_172'], Type['Variation_173'], Type['Variation_174'], Type['Variation_175'], Type['Variation_176'], Type['Variation_177'], Type['Variation_178'], Type['Variation_179'], Type['Variation_180'], Type['Variation_181'], Type['Variation_182'], Type['Variation_183'], Type['Variation_184'], Type['Variation_185']]:
        if key == 'MAS':
            return Variation_166
        if key == 'CAS':
            return Variation_167
        if key == 'FLD':
            return Variation_168
        if key == 'FVD':
            return Variation_169
        if key == 'TYPE':
            return Variation_170
        if key == 'CROSS':
            return Variation_171
        if key == 'DIV':
            return Variation_172
        if key == 'RRC':
            return Variation_173
        if key == 'RTC':
            return Variation_174
        if key == 'MRVA':
            return Variation_175
        if key == 'VRAMCRM':
            return Variation_176
        if key == 'VRAMVRM':
            return Variation_177
        if key == 'VRAMVTM':
            return Variation_178
        if key == 'HAMHD':
            return Variation_179
        if key == 'HAMRD':
            return Variation_180
        if key == 'HAMVD':
            return Variation_181
        if key == 'DBPSMARR':
            return Variation_182
        if key == 'DBPSMDEP':
            return Variation_183
        if key == 'DBPSMTL':
            return Variation_184
        if key == 'AIW':
            return Variation_185
        assert_never(key)

    def __init__(self, arg : Variation_186_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_186_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_186_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_186_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MAS']) -> Variation_166:
        ...

    @overload
    def get_item(self, name : Literal['CAS']) -> Variation_167:
        ...

    @overload
    def get_item(self, name : Literal['FLD']) -> Variation_168:
        ...

    @overload
    def get_item(self, name : Literal['FVD']) -> Variation_169:
        ...

    @overload
    def get_item(self, name : Literal['TYPE']) -> Variation_170:
        ...

    @overload
    def get_item(self, name : Literal['CROSS']) -> Variation_171:
        ...

    @overload
    def get_item(self, name : Literal['DIV']) -> Variation_172:
        ...

    @overload
    def get_item(self, name : Literal['RRC']) -> Variation_173:
        ...

    @overload
    def get_item(self, name : Literal['RTC']) -> Variation_174:
        ...

    @overload
    def get_item(self, name : Literal['MRVA']) -> Variation_175:
        ...

    @overload
    def get_item(self, name : Literal['VRAMCRM']) -> Variation_176:
        ...

    @overload
    def get_item(self, name : Literal['VRAMVRM']) -> Variation_177:
        ...

    @overload
    def get_item(self, name : Literal['VRAMVTM']) -> Variation_178:
        ...

    @overload
    def get_item(self, name : Literal['HAMHD']) -> Variation_179:
        ...

    @overload
    def get_item(self, name : Literal['HAMRD']) -> Variation_180:
        ...

    @overload
    def get_item(self, name : Literal['HAMVD']) -> Variation_181:
        ...

    @overload
    def get_item(self, name : Literal['DBPSMARR']) -> Variation_182:
        ...

    @overload
    def get_item(self, name : Literal['DBPSMDEP']) -> Variation_183:
        ...

    @overload
    def get_item(self, name : Literal['DBPSMTL']) -> Variation_184:
        ...

    @overload
    def get_item(self, name : Literal['AIW']) -> Variation_185:
        ...

    def get_item(self, name : Union[Literal['MAS'], Literal['CAS'], Literal['FLD'], Literal['FVD'], Literal['TYPE'], Literal['CROSS'], Literal['DIV'], Literal['RRC'], Literal['RTC'], Literal['MRVA'], Literal['VRAMCRM'], Literal['VRAMVRM'], Literal['VRAMVTM'], Literal['HAMHD'], Literal['HAMRD'], Literal['HAMVD'], Literal['DBPSMARR'], Literal['DBPSMDEP'], Literal['DBPSMTL'], Literal['AIW']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MAS'], val : Union[Variation_166, Variation_166_Arg]) -> 'Variation_186':
        ...

    @overload
    def set_item(self, name : Literal['CAS'], val : Union[Variation_167, Variation_167_Arg]) -> 'Variation_186':
        ...

    @overload
    def set_item(self, name : Literal['FLD'], val : Union[Variation_168, Variation_168_Arg]) -> 'Variation_186':
        ...

    @overload
    def set_item(self, name : Literal['FVD'], val : Union[Variation_169, Variation_169_Arg]) -> 'Variation_186':
        ...

    @overload
    def set_item(self, name : Literal['TYPE'], val : Union[Variation_170, Variation_170_Arg]) -> 'Variation_186':
        ...

    @overload
    def set_item(self, name : Literal['CROSS'], val : Union[Variation_171, Variation_171_Arg]) -> 'Variation_186':
        ...

    @overload
    def set_item(self, name : Literal['DIV'], val : Union[Variation_172, Variation_172_Arg]) -> 'Variation_186':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MAS'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['CAS'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['FLD'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['FVD'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['TYPE'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['CROSS'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['DIV'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['RRC'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['RTC'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['MRVA'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['VRAMCRM'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['VRAMVRM'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['VRAMVTM'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['HAMHD'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['HAMRD'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['HAMVD'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['DBPSMARR'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['DBPSMDEP'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['DBPSMTL'], f : Any) -> 'Variation_186':
        ...

    @overload
    def modify_item(self, name : Literal['AIW'], f : Any) -> 'Variation_186':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_187_Arg : TypeAlias = Raw
class Variation_187(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 4

    def __init__(self, arg : Variation_187_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_188_Arg : TypeAlias = Raw
class Variation_188(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'LOW',
        1: 'HIGH',
    }

    def __init__(self, arg : Variation_188_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_189_Arg_Group = TypedDict('Variation_189_Arg_Group', {
    'TID': Union[Variation_187, Variation_187_Arg],
    'CPC': Union[Variation_93, Variation_93_Arg],
    'CS': Union[Variation_188, Variation_188_Arg],
})
Variation_189_Arg : TypeAlias = Union[Raw, Variation_189_Arg_Group]
class Variation_189(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('TID', Variation_187),
        ('CPC', Variation_93),
        ('CS', Variation_188),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TID': ('Identification of Conflict Categories Definition Table', Variation_187, 0, 4),
        'CPC': ('Conflict Properties Class', Variation_93, 4, 3),
        'CS': ('Conflict Severity', Variation_188, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CPC']) -> Type[Variation_93]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CS']) -> Type[Variation_188]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TID'], Literal['CPC'], Literal['CS']]) -> Union[Type['Variation_187'], Type['Variation_93'], Type['Variation_188']]:
        if key == 'TID':
            return Variation_187
        if key == 'CPC':
            return Variation_93
        if key == 'CS':
            return Variation_188
        assert_never(key)

    def __init__(self, arg : Variation_189_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['CPC']) -> Variation_93:
        ...

    @overload
    def get_item(self, name : Literal['CS']) -> Variation_188:
        ...

    def get_item(self, name : Union[Literal['TID'], Literal['CPC'], Literal['CS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_189':
        ...

    @overload
    def set_item(self, name : Literal['CPC'], val : Union[Variation_93, Variation_93_Arg]) -> 'Variation_189':
        ...

    @overload
    def set_item(self, name : Literal['CS'], val : Union[Variation_188, Variation_188_Arg]) -> 'Variation_189':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_189':
        ...

    @overload
    def modify_item(self, name : Literal['CPC'], f : Any) -> 'Variation_189':
        ...

    @overload
    def modify_item(self, name : Literal['CS'], f : Any) -> 'Variation_189':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_190_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['%']]]
class Variation_190(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 0.5, '%')

    def __init__(self, arg : Variation_190_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_191_Arg = TypedDict('Variation_191_Arg', {
    'CN': Union[Variation_186, Variation_186_Arg],
    'CC': Union[Variation_189, Variation_189_Arg],
    'CP': Union[Variation_190, Variation_190_Arg],
    'CD': Union[Variation_80, Variation_80_Arg],
}, total=False)
class Variation_191(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('CN', Variation_186),
        ('CC', Variation_189),
        ('CP', Variation_190),
        ('CD', Variation_80),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'CN': ('Conflict Nature', Variation_186, 0x80),
        'CC': ('Conflict Classification', Variation_189, 0x40),
        'CP': ('Conflict Probability', Variation_190, 0x20),
        'CD': ('Conflict Duration', Variation_80, 0x10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CN']) -> Type[Variation_186]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CC']) -> Type[Variation_189]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CP']) -> Type[Variation_190]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CD']) -> Type[Variation_80]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CN'], Literal['CC'], Literal['CP'], Literal['CD']]) -> Union[Type['Variation_186'], Type['Variation_189'], Type['Variation_190'], Type['Variation_80']]:
        if key == 'CN':
            return Variation_186
        if key == 'CC':
            return Variation_189
        if key == 'CP':
            return Variation_190
        if key == 'CD':
            return Variation_80
        assert_never(key)

    def __init__(self, arg : Optional[Variation_191_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['CN'], val : Union[Variation_186, Variation_186_Arg]) -> 'Variation_191':
        ...

    @overload
    def set_item(self, name : Literal['CC'], val : Union[Variation_189, Variation_189_Arg]) -> 'Variation_191':
        ...

    @overload
    def set_item(self, name : Literal['CP'], val : Union[Variation_190, Variation_190_Arg]) -> 'Variation_191':
        ...

    @overload
    def set_item(self, name : Literal['CD'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_191':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['CN']) -> 'Variation_191':
        ...

    @overload
    def del_item(self, name : Literal['CC']) -> 'Variation_191':
        ...

    @overload
    def del_item(self, name : Literal['CP']) -> 'Variation_191':
        ...

    @overload
    def del_item(self, name : Literal['CD']) -> 'Variation_191':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['CN']) -> Variation_186:
        ...

    @overload
    def get_item(self, name : Literal['CC']) -> Variation_189:
        ...

    @overload
    def get_item(self, name : Literal['CP']) -> Variation_190:
        ...

    @overload
    def get_item(self, name : Literal['CD']) -> Variation_80:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['CN'], f : Any) -> 'Variation_191':
        ...

    @overload
    def modify_item(self, name : Literal['CC'], f : Any) -> 'Variation_191':
        ...

    @overload
    def modify_item(self, name : Literal['CP'], f : Any) -> 'Variation_191':
        ...

    @overload
    def modify_item(self, name : Literal['CD'], f : Any) -> 'Variation_191':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_192_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_192(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Unsigned', 0.5, 'm')

    def __init__(self, arg : Variation_192_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_193_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft']]]
class Variation_193(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 25.0, 'ft')

    def __init__(self, arg : Variation_193_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_194_Arg = TypedDict('Variation_194_Arg', {
    'TC': Union[Variation_80, Variation_80_Arg],
    'TCA': Union[Variation_80, Variation_80_Arg],
    'CHS': Union[Variation_192, Variation_192_Arg],
    'MHS': Union[Variation_152, Variation_152_Arg],
    'CVS': Union[Variation_193, Variation_193_Arg],
    'MVS': Union[Variation_193, Variation_193_Arg],
}, total=False)
class Variation_194(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('TC', Variation_80),
        ('TCA', Variation_80),
        ('CHS', Variation_192),
        ('MHS', Variation_152),
        ('CVS', Variation_193),
        ('MVS', Variation_193),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'TC': ('Time to Conflict', Variation_80, 0x80),
        'TCA': ('Time to Closest Approach', Variation_80, 0x40),
        'CHS': ('Current Horizontal Separation', Variation_192, 0x20),
        'MHS': ('Estimated Minimum Horizontal Separation', Variation_152, 0x10),
        'CVS': ('Current Vertical Separation', Variation_193, 0x08),
        'MVS': ('Estimated Minimum Vertical Separation', Variation_193, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TC']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCA']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHS']) -> Type[Variation_192]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MHS']) -> Type[Variation_152]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CVS']) -> Type[Variation_193]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MVS']) -> Type[Variation_193]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TC'], Literal['TCA'], Literal['CHS'], Literal['MHS'], Literal['CVS'], Literal['MVS']]) -> Union[Type['Variation_80'], Type['Variation_80'], Type['Variation_192'], Type['Variation_152'], Type['Variation_193'], Type['Variation_193']]:
        if key == 'TC':
            return Variation_80
        if key == 'TCA':
            return Variation_80
        if key == 'CHS':
            return Variation_192
        if key == 'MHS':
            return Variation_152
        if key == 'CVS':
            return Variation_193
        if key == 'MVS':
            return Variation_193
        assert_never(key)

    def __init__(self, arg : Optional[Variation_194_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['TC'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_194':
        ...

    @overload
    def set_item(self, name : Literal['TCA'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_194':
        ...

    @overload
    def set_item(self, name : Literal['CHS'], val : Union[Variation_192, Variation_192_Arg]) -> 'Variation_194':
        ...

    @overload
    def set_item(self, name : Literal['MHS'], val : Union[Variation_152, Variation_152_Arg]) -> 'Variation_194':
        ...

    @overload
    def set_item(self, name : Literal['CVS'], val : Union[Variation_193, Variation_193_Arg]) -> 'Variation_194':
        ...

    @overload
    def set_item(self, name : Literal['MVS'], val : Union[Variation_193, Variation_193_Arg]) -> 'Variation_194':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['TC']) -> 'Variation_194':
        ...

    @overload
    def del_item(self, name : Literal['TCA']) -> 'Variation_194':
        ...

    @overload
    def del_item(self, name : Literal['CHS']) -> 'Variation_194':
        ...

    @overload
    def del_item(self, name : Literal['MHS']) -> 'Variation_194':
        ...

    @overload
    def del_item(self, name : Literal['CVS']) -> 'Variation_194':
        ...

    @overload
    def del_item(self, name : Literal['MVS']) -> 'Variation_194':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['TC']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['TCA']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['CHS']) -> Variation_192:
        ...

    @overload
    def get_item(self, name : Literal['MHS']) -> Variation_152:
        ...

    @overload
    def get_item(self, name : Literal['CVS']) -> Variation_193:
        ...

    @overload
    def get_item(self, name : Literal['MVS']) -> Variation_193:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['TC'], f : Any) -> 'Variation_194':
        ...

    @overload
    def modify_item(self, name : Literal['TCA'], f : Any) -> 'Variation_194':
        ...

    @overload
    def modify_item(self, name : Literal['CHS'], f : Any) -> 'Variation_194':
        ...

    @overload
    def modify_item(self, name : Literal['MHS'], f : Any) -> 'Variation_194':
        ...

    @overload
    def modify_item(self, name : Literal['CVS'], f : Any) -> 'Variation_194':
        ...

    @overload
    def modify_item(self, name : Literal['MVS'], f : Any) -> 'Variation_194':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_195_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_195(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 32.0, 'm')

    def __init__(self, arg : Variation_195_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_196_Arg : TypeAlias = Union[Raw,str]
class Variation_196(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 48
    string_type = StringICAO()

    def __init__(self, arg : Variation_196_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, str):
            super().__init__(self._from_string(arg)); return
        assert_never(arg)


    def to_string(self) -> str:
        return self._to_string()


Variation_197_Arg = TypedDict('Variation_197_Arg', {
    'AN': Union[Variation_196, Variation_196_Arg],
    'CAN': Union[Variation_145, Variation_145_Arg],
    'RT1': Union[Variation_145, Variation_145_Arg],
    'RT2': Union[Variation_145, Variation_145_Arg],
    'SB': Union[Variation_145, Variation_145_Arg],
    'G': Union[Variation_145, Variation_145_Arg],
}, total=False)
class Variation_197(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('AN', Variation_196),
        ('CAN', Variation_145),
        ('RT1', Variation_145),
        ('RT2', Variation_145),
        ('SB', Variation_145),
        ('G', Variation_145),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'AN': ('Area Name', Variation_196, 0x80),
        'CAN': ('Crossing Area Name', Variation_145, 0x40),
        'RT1': ('Runway/Taxiway Designator 1', Variation_145, 0x20),
        'RT2': ('Runway/Taxiway Designator 2', Variation_145, 0x10),
        'SB': ('Stop Bar Designator', Variation_145, 0x08),
        'G': ('Gate Designator', Variation_145, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AN']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CAN']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RT1']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RT2']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SB']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_145]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AN'], Literal['CAN'], Literal['RT1'], Literal['RT2'], Literal['SB'], Literal['G']]) -> Union[Type['Variation_196'], Type['Variation_145'], Type['Variation_145'], Type['Variation_145'], Type['Variation_145'], Type['Variation_145']]:
        if key == 'AN':
            return Variation_196
        if key == 'CAN':
            return Variation_145
        if key == 'RT1':
            return Variation_145
        if key == 'RT2':
            return Variation_145
        if key == 'SB':
            return Variation_145
        if key == 'G':
            return Variation_145
        assert_never(key)

    def __init__(self, arg : Optional[Variation_197_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['AN'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_197':
        ...

    @overload
    def set_item(self, name : Literal['CAN'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_197':
        ...

    @overload
    def set_item(self, name : Literal['RT1'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_197':
        ...

    @overload
    def set_item(self, name : Literal['RT2'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_197':
        ...

    @overload
    def set_item(self, name : Literal['SB'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_197':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_197':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['AN']) -> 'Variation_197':
        ...

    @overload
    def del_item(self, name : Literal['CAN']) -> 'Variation_197':
        ...

    @overload
    def del_item(self, name : Literal['RT1']) -> 'Variation_197':
        ...

    @overload
    def del_item(self, name : Literal['RT2']) -> 'Variation_197':
        ...

    @overload
    def del_item(self, name : Literal['SB']) -> 'Variation_197':
        ...

    @overload
    def del_item(self, name : Literal['G']) -> 'Variation_197':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['AN']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['CAN']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['RT1']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['RT2']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['SB']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_145:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['AN'], f : Any) -> 'Variation_197':
        ...

    @overload
    def modify_item(self, name : Literal['CAN'], f : Any) -> 'Variation_197':
        ...

    @overload
    def modify_item(self, name : Literal['RT1'], f : Any) -> 'Variation_197':
        ...

    @overload
    def modify_item(self, name : Literal['RT2'], f : Any) -> 'Variation_197':
        ...

    @overload
    def modify_item(self, name : Literal['SB'], f : Any) -> 'Variation_197':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_197':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_198_Arg_Group = TypedDict('Variation_198_Arg_Group', {
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_198_Arg : TypeAlias = Union[Raw, Variation_198_Arg_Group]
class Variation_198(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MODE3A': ('Mode-3/A Code (Converted Into Octal Representation) of Aircraft 2 Involved in the Conflict', Variation_19, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['MODE3A']]) -> Union[Type['Variation_19']]:
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_198_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['MODE3A']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_198':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_198':
        return self._modify_item(name, f) # type: ignore

Variation_199_Arg = TypedDict('Variation_199_Arg', {
    'AI2': Union[Variation_145, Variation_145_Arg],
    'M32': Union[Variation_198, Variation_198_Arg],
    'CPW': Union[Variation_149, Variation_149_Arg],
    'CPL': Union[Variation_151, Variation_151_Arg],
    'TT2': Union[Variation_80, Variation_80_Arg],
    'DT2': Union[Variation_152, Variation_152_Arg],
    'AC2': Union[Variation_160, Variation_160_Arg],
    'MS2': Union[Variation_161, Variation_161_Arg],
    'FP2': Union[Variation_163, Variation_163_Arg],
    'CF2': Union[Variation_164, Variation_164_Arg],
}, total=False)
class Variation_199(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('AI2', Variation_145),
        ('M32', Variation_198),
        ('CPW', Variation_149),
        ('CPL', Variation_151),
        ('TT2', Variation_80),
        ('DT2', Variation_152),
        ('AC2', Variation_160),
        ('MS2', Variation_161),
        ('FP2', Variation_163),
        ('CF2', Variation_164),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'AI2': ('Aircraft Identifier (in 7 Characters) of Aircraft 2 Involved in the Conflict', Variation_145, 0x8000),
        'M32': ('Mode 3/A Code Aircraft 2', Variation_198, 0x4000),
        'CPW': ('Predicted Conflict Position Target 2 in WGS-84 Coordinates', Variation_149, 0x2000),
        'CPL': ('Predicted Conflict Position for the Aircraft 2 Involved in the Conflict', Variation_151, 0x1000),
        'TT2': ('Time to Runway Threshold for Second Approaching Aircraft in a RIMCA', Variation_80, 0x0800),
        'DT2': ('Distance to Runway Threshold for Aircraft 2 Involved in a RIMCA', Variation_152, 0x0400),
        'AC2': ('Characteristics of Aircraft 2 Involved in the Conflict', Variation_160, 0x0200),
        'MS2': ('Aircraft Identification Downloaded From Aircraft 2 Involved in the Conflict If Eequipped With a Mode-S Transponder', Variation_161, 0x0180),
        'FP2': ('Number of the Flight Plan Correlated to Aircraft 2 Involved in the Conflict', Variation_163, 0x0140),
        'CF2': ('Cleared Flight Level for Aircraft 2 Involved in the Conflict', Variation_164, 0x0120),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AI2']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M32']) -> Type[Variation_198]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CPW']) -> Type[Variation_149]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CPL']) -> Type[Variation_151]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TT2']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DT2']) -> Type[Variation_152]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AC2']) -> Type[Variation_160]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MS2']) -> Type[Variation_161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FP2']) -> Type[Variation_163]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CF2']) -> Type[Variation_164]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AI2'], Literal['M32'], Literal['CPW'], Literal['CPL'], Literal['TT2'], Literal['DT2'], Literal['AC2'], Literal['MS2'], Literal['FP2'], Literal['CF2']]) -> Union[Type['Variation_145'], Type['Variation_198'], Type['Variation_149'], Type['Variation_151'], Type['Variation_80'], Type['Variation_152'], Type['Variation_160'], Type['Variation_161'], Type['Variation_163'], Type['Variation_164']]:
        if key == 'AI2':
            return Variation_145
        if key == 'M32':
            return Variation_198
        if key == 'CPW':
            return Variation_149
        if key == 'CPL':
            return Variation_151
        if key == 'TT2':
            return Variation_80
        if key == 'DT2':
            return Variation_152
        if key == 'AC2':
            return Variation_160
        if key == 'MS2':
            return Variation_161
        if key == 'FP2':
            return Variation_163
        if key == 'CF2':
            return Variation_164
        assert_never(key)

    def __init__(self, arg : Optional[Variation_199_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['AI2'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_199':
        ...

    @overload
    def set_item(self, name : Literal['M32'], val : Union[Variation_198, Variation_198_Arg]) -> 'Variation_199':
        ...

    @overload
    def set_item(self, name : Literal['CPW'], val : Union[Variation_149, Variation_149_Arg]) -> 'Variation_199':
        ...

    @overload
    def set_item(self, name : Literal['CPL'], val : Union[Variation_151, Variation_151_Arg]) -> 'Variation_199':
        ...

    @overload
    def set_item(self, name : Literal['TT2'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_199':
        ...

    @overload
    def set_item(self, name : Literal['DT2'], val : Union[Variation_152, Variation_152_Arg]) -> 'Variation_199':
        ...

    @overload
    def set_item(self, name : Literal['AC2'], val : Union[Variation_160, Variation_160_Arg]) -> 'Variation_199':
        ...

    @overload
    def set_item(self, name : Literal['MS2'], val : Union[Variation_161, Variation_161_Arg]) -> 'Variation_199':
        ...

    @overload
    def set_item(self, name : Literal['FP2'], val : Union[Variation_163, Variation_163_Arg]) -> 'Variation_199':
        ...

    @overload
    def set_item(self, name : Literal['CF2'], val : Union[Variation_164, Variation_164_Arg]) -> 'Variation_199':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['AI2']) -> 'Variation_199':
        ...

    @overload
    def del_item(self, name : Literal['M32']) -> 'Variation_199':
        ...

    @overload
    def del_item(self, name : Literal['CPW']) -> 'Variation_199':
        ...

    @overload
    def del_item(self, name : Literal['CPL']) -> 'Variation_199':
        ...

    @overload
    def del_item(self, name : Literal['TT2']) -> 'Variation_199':
        ...

    @overload
    def del_item(self, name : Literal['DT2']) -> 'Variation_199':
        ...

    @overload
    def del_item(self, name : Literal['AC2']) -> 'Variation_199':
        ...

    @overload
    def del_item(self, name : Literal['MS2']) -> 'Variation_199':
        ...

    @overload
    def del_item(self, name : Literal['FP2']) -> 'Variation_199':
        ...

    @overload
    def del_item(self, name : Literal['CF2']) -> 'Variation_199':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['AI2']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['M32']) -> Variation_198:
        ...

    @overload
    def get_item(self, name : Literal['CPW']) -> Variation_149:
        ...

    @overload
    def get_item(self, name : Literal['CPL']) -> Variation_151:
        ...

    @overload
    def get_item(self, name : Literal['TT2']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['DT2']) -> Variation_152:
        ...

    @overload
    def get_item(self, name : Literal['AC2']) -> Variation_160:
        ...

    @overload
    def get_item(self, name : Literal['MS2']) -> Variation_161:
        ...

    @overload
    def get_item(self, name : Literal['FP2']) -> Variation_163:
        ...

    @overload
    def get_item(self, name : Literal['CF2']) -> Variation_164:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['AI2'], f : Any) -> 'Variation_199':
        ...

    @overload
    def modify_item(self, name : Literal['M32'], f : Any) -> 'Variation_199':
        ...

    @overload
    def modify_item(self, name : Literal['CPW'], f : Any) -> 'Variation_199':
        ...

    @overload
    def modify_item(self, name : Literal['CPL'], f : Any) -> 'Variation_199':
        ...

    @overload
    def modify_item(self, name : Literal['TT2'], f : Any) -> 'Variation_199':
        ...

    @overload
    def modify_item(self, name : Literal['DT2'], f : Any) -> 'Variation_199':
        ...

    @overload
    def modify_item(self, name : Literal['AC2'], f : Any) -> 'Variation_199':
        ...

    @overload
    def modify_item(self, name : Literal['MS2'], f : Any) -> 'Variation_199':
        ...

    @overload
    def modify_item(self, name : Literal['FP2'], f : Any) -> 'Variation_199':
        ...

    @overload
    def modify_item(self, name : Literal['CF2'], f : Any) -> 'Variation_199':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_200_Arg_Group = TypedDict('Variation_200_Arg_Group', {
    'CEN': Union[Variation_0, Variation_0_Arg],
    'POS': Union[Variation_0, Variation_0_Arg],
})
Variation_200_Arg : TypeAlias = Union[Raw, Variation_200_Arg_Group]
class Variation_200(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('CEN', Variation_0),
        ('POS', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CEN': ('', Variation_0, 0, 8),
        'POS': ('', Variation_0, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CEN']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CEN'], Literal['POS']]) -> Union[Type['Variation_0'], Type['Variation_0']]:
        if key == 'CEN':
            return Variation_0
        if key == 'POS':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_200_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CEN']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['CEN'], Literal['POS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CEN'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_200':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_200':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CEN'], f : Any) -> 'Variation_200':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_200':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_201_Arg : TypeAlias = Union[Variation_200, Variation_200_Arg]
class Variation_201(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_200

    @classmethod
    def spec(cls) -> Type[Variation_200]:
        return Variation_200

    def __init__(self, arg : List[Union[Variation_200, Variation_200_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_200, Variation_200_Arg]) -> 'Variation_201':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_200, Variation_200_Arg]) -> 'Variation_201':
        return self._prepend_item(arg) # type: ignore

Variation_202_Arg : TypeAlias = bytes
class Variation_202(Explicit):
    variation = 'Explicit'

    explicit_type = "ReservedExpansion"

    def __init__(self, arg : bytes) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, bytes):
            super().__init__(*self._from_bytes(arg)); return
        assert_never(arg)

Variation_203_Arg = TypedDict('Variation_203_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_91, Variation_91_Arg],
    '015': Union[Variation_92, Variation_92_Arg],
    '020': Union[Variation_80, Variation_80_Arg],
    '040': Union[Variation_64, Variation_64_Arg],
    '045': Union[Variation_94, Variation_94_Arg],
    '060': Union[Variation_144, Variation_144_Arg],
    '030': Union[Variation_64, Variation_64_Arg],
    '170': Union[Variation_165, Variation_165_Arg],
    '120': Union[Variation_191, Variation_191_Arg],
    '070': Union[Variation_194, Variation_194_Arg],
    '076': Union[Variation_148, Variation_148_Arg],
    '074': Union[Variation_195, Variation_195_Arg],
    '075': Union[Variation_150, Variation_150_Arg],
    '100': Union[Variation_197, Variation_197_Arg],
    '035': Union[Variation_64, Variation_64_Arg],
    '171': Union[Variation_199, Variation_199_Arg],
    '110': Union[Variation_201, Variation_201_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_203(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 3

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_91),
        ('015', Variation_92),
        ('020', Variation_80),
        ('040', Variation_64),
        ('045', Variation_94),
        ('060', Variation_144),
        ('030', Variation_64),
        ('170', Variation_165),
        ('120', Variation_191),
        ('070', Variation_194),
        ('076', Variation_148),
        ('074', Variation_195),
        ('075', Variation_150),
        ('100', Variation_197),
        ('035', Variation_64),
        ('171', Variation_199),
        ('110', Variation_201),
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x800000),
        '000': ('Message Type', Variation_91, 0x400000),
        '015': ('SDPS Identifier', Variation_92, 0x200000),
        '020': ('Time of Message', Variation_80, 0x100000),
        '040': ('Alert Identifier', Variation_64, 0x080000),
        '045': ('Alert Status', Variation_94, 0x040000),
        '060': ('Safety Net Function and System Status', Variation_144, 0x020000),
        '030': ('Track Number 1', Variation_64, 0x018000),
        '170': ('Aircraft Identification and Characteristics 1', Variation_165, 0x014000),
        '120': ('Conflict Characteristics', Variation_191, 0x012000),
        '070': ('Conflict Timing and Separation', Variation_194, 0x011000),
        '076': ('Vertical Deviation', Variation_148, 0x010800),
        '074': ('Longitudinal Deviation', Variation_195, 0x010400),
        '075': ('Transversal Distance Deviation', Variation_150, 0x010200),
        '100': ('Area Definition', Variation_197, 0x010180),
        '035': ('Track Number 2', Variation_64, 0x010140),
        '171': ('Aircraft Identification and Characteristics 2', Variation_199, 0x010120),
        '110': ('FDPS Sector Control Identification', Variation_201, 0x010110),
        'RE': ('Reserved Expansion Field', Variation_202, 0x010104),
        'SP': ('Special Purpose Field', Variation_62, 0x010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_91]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_92]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['045']) -> Type[Variation_94]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_144]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_165]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_191]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_194]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['076']) -> Type[Variation_148]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['074']) -> Type[Variation_195]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['075']) -> Type[Variation_150]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_197]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['035']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['171']) -> Type[Variation_199]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_201]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['015'], Literal['020'], Literal['040'], Literal['045'], Literal['060'], Literal['030'], Literal['170'], Literal['120'], Literal['070'], Literal['076'], Literal['074'], Literal['075'], Literal['100'], Literal['035'], Literal['171'], Literal['110'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_91'], Type['Variation_92'], Type['Variation_80'], Type['Variation_64'], Type['Variation_94'], Type['Variation_144'], Type['Variation_64'], Type['Variation_165'], Type['Variation_191'], Type['Variation_194'], Type['Variation_148'], Type['Variation_195'], Type['Variation_150'], Type['Variation_197'], Type['Variation_64'], Type['Variation_199'], Type['Variation_201'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_91
        if key == '015':
            return Variation_92
        if key == '020':
            return Variation_80
        if key == '040':
            return Variation_64
        if key == '045':
            return Variation_94
        if key == '060':
            return Variation_144
        if key == '030':
            return Variation_64
        if key == '170':
            return Variation_165
        if key == '120':
            return Variation_191
        if key == '070':
            return Variation_194
        if key == '076':
            return Variation_148
        if key == '074':
            return Variation_195
        if key == '075':
            return Variation_150
        if key == '100':
            return Variation_197
        if key == '035':
            return Variation_64
        if key == '171':
            return Variation_199
        if key == '110':
            return Variation_201
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_203_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_91, Variation_91_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_92, Variation_92_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['045'], val : Union[Variation_94, Variation_94_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_144, Variation_144_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_165, Variation_165_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_191, Variation_191_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_194, Variation_194_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['076'], val : Union[Variation_148, Variation_148_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['074'], val : Union[Variation_195, Variation_195_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['075'], val : Union[Variation_150, Variation_150_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_197, Variation_197_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['035'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['171'], val : Union[Variation_199, Variation_199_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_201, Variation_201_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_203':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_203':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['045']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['076']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['074']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['075']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['035']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['171']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_203':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_203':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_91:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_92:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['045']) -> Variation_94:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_144:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_165:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_191:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_194:
        ...

    @overload
    def get_item(self, name : Literal['076']) -> Variation_148:
        ...

    @overload
    def get_item(self, name : Literal['074']) -> Variation_195:
        ...

    @overload
    def get_item(self, name : Literal['075']) -> Variation_150:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_197:
        ...

    @overload
    def get_item(self, name : Literal['035']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['171']) -> Variation_199:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_201:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['045'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['076'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['074'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['075'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['035'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['171'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_203':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_203':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_204_Arg : TypeAlias = Raw
class Variation_204(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Polar vector',
        2: 'Cartesian vector of start point/length',
        3: 'Contour record',
        4: 'Cartesian start point and end point vector',
        254: 'SOP message',
        255: 'EOP message',
    }

    def __init__(self, arg : Variation_204_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_205_Arg : TypeAlias = Raw
class Variation_205(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Local Coordinates',
        1: 'System Coordinates',
    }

    def __init__(self, arg : Variation_205_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_206_Arg : TypeAlias = Raw
class Variation_206(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 3

    def __init__(self, arg : Variation_206_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_207_Arg : TypeAlias = Raw
class Variation_207(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 3
    table = {
        0: '0°',
        1: '22.5°',
        2: '45°',
        3: '67.5°',
        4: '90°',
        5: '112.5°',
        6: '135°',
        7: '157.5°',
    }

    def __init__(self, arg : Variation_207_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_208_Arg : TypeAlias = Raw
class Variation_208(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Test vector',
    }

    def __init__(self, arg : Variation_208_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_209_Arg : TypeAlias = Raw
class Variation_209(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Error condition encountered',
    }

    def __init__(self, arg : Variation_209_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_210_Arg_Group_1 = TypedDict('Variation_210_Arg_Group_1', {
    'ORG': Union[Variation_205, Variation_205_Arg],
    'I': Union[Variation_206, Variation_206_Arg],
    'S': Union[Variation_207, Variation_207_Arg],
})
Variation_210_Arg_Group_2 = TypedDict('Variation_210_Arg_Group_2', {
    'ORG': Union[Variation_205, Variation_205_Arg],
    'I': Union[Variation_206, Variation_206_Arg],
    'S': Union[Variation_207, Variation_207_Arg],
    'TST': Union[Variation_208, Variation_208_Arg],
    'ER': Union[Variation_209, Variation_209_Arg],
})
Variation_210_Arg : TypeAlias = Union[
    int,
    Variation_210_Arg_Group_1,
    Tuple[int],
    Variation_210_Arg_Group_2,
    Tuple[int,int],
]
class Variation_210(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('ORG', Variation_205),
            ('I', Variation_206),
            ('S', Variation_207),
        ],
        [
            Spare(0, 5),
            ('TST', Variation_208),
            ('ER', Variation_209),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ORG': ('', Variation_205, 0, 1),
        'I': ('Intensity Level', Variation_206, 1, 3),
        'S': ('Shading Orientation with Respect to North', Variation_207, 4, 3),
        'TST': ('', Variation_208, 5, 1),
        'ER': ('', Variation_209, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ORG']) -> Type[Variation_205]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I']) -> Type[Variation_206]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['S']) -> Type[Variation_207]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_208]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ER']) -> Type[Variation_209]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ORG'], Literal['I'], Literal['S'], Literal['TST'], Literal['ER']]) -> Union[Type['Variation_205'], Type['Variation_206'], Type['Variation_207'], Type['Variation_208'], Type['Variation_209']]:
        if key == 'ORG':
            return Variation_205
        if key == 'I':
            return Variation_206
        if key == 'S':
            return Variation_207
        if key == 'TST':
            return Variation_208
        if key == 'ER':
            return Variation_209
        assert_never(key)

    def __init__(self, arg : Variation_210_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_210_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_210_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ORG']) -> Variation_205:
        ...

    @overload
    def get_item(self, name : Literal['I']) -> Variation_206:
        ...

    @overload
    def get_item(self, name : Literal['S']) -> Variation_207:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_208:
        ...

    @overload
    def get_item(self, name : Literal['ER']) -> Variation_209:
        ...

    def get_item(self, name : Union[Literal['ORG'], Literal['I'], Literal['S'], Literal['TST'], Literal['ER']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ORG'], val : Union[Variation_205, Variation_205_Arg]) -> 'Variation_210':
        ...

    @overload
    def set_item(self, name : Literal['I'], val : Union[Variation_206, Variation_206_Arg]) -> 'Variation_210':
        ...

    @overload
    def set_item(self, name : Literal['S'], val : Union[Variation_207, Variation_207_Arg]) -> 'Variation_210':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ORG'], f : Any) -> 'Variation_210':
        ...

    @overload
    def modify_item(self, name : Literal['I'], f : Any) -> 'Variation_210':
        ...

    @overload
    def modify_item(self, name : Literal['S'], f : Any) -> 'Variation_210':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_210':
        ...

    @overload
    def modify_item(self, name : Literal['ER'], f : Any) -> 'Variation_210':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_211_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['(NM)']]]
class Variation_211(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 1.5625e-2, '(NM)')

    def __init__(self, arg : Variation_211_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_212_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['(NM)']]]
class Variation_212(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 1.5625e-2, '(NM)')

    def __init__(self, arg : Variation_212_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_213_Arg_Group = TypedDict('Variation_213_Arg_Group', {
    'X': Union[Variation_211, Variation_211_Arg],
    'Y': Union[Variation_211, Variation_211_Arg],
    'LENGTH': Union[Variation_212, Variation_212_Arg],
})
Variation_213_Arg : TypeAlias = Union[Raw, Variation_213_Arg_Group]
class Variation_213(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('X', Variation_211),
        ('Y', Variation_211),
        ('LENGTH', Variation_212),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('X-Component', Variation_211, 0, 8),
        'Y': ('Y-Component', Variation_211, 8, 8),
        'LENGTH': ('Length', Variation_212, 16, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_211]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_211]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LENGTH']) -> Type[Variation_212]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y'], Literal['LENGTH']]) -> Union[Type['Variation_211'], Type['Variation_211'], Type['Variation_212']]:
        if key == 'X':
            return Variation_211
        if key == 'Y':
            return Variation_211
        if key == 'LENGTH':
            return Variation_212
        assert_never(key)

    def __init__(self, arg : Variation_213_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_211:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_211:
        ...

    @overload
    def get_item(self, name : Literal['LENGTH']) -> Variation_212:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y'], Literal['LENGTH']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_211, Variation_211_Arg]) -> 'Variation_213':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_211, Variation_211_Arg]) -> 'Variation_213':
        ...

    @overload
    def set_item(self, name : Literal['LENGTH'], val : Union[Variation_212, Variation_212_Arg]) -> 'Variation_213':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_213':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_213':
        ...

    @overload
    def modify_item(self, name : Literal['LENGTH'], f : Any) -> 'Variation_213':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_214_Arg : TypeAlias = Union[Variation_213, Variation_213_Arg]
class Variation_214(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 24
    variation_type = Variation_213

    @classmethod
    def spec(cls) -> Type[Variation_213]:
        return Variation_213

    def __init__(self, arg : List[Union[Variation_213, Variation_213_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_213, Variation_213_Arg]) -> 'Variation_214':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_213, Variation_213_Arg]) -> 'Variation_214':
        return self._prepend_item(arg) # type: ignore

Variation_215_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['(NM)']]]
class Variation_215(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 7.8125e-3, '(NM)')

    def __init__(self, arg : Variation_215_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_216_Arg_Group = TypedDict('Variation_216_Arg_Group', {
    'STR': Union[Variation_215, Variation_215_Arg],
    'ENDR': Union[Variation_215, Variation_215_Arg],
    'AZ': Union[Variation_14, Variation_14_Arg],
})
Variation_216_Arg : TypeAlias = Union[Raw, Variation_216_Arg_Group]
class Variation_216(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('STR', Variation_215),
        ('ENDR', Variation_215),
        ('AZ', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STR': ('Start Range', Variation_215, 0, 8),
        'ENDR': ('End Range', Variation_215, 8, 8),
        'AZ': ('Azimuth', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['STR']) -> Type[Variation_215]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ENDR']) -> Type[Variation_215]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AZ']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['STR'], Literal['ENDR'], Literal['AZ']]) -> Union[Type['Variation_215'], Type['Variation_215'], Type['Variation_14']]:
        if key == 'STR':
            return Variation_215
        if key == 'ENDR':
            return Variation_215
        if key == 'AZ':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_216_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['STR']) -> Variation_215:
        ...

    @overload
    def get_item(self, name : Literal['ENDR']) -> Variation_215:
        ...

    @overload
    def get_item(self, name : Literal['AZ']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['STR'], Literal['ENDR'], Literal['AZ']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['STR'], val : Union[Variation_215, Variation_215_Arg]) -> 'Variation_216':
        ...

    @overload
    def set_item(self, name : Literal['ENDR'], val : Union[Variation_215, Variation_215_Arg]) -> 'Variation_216':
        ...

    @overload
    def set_item(self, name : Literal['AZ'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_216':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['STR'], f : Any) -> 'Variation_216':
        ...

    @overload
    def modify_item(self, name : Literal['ENDR'], f : Any) -> 'Variation_216':
        ...

    @overload
    def modify_item(self, name : Literal['AZ'], f : Any) -> 'Variation_216':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_217_Arg : TypeAlias = Union[Variation_216, Variation_216_Arg]
class Variation_217(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 32
    variation_type = Variation_216

    @classmethod
    def spec(cls) -> Type[Variation_216]:
        return Variation_216

    def __init__(self, arg : List[Union[Variation_216, Variation_216_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_216, Variation_216_Arg]) -> 'Variation_217':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_216, Variation_216_Arg]) -> 'Variation_217':
        return self._prepend_item(arg) # type: ignore

Variation_218_Arg : TypeAlias = Raw
class Variation_218(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 2
    table = {
        0: 'Intermediate record of a contour',
        1: 'Last record of a contour of at least two records',
        2: 'First record of a contour of at least two records',
        3: 'First and only record, fully defining a contour',
    }

    def __init__(self, arg : Variation_218_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_219_Arg_Group = TypedDict('Variation_219_Arg_Group', {
    'ORG': Union[Variation_205, Variation_205_Arg],
    'I': Union[Variation_206, Variation_206_Arg],
    'FSTLST': Union[Variation_218, Variation_218_Arg],
    'CSN': Union[Variation_0, Variation_0_Arg],
})
Variation_219_Arg : TypeAlias = Union[Raw, Variation_219_Arg_Group]
class Variation_219(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('ORG', Variation_205),
        ('I', Variation_206),
        Spare(4, 2),
        ('FSTLST', Variation_218),
        ('CSN', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ORG': ('', Variation_205, 0, 1),
        'I': ('Intensity Level', Variation_206, 1, 3),
        'FSTLST': ('', Variation_218, 6, 2),
        'CSN': ('Contour Serial Number', Variation_0, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ORG']) -> Type[Variation_205]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I']) -> Type[Variation_206]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FSTLST']) -> Type[Variation_218]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CSN']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ORG'], Literal['I'], Literal['FSTLST'], Literal['CSN']]) -> Union[Type['Variation_205'], Type['Variation_206'], Type['Variation_218'], Type['Variation_0']]:
        if key == 'ORG':
            return Variation_205
        if key == 'I':
            return Variation_206
        if key == 'FSTLST':
            return Variation_218
        if key == 'CSN':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_219_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ORG']) -> Variation_205:
        ...

    @overload
    def get_item(self, name : Literal['I']) -> Variation_206:
        ...

    @overload
    def get_item(self, name : Literal['FSTLST']) -> Variation_218:
        ...

    @overload
    def get_item(self, name : Literal['CSN']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['ORG'], Literal['I'], Literal['FSTLST'], Literal['CSN']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ORG'], val : Union[Variation_205, Variation_205_Arg]) -> 'Variation_219':
        ...

    @overload
    def set_item(self, name : Literal['I'], val : Union[Variation_206, Variation_206_Arg]) -> 'Variation_219':
        ...

    @overload
    def set_item(self, name : Literal['FSTLST'], val : Union[Variation_218, Variation_218_Arg]) -> 'Variation_219':
        ...

    @overload
    def set_item(self, name : Literal['CSN'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_219':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ORG'], f : Any) -> 'Variation_219':
        ...

    @overload
    def modify_item(self, name : Literal['I'], f : Any) -> 'Variation_219':
        ...

    @overload
    def modify_item(self, name : Literal['FSTLST'], f : Any) -> 'Variation_219':
        ...

    @overload
    def modify_item(self, name : Literal['CSN'], f : Any) -> 'Variation_219':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_220_Arg_Group = TypedDict('Variation_220_Arg_Group', {
    'X1': Union[Variation_211, Variation_211_Arg],
    'Y1': Union[Variation_211, Variation_211_Arg],
})
Variation_220_Arg : TypeAlias = Union[Raw, Variation_220_Arg_Group]
class Variation_220(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('X1', Variation_211),
        ('Y1', Variation_211),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X1': ('', Variation_211, 0, 8),
        'Y1': ('', Variation_211, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X1']) -> Type[Variation_211]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y1']) -> Type[Variation_211]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X1'], Literal['Y1']]) -> Union[Type['Variation_211'], Type['Variation_211']]:
        if key == 'X1':
            return Variation_211
        if key == 'Y1':
            return Variation_211
        assert_never(key)

    def __init__(self, arg : Variation_220_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X1']) -> Variation_211:
        ...

    @overload
    def get_item(self, name : Literal['Y1']) -> Variation_211:
        ...

    def get_item(self, name : Union[Literal['X1'], Literal['Y1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X1'], val : Union[Variation_211, Variation_211_Arg]) -> 'Variation_220':
        ...

    @overload
    def set_item(self, name : Literal['Y1'], val : Union[Variation_211, Variation_211_Arg]) -> 'Variation_220':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X1'], f : Any) -> 'Variation_220':
        ...

    @overload
    def modify_item(self, name : Literal['Y1'], f : Any) -> 'Variation_220':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_221_Arg : TypeAlias = Union[Variation_220, Variation_220_Arg]
class Variation_221(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_220

    @classmethod
    def spec(cls) -> Type[Variation_220]:
        return Variation_220

    def __init__(self, arg : List[Union[Variation_220, Variation_220_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_220, Variation_220_Arg]) -> 'Variation_221':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_220, Variation_220_Arg]) -> 'Variation_221':
        return self._prepend_item(arg) # type: ignore

Variation_222_Arg : TypeAlias = Raw
class Variation_222(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 5

    def __init__(self, arg : Variation_222_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_223_Arg : TypeAlias = Raw
class Variation_223(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 3

    def __init__(self, arg : Variation_223_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_224_Arg : TypeAlias = Raw
class Variation_224(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 15

    def __init__(self, arg : Variation_224_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_225_Arg_Group_1 = TypedDict('Variation_225_Arg_Group_1', {
    'F': Union[Variation_222, Variation_222_Arg],
    'R': Union[Variation_223, Variation_223_Arg],
    'Q': Union[Variation_224, Variation_224_Arg],
})
Variation_225_Arg : TypeAlias = Union[
    int,
    Variation_225_Arg_Group_1,
    Tuple[int],
]
class Variation_225(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        23,
    ]

    subitems_list = [
        [
            ('F', Variation_222),
            ('R', Variation_223),
            ('Q', Variation_224),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'F': ('Scaling Factor', Variation_222, 0, 5),
        'R': ('Current Reduction Stage in Use', Variation_223, 5, 3),
        'Q': ('Processing Parameters', Variation_224, 8, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['F']) -> Type[Variation_222]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['R']) -> Type[Variation_223]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Q']) -> Type[Variation_224]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['F'], Literal['R'], Literal['Q']]) -> Union[Type['Variation_222'], Type['Variation_223'], Type['Variation_224']]:
        if key == 'F':
            return Variation_222
        if key == 'R':
            return Variation_223
        if key == 'Q':
            return Variation_224
        assert_never(key)

    def __init__(self, arg : Variation_225_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_225_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['F']) -> Variation_222:
        ...

    @overload
    def get_item(self, name : Literal['R']) -> Variation_223:
        ...

    @overload
    def get_item(self, name : Literal['Q']) -> Variation_224:
        ...

    def get_item(self, name : Union[Literal['F'], Literal['R'], Literal['Q']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['F'], val : Union[Variation_222, Variation_222_Arg]) -> 'Variation_225':
        ...

    @overload
    def set_item(self, name : Literal['R'], val : Union[Variation_223, Variation_223_Arg]) -> 'Variation_225':
        ...

    @overload
    def set_item(self, name : Literal['Q'], val : Union[Variation_224, Variation_224_Arg]) -> 'Variation_225':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['F'], f : Any) -> 'Variation_225':
        ...

    @overload
    def modify_item(self, name : Literal['R'], f : Any) -> 'Variation_225':
        ...

    @overload
    def modify_item(self, name : Literal['Q'], f : Any) -> 'Variation_225':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_226_Arg_Group = TypedDict('Variation_226_Arg_Group', {
    'X1': Union[Variation_211, Variation_211_Arg],
    'Y1': Union[Variation_211, Variation_211_Arg],
    'X2': Union[Variation_211, Variation_211_Arg],
    'Y2': Union[Variation_211, Variation_211_Arg],
})
Variation_226_Arg : TypeAlias = Union[Raw, Variation_226_Arg_Group]
class Variation_226(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('X1', Variation_211),
        ('Y1', Variation_211),
        ('X2', Variation_211),
        ('Y2', Variation_211),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X1': ('X1-Component', Variation_211, 0, 8),
        'Y1': ('Y1-Component', Variation_211, 8, 8),
        'X2': ('X2-Component', Variation_211, 16, 8),
        'Y2': ('Y2-Component', Variation_211, 24, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X1']) -> Type[Variation_211]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y1']) -> Type[Variation_211]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X2']) -> Type[Variation_211]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y2']) -> Type[Variation_211]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X1'], Literal['Y1'], Literal['X2'], Literal['Y2']]) -> Union[Type['Variation_211'], Type['Variation_211'], Type['Variation_211'], Type['Variation_211']]:
        if key == 'X1':
            return Variation_211
        if key == 'Y1':
            return Variation_211
        if key == 'X2':
            return Variation_211
        if key == 'Y2':
            return Variation_211
        assert_never(key)

    def __init__(self, arg : Variation_226_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X1']) -> Variation_211:
        ...

    @overload
    def get_item(self, name : Literal['Y1']) -> Variation_211:
        ...

    @overload
    def get_item(self, name : Literal['X2']) -> Variation_211:
        ...

    @overload
    def get_item(self, name : Literal['Y2']) -> Variation_211:
        ...

    def get_item(self, name : Union[Literal['X1'], Literal['Y1'], Literal['X2'], Literal['Y2']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X1'], val : Union[Variation_211, Variation_211_Arg]) -> 'Variation_226':
        ...

    @overload
    def set_item(self, name : Literal['Y1'], val : Union[Variation_211, Variation_211_Arg]) -> 'Variation_226':
        ...

    @overload
    def set_item(self, name : Literal['X2'], val : Union[Variation_211, Variation_211_Arg]) -> 'Variation_226':
        ...

    @overload
    def set_item(self, name : Literal['Y2'], val : Union[Variation_211, Variation_211_Arg]) -> 'Variation_226':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X1'], f : Any) -> 'Variation_226':
        ...

    @overload
    def modify_item(self, name : Literal['Y1'], f : Any) -> 'Variation_226':
        ...

    @overload
    def modify_item(self, name : Literal['X2'], f : Any) -> 'Variation_226':
        ...

    @overload
    def modify_item(self, name : Literal['Y2'], f : Any) -> 'Variation_226':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_227_Arg : TypeAlias = Union[Variation_226, Variation_226_Arg]
class Variation_227(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 32
    variation_type = Variation_226

    @classmethod
    def spec(cls) -> Type[Variation_226]:
        return Variation_226

    def __init__(self, arg : List[Union[Variation_226, Variation_226_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_226, Variation_226_Arg]) -> 'Variation_227':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_226, Variation_226_Arg]) -> 'Variation_227':
        return self._prepend_item(arg) # type: ignore

Variation_228_Arg = TypedDict('Variation_228_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_204, Variation_204_Arg],
    '020': Union[Variation_210, Variation_210_Arg],
    '036': Union[Variation_214, Variation_214_Arg],
    '034': Union[Variation_217, Variation_217_Arg],
    '040': Union[Variation_219, Variation_219_Arg],
    '050': Union[Variation_221, Variation_221_Arg],
    '090': Union[Variation_80, Variation_80_Arg],
    '100': Union[Variation_225, Variation_225_Arg],
    '110': Union[Variation_24, Variation_24_Arg],
    '120': Union[Variation_64, Variation_64_Arg],
    '038': Union[Variation_227, Variation_227_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_228(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_204),
        ('020', Variation_210),
        ('036', Variation_214),
        ('034', Variation_217),
        ('040', Variation_219),
        ('050', Variation_221),
        ('090', Variation_80),
        ('100', Variation_225),
        ('110', Variation_24),
        ('120', Variation_64),
        ('038', Variation_227),
        ('SP', Variation_62),
        None,
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Message Type', Variation_204, 0x4000),
        '020': ('Vector Qualifier', Variation_210, 0x2000),
        '036': ('Sequence of Cartesian Vectors in SPF Notation', Variation_214, 0x1000),
        '034': ('Sequence of Polar Vectors in SPF Notation', Variation_217, 0x0800),
        '040': ('Contour Identifier', Variation_219, 0x0400),
        '050': ('Sequence of Contour Points in SPF Notation', Variation_221, 0x0200),
        '090': ('Time of Day', Variation_80, 0x0180),
        '100': ('Processing Status', Variation_225, 0x0140),
        '110': ('Station Configuration Status', Variation_24, 0x0120),
        '120': ('Total Number of Items Constituting One Weather Picture', Variation_64, 0x0110),
        '038': ('Sequence of Weather Vectors in SPF Notation', Variation_227, 0x0108),
        'SP': ('Special Purpose Field', Variation_62, 0x0104),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_204]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_210]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['036']) -> Type[Variation_214]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['034']) -> Type[Variation_217]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_219]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_221]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_225]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_24]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['038']) -> Type[Variation_227]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['020'], Literal['036'], Literal['034'], Literal['040'], Literal['050'], Literal['090'], Literal['100'], Literal['110'], Literal['120'], Literal['038'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_204'], Type['Variation_210'], Type['Variation_214'], Type['Variation_217'], Type['Variation_219'], Type['Variation_221'], Type['Variation_80'], Type['Variation_225'], Type['Variation_24'], Type['Variation_64'], Type['Variation_227'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_204
        if key == '020':
            return Variation_210
        if key == '036':
            return Variation_214
        if key == '034':
            return Variation_217
        if key == '040':
            return Variation_219
        if key == '050':
            return Variation_221
        if key == '090':
            return Variation_80
        if key == '100':
            return Variation_225
        if key == '110':
            return Variation_24
        if key == '120':
            return Variation_64
        if key == '038':
            return Variation_227
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_228_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_204, Variation_204_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_210, Variation_210_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['036'], val : Union[Variation_214, Variation_214_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['034'], val : Union[Variation_217, Variation_217_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_219, Variation_219_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_221, Variation_221_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_225, Variation_225_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_24, Variation_24_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['038'], val : Union[Variation_227, Variation_227_Arg]) -> 'Variation_228':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_228':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['036']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['034']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['038']) -> 'Variation_228':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_228':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_204:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_210:
        ...

    @overload
    def get_item(self, name : Literal['036']) -> Variation_214:
        ...

    @overload
    def get_item(self, name : Literal['034']) -> Variation_217:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_219:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_221:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_225:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_24:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['038']) -> Variation_227:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['036'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['034'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['038'], f : Any) -> 'Variation_228':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_228':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_229_Arg : TypeAlias = Raw
class Variation_229(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        2: 'Cartesian vector',
        253: 'Intermediate-update-step message',
        254: 'Start-of-picture message',
        255: 'End-of-picture message',
    }

    def __init__(self, arg : Variation_229_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_230_Arg_Group_1 = TypedDict('Variation_230_Arg_Group_1', {
    'ORG': Union[Variation_205, Variation_205_Arg],
    'I': Union[Variation_206, Variation_206_Arg],
    'S': Union[Variation_207, Variation_207_Arg],
})
Variation_230_Arg : TypeAlias = Union[
    int,
    Variation_230_Arg_Group_1,
    Tuple[int],
]
class Variation_230(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            ('ORG', Variation_205),
            ('I', Variation_206),
            ('S', Variation_207),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ORG': ('', Variation_205, 0, 1),
        'I': ('Intensity Level', Variation_206, 1, 3),
        'S': ('Shading Orientation with Respect to North', Variation_207, 4, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ORG']) -> Type[Variation_205]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I']) -> Type[Variation_206]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['S']) -> Type[Variation_207]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ORG'], Literal['I'], Literal['S']]) -> Union[Type['Variation_205'], Type['Variation_206'], Type['Variation_207']]:
        if key == 'ORG':
            return Variation_205
        if key == 'I':
            return Variation_206
        if key == 'S':
            return Variation_207
        assert_never(key)

    def __init__(self, arg : Variation_230_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_230_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ORG']) -> Variation_205:
        ...

    @overload
    def get_item(self, name : Literal['I']) -> Variation_206:
        ...

    @overload
    def get_item(self, name : Literal['S']) -> Variation_207:
        ...

    def get_item(self, name : Union[Literal['ORG'], Literal['I'], Literal['S']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ORG'], val : Union[Variation_205, Variation_205_Arg]) -> 'Variation_230':
        ...

    @overload
    def set_item(self, name : Literal['I'], val : Union[Variation_206, Variation_206_Arg]) -> 'Variation_230':
        ...

    @overload
    def set_item(self, name : Literal['S'], val : Union[Variation_207, Variation_207_Arg]) -> 'Variation_230':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ORG'], f : Any) -> 'Variation_230':
        ...

    @overload
    def modify_item(self, name : Literal['I'], f : Any) -> 'Variation_230':
        ...

    @overload
    def modify_item(self, name : Literal['S'], f : Any) -> 'Variation_230':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_231_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['(NM)']]]
class Variation_231(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 1.5625e-2, '(NM)')

    def __init__(self, arg : Variation_231_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_232_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['(NM)']]]
class Variation_232(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.5625e-2, '(NM)')

    def __init__(self, arg : Variation_232_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_233_Arg_Group = TypedDict('Variation_233_Arg_Group', {
    'X': Union[Variation_231, Variation_231_Arg],
    'Y': Union[Variation_231, Variation_231_Arg],
    'L': Union[Variation_232, Variation_232_Arg],
})
Variation_233_Arg : TypeAlias = Union[Raw, Variation_233_Arg_Group]
class Variation_233(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('X', Variation_231),
        ('Y', Variation_231),
        ('L', Variation_232),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('X-coordinate', Variation_231, 0, 16),
        'Y': ('Y-coordinate', Variation_231, 16, 16),
        'L': ('Vector Length', Variation_232, 32, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_231]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_231]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_232]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y'], Literal['L']]) -> Union[Type['Variation_231'], Type['Variation_231'], Type['Variation_232']]:
        if key == 'X':
            return Variation_231
        if key == 'Y':
            return Variation_231
        if key == 'L':
            return Variation_232
        assert_never(key)

    def __init__(self, arg : Variation_233_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_231:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_231:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_232:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y'], Literal['L']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_231, Variation_231_Arg]) -> 'Variation_233':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_231, Variation_231_Arg]) -> 'Variation_233':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_232, Variation_232_Arg]) -> 'Variation_233':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_233':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_233':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_233':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_234_Arg : TypeAlias = Union[Variation_233, Variation_233_Arg]
class Variation_234(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 48
    variation_type = Variation_233

    @classmethod
    def spec(cls) -> Type[Variation_233]:
        return Variation_233

    def __init__(self, arg : List[Union[Variation_233, Variation_233_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_233, Variation_233_Arg]) -> 'Variation_234':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_233, Variation_233_Arg]) -> 'Variation_234':
        return self._prepend_item(arg) # type: ignore

Variation_235_Arg : TypeAlias = Raw
class Variation_235(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 6

    def __init__(self, arg : Variation_235_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_236_Arg_Group_1 = TypedDict('Variation_236_Arg_Group_1', {
    'SN': Union[Variation_235, Variation_235_Arg],
})
Variation_236_Arg : TypeAlias = Union[
    int,
    Variation_236_Arg_Group_1,
    Tuple[int],
]
class Variation_236(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            ('SN', Variation_235),
            Spare(6, 1),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SN': ('Step Number', Variation_235, 0, 6),
    }


    @classmethod
    def spec(cls, key : Union[Literal['SN']]) -> Union[Type['Variation_235']]:
        if key == 'SN':
            return Variation_235
        assert_never(key)

    def __init__(self, arg : Variation_236_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_236_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    def get_item(self, name : Literal['SN']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['SN'], val : Union[Variation_235, Variation_235_Arg]) -> 'Variation_236':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['SN'], f : Any) -> 'Variation_236':
        return self._modify_item(name, f) # type: ignore

Variation_237_Arg : TypeAlias = Raw
class Variation_237(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1

    def __init__(self, arg : Variation_237_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_238_Arg : TypeAlias = Raw
class Variation_238(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1

    def __init__(self, arg : Variation_238_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_239_Arg_Group = TypedDict('Variation_239_Arg_Group', {
    'SAC': Union[Variation_0, Variation_0_Arg],
    'SIC': Union[Variation_0, Variation_0_Arg],
    'CP': Union[Variation_237, Variation_237_Arg],
    'WO': Union[Variation_238, Variation_238_Arg],
    'R': Union[Variation_223, Variation_223_Arg],
})
Variation_239_Arg : TypeAlias = Union[Raw, Variation_239_Arg_Group]
class Variation_239(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('SAC', Variation_0),
        ('SIC', Variation_0),
        Spare(0, 3),
        ('CP', Variation_237),
        ('WO', Variation_238),
        ('R', Variation_223),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SAC': ('SAC of Radar Concerned', Variation_0, 0, 8),
        'SIC': ('SIC of Radar Concerned', Variation_0, 8, 8),
        'CP': ('Circular Polarisation', Variation_237, 19, 1),
        'WO': ('Weather Channel Overload', Variation_238, 20, 1),
        'R': ('Reduction Step in Use By Radar  Concerned', Variation_223, 21, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SAC']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIC']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CP']) -> Type[Variation_237]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WO']) -> Type[Variation_238]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['R']) -> Type[Variation_223]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SAC'], Literal['SIC'], Literal['CP'], Literal['WO'], Literal['R']]) -> Union[Type['Variation_0'], Type['Variation_0'], Type['Variation_237'], Type['Variation_238'], Type['Variation_223']]:
        if key == 'SAC':
            return Variation_0
        if key == 'SIC':
            return Variation_0
        if key == 'CP':
            return Variation_237
        if key == 'WO':
            return Variation_238
        if key == 'R':
            return Variation_223
        assert_never(key)

    def __init__(self, arg : Variation_239_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SAC']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SIC']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['CP']) -> Variation_237:
        ...

    @overload
    def get_item(self, name : Literal['WO']) -> Variation_238:
        ...

    @overload
    def get_item(self, name : Literal['R']) -> Variation_223:
        ...

    def get_item(self, name : Union[Literal['SAC'], Literal['SIC'], Literal['CP'], Literal['WO'], Literal['R']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SAC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_239':
        ...

    @overload
    def set_item(self, name : Literal['SIC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_239':
        ...

    @overload
    def set_item(self, name : Literal['CP'], val : Union[Variation_237, Variation_237_Arg]) -> 'Variation_239':
        ...

    @overload
    def set_item(self, name : Literal['WO'], val : Union[Variation_238, Variation_238_Arg]) -> 'Variation_239':
        ...

    @overload
    def set_item(self, name : Literal['R'], val : Union[Variation_223, Variation_223_Arg]) -> 'Variation_239':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SAC'], f : Any) -> 'Variation_239':
        ...

    @overload
    def modify_item(self, name : Literal['SIC'], f : Any) -> 'Variation_239':
        ...

    @overload
    def modify_item(self, name : Literal['CP'], f : Any) -> 'Variation_239':
        ...

    @overload
    def modify_item(self, name : Literal['WO'], f : Any) -> 'Variation_239':
        ...

    @overload
    def modify_item(self, name : Literal['R'], f : Any) -> 'Variation_239':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_240_Arg : TypeAlias = Union[Variation_239, Variation_239_Arg]
class Variation_240(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 24
    variation_type = Variation_239

    @classmethod
    def spec(cls) -> Type[Variation_239]:
        return Variation_239

    def __init__(self, arg : List[Union[Variation_239, Variation_239_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_239, Variation_239_Arg]) -> 'Variation_240':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_239, Variation_239_Arg]) -> 'Variation_240':
        return self._prepend_item(arg) # type: ignore

Variation_241_Arg = TypedDict('Variation_241_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_229, Variation_229_Arg],
    '020': Union[Variation_230, Variation_230_Arg],
    '030': Union[Variation_234, Variation_234_Arg],
    '060': Union[Variation_236, Variation_236_Arg],
    '070': Union[Variation_80, Variation_80_Arg],
    '080': Union[Variation_225, Variation_225_Arg],
    '090': Union[Variation_240, Variation_240_Arg],
    '100': Union[Variation_64, Variation_64_Arg],
}, total=False)
class Variation_241(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_229),
        ('020', Variation_230),
        ('030', Variation_234),
        ('060', Variation_236),
        ('070', Variation_80),
        ('080', Variation_225),
        ('090', Variation_240),
        ('100', Variation_64),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Message Type', Variation_229, 0x4000),
        '020': ('Vector Qualifier', Variation_230, 0x2000),
        '030': ('Sequence of Cartesian Vectors', Variation_234, 0x1000),
        '060': ('Synchronisation/Control Signal', Variation_236, 0x0800),
        '070': ('Time of Day', Variation_80, 0x0400),
        '080': ('Processing Status', Variation_225, 0x0200),
        '090': ('Radar Configuration and Status', Variation_240, 0x0180),
        '100': ('Vector Count', Variation_64, 0x0140),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_229]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_230]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_234]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_236]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_225]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_240]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_64]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['020'], Literal['030'], Literal['060'], Literal['070'], Literal['080'], Literal['090'], Literal['100']]) -> Union[Type['Variation_1'], Type['Variation_229'], Type['Variation_230'], Type['Variation_234'], Type['Variation_236'], Type['Variation_80'], Type['Variation_225'], Type['Variation_240'], Type['Variation_64']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_229
        if key == '020':
            return Variation_230
        if key == '030':
            return Variation_234
        if key == '060':
            return Variation_236
        if key == '070':
            return Variation_80
        if key == '080':
            return Variation_225
        if key == '090':
            return Variation_240
        if key == '100':
            return Variation_64
        assert_never(key)

    def __init__(self, arg : Optional[Variation_241_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_241':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_229, Variation_229_Arg]) -> 'Variation_241':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_230, Variation_230_Arg]) -> 'Variation_241':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_234, Variation_234_Arg]) -> 'Variation_241':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_236, Variation_236_Arg]) -> 'Variation_241':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_241':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_225, Variation_225_Arg]) -> 'Variation_241':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_240, Variation_240_Arg]) -> 'Variation_241':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_241':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_241':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_241':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_241':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_241':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_241':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_241':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_241':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_241':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_241':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_229:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_230:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_234:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_236:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_225:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_240:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_64:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_241':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_241':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_241':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_241':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_241':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_241':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_241':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_241':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_241':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_242_Arg : TypeAlias = Raw
class Variation_242(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Target Report',
        2: 'Start of Update Cycle',
        3: 'Periodic Status Message',
        4: 'Event-triggered Status Message',
    }

    def __init__(self, arg : Variation_242_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_243_Arg : TypeAlias = Raw
class Variation_243(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: 'SSR multilateration',
        1: 'Mode S multilateration',
        2: 'ADS-B',
        3: 'PSR',
        4: 'Magnetic Loop System',
        5: 'HF multilateration',
        6: 'Not defined',
        7: 'Other types',
    }

    def __init__(self, arg : Variation_243_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_244_Arg : TypeAlias = Raw
class Variation_244(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'No differential correction (ADS-B)',
        1: 'Differential correction (ADS-B)',
    }

    def __init__(self, arg : Variation_244_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_245_Arg : TypeAlias = Raw
class Variation_245(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Chain 1',
        1: 'Chain 2',
    }

    def __init__(self, arg : Variation_245_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_246_Arg : TypeAlias = Raw
class Variation_246(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Transponder Ground bit not set',
        1: 'Transponder Ground bit set',
    }

    def __init__(self, arg : Variation_246_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_247_Arg : TypeAlias = Raw
class Variation_247(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'No Corrupted reply in multilateration',
        1: 'Corrupted replies in multilateration',
    }

    def __init__(self, arg : Variation_247_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_248_Arg : TypeAlias = Raw
class Variation_248(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Actual target report',
        1: 'Simulated target report',
    }

    def __init__(self, arg : Variation_248_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_249_Arg : TypeAlias = Raw
class Variation_249(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Test Target',
    }

    def __init__(self, arg : Variation_249_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_250_Arg : TypeAlias = Raw
class Variation_250(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Report from target transponder',
        1: 'Report from field monitor (fixed transponder)',
    }

    def __init__(self, arg : Variation_250_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_251_Arg : TypeAlias = Raw
class Variation_251(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 2
    table = {
        0: 'Undetermined',
        1: 'Loop start',
        2: 'Loop finish',
    }

    def __init__(self, arg : Variation_251_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_252_Arg : TypeAlias = Raw
class Variation_252(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'Undetermined',
        1: 'Aircraft',
        2: 'Ground vehicle',
        3: 'Helicopter',
    }

    def __init__(self, arg : Variation_252_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_253_Arg : TypeAlias = Raw
class Variation_253(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Absence of SPI',
        1: 'Special Position Identification',
    }

    def __init__(self, arg : Variation_253_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_254_Arg_Group_1 = TypedDict('Variation_254_Arg_Group_1', {
    'TYP': Union[Variation_243, Variation_243_Arg],
    'DCR': Union[Variation_244, Variation_244_Arg],
    'CHN': Union[Variation_245, Variation_245_Arg],
    'GBS': Union[Variation_246, Variation_246_Arg],
    'CRT': Union[Variation_247, Variation_247_Arg],
})
Variation_254_Arg_Group_2 = TypedDict('Variation_254_Arg_Group_2', {
    'TYP': Union[Variation_243, Variation_243_Arg],
    'DCR': Union[Variation_244, Variation_244_Arg],
    'CHN': Union[Variation_245, Variation_245_Arg],
    'GBS': Union[Variation_246, Variation_246_Arg],
    'CRT': Union[Variation_247, Variation_247_Arg],
    'SIM': Union[Variation_248, Variation_248_Arg],
    'TST': Union[Variation_249, Variation_249_Arg],
    'RAB': Union[Variation_250, Variation_250_Arg],
    'LOP': Union[Variation_251, Variation_251_Arg],
    'TOT': Union[Variation_252, Variation_252_Arg],
})
Variation_254_Arg_Group_3 = TypedDict('Variation_254_Arg_Group_3', {
    'TYP': Union[Variation_243, Variation_243_Arg],
    'DCR': Union[Variation_244, Variation_244_Arg],
    'CHN': Union[Variation_245, Variation_245_Arg],
    'GBS': Union[Variation_246, Variation_246_Arg],
    'CRT': Union[Variation_247, Variation_247_Arg],
    'SIM': Union[Variation_248, Variation_248_Arg],
    'TST': Union[Variation_249, Variation_249_Arg],
    'RAB': Union[Variation_250, Variation_250_Arg],
    'LOP': Union[Variation_251, Variation_251_Arg],
    'TOT': Union[Variation_252, Variation_252_Arg],
    'SPI': Union[Variation_253, Variation_253_Arg],
})
Variation_254_Arg : TypeAlias = Union[
    int,
    Variation_254_Arg_Group_1,
    Tuple[int],
    Variation_254_Arg_Group_2,
    Tuple[int,int],
    Variation_254_Arg_Group_3,
    Tuple[int,int,int],
]
class Variation_254(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('TYP', Variation_243),
            ('DCR', Variation_244),
            ('CHN', Variation_245),
            ('GBS', Variation_246),
            ('CRT', Variation_247),
        ],
        [
            ('SIM', Variation_248),
            ('TST', Variation_249),
            ('RAB', Variation_250),
            ('LOP', Variation_251),
            ('TOT', Variation_252),
        ],
        [
            ('SPI', Variation_253),
            Spare(1, 6),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('', Variation_243, 0, 3),
        'DCR': ('', Variation_244, 3, 1),
        'CHN': ('', Variation_245, 4, 1),
        'GBS': ('', Variation_246, 5, 1),
        'CRT': ('', Variation_247, 6, 1),
        'SIM': ('', Variation_248, 0, 1),
        'TST': ('', Variation_249, 1, 1),
        'RAB': ('', Variation_250, 2, 1),
        'LOP': ('', Variation_251, 3, 2),
        'TOT': ('', Variation_252, 5, 2),
        'SPI': ('', Variation_253, 0, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_243]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DCR']) -> Type[Variation_244]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHN']) -> Type[Variation_245]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GBS']) -> Type[Variation_246]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CRT']) -> Type[Variation_247]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_248]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_249]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_250]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LOP']) -> Type[Variation_251]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOT']) -> Type[Variation_252]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_253]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['DCR'], Literal['CHN'], Literal['GBS'], Literal['CRT'], Literal['SIM'], Literal['TST'], Literal['RAB'], Literal['LOP'], Literal['TOT'], Literal['SPI']]) -> Union[Type['Variation_243'], Type['Variation_244'], Type['Variation_245'], Type['Variation_246'], Type['Variation_247'], Type['Variation_248'], Type['Variation_249'], Type['Variation_250'], Type['Variation_251'], Type['Variation_252'], Type['Variation_253']]:
        if key == 'TYP':
            return Variation_243
        if key == 'DCR':
            return Variation_244
        if key == 'CHN':
            return Variation_245
        if key == 'GBS':
            return Variation_246
        if key == 'CRT':
            return Variation_247
        if key == 'SIM':
            return Variation_248
        if key == 'TST':
            return Variation_249
        if key == 'RAB':
            return Variation_250
        if key == 'LOP':
            return Variation_251
        if key == 'TOT':
            return Variation_252
        if key == 'SPI':
            return Variation_253
        assert_never(key)

    def __init__(self, arg : Variation_254_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_254_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_254_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_254_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_243:
        ...

    @overload
    def get_item(self, name : Literal['DCR']) -> Variation_244:
        ...

    @overload
    def get_item(self, name : Literal['CHN']) -> Variation_245:
        ...

    @overload
    def get_item(self, name : Literal['GBS']) -> Variation_246:
        ...

    @overload
    def get_item(self, name : Literal['CRT']) -> Variation_247:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_248:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_249:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_250:
        ...

    @overload
    def get_item(self, name : Literal['LOP']) -> Variation_251:
        ...

    @overload
    def get_item(self, name : Literal['TOT']) -> Variation_252:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_253:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['DCR'], Literal['CHN'], Literal['GBS'], Literal['CRT'], Literal['SIM'], Literal['TST'], Literal['RAB'], Literal['LOP'], Literal['TOT'], Literal['SPI']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_243, Variation_243_Arg]) -> 'Variation_254':
        ...

    @overload
    def set_item(self, name : Literal['DCR'], val : Union[Variation_244, Variation_244_Arg]) -> 'Variation_254':
        ...

    @overload
    def set_item(self, name : Literal['CHN'], val : Union[Variation_245, Variation_245_Arg]) -> 'Variation_254':
        ...

    @overload
    def set_item(self, name : Literal['GBS'], val : Union[Variation_246, Variation_246_Arg]) -> 'Variation_254':
        ...

    @overload
    def set_item(self, name : Literal['CRT'], val : Union[Variation_247, Variation_247_Arg]) -> 'Variation_254':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['DCR'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['CHN'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['GBS'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['CRT'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['LOP'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['TOT'], f : Any) -> 'Variation_254':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_254':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_255_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_255(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 32
    quantity = Quantity('Signed', 8.381903171539307e-8, '°')

    def __init__(self, arg : Variation_255_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_256_Arg_Group = TypedDict('Variation_256_Arg_Group', {
    'LAT': Union[Variation_255, Variation_255_Arg],
    'LON': Union[Variation_255, Variation_255_Arg],
})
Variation_256_Arg : TypeAlias = Union[Raw, Variation_256_Arg_Group]
class Variation_256(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('LAT', Variation_255),
        ('LON', Variation_255),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude', Variation_255, 0, 32),
        'LON': ('Longitude', Variation_255, 32, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_255]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_255'], Type['Variation_255']]:
        if key == 'LAT':
            return Variation_255
        if key == 'LON':
            return Variation_255
        assert_never(key)

    def __init__(self, arg : Variation_256_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_255:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_255:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_256':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_256':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_256':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_256':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_257_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_257(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0, 'm')

    def __init__(self, arg : Variation_257_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_258_Arg_Group = TypedDict('Variation_258_Arg_Group', {
    'RHO': Union[Variation_257, Variation_257_Arg],
    'TH': Union[Variation_14, Variation_14_Arg],
})
Variation_258_Arg : TypeAlias = Union[Raw, Variation_258_Arg_Group]
class Variation_258(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('RHO', Variation_257),
        ('TH', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RHO': ('RHO', Variation_257, 0, 16),
        'TH': ('Theta', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RHO']) -> Type[Variation_257]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TH']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RHO'], Literal['TH']]) -> Union[Type['Variation_257'], Type['Variation_14']]:
        if key == 'RHO':
            return Variation_257
        if key == 'TH':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_258_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RHO']) -> Variation_257:
        ...

    @overload
    def get_item(self, name : Literal['TH']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['RHO'], Literal['TH']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RHO'], val : Union[Variation_257, Variation_257_Arg]) -> 'Variation_258':
        ...

    @overload
    def set_item(self, name : Literal['TH'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_258':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RHO'], f : Any) -> 'Variation_258':
        ...

    @overload
    def modify_item(self, name : Literal['TH'], f : Any) -> 'Variation_258':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_259_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_259(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 1.0, 'm')

    def __init__(self, arg : Variation_259_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_260_Arg_Group = TypedDict('Variation_260_Arg_Group', {
    'X': Union[Variation_259, Variation_259_Arg],
    'Y': Union[Variation_259, Variation_259_Arg],
})
Variation_260_Arg : TypeAlias = Union[Raw, Variation_260_Arg_Group]
class Variation_260(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('X', Variation_259),
        ('Y', Variation_259),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('X Coordinate', Variation_259, 0, 16),
        'Y': ('Y Coordinate', Variation_259, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_259]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_259]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_259'], Type['Variation_259']]:
        if key == 'X':
            return Variation_259
        if key == 'Y':
            return Variation_259
        assert_never(key)

    def __init__(self, arg : Variation_260_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_259:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_259:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_259, Variation_259_Arg]) -> 'Variation_260':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_259, Variation_259_Arg]) -> 'Variation_260':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_260':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_260':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_261_Arg_Group = TypedDict('Variation_261_Arg_Group', {
    'GSP': Union[Variation_67, Variation_67_Arg],
    'TRA': Union[Variation_14, Variation_14_Arg],
})
Variation_261_Arg : TypeAlias = Union[Raw, Variation_261_Arg_Group]
class Variation_261(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('GSP', Variation_67),
        ('TRA', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'GSP': ('Ground Speed', Variation_67, 0, 16),
        'TRA': ('Track Angle', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['GSP']) -> Type[Variation_67]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRA']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['GSP'], Literal['TRA']]) -> Union[Type['Variation_67'], Type['Variation_14']]:
        if key == 'GSP':
            return Variation_67
        if key == 'TRA':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_261_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['GSP']) -> Variation_67:
        ...

    @overload
    def get_item(self, name : Literal['TRA']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['GSP'], Literal['TRA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['GSP'], val : Union[Variation_67, Variation_67_Arg]) -> 'Variation_261':
        ...

    @overload
    def set_item(self, name : Literal['TRA'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_261':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['GSP'], f : Any) -> 'Variation_261':
        ...

    @overload
    def modify_item(self, name : Literal['TRA'], f : Any) -> 'Variation_261':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_262_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_262(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 6.25e-2, 'm/s')

    def __init__(self, arg : Variation_262_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_263_Arg_Group = TypedDict('Variation_263_Arg_Group', {
    'VX': Union[Variation_262, Variation_262_Arg],
    'VY': Union[Variation_262, Variation_262_Arg],
})
Variation_263_Arg : TypeAlias = Union[Raw, Variation_263_Arg_Group]
class Variation_263(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('VX', Variation_262),
        ('VY', Variation_262),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'VX': ('X Velocity', Variation_262, 0, 16),
        'VY': ('Y Velocity', Variation_262, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VX']) -> Type[Variation_262]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VY']) -> Type[Variation_262]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VX'], Literal['VY']]) -> Union[Type['Variation_262'], Type['Variation_262']]:
        if key == 'VX':
            return Variation_262
        if key == 'VY':
            return Variation_262
        assert_never(key)

    def __init__(self, arg : Variation_263_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['VX']) -> Variation_262:
        ...

    @overload
    def get_item(self, name : Literal['VY']) -> Variation_262:
        ...

    def get_item(self, name : Union[Literal['VX'], Literal['VY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['VX'], val : Union[Variation_262, Variation_262_Arg]) -> 'Variation_263':
        ...

    @overload
    def set_item(self, name : Literal['VY'], val : Union[Variation_262, Variation_262_Arg]) -> 'Variation_263':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['VX'], f : Any) -> 'Variation_263':
        ...

    @overload
    def modify_item(self, name : Literal['VY'], f : Any) -> 'Variation_263':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_264_Arg_Group = TypedDict('Variation_264_Arg_Group', {
    'TRK': Union[Variation_43, Variation_43_Arg],
})
Variation_264_Arg : TypeAlias = Union[Raw, Variation_264_Arg_Group]
class Variation_264(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('TRK', Variation_43),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TRK': ('Track Number', Variation_43, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['TRK']]) -> Union[Type['Variation_43']]:
        if key == 'TRK':
            return Variation_43
        assert_never(key)

    def __init__(self, arg : Variation_264_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['TRK']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['TRK'], val : Union[Variation_43, Variation_43_Arg]) -> 'Variation_264':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['TRK'], f : Any) -> 'Variation_264':
        return self._modify_item(name, f) # type: ignore

Variation_265_Arg : TypeAlias = Raw
class Variation_265(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Confirmed track',
        1: 'Track in initialisation phase',
    }

    def __init__(self, arg : Variation_265_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_266_Arg : TypeAlias = Raw
class Variation_266(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Last report for a track',
    }

    def __init__(self, arg : Variation_266_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_267_Arg : TypeAlias = Raw
class Variation_267(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'No extrapolation',
        1: 'Predictable extrapolation due to sensor refresh period (see NOTE)',
        2: 'Predictable extrapolation in masked area',
        3: 'Extrapolation due to unpredictable absence of detection',
    }

    def __init__(self, arg : Variation_267_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_268_Arg : TypeAlias = Raw
class Variation_268(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Horizontal manoeuvre',
    }

    def __init__(self, arg : Variation_268_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_269_Arg : TypeAlias = Raw
class Variation_269(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Tracking performed in \'Sensor Plane\', i.e. neither slant range correction nor projection was applied',
        1: 'Slant range correction and a suitable projection technique are used to track in a 2D.reference plane, tangential to the earth model at the Sensor Site co-ordinates',
    }

    def __init__(self, arg : Variation_269_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_270_Arg : TypeAlias = Raw
class Variation_270(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Measured position',
        1: 'Smoothed position',
    }

    def __init__(self, arg : Variation_270_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_271_Arg : TypeAlias = Raw
class Variation_271(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Unknown type of movement',
        1: 'Taking-off',
        2: 'Landing',
        3: 'Other types of movement',
    }

    def __init__(self, arg : Variation_271_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_272_Arg : TypeAlias = Raw
class Variation_272(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 3
    table = {
        0: 'No doubt',
        1: 'Doubtful correlation (undetermined reason)',
        2: 'Doubtful correlation in clutter',
        3: 'Loss of accuracy',
        4: 'Loss of accuracy in clutter',
        5: 'Unstable track',
        6: 'Previously coasted',
    }

    def __init__(self, arg : Variation_272_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_273_Arg : TypeAlias = Raw
class Variation_273(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'Merge or split indication undetermined',
        1: 'Track merged by association to plot',
        2: 'Track merged by non-association to plot',
        3: 'Split track',
    }

    def __init__(self, arg : Variation_273_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_274_Arg : TypeAlias = Raw
class Variation_274(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Ghost track',
    }

    def __init__(self, arg : Variation_274_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_275_Arg_Group_1 = TypedDict('Variation_275_Arg_Group_1', {
    'CNF': Union[Variation_265, Variation_265_Arg],
    'TRE': Union[Variation_266, Variation_266_Arg],
    'CST': Union[Variation_267, Variation_267_Arg],
    'MAH': Union[Variation_268, Variation_268_Arg],
    'TCC': Union[Variation_269, Variation_269_Arg],
    'STH': Union[Variation_270, Variation_270_Arg],
})
Variation_275_Arg_Group_2 = TypedDict('Variation_275_Arg_Group_2', {
    'CNF': Union[Variation_265, Variation_265_Arg],
    'TRE': Union[Variation_266, Variation_266_Arg],
    'CST': Union[Variation_267, Variation_267_Arg],
    'MAH': Union[Variation_268, Variation_268_Arg],
    'TCC': Union[Variation_269, Variation_269_Arg],
    'STH': Union[Variation_270, Variation_270_Arg],
    'TOM': Union[Variation_271, Variation_271_Arg],
    'DOU': Union[Variation_272, Variation_272_Arg],
    'MRS': Union[Variation_273, Variation_273_Arg],
})
Variation_275_Arg_Group_3 = TypedDict('Variation_275_Arg_Group_3', {
    'CNF': Union[Variation_265, Variation_265_Arg],
    'TRE': Union[Variation_266, Variation_266_Arg],
    'CST': Union[Variation_267, Variation_267_Arg],
    'MAH': Union[Variation_268, Variation_268_Arg],
    'TCC': Union[Variation_269, Variation_269_Arg],
    'STH': Union[Variation_270, Variation_270_Arg],
    'TOM': Union[Variation_271, Variation_271_Arg],
    'DOU': Union[Variation_272, Variation_272_Arg],
    'MRS': Union[Variation_273, Variation_273_Arg],
    'GHO': Union[Variation_274, Variation_274_Arg],
})
Variation_275_Arg : TypeAlias = Union[
    int,
    Variation_275_Arg_Group_1,
    Tuple[int],
    Variation_275_Arg_Group_2,
    Tuple[int,int],
    Variation_275_Arg_Group_3,
    Tuple[int,int,int],
]
class Variation_275(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('CNF', Variation_265),
            ('TRE', Variation_266),
            ('CST', Variation_267),
            ('MAH', Variation_268),
            ('TCC', Variation_269),
            ('STH', Variation_270),
        ],
        [
            ('TOM', Variation_271),
            ('DOU', Variation_272),
            ('MRS', Variation_273),
        ],
        [
            ('GHO', Variation_274),
            Spare(1, 6),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CNF': ('', Variation_265, 0, 1),
        'TRE': ('', Variation_266, 1, 1),
        'CST': ('', Variation_267, 2, 2),
        'MAH': ('', Variation_268, 4, 1),
        'TCC': ('', Variation_269, 5, 1),
        'STH': ('', Variation_270, 6, 1),
        'TOM': ('', Variation_271, 0, 2),
        'DOU': ('', Variation_272, 2, 3),
        'MRS': ('', Variation_273, 5, 2),
        'GHO': ('', Variation_274, 0, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_265]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRE']) -> Type[Variation_266]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_267]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAH']) -> Type[Variation_268]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCC']) -> Type[Variation_269]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STH']) -> Type[Variation_270]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOM']) -> Type[Variation_271]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DOU']) -> Type[Variation_272]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MRS']) -> Type[Variation_273]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GHO']) -> Type[Variation_274]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CNF'], Literal['TRE'], Literal['CST'], Literal['MAH'], Literal['TCC'], Literal['STH'], Literal['TOM'], Literal['DOU'], Literal['MRS'], Literal['GHO']]) -> Union[Type['Variation_265'], Type['Variation_266'], Type['Variation_267'], Type['Variation_268'], Type['Variation_269'], Type['Variation_270'], Type['Variation_271'], Type['Variation_272'], Type['Variation_273'], Type['Variation_274']]:
        if key == 'CNF':
            return Variation_265
        if key == 'TRE':
            return Variation_266
        if key == 'CST':
            return Variation_267
        if key == 'MAH':
            return Variation_268
        if key == 'TCC':
            return Variation_269
        if key == 'STH':
            return Variation_270
        if key == 'TOM':
            return Variation_271
        if key == 'DOU':
            return Variation_272
        if key == 'MRS':
            return Variation_273
        if key == 'GHO':
            return Variation_274
        assert_never(key)

    def __init__(self, arg : Variation_275_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_275_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_275_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_275_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_265:
        ...

    @overload
    def get_item(self, name : Literal['TRE']) -> Variation_266:
        ...

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_267:
        ...

    @overload
    def get_item(self, name : Literal['MAH']) -> Variation_268:
        ...

    @overload
    def get_item(self, name : Literal['TCC']) -> Variation_269:
        ...

    @overload
    def get_item(self, name : Literal['STH']) -> Variation_270:
        ...

    @overload
    def get_item(self, name : Literal['TOM']) -> Variation_271:
        ...

    @overload
    def get_item(self, name : Literal['DOU']) -> Variation_272:
        ...

    @overload
    def get_item(self, name : Literal['MRS']) -> Variation_273:
        ...

    @overload
    def get_item(self, name : Literal['GHO']) -> Variation_274:
        ...

    def get_item(self, name : Union[Literal['CNF'], Literal['TRE'], Literal['CST'], Literal['MAH'], Literal['TCC'], Literal['STH'], Literal['TOM'], Literal['DOU'], Literal['MRS'], Literal['GHO']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_265, Variation_265_Arg]) -> 'Variation_275':
        ...

    @overload
    def set_item(self, name : Literal['TRE'], val : Union[Variation_266, Variation_266_Arg]) -> 'Variation_275':
        ...

    @overload
    def set_item(self, name : Literal['CST'], val : Union[Variation_267, Variation_267_Arg]) -> 'Variation_275':
        ...

    @overload
    def set_item(self, name : Literal['MAH'], val : Union[Variation_268, Variation_268_Arg]) -> 'Variation_275':
        ...

    @overload
    def set_item(self, name : Literal['TCC'], val : Union[Variation_269, Variation_269_Arg]) -> 'Variation_275':
        ...

    @overload
    def set_item(self, name : Literal['STH'], val : Union[Variation_270, Variation_270_Arg]) -> 'Variation_275':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_275':
        ...

    @overload
    def modify_item(self, name : Literal['TRE'], f : Any) -> 'Variation_275':
        ...

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_275':
        ...

    @overload
    def modify_item(self, name : Literal['MAH'], f : Any) -> 'Variation_275':
        ...

    @overload
    def modify_item(self, name : Literal['TCC'], f : Any) -> 'Variation_275':
        ...

    @overload
    def modify_item(self, name : Literal['STH'], f : Any) -> 'Variation_275':
        ...

    @overload
    def modify_item(self, name : Literal['TOM'], f : Any) -> 'Variation_275':
        ...

    @overload
    def modify_item(self, name : Literal['DOU'], f : Any) -> 'Variation_275':
        ...

    @overload
    def modify_item(self, name : Literal['MRS'], f : Any) -> 'Variation_275':
        ...

    @overload
    def modify_item(self, name : Literal['GHO'], f : Any) -> 'Variation_275':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_276_Arg : TypeAlias = Raw
class Variation_276(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode-3/A code derived from the reply of the transponder',
        1: 'Mode-3/A code not extracted during the last scan',
    }

    def __init__(self, arg : Variation_276_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_277_Arg_Group = TypedDict('Variation_277_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_276, Variation_276_Arg],
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_277_Arg : TypeAlias = Union[Raw, Variation_277_Arg_Group]
class Variation_277(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_276),
        Spare(3, 1),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('Validated', Variation_16, 0, 1),
        'G': ('Garbled', Variation_17, 1, 1),
        'L': ('', Variation_276, 2, 1),
        'MODE3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_276]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_276'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_276
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_277_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_276:
        ...

    @overload
    def get_item(self, name : Literal['MODE3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_277':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_277':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_276, Variation_276_Arg]) -> 'Variation_277':
        ...

    @overload
    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_277':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_277':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_277':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_277':
        ...

    @overload
    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_277':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_278_Arg : TypeAlias = Raw
class Variation_278(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24

    def __init__(self, arg : Variation_278_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_279_Arg : TypeAlias = Raw
class Variation_279(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Callsign or registration downlinked from transponder',
        1: 'Callsign not downlinked from transponder',
        2: 'Registration not downlinked from transponder',
    }

    def __init__(self, arg : Variation_279_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_280_Arg_Group = TypedDict('Variation_280_Arg_Group', {
    'STI': Union[Variation_279, Variation_279_Arg],
    'CHR': Union[Variation_196, Variation_196_Arg],
})
Variation_280_Arg : TypeAlias = Union[Raw, Variation_280_Arg_Group]
class Variation_280(Group):
    variation = 'Group'

    bit_size = 56

    subitems_list = [
        ('STI', Variation_279),
        Spare(2, 6),
        ('CHR', Variation_196),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STI': ('', Variation_279, 0, 2),
        'CHR': ('Characters 1-8 (Coded on 6 Bits Each) Defining Target Identification', Variation_196, 8, 48),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['STI']) -> Type[Variation_279]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHR']) -> Type[Variation_196]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['STI'], Literal['CHR']]) -> Union[Type['Variation_279'], Type['Variation_196']]:
        if key == 'STI':
            return Variation_279
        if key == 'CHR':
            return Variation_196
        assert_never(key)

    def __init__(self, arg : Variation_280_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['STI']) -> Variation_279:
        ...

    @overload
    def get_item(self, name : Literal['CHR']) -> Variation_196:
        ...

    def get_item(self, name : Union[Literal['STI'], Literal['CHR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['STI'], val : Union[Variation_279, Variation_279_Arg]) -> 'Variation_280':
        ...

    @overload
    def set_item(self, name : Literal['CHR'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_280':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['STI'], f : Any) -> 'Variation_280':
        ...

    @overload
    def modify_item(self, name : Literal['CHR'], f : Any) -> 'Variation_280':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_281_Arg : TypeAlias = Raw
class Variation_281(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 56

    def __init__(self, arg : Variation_281_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_282_Arg : TypeAlias = Raw
class Variation_282(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 4

    def __init__(self, arg : Variation_282_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_283_Arg_Group = TypedDict('Variation_283_Arg_Group', {
    'MBDATA': Union[Variation_281, Variation_281_Arg],
    'BDS1': Union[Variation_187, Variation_187_Arg],
    'BDS2': Union[Variation_282, Variation_282_Arg],
})
Variation_283_Arg : TypeAlias = Union[Raw, Variation_283_Arg_Group]
class Variation_283(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('MBDATA', Variation_281),
        ('BDS1', Variation_187),
        ('BDS2', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MBDATA': ('', Variation_281, 0, 56),
        'BDS1': ('', Variation_187, 56, 4),
        'BDS2': ('', Variation_282, 60, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MBDATA']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BDS1']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BDS2']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MBDATA'], Literal['BDS1'], Literal['BDS2']]) -> Union[Type['Variation_281'], Type['Variation_187'], Type['Variation_282']]:
        if key == 'MBDATA':
            return Variation_281
        if key == 'BDS1':
            return Variation_187
        if key == 'BDS2':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_283_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MBDATA']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['BDS1']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['BDS2']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['MBDATA'], Literal['BDS1'], Literal['BDS2']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MBDATA'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_283':
        ...

    @overload
    def set_item(self, name : Literal['BDS1'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_283':
        ...

    @overload
    def set_item(self, name : Literal['BDS2'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_283':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MBDATA'], f : Any) -> 'Variation_283':
        ...

    @overload
    def modify_item(self, name : Literal['BDS1'], f : Any) -> 'Variation_283':
        ...

    @overload
    def modify_item(self, name : Literal['BDS2'], f : Any) -> 'Variation_283':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_284_Arg : TypeAlias = Union[Variation_283, Variation_283_Arg]
class Variation_284(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 64
    variation_type = Variation_283

    @classmethod
    def spec(cls) -> Type[Variation_283]:
        return Variation_283

    def __init__(self, arg : List[Union[Variation_283, Variation_283_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_283, Variation_283_Arg]) -> 'Variation_284':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_283, Variation_283_Arg]) -> 'Variation_284':
        return self._prepend_item(arg) # type: ignore

Variation_285_Arg : TypeAlias = Raw
class Variation_285(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'Unknown',
        1: 'ATC equipment maintenance',
        2: 'Airport maintenance',
        3: 'Fire',
        4: 'Bird scarer',
        5: 'Snow plough',
        6: 'Runway sweeper',
        7: 'Emergency',
        8: 'Police',
        9: 'Bus',
        10: 'Tug (push/tow)',
        11: 'Grass cutter',
        12: 'Fuel',
        13: 'Baggage',
        14: 'Catering',
        15: 'Aircraft maintenance',
        16: 'Flyco (follow me)',
    }

    def __init__(self, arg : Variation_285_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_286_Arg_Group = TypedDict('Variation_286_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'FL': Union[Variation_21, Variation_21_Arg],
})
Variation_286_Arg : TypeAlias = Union[Raw, Variation_286_Arg_Group]
class Variation_286(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('FL', Variation_21),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('Validated', Variation_16, 0, 1),
        'G': ('Garbled', Variation_17, 1, 1),
        'FL': ('Flight Level', Variation_21, 2, 14),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FL']) -> Type[Variation_21]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['FL']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_21']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'FL':
            return Variation_21
        assert_never(key)

    def __init__(self, arg : Variation_286_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['FL']) -> Variation_21:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['FL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_286':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_286':
        ...

    @overload
    def set_item(self, name : Literal['FL'], val : Union[Variation_21, Variation_21_Arg]) -> 'Variation_286':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_286':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_286':
        ...

    @overload
    def modify_item(self, name : Literal['FL'], f : Any) -> 'Variation_286':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_287_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft']]]
class Variation_287(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 6.25, 'ft')

    def __init__(self, arg : Variation_287_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_288_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_288(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    quantity = Quantity('Unsigned', 1.0, 'm')

    def __init__(self, arg : Variation_288_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_289_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_289(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    quantity = Quantity('Unsigned', 2.8125, '°')

    def __init__(self, arg : Variation_289_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_290_Arg_Group_1 = TypedDict('Variation_290_Arg_Group_1', {
    'LENGTH': Union[Variation_288, Variation_288_Arg],
})
Variation_290_Arg_Group_2 = TypedDict('Variation_290_Arg_Group_2', {
    'LENGTH': Union[Variation_288, Variation_288_Arg],
    'ORIENTATION': Union[Variation_289, Variation_289_Arg],
})
Variation_290_Arg_Group_3 = TypedDict('Variation_290_Arg_Group_3', {
    'LENGTH': Union[Variation_288, Variation_288_Arg],
    'ORIENTATION': Union[Variation_289, Variation_289_Arg],
    'WIDTH': Union[Variation_288, Variation_288_Arg],
})
Variation_290_Arg : TypeAlias = Union[
    int,
    Variation_290_Arg_Group_1,
    Tuple[int],
    Variation_290_Arg_Group_2,
    Tuple[int,int],
    Variation_290_Arg_Group_3,
    Tuple[int,int,int],
]
class Variation_290(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('LENGTH', Variation_288),
        ],
        [
            ('ORIENTATION', Variation_289),
        ],
        [
            ('WIDTH', Variation_288),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LENGTH': ('Length', Variation_288, 0, 7),
        'ORIENTATION': ('Orientation', Variation_289, 0, 7),
        'WIDTH': ('Width', Variation_288, 0, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LENGTH']) -> Type[Variation_288]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ORIENTATION']) -> Type[Variation_289]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WIDTH']) -> Type[Variation_288]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LENGTH'], Literal['ORIENTATION'], Literal['WIDTH']]) -> Union[Type['Variation_288'], Type['Variation_289'], Type['Variation_288']]:
        if key == 'LENGTH':
            return Variation_288
        if key == 'ORIENTATION':
            return Variation_289
        if key == 'WIDTH':
            return Variation_288
        assert_never(key)

    def __init__(self, arg : Variation_290_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_290_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_290_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_290_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LENGTH']) -> Variation_288:
        ...

    @overload
    def get_item(self, name : Literal['ORIENTATION']) -> Variation_289:
        ...

    @overload
    def get_item(self, name : Literal['WIDTH']) -> Variation_288:
        ...

    def get_item(self, name : Union[Literal['LENGTH'], Literal['ORIENTATION'], Literal['WIDTH']]) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['LENGTH'], val : Union[Variation_288, Variation_288_Arg]) -> 'Variation_290':
        return self._set_item(name, val) # type: ignore

    @overload
    def modify_item(self, name : Literal['LENGTH'], f : Any) -> 'Variation_290':
        ...

    @overload
    def modify_item(self, name : Literal['ORIENTATION'], f : Any) -> 'Variation_290':
        ...

    @overload
    def modify_item(self, name : Literal['WIDTH'], f : Any) -> 'Variation_290':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_291_Arg : TypeAlias = Raw
class Variation_291(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Operational',
        1: 'Degraded',
        2: 'NOGO',
    }

    def __init__(self, arg : Variation_291_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_292_Arg : TypeAlias = Raw
class Variation_292(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'No overload',
        1: 'Overload',
    }

    def __init__(self, arg : Variation_292_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_293_Arg : TypeAlias = Raw
class Variation_293(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Valid',
        1: 'Invalid',
    }

    def __init__(self, arg : Variation_293_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_294_Arg : TypeAlias = Raw
class Variation_294(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Normal Operation',
        1: 'Diversity degraded',
    }

    def __init__(self, arg : Variation_294_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_295_Arg : TypeAlias = Raw
class Variation_295(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Test Target Operative',
        1: 'Test Target Failure',
    }

    def __init__(self, arg : Variation_295_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_296_Arg_Group = TypedDict('Variation_296_Arg_Group', {
    'NOGO': Union[Variation_291, Variation_291_Arg],
    'OVL': Union[Variation_292, Variation_292_Arg],
    'TSV': Union[Variation_293, Variation_293_Arg],
    'DIV': Union[Variation_294, Variation_294_Arg],
    'TTF': Union[Variation_295, Variation_295_Arg],
})
Variation_296_Arg : TypeAlias = Union[Raw, Variation_296_Arg_Group]
class Variation_296(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('NOGO', Variation_291),
        ('OVL', Variation_292),
        ('TSV', Variation_293),
        ('DIV', Variation_294),
        ('TTF', Variation_295),
        Spare(6, 2),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NOGO': ('Operational Release Status of the System', Variation_291, 0, 2),
        'OVL': ('Overload Indicator', Variation_292, 2, 1),
        'TSV': ('Time Source Validity', Variation_293, 3, 1),
        'DIV': ('', Variation_294, 4, 1),
        'TTF': ('', Variation_295, 5, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NOGO']) -> Type[Variation_291]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVL']) -> Type[Variation_292]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSV']) -> Type[Variation_293]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DIV']) -> Type[Variation_294]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TTF']) -> Type[Variation_295]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NOGO'], Literal['OVL'], Literal['TSV'], Literal['DIV'], Literal['TTF']]) -> Union[Type['Variation_291'], Type['Variation_292'], Type['Variation_293'], Type['Variation_294'], Type['Variation_295']]:
        if key == 'NOGO':
            return Variation_291
        if key == 'OVL':
            return Variation_292
        if key == 'TSV':
            return Variation_293
        if key == 'DIV':
            return Variation_294
        if key == 'TTF':
            return Variation_295
        assert_never(key)

    def __init__(self, arg : Variation_296_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NOGO']) -> Variation_291:
        ...

    @overload
    def get_item(self, name : Literal['OVL']) -> Variation_292:
        ...

    @overload
    def get_item(self, name : Literal['TSV']) -> Variation_293:
        ...

    @overload
    def get_item(self, name : Literal['DIV']) -> Variation_294:
        ...

    @overload
    def get_item(self, name : Literal['TTF']) -> Variation_295:
        ...

    def get_item(self, name : Union[Literal['NOGO'], Literal['OVL'], Literal['TSV'], Literal['DIV'], Literal['TTF']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NOGO'], val : Union[Variation_291, Variation_291_Arg]) -> 'Variation_296':
        ...

    @overload
    def set_item(self, name : Literal['OVL'], val : Union[Variation_292, Variation_292_Arg]) -> 'Variation_296':
        ...

    @overload
    def set_item(self, name : Literal['TSV'], val : Union[Variation_293, Variation_293_Arg]) -> 'Variation_296':
        ...

    @overload
    def set_item(self, name : Literal['DIV'], val : Union[Variation_294, Variation_294_Arg]) -> 'Variation_296':
        ...

    @overload
    def set_item(self, name : Literal['TTF'], val : Union[Variation_295, Variation_295_Arg]) -> 'Variation_296':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NOGO'], f : Any) -> 'Variation_296':
        ...

    @overload
    def modify_item(self, name : Literal['OVL'], f : Any) -> 'Variation_296':
        ...

    @overload
    def modify_item(self, name : Literal['TSV'], f : Any) -> 'Variation_296':
        ...

    @overload
    def modify_item(self, name : Literal['DIV'], f : Any) -> 'Variation_296':
        ...

    @overload
    def modify_item(self, name : Literal['TTF'], f : Any) -> 'Variation_296':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_297_Arg : TypeAlias = Raw
class Variation_297(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default',
        1: 'In Trouble',
    }

    def __init__(self, arg : Variation_297_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_298_Arg : TypeAlias = Raw
class Variation_298(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 7
    table = {
        1: 'Towing aircraft',
        2: '“Follow me” operation',
        3: 'Runway check',
        4: 'Emergency operation (fire, medical...)',
        5: 'Work in progress (maintenance, birds scarer, sweepers...)',
    }

    def __init__(self, arg : Variation_298_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_299_Arg_Group = TypedDict('Variation_299_Arg_Group', {
    'TRB': Union[Variation_297, Variation_297_Arg],
    'MSG': Union[Variation_298, Variation_298_Arg],
})
Variation_299_Arg : TypeAlias = Union[Raw, Variation_299_Arg_Group]
class Variation_299(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('TRB', Variation_297),
        ('MSG', Variation_298),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TRB': ('', Variation_297, 0, 1),
        'MSG': ('', Variation_298, 1, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TRB']) -> Type[Variation_297]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSG']) -> Type[Variation_298]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TRB'], Literal['MSG']]) -> Union[Type['Variation_297'], Type['Variation_298']]:
        if key == 'TRB':
            return Variation_297
        if key == 'MSG':
            return Variation_298
        assert_never(key)

    def __init__(self, arg : Variation_299_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TRB']) -> Variation_297:
        ...

    @overload
    def get_item(self, name : Literal['MSG']) -> Variation_298:
        ...

    def get_item(self, name : Union[Literal['TRB'], Literal['MSG']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TRB'], val : Union[Variation_297, Variation_297_Arg]) -> 'Variation_299':
        ...

    @overload
    def set_item(self, name : Literal['MSG'], val : Union[Variation_298, Variation_298_Arg]) -> 'Variation_299':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TRB'], f : Any) -> 'Variation_299':
        ...

    @overload
    def modify_item(self, name : Literal['MSG'], f : Any) -> 'Variation_299':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_300_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_300(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 0.25, 'm')

    def __init__(self, arg : Variation_300_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_301_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_301(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 0.25, 'm')

    def __init__(self, arg : Variation_301_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_302_Arg_Group = TypedDict('Variation_302_Arg_Group', {
    'DEVX': Union[Variation_300, Variation_300_Arg],
    'DEVY': Union[Variation_300, Variation_300_Arg],
    'COVXY': Union[Variation_301, Variation_301_Arg],
})
Variation_302_Arg : TypeAlias = Union[Raw, Variation_302_Arg_Group]
class Variation_302(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('DEVX', Variation_300),
        ('DEVY', Variation_300),
        ('COVXY', Variation_301),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'DEVX': ('Standard Deviation of X Component', Variation_300, 0, 8),
        'DEVY': ('Standard Deviation of Y Component', Variation_300, 8, 8),
        'COVXY': ('Covariance in Two’s Complement Form', Variation_301, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['DEVX']) -> Type[Variation_300]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DEVY']) -> Type[Variation_300]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVXY']) -> Type[Variation_301]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['DEVX'], Literal['DEVY'], Literal['COVXY']]) -> Union[Type['Variation_300'], Type['Variation_300'], Type['Variation_301']]:
        if key == 'DEVX':
            return Variation_300
        if key == 'DEVY':
            return Variation_300
        if key == 'COVXY':
            return Variation_301
        assert_never(key)

    def __init__(self, arg : Variation_302_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['DEVX']) -> Variation_300:
        ...

    @overload
    def get_item(self, name : Literal['DEVY']) -> Variation_300:
        ...

    @overload
    def get_item(self, name : Literal['COVXY']) -> Variation_301:
        ...

    def get_item(self, name : Union[Literal['DEVX'], Literal['DEVY'], Literal['COVXY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['DEVX'], val : Union[Variation_300, Variation_300_Arg]) -> 'Variation_302':
        ...

    @overload
    def set_item(self, name : Literal['DEVY'], val : Union[Variation_300, Variation_300_Arg]) -> 'Variation_302':
        ...

    @overload
    def set_item(self, name : Literal['COVXY'], val : Union[Variation_301, Variation_301_Arg]) -> 'Variation_302':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['DEVX'], f : Any) -> 'Variation_302':
        ...

    @overload
    def modify_item(self, name : Literal['DEVY'], f : Any) -> 'Variation_302':
        ...

    @overload
    def modify_item(self, name : Literal['COVXY'], f : Any) -> 'Variation_302':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_303_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_303(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 1.0, 'm')

    def __init__(self, arg : Variation_303_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_304_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_304(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 0.15, '°')

    def __init__(self, arg : Variation_304_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_305_Arg_Group = TypedDict('Variation_305_Arg_Group', {
    'DRHO': Union[Variation_303, Variation_303_Arg],
    'DTHETA': Union[Variation_304, Variation_304_Arg],
})
Variation_305_Arg : TypeAlias = Union[Raw, Variation_305_Arg_Group]
class Variation_305(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('DRHO', Variation_303),
        ('DTHETA', Variation_304),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'DRHO': ('', Variation_303, 0, 8),
        'DTHETA': ('', Variation_304, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['DRHO']) -> Type[Variation_303]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DTHETA']) -> Type[Variation_304]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['DRHO'], Literal['DTHETA']]) -> Union[Type['Variation_303'], Type['Variation_304']]:
        if key == 'DRHO':
            return Variation_303
        if key == 'DTHETA':
            return Variation_304
        assert_never(key)

    def __init__(self, arg : Variation_305_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['DRHO']) -> Variation_303:
        ...

    @overload
    def get_item(self, name : Literal['DTHETA']) -> Variation_304:
        ...

    def get_item(self, name : Union[Literal['DRHO'], Literal['DTHETA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['DRHO'], val : Union[Variation_303, Variation_303_Arg]) -> 'Variation_305':
        ...

    @overload
    def set_item(self, name : Literal['DTHETA'], val : Union[Variation_304, Variation_304_Arg]) -> 'Variation_305':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['DRHO'], f : Any) -> 'Variation_305':
        ...

    @overload
    def modify_item(self, name : Literal['DTHETA'], f : Any) -> 'Variation_305':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_306_Arg : TypeAlias = Union[Variation_305, Variation_305_Arg]
class Variation_306(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_305

    @classmethod
    def spec(cls) -> Type[Variation_305]:
        return Variation_305

    def __init__(self, arg : List[Union[Variation_305, Variation_305_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_305, Variation_305_Arg]) -> 'Variation_306':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_305, Variation_305_Arg]) -> 'Variation_306':
        return self._prepend_item(arg) # type: ignore

Variation_307_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_307(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 6.25e-2, 'm/s²')

    def __init__(self, arg : Variation_307_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_308_Arg_Group = TypedDict('Variation_308_Arg_Group', {
    'AX': Union[Variation_307, Variation_307_Arg],
    'AY': Union[Variation_307, Variation_307_Arg],
})
Variation_308_Arg : TypeAlias = Union[Raw, Variation_308_Arg_Group]
class Variation_308(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('AX', Variation_307),
        ('AY', Variation_307),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'AX': ('X Acceleration', Variation_307, 0, 8),
        'AY': ('Y Acceleration', Variation_307, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AX']) -> Type[Variation_307]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AY']) -> Type[Variation_307]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AX'], Literal['AY']]) -> Union[Type['Variation_307'], Type['Variation_307']]:
        if key == 'AX':
            return Variation_307
        if key == 'AY':
            return Variation_307
        assert_never(key)

    def __init__(self, arg : Variation_308_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['AX']) -> Variation_307:
        ...

    @overload
    def get_item(self, name : Literal['AY']) -> Variation_307:
        ...

    def get_item(self, name : Union[Literal['AX'], Literal['AY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['AX'], val : Union[Variation_307, Variation_307_Arg]) -> 'Variation_308':
        ...

    @overload
    def set_item(self, name : Literal['AY'], val : Union[Variation_307, Variation_307_Arg]) -> 'Variation_308':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['AX'], f : Any) -> 'Variation_308':
        ...

    @overload
    def modify_item(self, name : Literal['AY'], f : Any) -> 'Variation_308':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_309_Arg = TypedDict('Variation_309_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_242, Variation_242_Arg],
    '020': Union[Variation_254, Variation_254_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '041': Union[Variation_256, Variation_256_Arg],
    '040': Union[Variation_258, Variation_258_Arg],
    '042': Union[Variation_260, Variation_260_Arg],
    '200': Union[Variation_261, Variation_261_Arg],
    '202': Union[Variation_263, Variation_263_Arg],
    '161': Union[Variation_264, Variation_264_Arg],
    '170': Union[Variation_275, Variation_275_Arg],
    '060': Union[Variation_277, Variation_277_Arg],
    '220': Union[Variation_278, Variation_278_Arg],
    '245': Union[Variation_280, Variation_280_Arg],
    '250': Union[Variation_284, Variation_284_Arg],
    '300': Union[Variation_285, Variation_285_Arg],
    '090': Union[Variation_286, Variation_286_Arg],
    '091': Union[Variation_287, Variation_287_Arg],
    '270': Union[Variation_290, Variation_290_Arg],
    '550': Union[Variation_296, Variation_296_Arg],
    '310': Union[Variation_299, Variation_299_Arg],
    '500': Union[Variation_302, Variation_302_Arg],
    '280': Union[Variation_306, Variation_306_Arg],
    '131': Union[Variation_0, Variation_0_Arg],
    '210': Union[Variation_308, Variation_308_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
}, total=False)
class Variation_309(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_242),
        ('020', Variation_254),
        ('140', Variation_80),
        ('041', Variation_256),
        ('040', Variation_258),
        ('042', Variation_260),
        ('200', Variation_261),
        ('202', Variation_263),
        ('161', Variation_264),
        ('170', Variation_275),
        ('060', Variation_277),
        ('220', Variation_278),
        ('245', Variation_280),
        ('250', Variation_284),
        ('300', Variation_285),
        ('090', Variation_286),
        ('091', Variation_287),
        ('270', Variation_290),
        ('550', Variation_296),
        ('310', Variation_299),
        ('500', Variation_302),
        ('280', Variation_306),
        ('131', Variation_0),
        ('210', Variation_308),
        None,
        ('SP', Variation_62),
        ('RE', Variation_202),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '000': ('Message Type', Variation_242, 0x40000000),
        '020': ('Target Report Descriptor', Variation_254, 0x20000000),
        '140': ('Time of Day', Variation_80, 0x10000000),
        '041': ('Position in WGS-84 Co-ordinates', Variation_256, 0x08000000),
        '040': ('Measured Position in Polar Co-ordinates', Variation_258, 0x04000000),
        '042': ('Position in Cartesian Co-ordinates', Variation_260, 0x02000000),
        '200': ('Calculated Track Velocity in Polar Co-ordinates', Variation_261, 0x01800000),
        '202': ('Calculated Track Velocity in Cartesian Co-ordinates', Variation_263, 0x01400000),
        '161': ('Track Number', Variation_264, 0x01200000),
        '170': ('Track Status', Variation_275, 0x01100000),
        '060': ('Mode-3/A Code in Octal Representation', Variation_277, 0x01080000),
        '220': ('Target Address', Variation_278, 0x01040000),
        '245': ('Target Identification', Variation_280, 0x01020000),
        '250': ('Mode S MB Data', Variation_284, 0x01018000),
        '300': ('Vehicle Fleet Identification', Variation_285, 0x01014000),
        '090': ('Flight Level in Binary Representation', Variation_286, 0x01012000),
        '091': ('Measured Height', Variation_287, 0x01011000),
        '270': ('Target Size and Orientation', Variation_290, 0x01010800),
        '550': ('System Status', Variation_296, 0x01010400),
        '310': ('Pre-programmed Message', Variation_299, 0x01010200),
        '500': ('Standard Deviation of Position', Variation_302, 0x01010180),
        '280': ('Presence', Variation_306, 0x01010140),
        '131': ('Amplitude of Primary Plot', Variation_0, 0x01010120),
        '210': ('Calculated Acceleration', Variation_308, 0x01010110),
        'SP': ('Special Purpose Field', Variation_62, 0x01010104),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_242]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_254]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_256]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_258]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_260]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_261]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['202']) -> Type[Variation_263]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_264]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_275]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_277]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['245']) -> Type[Variation_280]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_284]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_285]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_286]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['091']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['270']) -> Type[Variation_290]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['550']) -> Type[Variation_296]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['310']) -> Type[Variation_299]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_302]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['280']) -> Type[Variation_306]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['131']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_308]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['020'], Literal['140'], Literal['041'], Literal['040'], Literal['042'], Literal['200'], Literal['202'], Literal['161'], Literal['170'], Literal['060'], Literal['220'], Literal['245'], Literal['250'], Literal['300'], Literal['090'], Literal['091'], Literal['270'], Literal['550'], Literal['310'], Literal['500'], Literal['280'], Literal['131'], Literal['210'], Literal['SP'], Literal['RE']]) -> Union[Type['Variation_1'], Type['Variation_242'], Type['Variation_254'], Type['Variation_80'], Type['Variation_256'], Type['Variation_258'], Type['Variation_260'], Type['Variation_261'], Type['Variation_263'], Type['Variation_264'], Type['Variation_275'], Type['Variation_277'], Type['Variation_278'], Type['Variation_280'], Type['Variation_284'], Type['Variation_285'], Type['Variation_286'], Type['Variation_287'], Type['Variation_290'], Type['Variation_296'], Type['Variation_299'], Type['Variation_302'], Type['Variation_306'], Type['Variation_0'], Type['Variation_308'], Type['Variation_62'], Type['Variation_202']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_242
        if key == '020':
            return Variation_254
        if key == '140':
            return Variation_80
        if key == '041':
            return Variation_256
        if key == '040':
            return Variation_258
        if key == '042':
            return Variation_260
        if key == '200':
            return Variation_261
        if key == '202':
            return Variation_263
        if key == '161':
            return Variation_264
        if key == '170':
            return Variation_275
        if key == '060':
            return Variation_277
        if key == '220':
            return Variation_278
        if key == '245':
            return Variation_280
        if key == '250':
            return Variation_284
        if key == '300':
            return Variation_285
        if key == '090':
            return Variation_286
        if key == '091':
            return Variation_287
        if key == '270':
            return Variation_290
        if key == '550':
            return Variation_296
        if key == '310':
            return Variation_299
        if key == '500':
            return Variation_302
        if key == '280':
            return Variation_306
        if key == '131':
            return Variation_0
        if key == '210':
            return Variation_308
        if key == 'SP':
            return Variation_62
        if key == 'RE':
            return Variation_202
        assert_never(key)

    def __init__(self, arg : Optional[Variation_309_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_242, Variation_242_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_254, Variation_254_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_256, Variation_256_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_258, Variation_258_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_260, Variation_260_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_261, Variation_261_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['202'], val : Union[Variation_263, Variation_263_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_264, Variation_264_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_275, Variation_275_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_277, Variation_277_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['245'], val : Union[Variation_280, Variation_280_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_284, Variation_284_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_285, Variation_285_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_286, Variation_286_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['091'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['270'], val : Union[Variation_290, Variation_290_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['550'], val : Union[Variation_296, Variation_296_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['310'], val : Union[Variation_299, Variation_299_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_302, Variation_302_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['280'], val : Union[Variation_306, Variation_306_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['131'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_308, Variation_308_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_309':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_309':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['202']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['245']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['091']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['270']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['550']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['310']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['280']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['131']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_309':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_309':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_242:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_254:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_256:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_258:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_260:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_261:
        ...

    @overload
    def get_item(self, name : Literal['202']) -> Variation_263:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_264:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_275:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_277:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['245']) -> Variation_280:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_284:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_285:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_286:
        ...

    @overload
    def get_item(self, name : Literal['091']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['270']) -> Variation_290:
        ...

    @overload
    def get_item(self, name : Literal['550']) -> Variation_296:
        ...

    @overload
    def get_item(self, name : Literal['310']) -> Variation_299:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_302:
        ...

    @overload
    def get_item(self, name : Literal['280']) -> Variation_306:
        ...

    @overload
    def get_item(self, name : Literal['131']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_308:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['202'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['245'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['091'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['270'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['550'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['310'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['280'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['131'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_309':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_309':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_310_Arg_Group = TypedDict('Variation_310_Arg_Group', {
    'SAC': Union[Variation_0, Variation_0_Arg],
    'SIC': Union[Variation_0, Variation_0_Arg],
})
Variation_310_Arg : TypeAlias = Union[Raw, Variation_310_Arg_Group]
class Variation_310(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('SAC', Variation_0),
        ('SIC', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SAC': ('System Area Code Fixed to Zero', Variation_0, 0, 8),
        'SIC': ('System Identification Code', Variation_0, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SAC']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIC']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SAC'], Literal['SIC']]) -> Union[Type['Variation_0'], Type['Variation_0']]:
        if key == 'SAC':
            return Variation_0
        if key == 'SIC':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_310_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SAC']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SIC']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['SAC'], Literal['SIC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SAC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_310':
        ...

    @overload
    def set_item(self, name : Literal['SIC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_310':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SAC'], f : Any) -> 'Variation_310':
        ...

    @overload
    def modify_item(self, name : Literal['SIC'], f : Any) -> 'Variation_310':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_311_Arg : TypeAlias = Raw
class Variation_311(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Target reports, flight plan data and basic alerts',
        2: 'Manual attachment of flight plan to track',
        3: 'Manual detachment of flight plan to track',
        4: 'Insertion of flight plan data',
        5: 'Suppression of flight plan data',
        6: 'Modification of flight plan data',
        7: 'Holdbar status',
    }

    def __init__(self, arg : Variation_311_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_312_Arg_Group = TypedDict('Variation_312_Arg_Group', {
    'LAT': Union[Variation_255, Variation_255_Arg],
    'LON': Union[Variation_255, Variation_255_Arg],
})
Variation_312_Arg : TypeAlias = Union[Raw, Variation_312_Arg_Group]
class Variation_312(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('LAT', Variation_255),
        ('LON', Variation_255),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude in WGS-84 in Two\'s Complement', Variation_255, 0, 32),
        'LON': ('Longitude in WGS-84 in Two\'s Complement', Variation_255, 32, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_255]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_255'], Type['Variation_255']]:
        if key == 'LAT':
            return Variation_255
        if key == 'LON':
            return Variation_255
        assert_never(key)

    def __init__(self, arg : Variation_312_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_255:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_255:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_312':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_312':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_312':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_312':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_313_Arg_Group = TypedDict('Variation_313_Arg_Group', {
    'X': Union[Variation_259, Variation_259_Arg],
    'Y': Union[Variation_259, Variation_259_Arg],
})
Variation_313_Arg : TypeAlias = Union[Raw, Variation_313_Arg_Group]
class Variation_313(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('X', Variation_259),
        ('Y', Variation_259),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('X-Component', Variation_259, 0, 16),
        'Y': ('Y-Component', Variation_259, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_259]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_259]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_259'], Type['Variation_259']]:
        if key == 'X':
            return Variation_259
        if key == 'Y':
            return Variation_259
        assert_never(key)

    def __init__(self, arg : Variation_313_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_259:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_259:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_259, Variation_259_Arg]) -> 'Variation_313':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_259, Variation_259_Arg]) -> 'Variation_313':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_313':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_313':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_314_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_314(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 0.25, 'm/s')

    def __init__(self, arg : Variation_314_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_315_Arg_Group = TypedDict('Variation_315_Arg_Group', {
    'VX': Union[Variation_314, Variation_314_Arg],
    'VY': Union[Variation_314, Variation_314_Arg],
})
Variation_315_Arg : TypeAlias = Union[Raw, Variation_315_Arg_Group]
class Variation_315(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('VX', Variation_314),
        ('VY', Variation_314),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'VX': ('Vx', Variation_314, 0, 16),
        'VY': ('Vy', Variation_314, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VX']) -> Type[Variation_314]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VY']) -> Type[Variation_314]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VX'], Literal['VY']]) -> Union[Type['Variation_314'], Type['Variation_314']]:
        if key == 'VX':
            return Variation_314
        if key == 'VY':
            return Variation_314
        assert_never(key)

    def __init__(self, arg : Variation_315_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['VX']) -> Variation_314:
        ...

    @overload
    def get_item(self, name : Literal['VY']) -> Variation_314:
        ...

    def get_item(self, name : Union[Literal['VX'], Literal['VY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['VX'], val : Union[Variation_314, Variation_314_Arg]) -> 'Variation_315':
        ...

    @overload
    def set_item(self, name : Literal['VY'], val : Union[Variation_314, Variation_314_Arg]) -> 'Variation_315':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['VX'], f : Any) -> 'Variation_315':
        ...

    @overload
    def modify_item(self, name : Literal['VY'], f : Any) -> 'Variation_315':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_316_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_316(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 0.25, 'm/s²')

    def __init__(self, arg : Variation_316_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_317_Arg_Group = TypedDict('Variation_317_Arg_Group', {
    'AX': Union[Variation_316, Variation_316_Arg],
    'AY': Union[Variation_316, Variation_316_Arg],
})
Variation_317_Arg : TypeAlias = Union[Raw, Variation_317_Arg_Group]
class Variation_317(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('AX', Variation_316),
        ('AY', Variation_316),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'AX': ('Ax', Variation_316, 0, 8),
        'AY': ('Ay', Variation_316, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AX']) -> Type[Variation_316]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AY']) -> Type[Variation_316]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AX'], Literal['AY']]) -> Union[Type['Variation_316'], Type['Variation_316']]:
        if key == 'AX':
            return Variation_316
        if key == 'AY':
            return Variation_316
        assert_never(key)

    def __init__(self, arg : Variation_317_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['AX']) -> Variation_316:
        ...

    @overload
    def get_item(self, name : Literal['AY']) -> Variation_316:
        ...

    def get_item(self, name : Union[Literal['AX'], Literal['AY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['AX'], val : Union[Variation_316, Variation_316_Arg]) -> 'Variation_317':
        ...

    @overload
    def set_item(self, name : Literal['AY'], val : Union[Variation_316, Variation_316_Arg]) -> 'Variation_317':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['AX'], f : Any) -> 'Variation_317':
        ...

    @overload
    def modify_item(self, name : Literal['AY'], f : Any) -> 'Variation_317':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_318_Arg_Group = TypedDict('Variation_318_Arg_Group', {
    'MOD3A': Union[Variation_19, Variation_19_Arg],
})
Variation_318_Arg : TypeAlias = Union[Raw, Variation_318_Arg_Group]
class Variation_318(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('MOD3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MOD3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['MOD3A']]) -> Union[Type['Variation_19']]:
        if key == 'MOD3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_318_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['MOD3A']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['MOD3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_318':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['MOD3A'], f : Any) -> 'Variation_318':
        return self._modify_item(name, f) # type: ignore

Variation_319_Arg_Group = TypedDict('Variation_319_Arg_Group', {
    'STI': Union[Variation_279, Variation_279_Arg],
    'TID': Union[Variation_196, Variation_196_Arg],
})
Variation_319_Arg : TypeAlias = Union[Raw, Variation_319_Arg_Group]
class Variation_319(Group):
    variation = 'Group'

    bit_size = 56

    subitems_list = [
        ('STI', Variation_279),
        Spare(2, 6),
        ('TID', Variation_196),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STI': ('', Variation_279, 0, 2),
        'TID': ('Target Identification', Variation_196, 8, 48),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['STI']) -> Type[Variation_279]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_196]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['STI'], Literal['TID']]) -> Union[Type['Variation_279'], Type['Variation_196']]:
        if key == 'STI':
            return Variation_279
        if key == 'TID':
            return Variation_196
        assert_never(key)

    def __init__(self, arg : Variation_319_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['STI']) -> Variation_279:
        ...

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_196:
        ...

    def get_item(self, name : Union[Literal['STI'], Literal['TID']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['STI'], val : Union[Variation_279, Variation_279_Arg]) -> 'Variation_319':
        ...

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_319':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['STI'], f : Any) -> 'Variation_319':
        ...

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_319':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_320_Arg : TypeAlias = Raw
class Variation_320(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 64

    def __init__(self, arg : Variation_320_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_321_Arg : TypeAlias = Union[Variation_320, Variation_320_Arg]
class Variation_321(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 64
    variation_type = Variation_320

    @classmethod
    def spec(cls) -> Type[Variation_320]:
        return Variation_320

    def __init__(self, arg : List[Union[Variation_320, Variation_320_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_320, Variation_320_Arg]) -> 'Variation_321':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_320, Variation_320_Arg]) -> 'Variation_321':
        return self._prepend_item(arg) # type: ignore

Variation_322_Arg : TypeAlias = Raw
class Variation_322(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: 'No communications capability (surveillance only)',
        1: 'Comm. A and Comm. B capability',
        2: 'Comm. A, Comm. B and Uplink ELM',
        3: 'Comm. A, Comm. B, Uplink ELM and Downlink ELM',
        4: 'Level 5 Transponder capability',
        5: 'Not assigned',
        6: 'Not assigned',
        7: 'Not assigned',
    }

    def __init__(self, arg : Variation_322_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_323_Arg : TypeAlias = Raw
class Variation_323(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 4
    table = {
        0: 'No alert, no SPI, aircraft airborne',
        1: 'No alert, no SPI, aircraft on ground',
        2: 'Alert, no SPI, aircraft airborne',
        3: 'Alert, no SPI, aircraft on ground',
        4: 'Alert, SPI, aircraft airborne or on ground',
        5: 'No alert, SPI, aircraft airborne or on ground',
        6: 'General Emergency',
        7: 'Lifeguard / medical',
        8: 'Minimum fuel',
        9: 'No communications',
        10: 'Unlawful',
    }

    def __init__(self, arg : Variation_323_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_324_Arg : TypeAlias = Raw
class Variation_324(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No',
        1: 'Yes',
    }

    def __init__(self, arg : Variation_324_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_325_Arg : TypeAlias = Raw
class Variation_325(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: '100 ft resolution',
        1: '25 ft resolution',
    }

    def __init__(self, arg : Variation_325_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_326_Arg : TypeAlias = Raw
class Variation_326(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'No',
        1: 'Yes',
    }

    def __init__(self, arg : Variation_326_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_327_Arg : TypeAlias = Raw
class Variation_327(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'No',
        1: 'Yes',
    }

    def __init__(self, arg : Variation_327_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_328_Arg : TypeAlias = Raw
class Variation_328(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Yes',
        1: 'No',
    }

    def __init__(self, arg : Variation_328_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_329_Arg_Group = TypedDict('Variation_329_Arg_Group', {
    'COM': Union[Variation_322, Variation_322_Arg],
    'STAT': Union[Variation_323, Variation_323_Arg],
    'SSC': Union[Variation_324, Variation_324_Arg],
    'ARC': Union[Variation_325, Variation_325_Arg],
    'AIC': Union[Variation_326, Variation_326_Arg],
    'B1A': Union[Variation_237, Variation_237_Arg],
    'B1B': Union[Variation_282, Variation_282_Arg],
    'AC': Union[Variation_324, Variation_324_Arg],
    'MN': Union[Variation_327, Variation_327_Arg],
    'DC': Union[Variation_328, Variation_328_Arg],
})
Variation_329_Arg : TypeAlias = Union[Raw, Variation_329_Arg_Group]
class Variation_329(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('COM', Variation_322),
        ('STAT', Variation_323),
        Spare(7, 1),
        ('SSC', Variation_324),
        ('ARC', Variation_325),
        ('AIC', Variation_326),
        ('B1A', Variation_237),
        ('B1B', Variation_282),
        ('AC', Variation_324),
        ('MN', Variation_327),
        ('DC', Variation_328),
        Spare(3, 5),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COM': ('Communications Capability of the Transponder', Variation_322, 0, 3),
        'STAT': ('Flight Status', Variation_323, 3, 4),
        'SSC': ('Specific Service Capability', Variation_324, 8, 1),
        'ARC': ('Altitude Reporting Capability', Variation_325, 9, 1),
        'AIC': ('Aircraft Identification Capability', Variation_326, 10, 1),
        'B1A': ('BDS 1,0 Bit 16', Variation_237, 11, 1),
        'B1B': ('BDS 1,0 Bit 37/40', Variation_282, 12, 4),
        'AC': ('ACAS Operational', Variation_324, 16, 1),
        'MN': ('Multiple Navigational Aids Operating', Variation_327, 17, 1),
        'DC': ('Differential Correction', Variation_328, 18, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_322]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STAT']) -> Type[Variation_323]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSC']) -> Type[Variation_324]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_325]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AIC']) -> Type[Variation_326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1A']) -> Type[Variation_237]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1B']) -> Type[Variation_282]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AC']) -> Type[Variation_324]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MN']) -> Type[Variation_327]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DC']) -> Type[Variation_328]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COM'], Literal['STAT'], Literal['SSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B'], Literal['AC'], Literal['MN'], Literal['DC']]) -> Union[Type['Variation_322'], Type['Variation_323'], Type['Variation_324'], Type['Variation_325'], Type['Variation_326'], Type['Variation_237'], Type['Variation_282'], Type['Variation_324'], Type['Variation_327'], Type['Variation_328']]:
        if key == 'COM':
            return Variation_322
        if key == 'STAT':
            return Variation_323
        if key == 'SSC':
            return Variation_324
        if key == 'ARC':
            return Variation_325
        if key == 'AIC':
            return Variation_326
        if key == 'B1A':
            return Variation_237
        if key == 'B1B':
            return Variation_282
        if key == 'AC':
            return Variation_324
        if key == 'MN':
            return Variation_327
        if key == 'DC':
            return Variation_328
        assert_never(key)

    def __init__(self, arg : Variation_329_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_322:
        ...

    @overload
    def get_item(self, name : Literal['STAT']) -> Variation_323:
        ...

    @overload
    def get_item(self, name : Literal['SSC']) -> Variation_324:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_325:
        ...

    @overload
    def get_item(self, name : Literal['AIC']) -> Variation_326:
        ...

    @overload
    def get_item(self, name : Literal['B1A']) -> Variation_237:
        ...

    @overload
    def get_item(self, name : Literal['B1B']) -> Variation_282:
        ...

    @overload
    def get_item(self, name : Literal['AC']) -> Variation_324:
        ...

    @overload
    def get_item(self, name : Literal['MN']) -> Variation_327:
        ...

    @overload
    def get_item(self, name : Literal['DC']) -> Variation_328:
        ...

    def get_item(self, name : Union[Literal['COM'], Literal['STAT'], Literal['SSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B'], Literal['AC'], Literal['MN'], Literal['DC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_322, Variation_322_Arg]) -> 'Variation_329':
        ...

    @overload
    def set_item(self, name : Literal['STAT'], val : Union[Variation_323, Variation_323_Arg]) -> 'Variation_329':
        ...

    @overload
    def set_item(self, name : Literal['SSC'], val : Union[Variation_324, Variation_324_Arg]) -> 'Variation_329':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_325, Variation_325_Arg]) -> 'Variation_329':
        ...

    @overload
    def set_item(self, name : Literal['AIC'], val : Union[Variation_326, Variation_326_Arg]) -> 'Variation_329':
        ...

    @overload
    def set_item(self, name : Literal['B1A'], val : Union[Variation_237, Variation_237_Arg]) -> 'Variation_329':
        ...

    @overload
    def set_item(self, name : Literal['B1B'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_329':
        ...

    @overload
    def set_item(self, name : Literal['AC'], val : Union[Variation_324, Variation_324_Arg]) -> 'Variation_329':
        ...

    @overload
    def set_item(self, name : Literal['MN'], val : Union[Variation_327, Variation_327_Arg]) -> 'Variation_329':
        ...

    @overload
    def set_item(self, name : Literal['DC'], val : Union[Variation_328, Variation_328_Arg]) -> 'Variation_329':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_329':
        ...

    @overload
    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_329':
        ...

    @overload
    def modify_item(self, name : Literal['SSC'], f : Any) -> 'Variation_329':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_329':
        ...

    @overload
    def modify_item(self, name : Literal['AIC'], f : Any) -> 'Variation_329':
        ...

    @overload
    def modify_item(self, name : Literal['B1A'], f : Any) -> 'Variation_329':
        ...

    @overload
    def modify_item(self, name : Literal['B1B'], f : Any) -> 'Variation_329':
        ...

    @overload
    def modify_item(self, name : Literal['AC'], f : Any) -> 'Variation_329':
        ...

    @overload
    def modify_item(self, name : Literal['MN'], f : Any) -> 'Variation_329':
        ...

    @overload
    def modify_item(self, name : Literal['DC'], f : Any) -> 'Variation_329':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_330_Arg : TypeAlias = Union[Raw,str]
class Variation_330(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 32
    string_type = StringAscii()

    def __init__(self, arg : Variation_330_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, str):
            super().__init__(self._from_string(arg)); return
        assert_never(arg)


    def to_string(self) -> str:
        return self._to_string()


Variation_331_Arg : TypeAlias = Raw
class Variation_331(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Light aircraft <= 7000 kg',
        2: 'Reserved',
        3: '7000 kg &lt; medium aircraft &lt; 136000 kg',
        4: 'Reserved',
        5: '136000 kg <= heavy aircraft',
        6: 'Highly manoeuvrable (5g acceleration capability) and high speed (&gt;400 knots cruise)',
        7: 'Reserved',
        8: 'Reserved',
        9: 'Reserved',
        10: 'Rotocraft',
        11: 'Glider / sailplane',
        12: 'Lighter-than-air',
        13: 'Unmanned aerial vehicle',
        14: 'Space / transatmospheric vehicle',
        15: 'Ultralight / handglider / paraglider',
        16: 'Parachutist / skydiver',
        17: 'Reserved',
        18: 'Reserved',
        19: 'Reserved',
        20: 'Surface emergency vehicle',
        21: 'Surface service vehicle',
        22: 'Fixed ground or tethered obstruction',
        23: 'Reserved',
        24: 'Reserved',
    }

    def __init__(self, arg : Variation_331_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_332_Arg : TypeAlias = Raw
class Variation_332(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'VDL Mode 4 available',
        1: 'VDL Mode 4 not available',
    }

    def __init__(self, arg : Variation_332_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_333_Arg : TypeAlias = Raw
class Variation_333(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Mode S available',
        1: 'Mode S not available',
    }

    def __init__(self, arg : Variation_333_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_334_Arg : TypeAlias = Raw
class Variation_334(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'UAT available',
        1: 'UAT not available',
    }

    def __init__(self, arg : Variation_334_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_335_Arg_Group = TypedDict('Variation_335_Arg_Group', {
    'VDL': Union[Variation_332, Variation_332_Arg],
    'MDS': Union[Variation_333, Variation_333_Arg],
    'UAT': Union[Variation_334, Variation_334_Arg],
})
Variation_335_Arg : TypeAlias = Union[Raw, Variation_335_Arg_Group]
class Variation_335(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('VDL', Variation_332),
        ('MDS', Variation_333),
        ('UAT', Variation_334),
        Spare(3, 5),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'VDL': ('VDL Mode 4', Variation_332, 0, 1),
        'MDS': ('Mode S', Variation_333, 1, 1),
        'UAT': ('UAT', Variation_334, 2, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VDL']) -> Type[Variation_332]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_333]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['UAT']) -> Type[Variation_334]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VDL'], Literal['MDS'], Literal['UAT']]) -> Union[Type['Variation_332'], Type['Variation_333'], Type['Variation_334']]:
        if key == 'VDL':
            return Variation_332
        if key == 'MDS':
            return Variation_333
        if key == 'UAT':
            return Variation_334
        assert_never(key)

    def __init__(self, arg : Variation_335_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['VDL']) -> Variation_332:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_333:
        ...

    @overload
    def get_item(self, name : Literal['UAT']) -> Variation_334:
        ...

    def get_item(self, name : Union[Literal['VDL'], Literal['MDS'], Literal['UAT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['VDL'], val : Union[Variation_332, Variation_332_Arg]) -> 'Variation_335':
        ...

    @overload
    def set_item(self, name : Literal['MDS'], val : Union[Variation_333, Variation_333_Arg]) -> 'Variation_335':
        ...

    @overload
    def set_item(self, name : Literal['UAT'], val : Union[Variation_334, Variation_334_Arg]) -> 'Variation_335':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['VDL'], f : Any) -> 'Variation_335':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_335':
        ...

    @overload
    def modify_item(self, name : Literal['UAT'], f : Any) -> 'Variation_335':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_336_Arg = TypedDict('Variation_336_Arg', {
    'MB': Union[Variation_321, Variation_321_Arg],
    'ADR': Union[Variation_278, Variation_278_Arg],
    'COMACAS': Union[Variation_329, Variation_329_Arg],
    'ACT': Union[Variation_330, Variation_330_Arg],
    'ECAT': Union[Variation_331, Variation_331_Arg],
    'AVTECH': Union[Variation_335, Variation_335_Arg],
}, total=False)
class Variation_336(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('MB', Variation_321),
        ('ADR', Variation_278),
        None,
        ('COMACAS', Variation_329),
        None,
        None,
        None,
        ('ACT', Variation_330),
        ('ECAT', Variation_331),
        None,
        ('AVTECH', Variation_335),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'MB': ('BDS', Variation_321, 0x8000),
        'ADR': ('24 Bits Aircraft Address', Variation_278, 0x4000),
        'COMACAS': ('Communications/ACAS Capability and Flight Status', Variation_329, 0x1000),
        'ACT': ('Aircraft Derived Aircraft Type', Variation_330, 0x0180),
        'ECAT': ('Emitter Category', Variation_331, 0x0140),
        'AVTECH': ('Available Technologies', Variation_335, 0x0110),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MB']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADR']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COMACAS']) -> Type[Variation_329]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ACT']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ECAT']) -> Type[Variation_331]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AVTECH']) -> Type[Variation_335]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MB'], Literal['ADR'], Literal['COMACAS'], Literal['ACT'], Literal['ECAT'], Literal['AVTECH']]) -> Union[Type['Variation_321'], Type['Variation_278'], Type['Variation_329'], Type['Variation_330'], Type['Variation_331'], Type['Variation_335']]:
        if key == 'MB':
            return Variation_321
        if key == 'ADR':
            return Variation_278
        if key == 'COMACAS':
            return Variation_329
        if key == 'ACT':
            return Variation_330
        if key == 'ECAT':
            return Variation_331
        if key == 'AVTECH':
            return Variation_335
        assert_never(key)

    def __init__(self, arg : Optional[Variation_336_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['MB'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_336':
        ...

    @overload
    def set_item(self, name : Literal['ADR'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_336':
        ...

    @overload
    def set_item(self, name : Literal['COMACAS'], val : Union[Variation_329, Variation_329_Arg]) -> 'Variation_336':
        ...

    @overload
    def set_item(self, name : Literal['ACT'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_336':
        ...

    @overload
    def set_item(self, name : Literal['ECAT'], val : Union[Variation_331, Variation_331_Arg]) -> 'Variation_336':
        ...

    @overload
    def set_item(self, name : Literal['AVTECH'], val : Union[Variation_335, Variation_335_Arg]) -> 'Variation_336':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['MB']) -> 'Variation_336':
        ...

    @overload
    def del_item(self, name : Literal['ADR']) -> 'Variation_336':
        ...

    @overload
    def del_item(self, name : Literal['COMACAS']) -> 'Variation_336':
        ...

    @overload
    def del_item(self, name : Literal['ACT']) -> 'Variation_336':
        ...

    @overload
    def del_item(self, name : Literal['ECAT']) -> 'Variation_336':
        ...

    @overload
    def del_item(self, name : Literal['AVTECH']) -> 'Variation_336':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['MB']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['ADR']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['COMACAS']) -> Variation_329:
        ...

    @overload
    def get_item(self, name : Literal['ACT']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['ECAT']) -> Variation_331:
        ...

    @overload
    def get_item(self, name : Literal['AVTECH']) -> Variation_335:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['MB'], f : Any) -> 'Variation_336':
        ...

    @overload
    def modify_item(self, name : Literal['ADR'], f : Any) -> 'Variation_336':
        ...

    @overload
    def modify_item(self, name : Literal['COMACAS'], f : Any) -> 'Variation_336':
        ...

    @overload
    def modify_item(self, name : Literal['ACT'], f : Any) -> 'Variation_336':
        ...

    @overload
    def modify_item(self, name : Literal['ECAT'], f : Any) -> 'Variation_336':
        ...

    @overload
    def modify_item(self, name : Literal['AVTECH'], f : Any) -> 'Variation_336':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_337_Arg : TypeAlias = Raw
class Variation_337(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 15

    def __init__(self, arg : Variation_337_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_338_Arg_Group = TypedDict('Variation_338_Arg_Group', {
    'FTN': Union[Variation_337, Variation_337_Arg],
})
Variation_338_Arg : TypeAlias = Union[Raw, Variation_338_Arg_Group]
class Variation_338(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 1),
        ('FTN', Variation_337),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FTN': ('Fusion Track Number', Variation_337, 1, 15),
    }


    @classmethod
    def spec(cls, key : Union[Literal['FTN']]) -> Union[Type['Variation_337']]:
        if key == 'FTN':
            return Variation_337
        assert_never(key)

    def __init__(self, arg : Variation_338_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['FTN']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['FTN'], val : Union[Variation_337, Variation_337_Arg]) -> 'Variation_338':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['FTN'], f : Any) -> 'Variation_338':
        return self._modify_item(name, f) # type: ignore

Variation_339_Arg : TypeAlias = Raw
class Variation_339(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Multisensor Track',
        1: 'Monosensor Track',
    }

    def __init__(self, arg : Variation_339_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_340_Arg : TypeAlias = Raw
class Variation_340(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Transponder Ground bit not set or unknown',
        1: 'Transponder Ground bit set',
    }

    def __init__(self, arg : Variation_340_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_341_Arg : TypeAlias = Raw
class Variation_341(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Barometric altitude (Mode C) more reliable',
        1: 'Geometric altitude more reliable',
    }

    def __init__(self, arg : Variation_341_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_342_Arg : TypeAlias = Raw
class Variation_342(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 3
    table = {
        0: 'No source',
        1: 'GPS',
        2: '3d radar',
        3: 'Triangulation',
        4: 'Height from coverage',
        5: 'Speed look-up table',
        6: 'Default height',
        7: 'Multilateration',
    }

    def __init__(self, arg : Variation_342_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_343_Arg : TypeAlias = Raw
class Variation_343(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Confirmed track',
        1: 'Tentative track',
    }

    def __init__(self, arg : Variation_343_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_344_Arg : TypeAlias = Raw
class Variation_344(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Actual Track',
        1: 'Simulated track',
    }

    def __init__(self, arg : Variation_344_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_345_Arg : TypeAlias = Raw
class Variation_345(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Track service end (i.e. last message transmitted to the user for the track)',
    }

    def __init__(self, arg : Variation_345_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_346_Arg : TypeAlias = Raw
class Variation_346(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Track service begin (i.e. first message transmitted to the user for the track)',
    }

    def __init__(self, arg : Variation_346_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_347_Arg : TypeAlias = Raw
class Variation_347(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 2
    table = {
        0: 'No Mode 4 interrogationt',
        1: 'Friendly target',
        2: 'Unknown target',
        3: 'No reply',
    }

    def __init__(self, arg : Variation_347_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_348_Arg : TypeAlias = Raw
class Variation_348(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Military Emergency present in the last report received from a sensor capable of decoding this data',
    }

    def __init__(self, arg : Variation_348_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_349_Arg : TypeAlias = Raw
class Variation_349(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'End of Data Item',
        1: 'Military Identification present in the last report received from a sensor capable of decoding this data',
    }

    def __init__(self, arg : Variation_349_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_350_Arg : TypeAlias = Raw
class Variation_350(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Track not resulting from amalgamation process',
        1: 'Track resulting from amalgamation process',
    }

    def __init__(self, arg : Variation_350_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_351_Arg : TypeAlias = Raw
class Variation_351(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'SPI present in the last report received from a sensor capable of decoding this data',
    }

    def __init__(self, arg : Variation_351_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_352_Arg : TypeAlias = Raw
class Variation_352(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Age of the last received track update is higher than system dependent threshold (coasting)',
    }

    def __init__(self, arg : Variation_352_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_353_Arg : TypeAlias = Raw
class Variation_353(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Not flight-plan correlated',
        1: 'Flight plan correlated',
    }

    def __init__(self, arg : Variation_353_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_354_Arg : TypeAlias = Raw
class Variation_354(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'ADS-B data inconsistent with other surveillance information',
    }

    def __init__(self, arg : Variation_354_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_355_Arg_Group_1 = TypedDict('Variation_355_Arg_Group_1', {
    'MON': Union[Variation_339, Variation_339_Arg],
    'GBS': Union[Variation_340, Variation_340_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_342, Variation_342_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
})
Variation_355_Arg_Group_2 = TypedDict('Variation_355_Arg_Group_2', {
    'MON': Union[Variation_339, Variation_339_Arg],
    'GBS': Union[Variation_340, Variation_340_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_342, Variation_342_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_344, Variation_344_Arg],
    'TSE': Union[Variation_345, Variation_345_Arg],
    'TSB': Union[Variation_346, Variation_346_Arg],
    'FRIFOE': Union[Variation_347, Variation_347_Arg],
    'ME': Union[Variation_348, Variation_348_Arg],
    'MI': Union[Variation_349, Variation_349_Arg],
})
Variation_355_Arg_Group_3 = TypedDict('Variation_355_Arg_Group_3', {
    'MON': Union[Variation_339, Variation_339_Arg],
    'GBS': Union[Variation_340, Variation_340_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_342, Variation_342_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_344, Variation_344_Arg],
    'TSE': Union[Variation_345, Variation_345_Arg],
    'TSB': Union[Variation_346, Variation_346_Arg],
    'FRIFOE': Union[Variation_347, Variation_347_Arg],
    'ME': Union[Variation_348, Variation_348_Arg],
    'MI': Union[Variation_349, Variation_349_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'CST': Union[Variation_352, Variation_352_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
})
Variation_355_Arg : TypeAlias = Union[
    int,
    Variation_355_Arg_Group_1,
    Tuple[int],
    Variation_355_Arg_Group_2,
    Tuple[int,int],
    Variation_355_Arg_Group_3,
    Tuple[int,int,int],
]
class Variation_355(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('MON', Variation_339),
            ('GBS', Variation_340),
            ('MRH', Variation_341),
            ('SRC', Variation_342),
            ('CNF', Variation_343),
        ],
        [
            ('SIM', Variation_344),
            ('TSE', Variation_345),
            ('TSB', Variation_346),
            ('FRIFOE', Variation_347),
            ('ME', Variation_348),
            ('MI', Variation_349),
        ],
        [
            ('AMA', Variation_350),
            ('SPI', Variation_351),
            ('CST', Variation_352),
            ('FPC', Variation_353),
            ('AFF', Variation_354),
            Spare(5, 2),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MON': ('', Variation_339, 0, 1),
        'GBS': ('', Variation_340, 1, 1),
        'MRH': ('', Variation_341, 2, 1),
        'SRC': ('', Variation_342, 3, 3),
        'CNF': ('', Variation_343, 6, 1),
        'SIM': ('', Variation_344, 0, 1),
        'TSE': ('', Variation_345, 1, 1),
        'TSB': ('', Variation_346, 2, 1),
        'FRIFOE': ('', Variation_347, 3, 2),
        'ME': ('', Variation_348, 5, 1),
        'MI': ('', Variation_349, 6, 1),
        'AMA': ('', Variation_350, 0, 1),
        'SPI': ('', Variation_351, 1, 1),
        'CST': ('', Variation_352, 2, 1),
        'FPC': ('', Variation_353, 3, 1),
        'AFF': ('', Variation_354, 4, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MON']) -> Type[Variation_339]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GBS']) -> Type[Variation_340]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MRH']) -> Type[Variation_341]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRC']) -> Type[Variation_342]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_343]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_344]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSE']) -> Type[Variation_345]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSB']) -> Type[Variation_346]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FRIFOE']) -> Type[Variation_347]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ME']) -> Type[Variation_348]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MI']) -> Type[Variation_349]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AMA']) -> Type[Variation_350]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_351]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_352]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FPC']) -> Type[Variation_353]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AFF']) -> Type[Variation_354]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MON'], Literal['GBS'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FRIFOE'], Literal['ME'], Literal['MI'], Literal['AMA'], Literal['SPI'], Literal['CST'], Literal['FPC'], Literal['AFF']]) -> Union[Type['Variation_339'], Type['Variation_340'], Type['Variation_341'], Type['Variation_342'], Type['Variation_343'], Type['Variation_344'], Type['Variation_345'], Type['Variation_346'], Type['Variation_347'], Type['Variation_348'], Type['Variation_349'], Type['Variation_350'], Type['Variation_351'], Type['Variation_352'], Type['Variation_353'], Type['Variation_354']]:
        if key == 'MON':
            return Variation_339
        if key == 'GBS':
            return Variation_340
        if key == 'MRH':
            return Variation_341
        if key == 'SRC':
            return Variation_342
        if key == 'CNF':
            return Variation_343
        if key == 'SIM':
            return Variation_344
        if key == 'TSE':
            return Variation_345
        if key == 'TSB':
            return Variation_346
        if key == 'FRIFOE':
            return Variation_347
        if key == 'ME':
            return Variation_348
        if key == 'MI':
            return Variation_349
        if key == 'AMA':
            return Variation_350
        if key == 'SPI':
            return Variation_351
        if key == 'CST':
            return Variation_352
        if key == 'FPC':
            return Variation_353
        if key == 'AFF':
            return Variation_354
        assert_never(key)

    def __init__(self, arg : Variation_355_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_355_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_355_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_355_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MON']) -> Variation_339:
        ...

    @overload
    def get_item(self, name : Literal['GBS']) -> Variation_340:
        ...

    @overload
    def get_item(self, name : Literal['MRH']) -> Variation_341:
        ...

    @overload
    def get_item(self, name : Literal['SRC']) -> Variation_342:
        ...

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_343:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_344:
        ...

    @overload
    def get_item(self, name : Literal['TSE']) -> Variation_345:
        ...

    @overload
    def get_item(self, name : Literal['TSB']) -> Variation_346:
        ...

    @overload
    def get_item(self, name : Literal['FRIFOE']) -> Variation_347:
        ...

    @overload
    def get_item(self, name : Literal['ME']) -> Variation_348:
        ...

    @overload
    def get_item(self, name : Literal['MI']) -> Variation_349:
        ...

    @overload
    def get_item(self, name : Literal['AMA']) -> Variation_350:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_351:
        ...

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_352:
        ...

    @overload
    def get_item(self, name : Literal['FPC']) -> Variation_353:
        ...

    @overload
    def get_item(self, name : Literal['AFF']) -> Variation_354:
        ...

    def get_item(self, name : Union[Literal['MON'], Literal['GBS'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FRIFOE'], Literal['ME'], Literal['MI'], Literal['AMA'], Literal['SPI'], Literal['CST'], Literal['FPC'], Literal['AFF']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MON'], val : Union[Variation_339, Variation_339_Arg]) -> 'Variation_355':
        ...

    @overload
    def set_item(self, name : Literal['GBS'], val : Union[Variation_340, Variation_340_Arg]) -> 'Variation_355':
        ...

    @overload
    def set_item(self, name : Literal['MRH'], val : Union[Variation_341, Variation_341_Arg]) -> 'Variation_355':
        ...

    @overload
    def set_item(self, name : Literal['SRC'], val : Union[Variation_342, Variation_342_Arg]) -> 'Variation_355':
        ...

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_343, Variation_343_Arg]) -> 'Variation_355':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MON'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['GBS'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['MRH'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['SRC'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['TSE'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['TSB'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['FRIFOE'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['ME'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['MI'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['AMA'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['FPC'], f : Any) -> 'Variation_355':
        ...

    @overload
    def modify_item(self, name : Literal['AFF'], f : Any) -> 'Variation_355':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_356_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_356(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 0.25, 's')

    def __init__(self, arg : Variation_356_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_357_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_357(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 0.25, 's')

    def __init__(self, arg : Variation_357_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_358_Arg = TypedDict('Variation_358_Arg', {
    'PSR': Union[Variation_356, Variation_356_Arg],
    'SSR': Union[Variation_356, Variation_356_Arg],
    'MDA': Union[Variation_356, Variation_356_Arg],
    'MFL': Union[Variation_356, Variation_356_Arg],
    'MDS': Union[Variation_356, Variation_356_Arg],
    'ADS': Union[Variation_357, Variation_357_Arg],
    'ADB': Union[Variation_356, Variation_356_Arg],
    'MD1': Union[Variation_356, Variation_356_Arg],
    'MD2': Union[Variation_356, Variation_356_Arg],
    'LOP': Union[Variation_356, Variation_356_Arg],
    'TRK': Union[Variation_356, Variation_356_Arg],
    'MUL': Union[Variation_356, Variation_356_Arg],
}, total=False)
class Variation_358(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('PSR', Variation_356),
        ('SSR', Variation_356),
        ('MDA', Variation_356),
        ('MFL', Variation_356),
        ('MDS', Variation_356),
        ('ADS', Variation_357),
        ('ADB', Variation_356),
        ('MD1', Variation_356),
        ('MD2', Variation_356),
        ('LOP', Variation_356),
        ('TRK', Variation_356),
        ('MUL', Variation_356),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'PSR': ('Age of The Last Primary Detection Used to Update the Track', Variation_356, 0x8000),
        'SSR': ('Age of the Last Secondary Detection Used to Update the Track', Variation_356, 0x4000),
        'MDA': ('Age of the Last Mode A Detection Used to Update the Track', Variation_356, 0x2000),
        'MFL': ('Age of the Last Mode C Detection Used to Update the Track', Variation_356, 0x1000),
        'MDS': ('Age of the Last Mode S Detection Used to Update the Track', Variation_356, 0x0800),
        'ADS': ('Age of the Last ADS Report Used to Update the Track', Variation_357, 0x0400),
        'ADB': ('Age of the Last ADS-B Report Used to Update the Track', Variation_356, 0x0200),
        'MD1': ('Age of the Last Valid Mode 1 Used to Update the Track', Variation_356, 0x0180),
        'MD2': ('Age of the Last Mode 2 Used to Update the Track', Variation_356, 0x0140),
        'LOP': ('Age of the Last Magentic Loop Detection', Variation_356, 0x0120),
        'TRK': ('Actual Track Age Since First Occurrence', Variation_356, 0x0110),
        'MUL': ('Age of the Last Multilateration Detection', Variation_356, 0x0108),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDA']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MFL']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADS']) -> Type[Variation_357]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADB']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD1']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD2']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LOP']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRK']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MUL']) -> Type[Variation_356]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PSR'], Literal['SSR'], Literal['MDA'], Literal['MFL'], Literal['MDS'], Literal['ADS'], Literal['ADB'], Literal['MD1'], Literal['MD2'], Literal['LOP'], Literal['TRK'], Literal['MUL']]) -> Union[Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_357'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356']]:
        if key == 'PSR':
            return Variation_356
        if key == 'SSR':
            return Variation_356
        if key == 'MDA':
            return Variation_356
        if key == 'MFL':
            return Variation_356
        if key == 'MDS':
            return Variation_356
        if key == 'ADS':
            return Variation_357
        if key == 'ADB':
            return Variation_356
        if key == 'MD1':
            return Variation_356
        if key == 'MD2':
            return Variation_356
        if key == 'LOP':
            return Variation_356
        if key == 'TRK':
            return Variation_356
        if key == 'MUL':
            return Variation_356
        assert_never(key)

    def __init__(self, arg : Optional[Variation_358_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['PSR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['SSR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['MDA'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['MFL'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['MDS'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['ADS'], val : Union[Variation_357, Variation_357_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['ADB'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['MD1'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['MD2'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['LOP'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['TRK'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    @overload
    def set_item(self, name : Literal['MUL'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_358':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['PSR']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['SSR']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['MDA']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['MFL']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['MDS']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['ADS']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['ADB']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['MD1']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['MD2']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['LOP']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['TRK']) -> 'Variation_358':
        ...

    @overload
    def del_item(self, name : Literal['MUL']) -> 'Variation_358':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MDA']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MFL']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['ADS']) -> Variation_357:
        ...

    @overload
    def get_item(self, name : Literal['ADB']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MD1']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MD2']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['LOP']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['TRK']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MUL']) -> Variation_356:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['MDA'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['MFL'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['ADS'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['ADB'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['MD1'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['MD2'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['LOP'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['TRK'], f : Any) -> 'Variation_358':
        ...

    @overload
    def modify_item(self, name : Literal['MUL'], f : Any) -> 'Variation_358':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_359_Arg : TypeAlias = Raw
class Variation_359(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'Unknown',
        1: 'On stand',
        2: 'Taxiing for departure',
        3: 'Taxiing for arrival',
        4: 'Runway for departure',
        5: 'Runway for arrival',
        6: 'Hold for departure',
        7: 'Hold for arrival',
        8: 'Push back',
        9: 'On finals',
    }

    def __init__(self, arg : Variation_359_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_360_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['FL']]]
class Variation_360(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 0.25, 'FL')

    def __init__(self, arg : Variation_360_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_361_Arg : TypeAlias = Raw
class Variation_361(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No QNH correction applied',
        1: 'QNH correction applied',
    }

    def __init__(self, arg : Variation_361_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_362_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['FL']]]
class Variation_362(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 15
    quantity = Quantity('Signed', 0.25, 'FL')

    def __init__(self, arg : Variation_362_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_363_Arg_Group = TypedDict('Variation_363_Arg_Group', {
    'QNH': Union[Variation_361, Variation_361_Arg],
    'CTBA': Union[Variation_362, Variation_362_Arg],
})
Variation_363_Arg : TypeAlias = Union[Raw, Variation_363_Arg_Group]
class Variation_363(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('QNH', Variation_361),
        ('CTBA', Variation_362),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'QNH': ('QNH Correction Applied', Variation_361, 0, 1),
        'CTBA': ('Calculated Track Barometric Altitude', Variation_362, 1, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['QNH']) -> Type[Variation_361]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CTBA']) -> Type[Variation_362]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['QNH'], Literal['CTBA']]) -> Union[Type['Variation_361'], Type['Variation_362']]:
        if key == 'QNH':
            return Variation_361
        if key == 'CTBA':
            return Variation_362
        assert_never(key)

    def __init__(self, arg : Variation_363_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['QNH']) -> Variation_361:
        ...

    @overload
    def get_item(self, name : Literal['CTBA']) -> Variation_362:
        ...

    def get_item(self, name : Union[Literal['QNH'], Literal['CTBA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['QNH'], val : Union[Variation_361, Variation_361_Arg]) -> 'Variation_363':
        ...

    @overload
    def set_item(self, name : Literal['CTBA'], val : Union[Variation_362, Variation_362_Arg]) -> 'Variation_363':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['QNH'], f : Any) -> 'Variation_363':
        ...

    @overload
    def modify_item(self, name : Literal['CTBA'], f : Any) -> 'Variation_363':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_364_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft/min']]]
class Variation_364(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 6.25, 'ft/min')

    def __init__(self, arg : Variation_364_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_365_Arg_Group = TypedDict('Variation_365_Arg_Group', {
    'SAC': Union[Variation_0, Variation_0_Arg],
    'SIC': Union[Variation_0, Variation_0_Arg],
})
Variation_365_Arg : TypeAlias = Union[Raw, Variation_365_Arg_Group]
class Variation_365(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('SAC', Variation_0),
        ('SIC', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SAC': ('System Area Code', Variation_0, 0, 8),
        'SIC': ('System Identity Code', Variation_0, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SAC']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIC']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SAC'], Literal['SIC']]) -> Union[Type['Variation_0'], Type['Variation_0']]:
        if key == 'SAC':
            return Variation_0
        if key == 'SIC':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_365_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SAC']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SIC']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['SAC'], Literal['SIC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SAC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_365':
        ...

    @overload
    def set_item(self, name : Literal['SIC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_365':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SAC'], f : Any) -> 'Variation_365':
        ...

    @overload
    def modify_item(self, name : Literal['SIC'], f : Any) -> 'Variation_365':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_366_Arg : TypeAlias = Raw
class Variation_366(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Plan number',
        1: 'Unit 1 internal flight number',
        2: 'Unit 2 internal flight number',
        3: 'Unit 3 internal flight number',
    }

    def __init__(self, arg : Variation_366_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_367_Arg : TypeAlias = Raw
class Variation_367(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 27

    def __init__(self, arg : Variation_367_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_368_Arg_Group = TypedDict('Variation_368_Arg_Group', {
    'TYP': Union[Variation_366, Variation_366_Arg],
    'NBR': Union[Variation_367, Variation_367_Arg],
})
Variation_368_Arg : TypeAlias = Union[Raw, Variation_368_Arg_Group]
class Variation_368(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('TYP', Variation_366),
        Spare(2, 3),
        ('NBR', Variation_367),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('IFPS Flight ID Type', Variation_366, 0, 2),
        'NBR': ('IFPS Flight ID Number', Variation_367, 5, 27),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_366]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NBR']) -> Type[Variation_367]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['NBR']]) -> Union[Type['Variation_366'], Type['Variation_367']]:
        if key == 'TYP':
            return Variation_366
        if key == 'NBR':
            return Variation_367
        assert_never(key)

    def __init__(self, arg : Variation_368_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_366:
        ...

    @overload
    def get_item(self, name : Literal['NBR']) -> Variation_367:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['NBR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_366, Variation_366_Arg]) -> 'Variation_368':
        ...

    @overload
    def set_item(self, name : Literal['NBR'], val : Union[Variation_367, Variation_367_Arg]) -> 'Variation_368':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_368':
        ...

    @overload
    def modify_item(self, name : Literal['NBR'], f : Any) -> 'Variation_368':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_369_Arg_Group = TypedDict('Variation_369_Arg_Group', {
    'GATOAT': Union[Variation_153, Variation_153_Arg],
    'FR1FR2': Union[Variation_154, Variation_154_Arg],
    'RVSM': Union[Variation_155, Variation_155_Arg],
    'HPR': Union[Variation_156, Variation_156_Arg],
})
Variation_369_Arg : TypeAlias = Union[Raw, Variation_369_Arg_Group]
class Variation_369(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('GATOAT', Variation_153),
        ('FR1FR2', Variation_154),
        ('RVSM', Variation_155),
        ('HPR', Variation_156),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'GATOAT': ('Flight Type', Variation_153, 0, 2),
        'FR1FR2': ('Flight Rules', Variation_154, 2, 2),
        'RVSM': ('RVSM', Variation_155, 4, 2),
        'HPR': ('Flight Priority', Variation_156, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['GATOAT']) -> Type[Variation_153]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FR1FR2']) -> Type[Variation_154]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RVSM']) -> Type[Variation_155]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HPR']) -> Type[Variation_156]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['RVSM'], Literal['HPR']]) -> Union[Type['Variation_153'], Type['Variation_154'], Type['Variation_155'], Type['Variation_156']]:
        if key == 'GATOAT':
            return Variation_153
        if key == 'FR1FR2':
            return Variation_154
        if key == 'RVSM':
            return Variation_155
        if key == 'HPR':
            return Variation_156
        assert_never(key)

    def __init__(self, arg : Variation_369_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['GATOAT']) -> Variation_153:
        ...

    @overload
    def get_item(self, name : Literal['FR1FR2']) -> Variation_154:
        ...

    @overload
    def get_item(self, name : Literal['RVSM']) -> Variation_155:
        ...

    @overload
    def get_item(self, name : Literal['HPR']) -> Variation_156:
        ...

    def get_item(self, name : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['RVSM'], Literal['HPR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['GATOAT'], val : Union[Variation_153, Variation_153_Arg]) -> 'Variation_369':
        ...

    @overload
    def set_item(self, name : Literal['FR1FR2'], val : Union[Variation_154, Variation_154_Arg]) -> 'Variation_369':
        ...

    @overload
    def set_item(self, name : Literal['RVSM'], val : Union[Variation_155, Variation_155_Arg]) -> 'Variation_369':
        ...

    @overload
    def set_item(self, name : Literal['HPR'], val : Union[Variation_156, Variation_156_Arg]) -> 'Variation_369':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['GATOAT'], f : Any) -> 'Variation_369':
        ...

    @overload
    def modify_item(self, name : Literal['FR1FR2'], f : Any) -> 'Variation_369':
        ...

    @overload
    def modify_item(self, name : Literal['RVSM'], f : Any) -> 'Variation_369':
        ...

    @overload
    def modify_item(self, name : Literal['HPR'], f : Any) -> 'Variation_369':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_370_Arg : TypeAlias = Raw
class Variation_370(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        76: 'Light',
        77: 'Medium',
        72: 'Heavy',
        74: 'Super',
    }

    def __init__(self, arg : Variation_370_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_371_Arg : TypeAlias = Union[Raw,str]
class Variation_371(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    string_type = StringAscii()

    def __init__(self, arg : Variation_371_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, str):
            super().__init__(self._from_string(arg)); return
        assert_never(arg)


    def to_string(self) -> str:
        return self._to_string()


Variation_372_Arg_Group = TypedDict('Variation_372_Arg_Group', {
    'CENTRE': Union[Variation_0, Variation_0_Arg],
    'POSITION': Union[Variation_0, Variation_0_Arg],
})
Variation_372_Arg : TypeAlias = Union[Raw, Variation_372_Arg_Group]
class Variation_372(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('CENTRE', Variation_0),
        ('POSITION', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CENTRE': ('8-bit Group Identification Code', Variation_0, 0, 8),
        'POSITION': ('8-bit Control Position Identification Code', Variation_0, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CENTRE']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POSITION']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CENTRE'], Literal['POSITION']]) -> Union[Type['Variation_0'], Type['Variation_0']]:
        if key == 'CENTRE':
            return Variation_0
        if key == 'POSITION':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_372_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CENTRE']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['POSITION']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['CENTRE'], Literal['POSITION']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CENTRE'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_372':
        ...

    @overload
    def set_item(self, name : Literal['POSITION'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_372':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CENTRE'], f : Any) -> 'Variation_372':
        ...

    @overload
    def modify_item(self, name : Literal['POSITION'], f : Any) -> 'Variation_372':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_373_Arg : TypeAlias = Raw
class Variation_373(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 5
    table = {
        0: 'Scheduled off-block time',
        1: 'Estimated off-block time',
        2: 'Estimated take-off time',
        3: 'Actual off-block time',
        4: 'Predicted time at runway hold',
        5: 'Actual time at runway hold',
        6: 'Actual line-up time',
        7: 'Actual take-off time',
        8: 'Estimated time of arrival',
        9: 'Predicted landing time',
        10: 'Actual landing time',
        11: 'Actual time off runway',
        12: 'Predicted time to gate',
        13: 'Actual on-block time',
    }

    def __init__(self, arg : Variation_373_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_374_Arg : TypeAlias = Raw
class Variation_374(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'Today',
        1: 'Yesterday',
        2: 'Tomorrow',
    }

    def __init__(self, arg : Variation_374_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_375_Arg : TypeAlias = Raw
class Variation_375(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 5

    def __init__(self, arg : Variation_375_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_376_Arg : TypeAlias = Raw
class Variation_376(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 6

    def __init__(self, arg : Variation_376_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_377_Arg : TypeAlias = Raw
class Variation_377(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Seconds available',
        1: 'Seconds not available',
    }

    def __init__(self, arg : Variation_377_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_378_Arg_Group = TypedDict('Variation_378_Arg_Group', {
    'TYP': Union[Variation_373, Variation_373_Arg],
    'DAY': Union[Variation_374, Variation_374_Arg],
    'HOR': Union[Variation_375, Variation_375_Arg],
    'MIN': Union[Variation_376, Variation_376_Arg],
    'AVS': Union[Variation_377, Variation_377_Arg],
    'SEC': Union[Variation_376, Variation_376_Arg],
})
Variation_378_Arg : TypeAlias = Union[Raw, Variation_378_Arg_Group]
class Variation_378(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('TYP', Variation_373),
        ('DAY', Variation_374),
        Spare(7, 4),
        ('HOR', Variation_375),
        Spare(0, 2),
        ('MIN', Variation_376),
        ('AVS', Variation_377),
        Spare(1, 1),
        ('SEC', Variation_376),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('Time Type', Variation_373, 0, 5),
        'DAY': ('Day', Variation_374, 5, 2),
        'HOR': ('Hours, from 0 to 23', Variation_375, 11, 5),
        'MIN': ('Minutes, from 0 to 59', Variation_376, 18, 6),
        'AVS': ('Seconds Available', Variation_377, 24, 1),
        'SEC': ('Seconds, from 0 to 59', Variation_376, 26, 6),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_373]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DAY']) -> Type[Variation_374]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HOR']) -> Type[Variation_375]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MIN']) -> Type[Variation_376]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AVS']) -> Type[Variation_377]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SEC']) -> Type[Variation_376]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['DAY'], Literal['HOR'], Literal['MIN'], Literal['AVS'], Literal['SEC']]) -> Union[Type['Variation_373'], Type['Variation_374'], Type['Variation_375'], Type['Variation_376'], Type['Variation_377'], Type['Variation_376']]:
        if key == 'TYP':
            return Variation_373
        if key == 'DAY':
            return Variation_374
        if key == 'HOR':
            return Variation_375
        if key == 'MIN':
            return Variation_376
        if key == 'AVS':
            return Variation_377
        if key == 'SEC':
            return Variation_376
        assert_never(key)

    def __init__(self, arg : Variation_378_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_373:
        ...

    @overload
    def get_item(self, name : Literal['DAY']) -> Variation_374:
        ...

    @overload
    def get_item(self, name : Literal['HOR']) -> Variation_375:
        ...

    @overload
    def get_item(self, name : Literal['MIN']) -> Variation_376:
        ...

    @overload
    def get_item(self, name : Literal['AVS']) -> Variation_377:
        ...

    @overload
    def get_item(self, name : Literal['SEC']) -> Variation_376:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['DAY'], Literal['HOR'], Literal['MIN'], Literal['AVS'], Literal['SEC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_373, Variation_373_Arg]) -> 'Variation_378':
        ...

    @overload
    def set_item(self, name : Literal['DAY'], val : Union[Variation_374, Variation_374_Arg]) -> 'Variation_378':
        ...

    @overload
    def set_item(self, name : Literal['HOR'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_378':
        ...

    @overload
    def set_item(self, name : Literal['MIN'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_378':
        ...

    @overload
    def set_item(self, name : Literal['AVS'], val : Union[Variation_377, Variation_377_Arg]) -> 'Variation_378':
        ...

    @overload
    def set_item(self, name : Literal['SEC'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_378':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_378':
        ...

    @overload
    def modify_item(self, name : Literal['DAY'], f : Any) -> 'Variation_378':
        ...

    @overload
    def modify_item(self, name : Literal['HOR'], f : Any) -> 'Variation_378':
        ...

    @overload
    def modify_item(self, name : Literal['MIN'], f : Any) -> 'Variation_378':
        ...

    @overload
    def modify_item(self, name : Literal['AVS'], f : Any) -> 'Variation_378':
        ...

    @overload
    def modify_item(self, name : Literal['SEC'], f : Any) -> 'Variation_378':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_379_Arg : TypeAlias = Union[Variation_378, Variation_378_Arg]
class Variation_379(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 32
    variation_type = Variation_378

    @classmethod
    def spec(cls) -> Type[Variation_378]:
        return Variation_378

    def __init__(self, arg : List[Union[Variation_378, Variation_378_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_378, Variation_378_Arg]) -> 'Variation_379':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_378, Variation_378_Arg]) -> 'Variation_379':
        return self._prepend_item(arg) # type: ignore

Variation_380_Arg : TypeAlias = Raw
class Variation_380(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Empty',
        1: 'Occupied',
        2: 'Unknown',
    }

    def __init__(self, arg : Variation_380_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_381_Arg : TypeAlias = Raw
class Variation_381(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'Available',
        1: 'Not available',
        2: 'Unknown',
    }

    def __init__(self, arg : Variation_381_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_382_Arg_Group = TypedDict('Variation_382_Arg_Group', {
    'EMP': Union[Variation_380, Variation_380_Arg],
    'AVL': Union[Variation_381, Variation_381_Arg],
})
Variation_382_Arg : TypeAlias = Union[Raw, Variation_382_Arg_Group]
class Variation_382(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('EMP', Variation_380),
        ('AVL', Variation_381),
        Spare(4, 4),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EMP': ('Stand Empty', Variation_380, 0, 2),
        'AVL': ('Stand Available', Variation_381, 2, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EMP']) -> Type[Variation_380]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AVL']) -> Type[Variation_381]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EMP'], Literal['AVL']]) -> Union[Type['Variation_380'], Type['Variation_381']]:
        if key == 'EMP':
            return Variation_380
        if key == 'AVL':
            return Variation_381
        assert_never(key)

    def __init__(self, arg : Variation_382_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EMP']) -> Variation_380:
        ...

    @overload
    def get_item(self, name : Literal['AVL']) -> Variation_381:
        ...

    def get_item(self, name : Union[Literal['EMP'], Literal['AVL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EMP'], val : Union[Variation_380, Variation_380_Arg]) -> 'Variation_382':
        ...

    @overload
    def set_item(self, name : Literal['AVL'], val : Union[Variation_381, Variation_381_Arg]) -> 'Variation_382':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EMP'], f : Any) -> 'Variation_382':
        ...

    @overload
    def modify_item(self, name : Literal['AVL'], f : Any) -> 'Variation_382':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_383_Arg = TypedDict('Variation_383_Arg', {
    'FPPSID': Union[Variation_365, Variation_365_Arg],
    'CSN': Union[Variation_145, Variation_145_Arg],
    'IFPSFLIGHTID': Union[Variation_368, Variation_368_Arg],
    'FLIGHTCAT': Union[Variation_369, Variation_369_Arg],
    'TOA': Union[Variation_330, Variation_330_Arg],
    'WTC': Union[Variation_370, Variation_370_Arg],
    'ADEP': Union[Variation_330, Variation_330_Arg],
    'ADES': Union[Variation_330, Variation_330_Arg],
    'RWY': Union[Variation_371, Variation_371_Arg],
    'CFL': Union[Variation_164, Variation_164_Arg],
    'CCP': Union[Variation_372, Variation_372_Arg],
    'TOD': Union[Variation_379, Variation_379_Arg],
    'AST': Union[Variation_161, Variation_161_Arg],
    'STS': Union[Variation_382, Variation_382_Arg],
}, total=False)
class Variation_383(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('FPPSID', Variation_365),
        ('CSN', Variation_145),
        ('IFPSFLIGHTID', Variation_368),
        ('FLIGHTCAT', Variation_369),
        ('TOA', Variation_330),
        ('WTC', Variation_370),
        ('ADEP', Variation_330),
        ('ADES', Variation_330),
        ('RWY', Variation_371),
        ('CFL', Variation_164),
        ('CCP', Variation_372),
        ('TOD', Variation_379),
        ('AST', Variation_161),
        ('STS', Variation_382),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'FPPSID': ('FPPS Identification Tag', Variation_365, 0x8000),
        'CSN': ('Callsign', Variation_145, 0x4000),
        'IFPSFLIGHTID': ('IFPS_FLIGHT_ID', Variation_368, 0x2000),
        'FLIGHTCAT': ('Flight Category', Variation_369, 0x1000),
        'TOA': ('Type of Aircraft', Variation_330, 0x0800),
        'WTC': ('Wake Turbulence Category', Variation_370, 0x0400),
        'ADEP': ('Departure Airport', Variation_330, 0x0200),
        'ADES': ('Destination Airport', Variation_330, 0x0180),
        'RWY': ('Runway Designation', Variation_371, 0x0140),
        'CFL': ('Current Cleared Flight Level', Variation_164, 0x0120),
        'CCP': ('Current Control Position', Variation_372, 0x0110),
        'TOD': ('Time of Departure', Variation_379, 0x0108),
        'AST': ('Aircraft Stand', Variation_161, 0x0104),
        'STS': ('Stand Status', Variation_382, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['FPPSID']) -> Type[Variation_365]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CSN']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IFPSFLIGHTID']) -> Type[Variation_368]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FLIGHTCAT']) -> Type[Variation_369]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOA']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WTC']) -> Type[Variation_370]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADEP']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADES']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RWY']) -> Type[Variation_371]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CFL']) -> Type[Variation_164]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CCP']) -> Type[Variation_372]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOD']) -> Type[Variation_379]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AST']) -> Type[Variation_161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STS']) -> Type[Variation_382]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['FPPSID'], Literal['CSN'], Literal['IFPSFLIGHTID'], Literal['FLIGHTCAT'], Literal['TOA'], Literal['WTC'], Literal['ADEP'], Literal['ADES'], Literal['RWY'], Literal['CFL'], Literal['CCP'], Literal['TOD'], Literal['AST'], Literal['STS']]) -> Union[Type['Variation_365'], Type['Variation_145'], Type['Variation_368'], Type['Variation_369'], Type['Variation_330'], Type['Variation_370'], Type['Variation_330'], Type['Variation_330'], Type['Variation_371'], Type['Variation_164'], Type['Variation_372'], Type['Variation_379'], Type['Variation_161'], Type['Variation_382']]:
        if key == 'FPPSID':
            return Variation_365
        if key == 'CSN':
            return Variation_145
        if key == 'IFPSFLIGHTID':
            return Variation_368
        if key == 'FLIGHTCAT':
            return Variation_369
        if key == 'TOA':
            return Variation_330
        if key == 'WTC':
            return Variation_370
        if key == 'ADEP':
            return Variation_330
        if key == 'ADES':
            return Variation_330
        if key == 'RWY':
            return Variation_371
        if key == 'CFL':
            return Variation_164
        if key == 'CCP':
            return Variation_372
        if key == 'TOD':
            return Variation_379
        if key == 'AST':
            return Variation_161
        if key == 'STS':
            return Variation_382
        assert_never(key)

    def __init__(self, arg : Optional[Variation_383_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['FPPSID'], val : Union[Variation_365, Variation_365_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['CSN'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['IFPSFLIGHTID'], val : Union[Variation_368, Variation_368_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['FLIGHTCAT'], val : Union[Variation_369, Variation_369_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['TOA'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['WTC'], val : Union[Variation_370, Variation_370_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['ADEP'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['ADES'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['RWY'], val : Union[Variation_371, Variation_371_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['CFL'], val : Union[Variation_164, Variation_164_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['CCP'], val : Union[Variation_372, Variation_372_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['TOD'], val : Union[Variation_379, Variation_379_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['AST'], val : Union[Variation_161, Variation_161_Arg]) -> 'Variation_383':
        ...

    @overload
    def set_item(self, name : Literal['STS'], val : Union[Variation_382, Variation_382_Arg]) -> 'Variation_383':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['FPPSID']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['CSN']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['IFPSFLIGHTID']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['FLIGHTCAT']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['TOA']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['WTC']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['ADEP']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['ADES']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['RWY']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['CFL']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['CCP']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['TOD']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['AST']) -> 'Variation_383':
        ...

    @overload
    def del_item(self, name : Literal['STS']) -> 'Variation_383':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['FPPSID']) -> Variation_365:
        ...

    @overload
    def get_item(self, name : Literal['CSN']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['IFPSFLIGHTID']) -> Variation_368:
        ...

    @overload
    def get_item(self, name : Literal['FLIGHTCAT']) -> Variation_369:
        ...

    @overload
    def get_item(self, name : Literal['TOA']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['WTC']) -> Variation_370:
        ...

    @overload
    def get_item(self, name : Literal['ADEP']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['ADES']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['RWY']) -> Variation_371:
        ...

    @overload
    def get_item(self, name : Literal['CFL']) -> Variation_164:
        ...

    @overload
    def get_item(self, name : Literal['CCP']) -> Variation_372:
        ...

    @overload
    def get_item(self, name : Literal['TOD']) -> Variation_379:
        ...

    @overload
    def get_item(self, name : Literal['AST']) -> Variation_161:
        ...

    @overload
    def get_item(self, name : Literal['STS']) -> Variation_382:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['FPPSID'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['CSN'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['IFPSFLIGHTID'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['FLIGHTCAT'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['TOA'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['WTC'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['ADEP'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['ADES'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['RWY'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['CFL'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['CCP'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['TOD'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['AST'], f : Any) -> 'Variation_383':
        ...

    @overload
    def modify_item(self, name : Literal['STS'], f : Any) -> 'Variation_383':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_384_Arg : TypeAlias = Raw
class Variation_384(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'Flyco (follow me)',
        1: 'ATC equipment maintenance',
        2: 'Airport maintenance',
        3: 'Fire',
        4: 'Bird scarer',
        5: 'Snow plough',
        6: 'Runway sweeper',
        7: 'Emergency',
        8: 'Police',
        9: 'Bus',
        10: 'Tug (push/tow)',
        11: 'Grass cutter',
        12: 'Fuel',
        13: 'Baggage',
        14: 'Catering',
        15: 'Aircraft maintenance',
        16: 'Unknown',
    }

    def __init__(self, arg : Variation_384_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_385_Arg : TypeAlias = Raw
class Variation_385(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 7
    table = {
        1: 'Towing aircraft',
        2: 'FOLLOW-ME operation',
        3: 'Runway check',
        4: 'Emergency operation (fire, medical...)',
        5: 'Work in progress (maintenance, birds scarer, sweepers...)',
    }

    def __init__(self, arg : Variation_385_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_386_Arg_Group = TypedDict('Variation_386_Arg_Group', {
    'TRB': Union[Variation_297, Variation_297_Arg],
    'MSG': Union[Variation_385, Variation_385_Arg],
})
Variation_386_Arg : TypeAlias = Union[Raw, Variation_386_Arg_Group]
class Variation_386(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('TRB', Variation_297),
        ('MSG', Variation_385),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TRB': ('In Trouble', Variation_297, 0, 1),
        'MSG': ('Message', Variation_385, 1, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TRB']) -> Type[Variation_297]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSG']) -> Type[Variation_385]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TRB'], Literal['MSG']]) -> Union[Type['Variation_297'], Type['Variation_385']]:
        if key == 'TRB':
            return Variation_297
        if key == 'MSG':
            return Variation_385
        assert_never(key)

    def __init__(self, arg : Variation_386_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TRB']) -> Variation_297:
        ...

    @overload
    def get_item(self, name : Literal['MSG']) -> Variation_385:
        ...

    def get_item(self, name : Union[Literal['TRB'], Literal['MSG']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TRB'], val : Union[Variation_297, Variation_297_Arg]) -> 'Variation_386':
        ...

    @overload
    def set_item(self, name : Literal['MSG'], val : Union[Variation_385, Variation_385_Arg]) -> 'Variation_386':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TRB'], f : Any) -> 'Variation_386':
        ...

    @overload
    def modify_item(self, name : Literal['MSG'], f : Any) -> 'Variation_386':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_387_Arg_Group = TypedDict('Variation_387_Arg_Group', {
    'X': Union[Variation_300, Variation_300_Arg],
    'Y': Union[Variation_300, Variation_300_Arg],
})
Variation_387_Arg : TypeAlias = Union[Raw, Variation_387_Arg_Group]
class Variation_387(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('X', Variation_300),
        ('Y', Variation_300),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('Estimated Accuracy of the Calculated Position of X Component', Variation_300, 0, 8),
        'Y': ('Estimated Accuracy of the Calculated Position of Y Component', Variation_300, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_300]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_300]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_300'], Type['Variation_300']]:
        if key == 'X':
            return Variation_300
        if key == 'Y':
            return Variation_300
        assert_never(key)

    def __init__(self, arg : Variation_387_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_300:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_300:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_300, Variation_300_Arg]) -> 'Variation_387':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_300, Variation_300_Arg]) -> 'Variation_387':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_387':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_387':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_388_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_388(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 8.381903171539307e-8, '°')

    def __init__(self, arg : Variation_388_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_389_Arg_Group = TypedDict('Variation_389_Arg_Group', {
    'LAT': Union[Variation_388, Variation_388_Arg],
    'LON': Union[Variation_388, Variation_388_Arg],
})
Variation_389_Arg : TypeAlias = Union[Raw, Variation_389_Arg_Group]
class Variation_389(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('LAT', Variation_388),
        ('LON', Variation_388),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('APW Latitude Component Accuracy', Variation_388, 0, 16),
        'LON': ('APW Longitude Component Accuracy', Variation_388, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_388]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_388]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_388'], Type['Variation_388']]:
        if key == 'LAT':
            return Variation_388
        if key == 'LON':
            return Variation_388
        assert_never(key)

    def __init__(self, arg : Variation_389_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_388:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_388:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_388, Variation_388_Arg]) -> 'Variation_389':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_388, Variation_388_Arg]) -> 'Variation_389':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_389':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_389':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_390_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_390(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 0.5, 'm')

    def __init__(self, arg : Variation_390_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_391_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_391(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 0.1, 'm/s')

    def __init__(self, arg : Variation_391_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_392_Arg_Group = TypedDict('Variation_392_Arg_Group', {
    'X': Union[Variation_391, Variation_391_Arg],
    'Y': Union[Variation_391, Variation_391_Arg],
})
Variation_392_Arg : TypeAlias = Union[Raw, Variation_392_Arg_Group]
class Variation_392(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('X', Variation_391),
        ('Y', Variation_391),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('Estimated Accuracy of the Calculated Velocity of X Component', Variation_391, 0, 8),
        'Y': ('Estimated Accuracy of the Calculated Velocity of Y Component', Variation_391, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_391]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_391]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_391'], Type['Variation_391']]:
        if key == 'X':
            return Variation_391
        if key == 'Y':
            return Variation_391
        assert_never(key)

    def __init__(self, arg : Variation_392_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_391:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_391:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_391, Variation_391_Arg]) -> 'Variation_392':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_391, Variation_391_Arg]) -> 'Variation_392':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_392':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_392':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_393_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_393(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 0.1, 'm/s')

    def __init__(self, arg : Variation_393_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_394_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_394(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 1.0e-2, 'm/s²')

    def __init__(self, arg : Variation_394_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_395_Arg_Group = TypedDict('Variation_395_Arg_Group', {
    'X': Union[Variation_394, Variation_394_Arg],
    'Y': Union[Variation_394, Variation_394_Arg],
})
Variation_395_Arg : TypeAlias = Union[Raw, Variation_395_Arg_Group]
class Variation_395(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('X', Variation_394),
        ('Y', Variation_394),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('Estimated Accuracy Of Acceleration of X Component', Variation_394, 0, 8),
        'Y': ('Estimated Accuracy Of Acceleration of Y Component', Variation_394, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_394]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_394]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_394'], Type['Variation_394']]:
        if key == 'X':
            return Variation_394
        if key == 'Y':
            return Variation_394
        assert_never(key)

    def __init__(self, arg : Variation_395_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_394:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_394:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_394, Variation_394_Arg]) -> 'Variation_395':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_394, Variation_394_Arg]) -> 'Variation_395':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_395':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_395':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_396_Arg = TypedDict('Variation_396_Arg', {
    'APC': Union[Variation_387, Variation_387_Arg],
    'APW': Union[Variation_389, Variation_389_Arg],
    'ATH': Union[Variation_390, Variation_390_Arg],
    'AVC': Union[Variation_392, Variation_392_Arg],
    'ARC': Union[Variation_393, Variation_393_Arg],
    'AAC': Union[Variation_395, Variation_395_Arg],
}, total=False)
class Variation_396(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('APC', Variation_387),
        ('APW', Variation_389),
        ('ATH', Variation_390),
        ('AVC', Variation_392),
        ('ARC', Variation_393),
        ('AAC', Variation_395),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'APC': ('Estimated Accuracy Of Track Position (Cartesian)', Variation_387, 0x80),
        'APW': ('Estimated Accuracy Of Track Position (WGS84)', Variation_389, 0x40),
        'ATH': ('Estimated Accuracy Of Track Height', Variation_390, 0x20),
        'AVC': ('Estimated Accuracy Of Track Velocity (Cartesian)', Variation_392, 0x10),
        'ARC': ('Estimated Accuracy Of Rate Of Climb / Descent', Variation_393, 0x08),
        'AAC': ('Estimated Accuracy Of Acceleration (Cartesian)', Variation_395, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['APC']) -> Type[Variation_387]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['APW']) -> Type[Variation_389]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ATH']) -> Type[Variation_390]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AVC']) -> Type[Variation_392]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_393]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AAC']) -> Type[Variation_395]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['APC'], Literal['APW'], Literal['ATH'], Literal['AVC'], Literal['ARC'], Literal['AAC']]) -> Union[Type['Variation_387'], Type['Variation_389'], Type['Variation_390'], Type['Variation_392'], Type['Variation_393'], Type['Variation_395']]:
        if key == 'APC':
            return Variation_387
        if key == 'APW':
            return Variation_389
        if key == 'ATH':
            return Variation_390
        if key == 'AVC':
            return Variation_392
        if key == 'ARC':
            return Variation_393
        if key == 'AAC':
            return Variation_395
        assert_never(key)

    def __init__(self, arg : Optional[Variation_396_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['APC'], val : Union[Variation_387, Variation_387_Arg]) -> 'Variation_396':
        ...

    @overload
    def set_item(self, name : Literal['APW'], val : Union[Variation_389, Variation_389_Arg]) -> 'Variation_396':
        ...

    @overload
    def set_item(self, name : Literal['ATH'], val : Union[Variation_390, Variation_390_Arg]) -> 'Variation_396':
        ...

    @overload
    def set_item(self, name : Literal['AVC'], val : Union[Variation_392, Variation_392_Arg]) -> 'Variation_396':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_393, Variation_393_Arg]) -> 'Variation_396':
        ...

    @overload
    def set_item(self, name : Literal['AAC'], val : Union[Variation_395, Variation_395_Arg]) -> 'Variation_396':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['APC']) -> 'Variation_396':
        ...

    @overload
    def del_item(self, name : Literal['APW']) -> 'Variation_396':
        ...

    @overload
    def del_item(self, name : Literal['ATH']) -> 'Variation_396':
        ...

    @overload
    def del_item(self, name : Literal['AVC']) -> 'Variation_396':
        ...

    @overload
    def del_item(self, name : Literal['ARC']) -> 'Variation_396':
        ...

    @overload
    def del_item(self, name : Literal['AAC']) -> 'Variation_396':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['APC']) -> Variation_387:
        ...

    @overload
    def get_item(self, name : Literal['APW']) -> Variation_389:
        ...

    @overload
    def get_item(self, name : Literal['ATH']) -> Variation_390:
        ...

    @overload
    def get_item(self, name : Literal['AVC']) -> Variation_392:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_393:
        ...

    @overload
    def get_item(self, name : Literal['AAC']) -> Variation_395:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['APC'], f : Any) -> 'Variation_396':
        ...

    @overload
    def modify_item(self, name : Literal['APW'], f : Any) -> 'Variation_396':
        ...

    @overload
    def modify_item(self, name : Literal['ATH'], f : Any) -> 'Variation_396':
        ...

    @overload
    def modify_item(self, name : Literal['AVC'], f : Any) -> 'Variation_396':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_396':
        ...

    @overload
    def modify_item(self, name : Literal['AAC'], f : Any) -> 'Variation_396':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_397_Arg : TypeAlias = Raw
class Variation_397(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Alert acknowledged',
        1: 'Alert not acknowledged',
    }

    def __init__(self, arg : Variation_397_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_398_Arg : TypeAlias = Raw
class Variation_398(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'End fo alert',
        1: 'Pre-alarm',
        2: 'Severe alert',
    }

    def __init__(self, arg : Variation_398_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_399_Arg_Group = TypedDict('Variation_399_Arg_Group', {
    'ACK': Union[Variation_397, Variation_397_Arg],
    'SVR': Union[Variation_398, Variation_398_Arg],
    'AT': Union[Variation_0, Variation_0_Arg],
    'AN': Union[Variation_0, Variation_0_Arg],
})
Variation_399_Arg : TypeAlias = Union[Raw, Variation_399_Arg_Group]
class Variation_399(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('ACK', Variation_397),
        ('SVR', Variation_398),
        Spare(3, 5),
        ('AT', Variation_0),
        ('AN', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ACK': ('Alert Acknowleged', Variation_397, 0, 1),
        'SVR': ('Alert Severity', Variation_398, 1, 2),
        'AT': ('Alert Type', Variation_0, 8, 8),
        'AN': ('Alert Number', Variation_0, 16, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ACK']) -> Type[Variation_397]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SVR']) -> Type[Variation_398]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AT']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AN']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ACK'], Literal['SVR'], Literal['AT'], Literal['AN']]) -> Union[Type['Variation_397'], Type['Variation_398'], Type['Variation_0'], Type['Variation_0']]:
        if key == 'ACK':
            return Variation_397
        if key == 'SVR':
            return Variation_398
        if key == 'AT':
            return Variation_0
        if key == 'AN':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_399_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ACK']) -> Variation_397:
        ...

    @overload
    def get_item(self, name : Literal['SVR']) -> Variation_398:
        ...

    @overload
    def get_item(self, name : Literal['AT']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['AN']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['ACK'], Literal['SVR'], Literal['AT'], Literal['AN']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ACK'], val : Union[Variation_397, Variation_397_Arg]) -> 'Variation_399':
        ...

    @overload
    def set_item(self, name : Literal['SVR'], val : Union[Variation_398, Variation_398_Arg]) -> 'Variation_399':
        ...

    @overload
    def set_item(self, name : Literal['AT'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_399':
        ...

    @overload
    def set_item(self, name : Literal['AN'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_399':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ACK'], f : Any) -> 'Variation_399':
        ...

    @overload
    def modify_item(self, name : Literal['SVR'], f : Any) -> 'Variation_399':
        ...

    @overload
    def modify_item(self, name : Literal['AT'], f : Any) -> 'Variation_399':
        ...

    @overload
    def modify_item(self, name : Literal['AN'], f : Any) -> 'Variation_399':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_400_Arg_Group = TypedDict('Variation_400_Arg_Group', {
    'FTN': Union[Variation_43, Variation_43_Arg],
})
Variation_400_Arg : TypeAlias = Union[Raw, Variation_400_Arg_Group]
class Variation_400(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('FTN', Variation_43),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FTN': ('Fusion Track Number', Variation_43, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['FTN']]) -> Union[Type['Variation_43']]:
        if key == 'FTN':
            return Variation_43
        assert_never(key)

    def __init__(self, arg : Variation_400_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['FTN']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['FTN'], val : Union[Variation_43, Variation_43_Arg]) -> 'Variation_400':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['FTN'], f : Any) -> 'Variation_400':
        return self._modify_item(name, f) # type: ignore

Variation_401_Arg : TypeAlias = Union[Variation_400, Variation_400_Arg]
class Variation_401(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_400

    @classmethod
    def spec(cls) -> Type[Variation_400]:
        return Variation_400

    def __init__(self, arg : List[Union[Variation_400, Variation_400_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_400, Variation_400_Arg]) -> 'Variation_401':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_400, Variation_400_Arg]) -> 'Variation_401':
        return self._prepend_item(arg) # type: ignore

Variation_402_Arg : TypeAlias = Raw
class Variation_402(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Indicator on',
        1: 'Indicator off',
    }

    def __init__(self, arg : Variation_402_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_403_Arg : TypeAlias = Raw
class Variation_403(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Indicator on',
        1: 'Indicator off',
    }

    def __init__(self, arg : Variation_403_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_404_Arg : TypeAlias = Raw
class Variation_404(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Indicator on',
        1: 'Indicator off',
    }

    def __init__(self, arg : Variation_404_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_405_Arg : TypeAlias = Raw
class Variation_405(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'Indicator on',
        1: 'Indicator off',
    }

    def __init__(self, arg : Variation_405_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_406_Arg : TypeAlias = Raw
class Variation_406(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Indicator on',
        1: 'Indicator off',
    }

    def __init__(self, arg : Variation_406_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_407_Arg : TypeAlias = Raw
class Variation_407(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Indicator on',
        1: 'Indicator off',
    }

    def __init__(self, arg : Variation_407_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_408_Arg : TypeAlias = Raw
class Variation_408(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Indicator on',
        1: 'Indicator off',
    }

    def __init__(self, arg : Variation_408_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_409_Arg : TypeAlias = Raw
class Variation_409(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Indicator on',
        1: 'Indicator off',
    }

    def __init__(self, arg : Variation_409_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_410_Arg_Group = TypedDict('Variation_410_Arg_Group', {
    'BKN': Union[Variation_187, Variation_187_Arg],
    'I1': Union[Variation_402, Variation_402_Arg],
    'I2': Union[Variation_403, Variation_403_Arg],
    'I3': Union[Variation_404, Variation_404_Arg],
    'I4': Union[Variation_405, Variation_405_Arg],
    'I5': Union[Variation_406, Variation_406_Arg],
    'I6': Union[Variation_407, Variation_407_Arg],
    'I7': Union[Variation_408, Variation_408_Arg],
    'I8': Union[Variation_409, Variation_409_Arg],
    'I9': Union[Variation_402, Variation_402_Arg],
    'I10': Union[Variation_403, Variation_403_Arg],
    'I11': Union[Variation_404, Variation_404_Arg],
    'I12': Union[Variation_405, Variation_405_Arg],
})
Variation_410_Arg : TypeAlias = Union[Raw, Variation_410_Arg_Group]
class Variation_410(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('BKN', Variation_187),
        ('I1', Variation_402),
        ('I2', Variation_403),
        ('I3', Variation_404),
        ('I4', Variation_405),
        ('I5', Variation_406),
        ('I6', Variation_407),
        ('I7', Variation_408),
        ('I8', Variation_409),
        ('I9', Variation_402),
        ('I10', Variation_403),
        ('I11', Variation_404),
        ('I12', Variation_405),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'BKN': ('Bank Number', Variation_187, 0, 4),
        'I1': ('Indicator 1', Variation_402, 4, 1),
        'I2': ('Indicator 2', Variation_403, 5, 1),
        'I3': ('Indicator 3', Variation_404, 6, 1),
        'I4': ('Indicator 4', Variation_405, 7, 1),
        'I5': ('Indicator 5', Variation_406, 8, 1),
        'I6': ('Indicator 6', Variation_407, 9, 1),
        'I7': ('Indicator 7', Variation_408, 10, 1),
        'I8': ('Indicator 8', Variation_409, 11, 1),
        'I9': ('Indicator 9', Variation_402, 12, 1),
        'I10': ('Indicator 10', Variation_403, 13, 1),
        'I11': ('Indicator 11', Variation_404, 14, 1),
        'I12': ('Indicator 12', Variation_405, 15, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['BKN']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I1']) -> Type[Variation_402]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I2']) -> Type[Variation_403]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I3']) -> Type[Variation_404]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I4']) -> Type[Variation_405]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I5']) -> Type[Variation_406]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I6']) -> Type[Variation_407]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I7']) -> Type[Variation_408]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I8']) -> Type[Variation_409]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I9']) -> Type[Variation_402]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I10']) -> Type[Variation_403]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I11']) -> Type[Variation_404]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['I12']) -> Type[Variation_405]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['BKN'], Literal['I1'], Literal['I2'], Literal['I3'], Literal['I4'], Literal['I5'], Literal['I6'], Literal['I7'], Literal['I8'], Literal['I9'], Literal['I10'], Literal['I11'], Literal['I12']]) -> Union[Type['Variation_187'], Type['Variation_402'], Type['Variation_403'], Type['Variation_404'], Type['Variation_405'], Type['Variation_406'], Type['Variation_407'], Type['Variation_408'], Type['Variation_409'], Type['Variation_402'], Type['Variation_403'], Type['Variation_404'], Type['Variation_405']]:
        if key == 'BKN':
            return Variation_187
        if key == 'I1':
            return Variation_402
        if key == 'I2':
            return Variation_403
        if key == 'I3':
            return Variation_404
        if key == 'I4':
            return Variation_405
        if key == 'I5':
            return Variation_406
        if key == 'I6':
            return Variation_407
        if key == 'I7':
            return Variation_408
        if key == 'I8':
            return Variation_409
        if key == 'I9':
            return Variation_402
        if key == 'I10':
            return Variation_403
        if key == 'I11':
            return Variation_404
        if key == 'I12':
            return Variation_405
        assert_never(key)

    def __init__(self, arg : Variation_410_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['BKN']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['I1']) -> Variation_402:
        ...

    @overload
    def get_item(self, name : Literal['I2']) -> Variation_403:
        ...

    @overload
    def get_item(self, name : Literal['I3']) -> Variation_404:
        ...

    @overload
    def get_item(self, name : Literal['I4']) -> Variation_405:
        ...

    @overload
    def get_item(self, name : Literal['I5']) -> Variation_406:
        ...

    @overload
    def get_item(self, name : Literal['I6']) -> Variation_407:
        ...

    @overload
    def get_item(self, name : Literal['I7']) -> Variation_408:
        ...

    @overload
    def get_item(self, name : Literal['I8']) -> Variation_409:
        ...

    @overload
    def get_item(self, name : Literal['I9']) -> Variation_402:
        ...

    @overload
    def get_item(self, name : Literal['I10']) -> Variation_403:
        ...

    @overload
    def get_item(self, name : Literal['I11']) -> Variation_404:
        ...

    @overload
    def get_item(self, name : Literal['I12']) -> Variation_405:
        ...

    def get_item(self, name : Union[Literal['BKN'], Literal['I1'], Literal['I2'], Literal['I3'], Literal['I4'], Literal['I5'], Literal['I6'], Literal['I7'], Literal['I8'], Literal['I9'], Literal['I10'], Literal['I11'], Literal['I12']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['BKN'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I1'], val : Union[Variation_402, Variation_402_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I2'], val : Union[Variation_403, Variation_403_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I3'], val : Union[Variation_404, Variation_404_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I4'], val : Union[Variation_405, Variation_405_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I5'], val : Union[Variation_406, Variation_406_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I6'], val : Union[Variation_407, Variation_407_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I7'], val : Union[Variation_408, Variation_408_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I8'], val : Union[Variation_409, Variation_409_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I9'], val : Union[Variation_402, Variation_402_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I10'], val : Union[Variation_403, Variation_403_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I11'], val : Union[Variation_404, Variation_404_Arg]) -> 'Variation_410':
        ...

    @overload
    def set_item(self, name : Literal['I12'], val : Union[Variation_405, Variation_405_Arg]) -> 'Variation_410':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['BKN'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I1'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I2'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I3'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I4'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I5'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I6'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I7'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I8'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I9'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I10'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I11'], f : Any) -> 'Variation_410':
        ...

    @overload
    def modify_item(self, name : Literal['I12'], f : Any) -> 'Variation_410':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_411_Arg : TypeAlias = Union[Variation_410, Variation_410_Arg]
class Variation_411(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_410

    @classmethod
    def spec(cls) -> Type[Variation_410]:
        return Variation_410

    def __init__(self, arg : List[Union[Variation_410, Variation_410_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_410, Variation_410_Arg]) -> 'Variation_411':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_410, Variation_410_Arg]) -> 'Variation_411':
        return self._prepend_item(arg) # type: ignore

Variation_412_Arg = TypedDict('Variation_412_Arg', {
    '010': Union[Variation_310, Variation_310_Arg],
    '000': Union[Variation_311, Variation_311_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '041': Union[Variation_312, Variation_312_Arg],
    '042': Union[Variation_313, Variation_313_Arg],
    '202': Union[Variation_315, Variation_315_Arg],
    '210': Union[Variation_317, Variation_317_Arg],
    '060': Union[Variation_318, Variation_318_Arg],
    '245': Union[Variation_319, Variation_319_Arg],
    '380': Union[Variation_336, Variation_336_Arg],
    '161': Union[Variation_338, Variation_338_Arg],
    '170': Union[Variation_355, Variation_355_Arg],
    '290': Union[Variation_358, Variation_358_Arg],
    '430': Union[Variation_359, Variation_359_Arg],
    '090': Union[Variation_360, Variation_360_Arg],
    '093': Union[Variation_363, Variation_363_Arg],
    '092': Union[Variation_287, Variation_287_Arg],
    '215': Union[Variation_364, Variation_364_Arg],
    '270': Union[Variation_290, Variation_290_Arg],
    '390': Union[Variation_383, Variation_383_Arg],
    '300': Union[Variation_384, Variation_384_Arg],
    '310': Union[Variation_386, Variation_386_Arg],
    '500': Union[Variation_396, Variation_396_Arg],
    '600': Union[Variation_399, Variation_399_Arg],
    '605': Union[Variation_401, Variation_401_Arg],
    '610': Union[Variation_411, Variation_411_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
}, total=False)
class Variation_412(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('010', Variation_310),
        ('000', Variation_311),
        ('015', Variation_0),
        ('140', Variation_80),
        ('041', Variation_312),
        ('042', Variation_313),
        ('202', Variation_315),
        ('210', Variation_317),
        ('060', Variation_318),
        ('245', Variation_319),
        ('380', Variation_336),
        ('161', Variation_338),
        ('170', Variation_355),
        ('290', Variation_358),
        ('430', Variation_359),
        ('090', Variation_360),
        ('093', Variation_363),
        ('092', Variation_287),
        ('215', Variation_364),
        ('270', Variation_290),
        ('390', Variation_383),
        ('300', Variation_384),
        ('310', Variation_386),
        ('500', Variation_396),
        ('600', Variation_399),
        ('605', Variation_401),
        ('610', Variation_411),
        ('SP', Variation_62),
        ('RE', Variation_202),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_310, 0x8000000000),
        '000': ('Message Type', Variation_311, 0x4000000000),
        '015': ('Service Identification', Variation_0, 0x2000000000),
        '140': ('Time of Track Information', Variation_80, 0x1000000000),
        '041': ('Position in WGS-84 Coordinates', Variation_312, 0x0800000000),
        '042': ('Calculated Position in Cartesian Co-ordinates', Variation_313, 0x0400000000),
        '202': ('Calculated Track Velocity in Cartesian Coordinates', Variation_315, 0x0200000000),
        '210': ('Calculated Acceleration', Variation_317, 0x0180000000),
        '060': ('Mode-3/A Code in Octal Representation', Variation_318, 0x0140000000),
        '245': ('Target Identification', Variation_319, 0x0120000000),
        '380': ('Mode-S / ADS-B Related Data', Variation_336, 0x0110000000),
        '161': ('Track Number', Variation_338, 0x0108000000),
        '170': ('Track Status', Variation_355, 0x0104000000),
        '290': ('System Track Update Ages', Variation_358, 0x0102000000),
        '430': ('Phase of Flight', Variation_359, 0x0101800000),
        '090': ('Measured Flight Level', Variation_360, 0x0101400000),
        '093': ('Calculated Track Barometric Altitude', Variation_363, 0x0101200000),
        '092': ('Calculated Track Geometric Altitude', Variation_287, 0x0101100000),
        '215': ('Calculated Rate Of Climb/Descent', Variation_364, 0x0101080000),
        '270': ('Target Size and Orientation', Variation_290, 0x0101040000),
        '390': ('Flight Plan Related Data', Variation_383, 0x0101020000),
        '300': ('Vehicle Fleet Identification', Variation_384, 0x0101018000),
        '310': ('Pre-programmed Message', Variation_386, 0x0101014000),
        '500': ('Estimated Accuracies', Variation_396, 0x0101012000),
        '600': ('Alert Messages', Variation_399, 0x0101011000),
        '605': ('Tracks in Alert', Variation_401, 0x0101010800),
        '610': ('Holdbar Status', Variation_411, 0x0101010400),
        'SP': ('Special Purpose Field', Variation_62, 0x0101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0101010180),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_310]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_311]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_312]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_313]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['202']) -> Type[Variation_315]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_317]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_318]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['245']) -> Type[Variation_319]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['380']) -> Type[Variation_336]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_338]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_355]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['290']) -> Type[Variation_358]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['430']) -> Type[Variation_359]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['093']) -> Type[Variation_363]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['092']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['215']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['270']) -> Type[Variation_290]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['390']) -> Type[Variation_383]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_384]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['310']) -> Type[Variation_386]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_396]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['600']) -> Type[Variation_399]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['605']) -> Type[Variation_401]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['610']) -> Type[Variation_411]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['015'], Literal['140'], Literal['041'], Literal['042'], Literal['202'], Literal['210'], Literal['060'], Literal['245'], Literal['380'], Literal['161'], Literal['170'], Literal['290'], Literal['430'], Literal['090'], Literal['093'], Literal['092'], Literal['215'], Literal['270'], Literal['390'], Literal['300'], Literal['310'], Literal['500'], Literal['600'], Literal['605'], Literal['610'], Literal['SP'], Literal['RE']]) -> Union[Type['Variation_310'], Type['Variation_311'], Type['Variation_0'], Type['Variation_80'], Type['Variation_312'], Type['Variation_313'], Type['Variation_315'], Type['Variation_317'], Type['Variation_318'], Type['Variation_319'], Type['Variation_336'], Type['Variation_338'], Type['Variation_355'], Type['Variation_358'], Type['Variation_359'], Type['Variation_360'], Type['Variation_363'], Type['Variation_287'], Type['Variation_364'], Type['Variation_290'], Type['Variation_383'], Type['Variation_384'], Type['Variation_386'], Type['Variation_396'], Type['Variation_399'], Type['Variation_401'], Type['Variation_411'], Type['Variation_62'], Type['Variation_202']]:
        if key == '010':
            return Variation_310
        if key == '000':
            return Variation_311
        if key == '015':
            return Variation_0
        if key == '140':
            return Variation_80
        if key == '041':
            return Variation_312
        if key == '042':
            return Variation_313
        if key == '202':
            return Variation_315
        if key == '210':
            return Variation_317
        if key == '060':
            return Variation_318
        if key == '245':
            return Variation_319
        if key == '380':
            return Variation_336
        if key == '161':
            return Variation_338
        if key == '170':
            return Variation_355
        if key == '290':
            return Variation_358
        if key == '430':
            return Variation_359
        if key == '090':
            return Variation_360
        if key == '093':
            return Variation_363
        if key == '092':
            return Variation_287
        if key == '215':
            return Variation_364
        if key == '270':
            return Variation_290
        if key == '390':
            return Variation_383
        if key == '300':
            return Variation_384
        if key == '310':
            return Variation_386
        if key == '500':
            return Variation_396
        if key == '600':
            return Variation_399
        if key == '605':
            return Variation_401
        if key == '610':
            return Variation_411
        if key == 'SP':
            return Variation_62
        if key == 'RE':
            return Variation_202
        assert_never(key)

    def __init__(self, arg : Optional[Variation_412_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_310, Variation_310_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_311, Variation_311_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_312, Variation_312_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_313, Variation_313_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['202'], val : Union[Variation_315, Variation_315_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_317, Variation_317_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_318, Variation_318_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['245'], val : Union[Variation_319, Variation_319_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['380'], val : Union[Variation_336, Variation_336_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_338, Variation_338_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_355, Variation_355_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['290'], val : Union[Variation_358, Variation_358_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['430'], val : Union[Variation_359, Variation_359_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['093'], val : Union[Variation_363, Variation_363_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['092'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['215'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['270'], val : Union[Variation_290, Variation_290_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['390'], val : Union[Variation_383, Variation_383_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_384, Variation_384_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['310'], val : Union[Variation_386, Variation_386_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_396, Variation_396_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['600'], val : Union[Variation_399, Variation_399_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['605'], val : Union[Variation_401, Variation_401_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['610'], val : Union[Variation_411, Variation_411_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_412':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_412':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['202']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['245']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['380']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['290']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['430']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['093']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['092']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['215']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['270']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['390']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['310']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['600']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['605']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['610']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_412':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_412':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_310:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_311:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_312:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_313:
        ...

    @overload
    def get_item(self, name : Literal['202']) -> Variation_315:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_317:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_318:
        ...

    @overload
    def get_item(self, name : Literal['245']) -> Variation_319:
        ...

    @overload
    def get_item(self, name : Literal['380']) -> Variation_336:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_338:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_355:
        ...

    @overload
    def get_item(self, name : Literal['290']) -> Variation_358:
        ...

    @overload
    def get_item(self, name : Literal['430']) -> Variation_359:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['093']) -> Variation_363:
        ...

    @overload
    def get_item(self, name : Literal['092']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['215']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['270']) -> Variation_290:
        ...

    @overload
    def get_item(self, name : Literal['390']) -> Variation_383:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_384:
        ...

    @overload
    def get_item(self, name : Literal['310']) -> Variation_386:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_396:
        ...

    @overload
    def get_item(self, name : Literal['600']) -> Variation_399:
        ...

    @overload
    def get_item(self, name : Literal['605']) -> Variation_401:
        ...

    @overload
    def get_item(self, name : Literal['610']) -> Variation_411:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['202'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['245'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['380'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['290'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['430'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['093'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['092'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['215'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['270'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['390'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['310'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['600'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['605'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['610'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_412':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_412':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_413_Arg : TypeAlias = Raw
class Variation_413(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 4
    table = {
        0: 'No alert, no SPI, aircraft airborne',
        1: 'No alert, no SPI, aircraft on ground',
        2: 'Alert, no SPI, aircraft airborne',
        3: 'Alert, no SPI, aircraft on ground',
        4: 'Alert, SPI, aircraft airborne or on ground',
        5: 'No alert, SPI, aircraft airborne or on ground',
        6: 'General Emergency',
        7: 'Lifeguard / medical',
        8: 'Minimum fuel',
        9: 'No communications',
        10: 'Unlawful interference',
    }

    def __init__(self, arg : Variation_413_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_414_Arg_Group = TypedDict('Variation_414_Arg_Group', {
    'COM': Union[Variation_322, Variation_322_Arg],
    'STAT': Union[Variation_413, Variation_413_Arg],
    'SSC': Union[Variation_324, Variation_324_Arg],
    'ARC': Union[Variation_325, Variation_325_Arg],
    'AIC': Union[Variation_326, Variation_326_Arg],
    'B1A': Union[Variation_237, Variation_237_Arg],
    'B1B': Union[Variation_282, Variation_282_Arg],
    'AC': Union[Variation_324, Variation_324_Arg],
    'MN': Union[Variation_327, Variation_327_Arg],
    'DC': Union[Variation_328, Variation_328_Arg],
})
Variation_414_Arg : TypeAlias = Union[Raw, Variation_414_Arg_Group]
class Variation_414(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('COM', Variation_322),
        ('STAT', Variation_413),
        Spare(7, 1),
        ('SSC', Variation_324),
        ('ARC', Variation_325),
        ('AIC', Variation_326),
        ('B1A', Variation_237),
        ('B1B', Variation_282),
        ('AC', Variation_324),
        ('MN', Variation_327),
        ('DC', Variation_328),
        Spare(3, 5),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COM': ('Communications Capability of the Transponder', Variation_322, 0, 3),
        'STAT': ('Flight Status', Variation_413, 3, 4),
        'SSC': ('Specific Service Capability', Variation_324, 8, 1),
        'ARC': ('Altitude Reporting Capability', Variation_325, 9, 1),
        'AIC': ('Aircraft Identification Capability', Variation_326, 10, 1),
        'B1A': ('BDS 1,0 Bit 16', Variation_237, 11, 1),
        'B1B': ('BDS 1,0 Bit 37/40', Variation_282, 12, 4),
        'AC': ('ACAS Operational', Variation_324, 16, 1),
        'MN': ('Multiple Navigational Aids Operating', Variation_327, 17, 1),
        'DC': ('Differential Correction', Variation_328, 18, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_322]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STAT']) -> Type[Variation_413]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSC']) -> Type[Variation_324]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_325]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AIC']) -> Type[Variation_326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1A']) -> Type[Variation_237]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1B']) -> Type[Variation_282]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AC']) -> Type[Variation_324]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MN']) -> Type[Variation_327]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DC']) -> Type[Variation_328]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COM'], Literal['STAT'], Literal['SSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B'], Literal['AC'], Literal['MN'], Literal['DC']]) -> Union[Type['Variation_322'], Type['Variation_413'], Type['Variation_324'], Type['Variation_325'], Type['Variation_326'], Type['Variation_237'], Type['Variation_282'], Type['Variation_324'], Type['Variation_327'], Type['Variation_328']]:
        if key == 'COM':
            return Variation_322
        if key == 'STAT':
            return Variation_413
        if key == 'SSC':
            return Variation_324
        if key == 'ARC':
            return Variation_325
        if key == 'AIC':
            return Variation_326
        if key == 'B1A':
            return Variation_237
        if key == 'B1B':
            return Variation_282
        if key == 'AC':
            return Variation_324
        if key == 'MN':
            return Variation_327
        if key == 'DC':
            return Variation_328
        assert_never(key)

    def __init__(self, arg : Variation_414_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_322:
        ...

    @overload
    def get_item(self, name : Literal['STAT']) -> Variation_413:
        ...

    @overload
    def get_item(self, name : Literal['SSC']) -> Variation_324:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_325:
        ...

    @overload
    def get_item(self, name : Literal['AIC']) -> Variation_326:
        ...

    @overload
    def get_item(self, name : Literal['B1A']) -> Variation_237:
        ...

    @overload
    def get_item(self, name : Literal['B1B']) -> Variation_282:
        ...

    @overload
    def get_item(self, name : Literal['AC']) -> Variation_324:
        ...

    @overload
    def get_item(self, name : Literal['MN']) -> Variation_327:
        ...

    @overload
    def get_item(self, name : Literal['DC']) -> Variation_328:
        ...

    def get_item(self, name : Union[Literal['COM'], Literal['STAT'], Literal['SSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B'], Literal['AC'], Literal['MN'], Literal['DC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_322, Variation_322_Arg]) -> 'Variation_414':
        ...

    @overload
    def set_item(self, name : Literal['STAT'], val : Union[Variation_413, Variation_413_Arg]) -> 'Variation_414':
        ...

    @overload
    def set_item(self, name : Literal['SSC'], val : Union[Variation_324, Variation_324_Arg]) -> 'Variation_414':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_325, Variation_325_Arg]) -> 'Variation_414':
        ...

    @overload
    def set_item(self, name : Literal['AIC'], val : Union[Variation_326, Variation_326_Arg]) -> 'Variation_414':
        ...

    @overload
    def set_item(self, name : Literal['B1A'], val : Union[Variation_237, Variation_237_Arg]) -> 'Variation_414':
        ...

    @overload
    def set_item(self, name : Literal['B1B'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_414':
        ...

    @overload
    def set_item(self, name : Literal['AC'], val : Union[Variation_324, Variation_324_Arg]) -> 'Variation_414':
        ...

    @overload
    def set_item(self, name : Literal['MN'], val : Union[Variation_327, Variation_327_Arg]) -> 'Variation_414':
        ...

    @overload
    def set_item(self, name : Literal['DC'], val : Union[Variation_328, Variation_328_Arg]) -> 'Variation_414':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_414':
        ...

    @overload
    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_414':
        ...

    @overload
    def modify_item(self, name : Literal['SSC'], f : Any) -> 'Variation_414':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_414':
        ...

    @overload
    def modify_item(self, name : Literal['AIC'], f : Any) -> 'Variation_414':
        ...

    @overload
    def modify_item(self, name : Literal['B1A'], f : Any) -> 'Variation_414':
        ...

    @overload
    def modify_item(self, name : Literal['B1B'], f : Any) -> 'Variation_414':
        ...

    @overload
    def modify_item(self, name : Literal['AC'], f : Any) -> 'Variation_414':
        ...

    @overload
    def modify_item(self, name : Literal['MN'], f : Any) -> 'Variation_414':
        ...

    @overload
    def modify_item(self, name : Literal['DC'], f : Any) -> 'Variation_414':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_415_Arg = TypedDict('Variation_415_Arg', {
    'MB': Union[Variation_321, Variation_321_Arg],
    'ADR': Union[Variation_278, Variation_278_Arg],
    'COMACAS': Union[Variation_414, Variation_414_Arg],
    'ACT': Union[Variation_330, Variation_330_Arg],
    'ECAT': Union[Variation_331, Variation_331_Arg],
    'AVTECH': Union[Variation_335, Variation_335_Arg],
}, total=False)
class Variation_415(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('MB', Variation_321),
        ('ADR', Variation_278),
        None,
        ('COMACAS', Variation_414),
        None,
        None,
        None,
        ('ACT', Variation_330),
        ('ECAT', Variation_331),
        None,
        ('AVTECH', Variation_335),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'MB': ('BDS', Variation_321, 0x8000),
        'ADR': ('24 Bits Aircraft Address', Variation_278, 0x4000),
        'COMACAS': ('Communications/ACAS Capability and Flight Status', Variation_414, 0x1000),
        'ACT': ('Aircraft Derived Aircraft Type', Variation_330, 0x0180),
        'ECAT': ('Emitter Category', Variation_331, 0x0140),
        'AVTECH': ('Available Technologies', Variation_335, 0x0110),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MB']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADR']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COMACAS']) -> Type[Variation_414]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ACT']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ECAT']) -> Type[Variation_331]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AVTECH']) -> Type[Variation_335]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MB'], Literal['ADR'], Literal['COMACAS'], Literal['ACT'], Literal['ECAT'], Literal['AVTECH']]) -> Union[Type['Variation_321'], Type['Variation_278'], Type['Variation_414'], Type['Variation_330'], Type['Variation_331'], Type['Variation_335']]:
        if key == 'MB':
            return Variation_321
        if key == 'ADR':
            return Variation_278
        if key == 'COMACAS':
            return Variation_414
        if key == 'ACT':
            return Variation_330
        if key == 'ECAT':
            return Variation_331
        if key == 'AVTECH':
            return Variation_335
        assert_never(key)

    def __init__(self, arg : Optional[Variation_415_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['MB'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_415':
        ...

    @overload
    def set_item(self, name : Literal['ADR'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_415':
        ...

    @overload
    def set_item(self, name : Literal['COMACAS'], val : Union[Variation_414, Variation_414_Arg]) -> 'Variation_415':
        ...

    @overload
    def set_item(self, name : Literal['ACT'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_415':
        ...

    @overload
    def set_item(self, name : Literal['ECAT'], val : Union[Variation_331, Variation_331_Arg]) -> 'Variation_415':
        ...

    @overload
    def set_item(self, name : Literal['AVTECH'], val : Union[Variation_335, Variation_335_Arg]) -> 'Variation_415':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['MB']) -> 'Variation_415':
        ...

    @overload
    def del_item(self, name : Literal['ADR']) -> 'Variation_415':
        ...

    @overload
    def del_item(self, name : Literal['COMACAS']) -> 'Variation_415':
        ...

    @overload
    def del_item(self, name : Literal['ACT']) -> 'Variation_415':
        ...

    @overload
    def del_item(self, name : Literal['ECAT']) -> 'Variation_415':
        ...

    @overload
    def del_item(self, name : Literal['AVTECH']) -> 'Variation_415':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['MB']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['ADR']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['COMACAS']) -> Variation_414:
        ...

    @overload
    def get_item(self, name : Literal['ACT']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['ECAT']) -> Variation_331:
        ...

    @overload
    def get_item(self, name : Literal['AVTECH']) -> Variation_335:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['MB'], f : Any) -> 'Variation_415':
        ...

    @overload
    def modify_item(self, name : Literal['ADR'], f : Any) -> 'Variation_415':
        ...

    @overload
    def modify_item(self, name : Literal['COMACAS'], f : Any) -> 'Variation_415':
        ...

    @overload
    def modify_item(self, name : Literal['ACT'], f : Any) -> 'Variation_415':
        ...

    @overload
    def modify_item(self, name : Literal['ECAT'], f : Any) -> 'Variation_415':
        ...

    @overload
    def modify_item(self, name : Literal['AVTECH'], f : Any) -> 'Variation_415':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_416_Arg : TypeAlias = Raw
class Variation_416(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Age of the last received PSR track update is higher than system dependent threshold',
    }

    def __init__(self, arg : Variation_416_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_417_Arg : TypeAlias = Raw
class Variation_417(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Age of the last received SSR track update is higher than system dependent threshold',
    }

    def __init__(self, arg : Variation_417_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_418_Arg : TypeAlias = Raw
class Variation_418(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Age of the last received Mode S track update is higher than system dependent threshold',
    }

    def __init__(self, arg : Variation_418_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_419_Arg : TypeAlias = Raw
class Variation_419(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Age of the last received ADS track update is higher than system dependent threshold',
    }

    def __init__(self, arg : Variation_419_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_420_Arg : TypeAlias = Raw
class Variation_420(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Special Used Code (Mode A codes to be defined in the system to mark a track with special interest)',
    }

    def __init__(self, arg : Variation_420_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_421_Arg : TypeAlias = Raw
class Variation_421(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Assigned Mode A Code Conflict (same individual Mode A Code assigned to another track)',
    }

    def __init__(self, arg : Variation_421_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_422_Arg_Group_1 = TypedDict('Variation_422_Arg_Group_1', {
    'MON': Union[Variation_339, Variation_339_Arg],
    'GBS': Union[Variation_340, Variation_340_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_342, Variation_342_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
})
Variation_422_Arg_Group_2 = TypedDict('Variation_422_Arg_Group_2', {
    'MON': Union[Variation_339, Variation_339_Arg],
    'GBS': Union[Variation_340, Variation_340_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_342, Variation_342_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_344, Variation_344_Arg],
    'TSE': Union[Variation_345, Variation_345_Arg],
    'TSB': Union[Variation_346, Variation_346_Arg],
    'FRIFOE': Union[Variation_347, Variation_347_Arg],
    'ME': Union[Variation_348, Variation_348_Arg],
    'MI': Union[Variation_349, Variation_349_Arg],
})
Variation_422_Arg_Group_3 = TypedDict('Variation_422_Arg_Group_3', {
    'MON': Union[Variation_339, Variation_339_Arg],
    'GBS': Union[Variation_340, Variation_340_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_342, Variation_342_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_344, Variation_344_Arg],
    'TSE': Union[Variation_345, Variation_345_Arg],
    'TSB': Union[Variation_346, Variation_346_Arg],
    'FRIFOE': Union[Variation_347, Variation_347_Arg],
    'ME': Union[Variation_348, Variation_348_Arg],
    'MI': Union[Variation_349, Variation_349_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'CST': Union[Variation_352, Variation_352_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
})
Variation_422_Arg_Group_4 = TypedDict('Variation_422_Arg_Group_4', {
    'MON': Union[Variation_339, Variation_339_Arg],
    'GBS': Union[Variation_340, Variation_340_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_342, Variation_342_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_344, Variation_344_Arg],
    'TSE': Union[Variation_345, Variation_345_Arg],
    'TSB': Union[Variation_346, Variation_346_Arg],
    'FRIFOE': Union[Variation_347, Variation_347_Arg],
    'ME': Union[Variation_348, Variation_348_Arg],
    'MI': Union[Variation_349, Variation_349_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'CST': Union[Variation_352, Variation_352_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_419, Variation_419_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_421, Variation_421_Arg],
})
Variation_422_Arg : TypeAlias = Union[
    int,
    Variation_422_Arg_Group_1,
    Tuple[int],
    Variation_422_Arg_Group_2,
    Tuple[int,int],
    Variation_422_Arg_Group_3,
    Tuple[int,int,int],
    Variation_422_Arg_Group_4,
    Tuple[int,int,int,int],
]
class Variation_422(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('MON', Variation_339),
            ('GBS', Variation_340),
            ('MRH', Variation_341),
            ('SRC', Variation_342),
            ('CNF', Variation_343),
        ],
        [
            ('SIM', Variation_344),
            ('TSE', Variation_345),
            ('TSB', Variation_346),
            ('FRIFOE', Variation_347),
            ('ME', Variation_348),
            ('MI', Variation_349),
        ],
        [
            ('AMA', Variation_350),
            ('SPI', Variation_351),
            ('CST', Variation_352),
            ('FPC', Variation_353),
            ('AFF', Variation_354),
            Spare(5, 2),
        ],
        [
            Spare(0, 1),
            ('PSR', Variation_416),
            ('SSR', Variation_417),
            ('MDS', Variation_418),
            ('ADS', Variation_419),
            ('SUC', Variation_420),
            ('AAC', Variation_421),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MON': ('', Variation_339, 0, 1),
        'GBS': ('', Variation_340, 1, 1),
        'MRH': ('', Variation_341, 2, 1),
        'SRC': ('', Variation_342, 3, 3),
        'CNF': ('', Variation_343, 6, 1),
        'SIM': ('', Variation_344, 0, 1),
        'TSE': ('', Variation_345, 1, 1),
        'TSB': ('', Variation_346, 2, 1),
        'FRIFOE': ('', Variation_347, 3, 2),
        'ME': ('', Variation_348, 5, 1),
        'MI': ('', Variation_349, 6, 1),
        'AMA': ('', Variation_350, 0, 1),
        'SPI': ('', Variation_351, 1, 1),
        'CST': ('', Variation_352, 2, 1),
        'FPC': ('', Variation_353, 3, 1),
        'AFF': ('', Variation_354, 4, 1),
        'PSR': ('', Variation_416, 1, 1),
        'SSR': ('', Variation_417, 2, 1),
        'MDS': ('', Variation_418, 3, 1),
        'ADS': ('', Variation_419, 4, 1),
        'SUC': ('', Variation_420, 5, 1),
        'AAC': ('', Variation_421, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MON']) -> Type[Variation_339]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GBS']) -> Type[Variation_340]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MRH']) -> Type[Variation_341]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRC']) -> Type[Variation_342]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_343]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_344]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSE']) -> Type[Variation_345]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSB']) -> Type[Variation_346]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FRIFOE']) -> Type[Variation_347]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ME']) -> Type[Variation_348]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MI']) -> Type[Variation_349]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AMA']) -> Type[Variation_350]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_351]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_352]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FPC']) -> Type[Variation_353]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AFF']) -> Type[Variation_354]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_416]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_417]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_418]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADS']) -> Type[Variation_419]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SUC']) -> Type[Variation_420]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AAC']) -> Type[Variation_421]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MON'], Literal['GBS'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FRIFOE'], Literal['ME'], Literal['MI'], Literal['AMA'], Literal['SPI'], Literal['CST'], Literal['FPC'], Literal['AFF'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['SUC'], Literal['AAC']]) -> Union[Type['Variation_339'], Type['Variation_340'], Type['Variation_341'], Type['Variation_342'], Type['Variation_343'], Type['Variation_344'], Type['Variation_345'], Type['Variation_346'], Type['Variation_347'], Type['Variation_348'], Type['Variation_349'], Type['Variation_350'], Type['Variation_351'], Type['Variation_352'], Type['Variation_353'], Type['Variation_354'], Type['Variation_416'], Type['Variation_417'], Type['Variation_418'], Type['Variation_419'], Type['Variation_420'], Type['Variation_421']]:
        if key == 'MON':
            return Variation_339
        if key == 'GBS':
            return Variation_340
        if key == 'MRH':
            return Variation_341
        if key == 'SRC':
            return Variation_342
        if key == 'CNF':
            return Variation_343
        if key == 'SIM':
            return Variation_344
        if key == 'TSE':
            return Variation_345
        if key == 'TSB':
            return Variation_346
        if key == 'FRIFOE':
            return Variation_347
        if key == 'ME':
            return Variation_348
        if key == 'MI':
            return Variation_349
        if key == 'AMA':
            return Variation_350
        if key == 'SPI':
            return Variation_351
        if key == 'CST':
            return Variation_352
        if key == 'FPC':
            return Variation_353
        if key == 'AFF':
            return Variation_354
        if key == 'PSR':
            return Variation_416
        if key == 'SSR':
            return Variation_417
        if key == 'MDS':
            return Variation_418
        if key == 'ADS':
            return Variation_419
        if key == 'SUC':
            return Variation_420
        if key == 'AAC':
            return Variation_421
        assert_never(key)

    def __init__(self, arg : Variation_422_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_422_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_422_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_422_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            if Variation_422_Arg_Group_4.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(4, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MON']) -> Variation_339:
        ...

    @overload
    def get_item(self, name : Literal['GBS']) -> Variation_340:
        ...

    @overload
    def get_item(self, name : Literal['MRH']) -> Variation_341:
        ...

    @overload
    def get_item(self, name : Literal['SRC']) -> Variation_342:
        ...

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_343:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_344:
        ...

    @overload
    def get_item(self, name : Literal['TSE']) -> Variation_345:
        ...

    @overload
    def get_item(self, name : Literal['TSB']) -> Variation_346:
        ...

    @overload
    def get_item(self, name : Literal['FRIFOE']) -> Variation_347:
        ...

    @overload
    def get_item(self, name : Literal['ME']) -> Variation_348:
        ...

    @overload
    def get_item(self, name : Literal['MI']) -> Variation_349:
        ...

    @overload
    def get_item(self, name : Literal['AMA']) -> Variation_350:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_351:
        ...

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_352:
        ...

    @overload
    def get_item(self, name : Literal['FPC']) -> Variation_353:
        ...

    @overload
    def get_item(self, name : Literal['AFF']) -> Variation_354:
        ...

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_416:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_417:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_418:
        ...

    @overload
    def get_item(self, name : Literal['ADS']) -> Variation_419:
        ...

    @overload
    def get_item(self, name : Literal['SUC']) -> Variation_420:
        ...

    @overload
    def get_item(self, name : Literal['AAC']) -> Variation_421:
        ...

    def get_item(self, name : Union[Literal['MON'], Literal['GBS'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FRIFOE'], Literal['ME'], Literal['MI'], Literal['AMA'], Literal['SPI'], Literal['CST'], Literal['FPC'], Literal['AFF'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['SUC'], Literal['AAC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MON'], val : Union[Variation_339, Variation_339_Arg]) -> 'Variation_422':
        ...

    @overload
    def set_item(self, name : Literal['GBS'], val : Union[Variation_340, Variation_340_Arg]) -> 'Variation_422':
        ...

    @overload
    def set_item(self, name : Literal['MRH'], val : Union[Variation_341, Variation_341_Arg]) -> 'Variation_422':
        ...

    @overload
    def set_item(self, name : Literal['SRC'], val : Union[Variation_342, Variation_342_Arg]) -> 'Variation_422':
        ...

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_343, Variation_343_Arg]) -> 'Variation_422':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MON'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['GBS'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['MRH'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['SRC'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['TSE'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['TSB'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['FRIFOE'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['ME'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['MI'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['AMA'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['FPC'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['AFF'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['ADS'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['SUC'], f : Any) -> 'Variation_422':
        ...

    @overload
    def modify_item(self, name : Literal['AAC'], f : Any) -> 'Variation_422':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_423_Arg = TypedDict('Variation_423_Arg', {
    'PSR': Union[Variation_356, Variation_356_Arg],
    'SSR': Union[Variation_356, Variation_356_Arg],
    'MDA': Union[Variation_356, Variation_356_Arg],
    'MFL': Union[Variation_356, Variation_356_Arg],
    'MDS': Union[Variation_356, Variation_356_Arg],
    'ADS': Union[Variation_357, Variation_357_Arg],
    'ADB': Union[Variation_356, Variation_356_Arg],
    'MD1': Union[Variation_356, Variation_356_Arg],
    'MD2': Union[Variation_356, Variation_356_Arg],
    'LOP': Union[Variation_356, Variation_356_Arg],
    'TRK': Union[Variation_356, Variation_356_Arg],
    'MUL': Union[Variation_356, Variation_356_Arg],
}, total=False)
class Variation_423(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('PSR', Variation_356),
        ('SSR', Variation_356),
        ('MDA', Variation_356),
        ('MFL', Variation_356),
        ('MDS', Variation_356),
        ('ADS', Variation_357),
        ('ADB', Variation_356),
        ('MD1', Variation_356),
        ('MD2', Variation_356),
        ('LOP', Variation_356),
        ('TRK', Variation_356),
        ('MUL', Variation_356),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'PSR': ('Age of the Last Primary Report Used to Update the Track', Variation_356, 0x8000),
        'SSR': ('Age of the Last Secondary Report Used to Update the Track', Variation_356, 0x4000),
        'MDA': ('Age of the Last Valid Mode A Report Used to Update the Track', Variation_356, 0x2000),
        'MFL': ('Age of the Last Valid and Credible Mode C Used to Update the Track', Variation_356, 0x1000),
        'MDS': ('Age of the Last Mode S Report Used to Update the Track', Variation_356, 0x0800),
        'ADS': ('Age of the Last ADS Report Used to Update the Track', Variation_357, 0x0400),
        'ADB': ('Age of the Last ADS-B Report Used to Update the Track', Variation_356, 0x0200),
        'MD1': ('Age of the Last Valid Mode 1 Used to Update the Track', Variation_356, 0x0180),
        'MD2': ('Age of the Last Valid Mode 2 Used to Update the Track', Variation_356, 0x0140),
        'LOP': ('Age of the Last Magentic Loop Detection', Variation_356, 0x0120),
        'TRK': ('Actual Track Age Since First Occurrence', Variation_356, 0x0110),
        'MUL': ('Age of the Last Multilateration Detection', Variation_356, 0x0108),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDA']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MFL']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADS']) -> Type[Variation_357]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADB']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD1']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD2']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LOP']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRK']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MUL']) -> Type[Variation_356]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PSR'], Literal['SSR'], Literal['MDA'], Literal['MFL'], Literal['MDS'], Literal['ADS'], Literal['ADB'], Literal['MD1'], Literal['MD2'], Literal['LOP'], Literal['TRK'], Literal['MUL']]) -> Union[Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_357'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356']]:
        if key == 'PSR':
            return Variation_356
        if key == 'SSR':
            return Variation_356
        if key == 'MDA':
            return Variation_356
        if key == 'MFL':
            return Variation_356
        if key == 'MDS':
            return Variation_356
        if key == 'ADS':
            return Variation_357
        if key == 'ADB':
            return Variation_356
        if key == 'MD1':
            return Variation_356
        if key == 'MD2':
            return Variation_356
        if key == 'LOP':
            return Variation_356
        if key == 'TRK':
            return Variation_356
        if key == 'MUL':
            return Variation_356
        assert_never(key)

    def __init__(self, arg : Optional[Variation_423_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['PSR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['SSR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['MDA'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['MFL'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['MDS'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['ADS'], val : Union[Variation_357, Variation_357_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['ADB'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['MD1'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['MD2'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['LOP'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['TRK'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    @overload
    def set_item(self, name : Literal['MUL'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_423':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['PSR']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['SSR']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['MDA']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['MFL']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['MDS']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['ADS']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['ADB']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['MD1']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['MD2']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['LOP']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['TRK']) -> 'Variation_423':
        ...

    @overload
    def del_item(self, name : Literal['MUL']) -> 'Variation_423':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MDA']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MFL']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['ADS']) -> Variation_357:
        ...

    @overload
    def get_item(self, name : Literal['ADB']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MD1']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MD2']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['LOP']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['TRK']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MUL']) -> Variation_356:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['MDA'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['MFL'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['ADS'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['ADB'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['MD1'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['MD2'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['LOP'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['TRK'], f : Any) -> 'Variation_423':
        ...

    @overload
    def modify_item(self, name : Literal['MUL'], f : Any) -> 'Variation_423':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_424_Arg : TypeAlias = Raw
class Variation_424(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No QNH Correction Applied',
        1: 'QNH Correction Applied',
    }

    def __init__(self, arg : Variation_424_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_425_Arg_Group = TypedDict('Variation_425_Arg_Group', {
    'QNH': Union[Variation_424, Variation_424_Arg],
    'CTBA': Union[Variation_362, Variation_362_Arg],
})
Variation_425_Arg : TypeAlias = Union[Raw, Variation_425_Arg_Group]
class Variation_425(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('QNH', Variation_424),
        ('CTBA', Variation_362),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'QNH': ('QNH Correction Applied', Variation_424, 0, 1),
        'CTBA': ('Calculated Track Barometric Altitude', Variation_362, 1, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['QNH']) -> Type[Variation_424]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CTBA']) -> Type[Variation_362]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['QNH'], Literal['CTBA']]) -> Union[Type['Variation_424'], Type['Variation_362']]:
        if key == 'QNH':
            return Variation_424
        if key == 'CTBA':
            return Variation_362
        assert_never(key)

    def __init__(self, arg : Variation_425_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['QNH']) -> Variation_424:
        ...

    @overload
    def get_item(self, name : Literal['CTBA']) -> Variation_362:
        ...

    def get_item(self, name : Union[Literal['QNH'], Literal['CTBA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['QNH'], val : Union[Variation_424, Variation_424_Arg]) -> 'Variation_425':
        ...

    @overload
    def set_item(self, name : Literal['CTBA'], val : Union[Variation_362, Variation_362_Arg]) -> 'Variation_425':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['QNH'], f : Any) -> 'Variation_425':
        ...

    @overload
    def modify_item(self, name : Literal['CTBA'], f : Any) -> 'Variation_425':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_426_Arg : TypeAlias = Raw
class Variation_426(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'Instrument Flight Rules',
        1: 'Visual Flight Rules',
        2: 'Not applicable',
        3: 'Controlled Visual Flight Rules',
    }

    def __init__(self, arg : Variation_426_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_427_Arg_Group = TypedDict('Variation_427_Arg_Group', {
    'GATOAT': Union[Variation_153, Variation_153_Arg],
    'FR1FR2': Union[Variation_426, Variation_426_Arg],
    'RVSM': Union[Variation_155, Variation_155_Arg],
    'HPR': Union[Variation_156, Variation_156_Arg],
})
Variation_427_Arg : TypeAlias = Union[Raw, Variation_427_Arg_Group]
class Variation_427(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('GATOAT', Variation_153),
        ('FR1FR2', Variation_426),
        ('RVSM', Variation_155),
        ('HPR', Variation_156),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'GATOAT': ('Flight Type', Variation_153, 0, 2),
        'FR1FR2': ('Flight Rules', Variation_426, 2, 2),
        'RVSM': ('RVSM', Variation_155, 4, 2),
        'HPR': ('Flight Priority', Variation_156, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['GATOAT']) -> Type[Variation_153]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FR1FR2']) -> Type[Variation_426]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RVSM']) -> Type[Variation_155]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HPR']) -> Type[Variation_156]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['RVSM'], Literal['HPR']]) -> Union[Type['Variation_153'], Type['Variation_426'], Type['Variation_155'], Type['Variation_156']]:
        if key == 'GATOAT':
            return Variation_153
        if key == 'FR1FR2':
            return Variation_426
        if key == 'RVSM':
            return Variation_155
        if key == 'HPR':
            return Variation_156
        assert_never(key)

    def __init__(self, arg : Variation_427_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['GATOAT']) -> Variation_153:
        ...

    @overload
    def get_item(self, name : Literal['FR1FR2']) -> Variation_426:
        ...

    @overload
    def get_item(self, name : Literal['RVSM']) -> Variation_155:
        ...

    @overload
    def get_item(self, name : Literal['HPR']) -> Variation_156:
        ...

    def get_item(self, name : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['RVSM'], Literal['HPR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['GATOAT'], val : Union[Variation_153, Variation_153_Arg]) -> 'Variation_427':
        ...

    @overload
    def set_item(self, name : Literal['FR1FR2'], val : Union[Variation_426, Variation_426_Arg]) -> 'Variation_427':
        ...

    @overload
    def set_item(self, name : Literal['RVSM'], val : Union[Variation_155, Variation_155_Arg]) -> 'Variation_427':
        ...

    @overload
    def set_item(self, name : Literal['HPR'], val : Union[Variation_156, Variation_156_Arg]) -> 'Variation_427':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['GATOAT'], f : Any) -> 'Variation_427':
        ...

    @overload
    def modify_item(self, name : Literal['FR1FR2'], f : Any) -> 'Variation_427':
        ...

    @overload
    def modify_item(self, name : Literal['RVSM'], f : Any) -> 'Variation_427':
        ...

    @overload
    def modify_item(self, name : Literal['HPR'], f : Any) -> 'Variation_427':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_428_Arg = TypedDict('Variation_428_Arg', {
    'FPPSID': Union[Variation_365, Variation_365_Arg],
    'CSN': Union[Variation_145, Variation_145_Arg],
    'IFPSFLIGHTID': Union[Variation_368, Variation_368_Arg],
    'FLIGHTCAT': Union[Variation_427, Variation_427_Arg],
    'TOA': Union[Variation_330, Variation_330_Arg],
    'WTC': Union[Variation_370, Variation_370_Arg],
    'ADEP': Union[Variation_330, Variation_330_Arg],
    'ADES': Union[Variation_330, Variation_330_Arg],
    'RWY': Union[Variation_371, Variation_371_Arg],
    'CFL': Union[Variation_164, Variation_164_Arg],
    'CCP': Union[Variation_372, Variation_372_Arg],
    'TOD': Union[Variation_379, Variation_379_Arg],
    'AST': Union[Variation_161, Variation_161_Arg],
    'STS': Union[Variation_382, Variation_382_Arg],
}, total=False)
class Variation_428(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('FPPSID', Variation_365),
        ('CSN', Variation_145),
        ('IFPSFLIGHTID', Variation_368),
        ('FLIGHTCAT', Variation_427),
        ('TOA', Variation_330),
        ('WTC', Variation_370),
        ('ADEP', Variation_330),
        ('ADES', Variation_330),
        ('RWY', Variation_371),
        ('CFL', Variation_164),
        ('CCP', Variation_372),
        ('TOD', Variation_379),
        ('AST', Variation_161),
        ('STS', Variation_382),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'FPPSID': ('FPPS Identification Tag', Variation_365, 0x8000),
        'CSN': ('Callsign', Variation_145, 0x4000),
        'IFPSFLIGHTID': ('IFPS_FLIGHT_ID', Variation_368, 0x2000),
        'FLIGHTCAT': ('Flight Category', Variation_427, 0x1000),
        'TOA': ('Type of Aircraft', Variation_330, 0x0800),
        'WTC': ('Wake Turbulence Category', Variation_370, 0x0400),
        'ADEP': ('Departure Airport', Variation_330, 0x0200),
        'ADES': ('Destination Airport', Variation_330, 0x0180),
        'RWY': ('Runway Designation', Variation_371, 0x0140),
        'CFL': ('Current Cleared Flight Level', Variation_164, 0x0120),
        'CCP': ('Current Control Position', Variation_372, 0x0110),
        'TOD': ('Time of Departure', Variation_379, 0x0108),
        'AST': ('Aircraft Stand', Variation_161, 0x0104),
        'STS': ('Stand Status', Variation_382, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['FPPSID']) -> Type[Variation_365]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CSN']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IFPSFLIGHTID']) -> Type[Variation_368]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FLIGHTCAT']) -> Type[Variation_427]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOA']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WTC']) -> Type[Variation_370]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADEP']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADES']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RWY']) -> Type[Variation_371]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CFL']) -> Type[Variation_164]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CCP']) -> Type[Variation_372]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOD']) -> Type[Variation_379]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AST']) -> Type[Variation_161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STS']) -> Type[Variation_382]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['FPPSID'], Literal['CSN'], Literal['IFPSFLIGHTID'], Literal['FLIGHTCAT'], Literal['TOA'], Literal['WTC'], Literal['ADEP'], Literal['ADES'], Literal['RWY'], Literal['CFL'], Literal['CCP'], Literal['TOD'], Literal['AST'], Literal['STS']]) -> Union[Type['Variation_365'], Type['Variation_145'], Type['Variation_368'], Type['Variation_427'], Type['Variation_330'], Type['Variation_370'], Type['Variation_330'], Type['Variation_330'], Type['Variation_371'], Type['Variation_164'], Type['Variation_372'], Type['Variation_379'], Type['Variation_161'], Type['Variation_382']]:
        if key == 'FPPSID':
            return Variation_365
        if key == 'CSN':
            return Variation_145
        if key == 'IFPSFLIGHTID':
            return Variation_368
        if key == 'FLIGHTCAT':
            return Variation_427
        if key == 'TOA':
            return Variation_330
        if key == 'WTC':
            return Variation_370
        if key == 'ADEP':
            return Variation_330
        if key == 'ADES':
            return Variation_330
        if key == 'RWY':
            return Variation_371
        if key == 'CFL':
            return Variation_164
        if key == 'CCP':
            return Variation_372
        if key == 'TOD':
            return Variation_379
        if key == 'AST':
            return Variation_161
        if key == 'STS':
            return Variation_382
        assert_never(key)

    def __init__(self, arg : Optional[Variation_428_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['FPPSID'], val : Union[Variation_365, Variation_365_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['CSN'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['IFPSFLIGHTID'], val : Union[Variation_368, Variation_368_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['FLIGHTCAT'], val : Union[Variation_427, Variation_427_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['TOA'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['WTC'], val : Union[Variation_370, Variation_370_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['ADEP'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['ADES'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['RWY'], val : Union[Variation_371, Variation_371_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['CFL'], val : Union[Variation_164, Variation_164_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['CCP'], val : Union[Variation_372, Variation_372_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['TOD'], val : Union[Variation_379, Variation_379_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['AST'], val : Union[Variation_161, Variation_161_Arg]) -> 'Variation_428':
        ...

    @overload
    def set_item(self, name : Literal['STS'], val : Union[Variation_382, Variation_382_Arg]) -> 'Variation_428':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['FPPSID']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['CSN']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['IFPSFLIGHTID']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['FLIGHTCAT']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['TOA']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['WTC']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['ADEP']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['ADES']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['RWY']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['CFL']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['CCP']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['TOD']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['AST']) -> 'Variation_428':
        ...

    @overload
    def del_item(self, name : Literal['STS']) -> 'Variation_428':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['FPPSID']) -> Variation_365:
        ...

    @overload
    def get_item(self, name : Literal['CSN']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['IFPSFLIGHTID']) -> Variation_368:
        ...

    @overload
    def get_item(self, name : Literal['FLIGHTCAT']) -> Variation_427:
        ...

    @overload
    def get_item(self, name : Literal['TOA']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['WTC']) -> Variation_370:
        ...

    @overload
    def get_item(self, name : Literal['ADEP']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['ADES']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['RWY']) -> Variation_371:
        ...

    @overload
    def get_item(self, name : Literal['CFL']) -> Variation_164:
        ...

    @overload
    def get_item(self, name : Literal['CCP']) -> Variation_372:
        ...

    @overload
    def get_item(self, name : Literal['TOD']) -> Variation_379:
        ...

    @overload
    def get_item(self, name : Literal['AST']) -> Variation_161:
        ...

    @overload
    def get_item(self, name : Literal['STS']) -> Variation_382:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['FPPSID'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['CSN'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['IFPSFLIGHTID'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['FLIGHTCAT'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['TOA'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['WTC'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['ADEP'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['ADES'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['RWY'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['CFL'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['CCP'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['TOD'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['AST'], f : Any) -> 'Variation_428':
        ...

    @overload
    def modify_item(self, name : Literal['STS'], f : Any) -> 'Variation_428':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_429_Arg = TypedDict('Variation_429_Arg', {
    '010': Union[Variation_310, Variation_310_Arg],
    '000': Union[Variation_311, Variation_311_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '041': Union[Variation_312, Variation_312_Arg],
    '042': Union[Variation_313, Variation_313_Arg],
    '202': Union[Variation_315, Variation_315_Arg],
    '210': Union[Variation_317, Variation_317_Arg],
    '060': Union[Variation_318, Variation_318_Arg],
    '245': Union[Variation_319, Variation_319_Arg],
    '380': Union[Variation_415, Variation_415_Arg],
    '161': Union[Variation_338, Variation_338_Arg],
    '170': Union[Variation_422, Variation_422_Arg],
    '290': Union[Variation_423, Variation_423_Arg],
    '430': Union[Variation_359, Variation_359_Arg],
    '090': Union[Variation_360, Variation_360_Arg],
    '093': Union[Variation_425, Variation_425_Arg],
    '092': Union[Variation_287, Variation_287_Arg],
    '215': Union[Variation_364, Variation_364_Arg],
    '270': Union[Variation_290, Variation_290_Arg],
    '390': Union[Variation_428, Variation_428_Arg],
    '300': Union[Variation_384, Variation_384_Arg],
    '310': Union[Variation_386, Variation_386_Arg],
    '500': Union[Variation_396, Variation_396_Arg],
    '600': Union[Variation_399, Variation_399_Arg],
    '605': Union[Variation_401, Variation_401_Arg],
    '610': Union[Variation_411, Variation_411_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
}, total=False)
class Variation_429(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('010', Variation_310),
        ('000', Variation_311),
        ('015', Variation_0),
        ('140', Variation_80),
        ('041', Variation_312),
        ('042', Variation_313),
        ('202', Variation_315),
        ('210', Variation_317),
        ('060', Variation_318),
        ('245', Variation_319),
        ('380', Variation_415),
        ('161', Variation_338),
        ('170', Variation_422),
        ('290', Variation_423),
        ('430', Variation_359),
        ('090', Variation_360),
        ('093', Variation_425),
        ('092', Variation_287),
        ('215', Variation_364),
        ('270', Variation_290),
        ('390', Variation_428),
        ('300', Variation_384),
        ('310', Variation_386),
        ('500', Variation_396),
        ('600', Variation_399),
        ('605', Variation_401),
        ('610', Variation_411),
        ('SP', Variation_62),
        ('RE', Variation_202),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_310, 0x8000000000),
        '000': ('Message Type', Variation_311, 0x4000000000),
        '015': ('Service Identification', Variation_0, 0x2000000000),
        '140': ('Time of Track Information', Variation_80, 0x1000000000),
        '041': ('Position in WGS-84 Coordinates', Variation_312, 0x0800000000),
        '042': ('Calculated Position in Cartesian Co-ordinates', Variation_313, 0x0400000000),
        '202': ('Calculated Track Velocity in Cartesian Coordinates', Variation_315, 0x0200000000),
        '210': ('Calculated Acceleration', Variation_317, 0x0180000000),
        '060': ('Mode-3/A Code in Octal Representation', Variation_318, 0x0140000000),
        '245': ('Target Identification', Variation_319, 0x0120000000),
        '380': ('Mode-S / ADS-B Related Data', Variation_415, 0x0110000000),
        '161': ('Track Number', Variation_338, 0x0108000000),
        '170': ('Track Status', Variation_422, 0x0104000000),
        '290': ('System Track Update Ages', Variation_423, 0x0102000000),
        '430': ('Phase of Flight', Variation_359, 0x0101800000),
        '090': ('Measured Flight Level', Variation_360, 0x0101400000),
        '093': ('Calculated Track Barometric Altitude', Variation_425, 0x0101200000),
        '092': ('Calculated Track Geometric Altitude', Variation_287, 0x0101100000),
        '215': ('Calculated Rate Of Climb/Descent', Variation_364, 0x0101080000),
        '270': ('Target Size and Orientation', Variation_290, 0x0101040000),
        '390': ('Flight Plan Related Data', Variation_428, 0x0101020000),
        '300': ('Vehicle Fleet Identification', Variation_384, 0x0101018000),
        '310': ('Pre-programmed Message', Variation_386, 0x0101014000),
        '500': ('Estimated Accuracies', Variation_396, 0x0101012000),
        '600': ('Alert Messages', Variation_399, 0x0101011000),
        '605': ('Tracks in Alert', Variation_401, 0x0101010800),
        '610': ('Holdbar Status', Variation_411, 0x0101010400),
        'SP': ('Special Purpose Field', Variation_62, 0x0101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0101010180),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_310]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_311]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_312]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_313]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['202']) -> Type[Variation_315]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_317]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_318]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['245']) -> Type[Variation_319]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['380']) -> Type[Variation_415]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_338]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_422]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['290']) -> Type[Variation_423]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['430']) -> Type[Variation_359]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['093']) -> Type[Variation_425]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['092']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['215']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['270']) -> Type[Variation_290]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['390']) -> Type[Variation_428]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_384]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['310']) -> Type[Variation_386]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_396]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['600']) -> Type[Variation_399]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['605']) -> Type[Variation_401]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['610']) -> Type[Variation_411]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['015'], Literal['140'], Literal['041'], Literal['042'], Literal['202'], Literal['210'], Literal['060'], Literal['245'], Literal['380'], Literal['161'], Literal['170'], Literal['290'], Literal['430'], Literal['090'], Literal['093'], Literal['092'], Literal['215'], Literal['270'], Literal['390'], Literal['300'], Literal['310'], Literal['500'], Literal['600'], Literal['605'], Literal['610'], Literal['SP'], Literal['RE']]) -> Union[Type['Variation_310'], Type['Variation_311'], Type['Variation_0'], Type['Variation_80'], Type['Variation_312'], Type['Variation_313'], Type['Variation_315'], Type['Variation_317'], Type['Variation_318'], Type['Variation_319'], Type['Variation_415'], Type['Variation_338'], Type['Variation_422'], Type['Variation_423'], Type['Variation_359'], Type['Variation_360'], Type['Variation_425'], Type['Variation_287'], Type['Variation_364'], Type['Variation_290'], Type['Variation_428'], Type['Variation_384'], Type['Variation_386'], Type['Variation_396'], Type['Variation_399'], Type['Variation_401'], Type['Variation_411'], Type['Variation_62'], Type['Variation_202']]:
        if key == '010':
            return Variation_310
        if key == '000':
            return Variation_311
        if key == '015':
            return Variation_0
        if key == '140':
            return Variation_80
        if key == '041':
            return Variation_312
        if key == '042':
            return Variation_313
        if key == '202':
            return Variation_315
        if key == '210':
            return Variation_317
        if key == '060':
            return Variation_318
        if key == '245':
            return Variation_319
        if key == '380':
            return Variation_415
        if key == '161':
            return Variation_338
        if key == '170':
            return Variation_422
        if key == '290':
            return Variation_423
        if key == '430':
            return Variation_359
        if key == '090':
            return Variation_360
        if key == '093':
            return Variation_425
        if key == '092':
            return Variation_287
        if key == '215':
            return Variation_364
        if key == '270':
            return Variation_290
        if key == '390':
            return Variation_428
        if key == '300':
            return Variation_384
        if key == '310':
            return Variation_386
        if key == '500':
            return Variation_396
        if key == '600':
            return Variation_399
        if key == '605':
            return Variation_401
        if key == '610':
            return Variation_411
        if key == 'SP':
            return Variation_62
        if key == 'RE':
            return Variation_202
        assert_never(key)

    def __init__(self, arg : Optional[Variation_429_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_310, Variation_310_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_311, Variation_311_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_312, Variation_312_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_313, Variation_313_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['202'], val : Union[Variation_315, Variation_315_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_317, Variation_317_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_318, Variation_318_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['245'], val : Union[Variation_319, Variation_319_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['380'], val : Union[Variation_415, Variation_415_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_338, Variation_338_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_422, Variation_422_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['290'], val : Union[Variation_423, Variation_423_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['430'], val : Union[Variation_359, Variation_359_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['093'], val : Union[Variation_425, Variation_425_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['092'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['215'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['270'], val : Union[Variation_290, Variation_290_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['390'], val : Union[Variation_428, Variation_428_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_384, Variation_384_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['310'], val : Union[Variation_386, Variation_386_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_396, Variation_396_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['600'], val : Union[Variation_399, Variation_399_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['605'], val : Union[Variation_401, Variation_401_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['610'], val : Union[Variation_411, Variation_411_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_429':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_429':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['202']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['245']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['380']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['290']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['430']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['093']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['092']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['215']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['270']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['390']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['310']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['600']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['605']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['610']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_429':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_429':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_310:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_311:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_312:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_313:
        ...

    @overload
    def get_item(self, name : Literal['202']) -> Variation_315:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_317:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_318:
        ...

    @overload
    def get_item(self, name : Literal['245']) -> Variation_319:
        ...

    @overload
    def get_item(self, name : Literal['380']) -> Variation_415:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_338:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_422:
        ...

    @overload
    def get_item(self, name : Literal['290']) -> Variation_423:
        ...

    @overload
    def get_item(self, name : Literal['430']) -> Variation_359:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['093']) -> Variation_425:
        ...

    @overload
    def get_item(self, name : Literal['092']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['215']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['270']) -> Variation_290:
        ...

    @overload
    def get_item(self, name : Literal['390']) -> Variation_428:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_384:
        ...

    @overload
    def get_item(self, name : Literal['310']) -> Variation_386:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_396:
        ...

    @overload
    def get_item(self, name : Literal['600']) -> Variation_399:
        ...

    @overload
    def get_item(self, name : Literal['605']) -> Variation_401:
        ...

    @overload
    def get_item(self, name : Literal['610']) -> Variation_411:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['202'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['245'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['380'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['290'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['430'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['093'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['092'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['215'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['270'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['390'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['310'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['600'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['605'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['610'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_429':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_429':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_430_Arg : TypeAlias = Raw
class Variation_430(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    table = {
        1: 'Measurement Plot',
        2: 'Measurement Track',
        3: 'Sensor Centric Plot',
        4: 'Sensor Centric Track',
        5: 'Track End Message',
    }

    def __init__(self, arg : Variation_430_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_431_Arg : TypeAlias = Raw
class Variation_431(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'Periodic Report',
        1: 'Event Driven Report',
    }

    def __init__(self, arg : Variation_431_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_432_Arg_Group = TypedDict('Variation_432_Arg_Group', {
    'MT': Union[Variation_430, Variation_430_Arg],
    'RG': Union[Variation_431, Variation_431_Arg],
})
Variation_432_Arg : TypeAlias = Union[Raw, Variation_432_Arg_Group]
class Variation_432(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('MT', Variation_430),
        ('RG', Variation_431),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MT': ('Message Type', Variation_430, 0, 7),
        'RG': ('Report Generation', Variation_431, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MT']) -> Type[Variation_430]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RG']) -> Type[Variation_431]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MT'], Literal['RG']]) -> Union[Type['Variation_430'], Type['Variation_431']]:
        if key == 'MT':
            return Variation_430
        if key == 'RG':
            return Variation_431
        assert_never(key)

    def __init__(self, arg : Variation_432_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MT']) -> Variation_430:
        ...

    @overload
    def get_item(self, name : Literal['RG']) -> Variation_431:
        ...

    def get_item(self, name : Union[Literal['MT'], Literal['RG']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MT'], val : Union[Variation_430, Variation_430_Arg]) -> 'Variation_432':
        ...

    @overload
    def set_item(self, name : Literal['RG'], val : Union[Variation_431, Variation_431_Arg]) -> 'Variation_432':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MT'], f : Any) -> 'Variation_432':
        ...

    @overload
    def modify_item(self, name : Literal['RG'], f : Any) -> 'Variation_432':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_433_Arg : TypeAlias = Raw
class Variation_433(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Mono-Static Sensor',
        1: 'Multi-Static Sensor',
        2: 'Other',
        3: 'Unknown',
    }

    def __init__(self, arg : Variation_433_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_434_Arg : TypeAlias = Raw
class Variation_434(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'Actual Target Report',
        1: 'Reference Target',
        2: 'Synthetic Target',
        3: 'Simulated / Replayed Target',
    }

    def __init__(self, arg : Variation_434_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_435_Arg : TypeAlias = Raw
class Variation_435(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Forward',
        2: 'Backward',
        3: 'Static',
    }

    def __init__(self, arg : Variation_435_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_436_Arg_Group_1 = TypedDict('Variation_436_Arg_Group_1', {
    'MOMU': Union[Variation_433, Variation_433_Arg],
    'TTAX': Union[Variation_434, Variation_434_Arg],
    'SCD': Union[Variation_435, Variation_435_Arg],
})
Variation_436_Arg : TypeAlias = Union[
    int,
    Variation_436_Arg_Group_1,
    Tuple[int],
]
class Variation_436(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            ('MOMU', Variation_433),
            ('TTAX', Variation_434),
            ('SCD', Variation_435),
            Spare(6, 1),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MOMU': ('Mono-Static Target Report or Multi-Static Target Report', Variation_433, 0, 2),
        'TTAX': ('Target Taxonomy', Variation_434, 2, 2),
        'SCD': ('Scanning Direction', Variation_435, 4, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MOMU']) -> Type[Variation_433]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TTAX']) -> Type[Variation_434]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SCD']) -> Type[Variation_435]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MOMU'], Literal['TTAX'], Literal['SCD']]) -> Union[Type['Variation_433'], Type['Variation_434'], Type['Variation_435']]:
        if key == 'MOMU':
            return Variation_433
        if key == 'TTAX':
            return Variation_434
        if key == 'SCD':
            return Variation_435
        assert_never(key)

    def __init__(self, arg : Variation_436_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_436_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MOMU']) -> Variation_433:
        ...

    @overload
    def get_item(self, name : Literal['TTAX']) -> Variation_434:
        ...

    @overload
    def get_item(self, name : Literal['SCD']) -> Variation_435:
        ...

    def get_item(self, name : Union[Literal['MOMU'], Literal['TTAX'], Literal['SCD']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MOMU'], val : Union[Variation_433, Variation_433_Arg]) -> 'Variation_436':
        ...

    @overload
    def set_item(self, name : Literal['TTAX'], val : Union[Variation_434, Variation_434_Arg]) -> 'Variation_436':
        ...

    @overload
    def set_item(self, name : Literal['SCD'], val : Union[Variation_435, Variation_435_Arg]) -> 'Variation_436':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MOMU'], f : Any) -> 'Variation_436':
        ...

    @overload
    def modify_item(self, name : Literal['TTAX'], f : Any) -> 'Variation_436':
        ...

    @overload
    def modify_item(self, name : Literal['SCD'], f : Any) -> 'Variation_436':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_437_Arg : TypeAlias = Raw
class Variation_437(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Target not in Blind Zone',
        1: 'Target in Blind Zone',
    }

    def __init__(self, arg : Variation_437_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_438_Arg : TypeAlias = Raw
class Variation_438(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Target not in Blanked Zone',
        1: 'Target in Blanked Zone',
    }

    def __init__(self, arg : Variation_438_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_439_Arg : TypeAlias = Raw
class Variation_439(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Track Alive',
        1: 'Track Terminated by User Request',
    }

    def __init__(self, arg : Variation_439_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_440_Arg : TypeAlias = Raw
class Variation_440(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Not extrapolated',
        1: 'Extrapolated',
    }

    def __init__(self, arg : Variation_440_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_441_Arg : TypeAlias = Raw
class Variation_441(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Not extrapolated',
        1: 'Extrapolated',
    }

    def __init__(self, arg : Variation_441_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_442_Arg : TypeAlias = Raw
class Variation_442(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Confirmed Track',
        1: 'Tentative Track',
    }

    def __init__(self, arg : Variation_442_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_443_Arg_Group_1 = TypedDict('Variation_443_Arg_Group_1', {
    'BIZ': Union[Variation_437, Variation_437_Arg],
    'BAZ': Union[Variation_438, Variation_438_Arg],
    'TUR': Union[Variation_439, Variation_439_Arg],
    'CSTP': Union[Variation_440, Variation_440_Arg],
    'CSTH': Union[Variation_441, Variation_441_Arg],
    'CNF': Union[Variation_442, Variation_442_Arg],
})
Variation_443_Arg : TypeAlias = Union[
    int,
    Variation_443_Arg_Group_1,
    Tuple[int],
]
class Variation_443(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            ('BIZ', Variation_437),
            ('BAZ', Variation_438),
            ('TUR', Variation_439),
            Spare(3, 1),
            ('CSTP', Variation_440),
            ('CSTH', Variation_441),
            ('CNF', Variation_442),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'BIZ': ('', Variation_437, 0, 1),
        'BAZ': ('', Variation_438, 1, 1),
        'TUR': ('', Variation_439, 2, 1),
        'CSTP': ('Coasted - Position', Variation_440, 4, 1),
        'CSTH': ('Coasted – Height', Variation_441, 5, 1),
        'CNF': ('Confirmed vs. Tentative Track', Variation_442, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['BIZ']) -> Type[Variation_437]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BAZ']) -> Type[Variation_438]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TUR']) -> Type[Variation_439]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CSTP']) -> Type[Variation_440]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CSTH']) -> Type[Variation_441]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_442]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['BIZ'], Literal['BAZ'], Literal['TUR'], Literal['CSTP'], Literal['CSTH'], Literal['CNF']]) -> Union[Type['Variation_437'], Type['Variation_438'], Type['Variation_439'], Type['Variation_440'], Type['Variation_441'], Type['Variation_442']]:
        if key == 'BIZ':
            return Variation_437
        if key == 'BAZ':
            return Variation_438
        if key == 'TUR':
            return Variation_439
        if key == 'CSTP':
            return Variation_440
        if key == 'CSTH':
            return Variation_441
        if key == 'CNF':
            return Variation_442
        assert_never(key)

    def __init__(self, arg : Variation_443_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_443_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['BIZ']) -> Variation_437:
        ...

    @overload
    def get_item(self, name : Literal['BAZ']) -> Variation_438:
        ...

    @overload
    def get_item(self, name : Literal['TUR']) -> Variation_439:
        ...

    @overload
    def get_item(self, name : Literal['CSTP']) -> Variation_440:
        ...

    @overload
    def get_item(self, name : Literal['CSTH']) -> Variation_441:
        ...

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_442:
        ...

    def get_item(self, name : Union[Literal['BIZ'], Literal['BAZ'], Literal['TUR'], Literal['CSTP'], Literal['CSTH'], Literal['CNF']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['BIZ'], val : Union[Variation_437, Variation_437_Arg]) -> 'Variation_443':
        ...

    @overload
    def set_item(self, name : Literal['BAZ'], val : Union[Variation_438, Variation_438_Arg]) -> 'Variation_443':
        ...

    @overload
    def set_item(self, name : Literal['TUR'], val : Union[Variation_439, Variation_439_Arg]) -> 'Variation_443':
        ...

    @overload
    def set_item(self, name : Literal['CSTP'], val : Union[Variation_440, Variation_440_Arg]) -> 'Variation_443':
        ...

    @overload
    def set_item(self, name : Literal['CSTH'], val : Union[Variation_441, Variation_441_Arg]) -> 'Variation_443':
        ...

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_442, Variation_442_Arg]) -> 'Variation_443':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['BIZ'], f : Any) -> 'Variation_443':
        ...

    @overload
    def modify_item(self, name : Literal['BAZ'], f : Any) -> 'Variation_443':
        ...

    @overload
    def modify_item(self, name : Literal['TUR'], f : Any) -> 'Variation_443':
        ...

    @overload
    def modify_item(self, name : Literal['CSTP'], f : Any) -> 'Variation_443':
        ...

    @overload
    def modify_item(self, name : Literal['CSTH'], f : Any) -> 'Variation_443':
        ...

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_443':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_444_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_444(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 14
    quantity = Quantity('Unsigned', 7.8125e-3, 's')

    def __init__(self, arg : Variation_444_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_445_Arg_Group = TypedDict('Variation_445_Arg_Group', {
    'UPD': Union[Variation_444, Variation_444_Arg],
})
Variation_445_Arg : TypeAlias = Union[Raw, Variation_445_Arg_Group]
class Variation_445(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 2),
        ('UPD', Variation_444),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'UPD': ('Update Period', Variation_444, 2, 14),
    }


    @classmethod
    def spec(cls, key : Union[Literal['UPD']]) -> Union[Type['Variation_444']]:
        if key == 'UPD':
            return Variation_444
        assert_never(key)

    def __init__(self, arg : Variation_445_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['UPD']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['UPD'], val : Union[Variation_444, Variation_444_Arg]) -> 'Variation_445':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['UPD'], f : Any) -> 'Variation_445':
        return self._modify_item(name, f) # type: ignore

Variation_446_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_446(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0e-2, 'm')

    def __init__(self, arg : Variation_446_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_447_Arg = TypedDict('Variation_447_Arg', {
    'LEN': Union[Variation_446, Variation_446_Arg],
    'WDT': Union[Variation_446, Variation_446_Arg],
    'HGT': Union[Variation_446, Variation_446_Arg],
    'ORT': Union[Variation_14, Variation_14_Arg],
}, total=False)
class Variation_447(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('LEN', Variation_446),
        ('WDT', Variation_446),
        ('HGT', Variation_446),
        ('ORT', Variation_14),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'LEN': ('Target Length', Variation_446, 0x80),
        'WDT': ('Target Width', Variation_446, 0x40),
        'HGT': ('Target Height', Variation_446, 0x20),
        'ORT': ('Target Orientation', Variation_14, 0x10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LEN']) -> Type[Variation_446]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WDT']) -> Type[Variation_446]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HGT']) -> Type[Variation_446]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ORT']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LEN'], Literal['WDT'], Literal['HGT'], Literal['ORT']]) -> Union[Type['Variation_446'], Type['Variation_446'], Type['Variation_446'], Type['Variation_14']]:
        if key == 'LEN':
            return Variation_446
        if key == 'WDT':
            return Variation_446
        if key == 'HGT':
            return Variation_446
        if key == 'ORT':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Optional[Variation_447_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['LEN'], val : Union[Variation_446, Variation_446_Arg]) -> 'Variation_447':
        ...

    @overload
    def set_item(self, name : Literal['WDT'], val : Union[Variation_446, Variation_446_Arg]) -> 'Variation_447':
        ...

    @overload
    def set_item(self, name : Literal['HGT'], val : Union[Variation_446, Variation_446_Arg]) -> 'Variation_447':
        ...

    @overload
    def set_item(self, name : Literal['ORT'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_447':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['LEN']) -> 'Variation_447':
        ...

    @overload
    def del_item(self, name : Literal['WDT']) -> 'Variation_447':
        ...

    @overload
    def del_item(self, name : Literal['HGT']) -> 'Variation_447':
        ...

    @overload
    def del_item(self, name : Literal['ORT']) -> 'Variation_447':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['LEN']) -> Variation_446:
        ...

    @overload
    def get_item(self, name : Literal['WDT']) -> Variation_446:
        ...

    @overload
    def get_item(self, name : Literal['HGT']) -> Variation_446:
        ...

    @overload
    def get_item(self, name : Literal['ORT']) -> Variation_14:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['LEN'], f : Any) -> 'Variation_447':
        ...

    @overload
    def modify_item(self, name : Literal['WDT'], f : Any) -> 'Variation_447':
        ...

    @overload
    def modify_item(self, name : Literal['HGT'], f : Any) -> 'Variation_447':
        ...

    @overload
    def modify_item(self, name : Literal['ORT'], f : Any) -> 'Variation_447':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_448_Arg : TypeAlias = Raw
class Variation_448(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 9

    def __init__(self, arg : Variation_448_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_449_Arg : TypeAlias = Raw
class Variation_449(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 7

    def __init__(self, arg : Variation_449_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_450_Arg_Group = TypedDict('Variation_450_Arg_Group', {
    'CLS': Union[Variation_448, Variation_448_Arg],
    'PRB': Union[Variation_449, Variation_449_Arg],
})
Variation_450_Arg : TypeAlias = Union[Raw, Variation_450_Arg_Group]
class Variation_450(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('CLS', Variation_448),
        ('PRB', Variation_449),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CLS': ('Classification', Variation_448, 0, 9),
        'PRB': ('Probability', Variation_449, 9, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CLS']) -> Type[Variation_448]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PRB']) -> Type[Variation_449]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CLS'], Literal['PRB']]) -> Union[Type['Variation_448'], Type['Variation_449']]:
        if key == 'CLS':
            return Variation_448
        if key == 'PRB':
            return Variation_449
        assert_never(key)

    def __init__(self, arg : Variation_450_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CLS']) -> Variation_448:
        ...

    @overload
    def get_item(self, name : Literal['PRB']) -> Variation_449:
        ...

    def get_item(self, name : Union[Literal['CLS'], Literal['PRB']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CLS'], val : Union[Variation_448, Variation_448_Arg]) -> 'Variation_450':
        ...

    @overload
    def set_item(self, name : Literal['PRB'], val : Union[Variation_449, Variation_449_Arg]) -> 'Variation_450':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CLS'], f : Any) -> 'Variation_450':
        ...

    @overload
    def modify_item(self, name : Literal['PRB'], f : Any) -> 'Variation_450':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_451_Arg : TypeAlias = Union[Variation_450, Variation_450_Arg]
class Variation_451(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_450

    @classmethod
    def spec(cls) -> Type[Variation_450]:
        return Variation_450

    def __init__(self, arg : List[Union[Variation_450, Variation_450_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_450, Variation_450_Arg]) -> 'Variation_451':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_450, Variation_450_Arg]) -> 'Variation_451':
        return self._prepend_item(arg) # type: ignore

Variation_452_Arg_Group = TypedDict('Variation_452_Arg_Group', {
    'PID': Union[Variation_64, Variation_64_Arg],
    'ON': Union[Variation_278, Variation_278_Arg],
})
Variation_452_Arg : TypeAlias = Union[Raw, Variation_452_Arg_Group]
class Variation_452(Group):
    variation = 'Group'

    bit_size = 40

    subitems_list = [
        ('PID', Variation_64),
        ('ON', Variation_278),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PID': ('Pair Identifier', Variation_64, 0, 16),
        'ON': ('Observation Number', Variation_278, 16, 24),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PID']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ON']) -> Type[Variation_278]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PID'], Literal['ON']]) -> Union[Type['Variation_64'], Type['Variation_278']]:
        if key == 'PID':
            return Variation_64
        if key == 'ON':
            return Variation_278
        assert_never(key)

    def __init__(self, arg : Variation_452_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PID']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['ON']) -> Variation_278:
        ...

    def get_item(self, name : Union[Literal['PID'], Literal['ON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PID'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_452':
        ...

    @overload
    def set_item(self, name : Literal['ON'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_452':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PID'], f : Any) -> 'Variation_452':
        ...

    @overload
    def modify_item(self, name : Literal['ON'], f : Any) -> 'Variation_452':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_453_Arg_Group = TypedDict('Variation_453_Arg_Group', {
    'LATITUDE': Union[Variation_255, Variation_255_Arg],
    'LONGITUDE': Union[Variation_255, Variation_255_Arg],
})
Variation_453_Arg : TypeAlias = Union[Raw, Variation_453_Arg_Group]
class Variation_453(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('LATITUDE', Variation_255),
        ('LONGITUDE', Variation_255),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LATITUDE': ('', Variation_255, 0, 32),
        'LONGITUDE': ('', Variation_255, 32, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LATITUDE']) -> Type[Variation_255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LONGITUDE']) -> Type[Variation_255]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LATITUDE'], Literal['LONGITUDE']]) -> Union[Type['Variation_255'], Type['Variation_255']]:
        if key == 'LATITUDE':
            return Variation_255
        if key == 'LONGITUDE':
            return Variation_255
        assert_never(key)

    def __init__(self, arg : Variation_453_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LATITUDE']) -> Variation_255:
        ...

    @overload
    def get_item(self, name : Literal['LONGITUDE']) -> Variation_255:
        ...

    def get_item(self, name : Union[Literal['LATITUDE'], Literal['LONGITUDE']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LATITUDE'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_453':
        ...

    @overload
    def set_item(self, name : Literal['LONGITUDE'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_453':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LATITUDE'], f : Any) -> 'Variation_453':
        ...

    @overload
    def modify_item(self, name : Literal['LONGITUDE'], f : Any) -> 'Variation_453':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_454_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['']]]
class Variation_454(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 7.8125e-3, '')

    def __init__(self, arg : Variation_454_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_455_Arg_Group = TypedDict('Variation_455_Arg_Group', {
    'RSHPX': Union[Variation_152, Variation_152_Arg],
    'RSHPY': Union[Variation_152, Variation_152_Arg],
    'CORSHPXY': Union[Variation_454, Variation_454_Arg],
})
Variation_455_Arg : TypeAlias = Union[Raw, Variation_455_Arg_Group]
class Variation_455(Group):
    variation = 'Group'

    bit_size = 40

    subitems_list = [
        ('RSHPX', Variation_152),
        ('RSHPY', Variation_152),
        ('CORSHPXY', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RSHPX': ('', Variation_152, 0, 16),
        'RSHPY': ('', Variation_152, 16, 16),
        'CORSHPXY': ('', Variation_454, 32, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RSHPX']) -> Type[Variation_152]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSHPY']) -> Type[Variation_152]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CORSHPXY']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RSHPX'], Literal['RSHPY'], Literal['CORSHPXY']]) -> Union[Type['Variation_152'], Type['Variation_152'], Type['Variation_454']]:
        if key == 'RSHPX':
            return Variation_152
        if key == 'RSHPY':
            return Variation_152
        if key == 'CORSHPXY':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_455_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RSHPX']) -> Variation_152:
        ...

    @overload
    def get_item(self, name : Literal['RSHPY']) -> Variation_152:
        ...

    @overload
    def get_item(self, name : Literal['CORSHPXY']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['RSHPX'], Literal['RSHPY'], Literal['CORSHPXY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RSHPX'], val : Union[Variation_152, Variation_152_Arg]) -> 'Variation_455':
        ...

    @overload
    def set_item(self, name : Literal['RSHPY'], val : Union[Variation_152, Variation_152_Arg]) -> 'Variation_455':
        ...

    @overload
    def set_item(self, name : Literal['CORSHPXY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_455':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RSHPX'], f : Any) -> 'Variation_455':
        ...

    @overload
    def modify_item(self, name : Literal['RSHPY'], f : Any) -> 'Variation_455':
        ...

    @overload
    def modify_item(self, name : Literal['CORSHPXY'], f : Any) -> 'Variation_455':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_456_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_456(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 0.25, 'm')

    def __init__(self, arg : Variation_456_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_457_Arg_Group = TypedDict('Variation_457_Arg_Group', {
    'SDHPX': Union[Variation_456, Variation_456_Arg],
    'SDHPY': Union[Variation_456, Variation_456_Arg],
    'COSDHPXY': Union[Variation_454, Variation_454_Arg],
})
Variation_457_Arg : TypeAlias = Union[Raw, Variation_457_Arg_Group]
class Variation_457(Group):
    variation = 'Group'

    bit_size = 40

    subitems_list = [
        ('SDHPX', Variation_456),
        ('SDHPY', Variation_456),
        ('COSDHPXY', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SDHPX': ('', Variation_456, 0, 16),
        'SDHPY': ('', Variation_456, 16, 16),
        'COSDHPXY': ('', Variation_454, 32, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SDHPX']) -> Type[Variation_456]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDHPY']) -> Type[Variation_456]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COSDHPXY']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SDHPX'], Literal['SDHPY'], Literal['COSDHPXY']]) -> Union[Type['Variation_456'], Type['Variation_456'], Type['Variation_454']]:
        if key == 'SDHPX':
            return Variation_456
        if key == 'SDHPY':
            return Variation_456
        if key == 'COSDHPXY':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_457_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SDHPX']) -> Variation_456:
        ...

    @overload
    def get_item(self, name : Literal['SDHPY']) -> Variation_456:
        ...

    @overload
    def get_item(self, name : Literal['COSDHPXY']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['SDHPX'], Literal['SDHPY'], Literal['COSDHPXY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SDHPX'], val : Union[Variation_456, Variation_456_Arg]) -> 'Variation_457':
        ...

    @overload
    def set_item(self, name : Literal['SDHPY'], val : Union[Variation_456, Variation_456_Arg]) -> 'Variation_457':
        ...

    @overload
    def set_item(self, name : Literal['COSDHPXY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_457':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SDHPX'], f : Any) -> 'Variation_457':
        ...

    @overload
    def modify_item(self, name : Literal['SDHPY'], f : Any) -> 'Variation_457':
        ...

    @overload
    def modify_item(self, name : Literal['COSDHPXY'], f : Any) -> 'Variation_457':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_458_Arg = TypedDict('Variation_458_Arg', {
    'P84': Union[Variation_453, Variation_453_Arg],
    'HPR': Union[Variation_455, Variation_455_Arg],
    'HPP': Union[Variation_457, Variation_457_Arg],
}, total=False)
class Variation_458(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('P84', Variation_453),
        ('HPR', Variation_455),
        ('HPP', Variation_457),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'P84': ('Horizontal Position in WGS-84 Coordinates', Variation_453, 0x80),
        'HPR': ('Horizontal Position Resolution', Variation_455, 0x40),
        'HPP': ('Horizontal Position Precision', Variation_457, 0x20),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['P84']) -> Type[Variation_453]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HPR']) -> Type[Variation_455]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HPP']) -> Type[Variation_457]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['P84'], Literal['HPR'], Literal['HPP']]) -> Union[Type['Variation_453'], Type['Variation_455'], Type['Variation_457']]:
        if key == 'P84':
            return Variation_453
        if key == 'HPR':
            return Variation_455
        if key == 'HPP':
            return Variation_457
        assert_never(key)

    def __init__(self, arg : Optional[Variation_458_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['P84'], val : Union[Variation_453, Variation_453_Arg]) -> 'Variation_458':
        ...

    @overload
    def set_item(self, name : Literal['HPR'], val : Union[Variation_455, Variation_455_Arg]) -> 'Variation_458':
        ...

    @overload
    def set_item(self, name : Literal['HPP'], val : Union[Variation_457, Variation_457_Arg]) -> 'Variation_458':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['P84']) -> 'Variation_458':
        ...

    @overload
    def del_item(self, name : Literal['HPR']) -> 'Variation_458':
        ...

    @overload
    def del_item(self, name : Literal['HPP']) -> 'Variation_458':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['P84']) -> Variation_453:
        ...

    @overload
    def get_item(self, name : Literal['HPR']) -> Variation_455:
        ...

    @overload
    def get_item(self, name : Literal['HPP']) -> Variation_457:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['P84'], f : Any) -> 'Variation_458':
        ...

    @overload
    def modify_item(self, name : Literal['HPR'], f : Any) -> 'Variation_458':
        ...

    @overload
    def modify_item(self, name : Literal['HPP'], f : Any) -> 'Variation_458':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_459_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_459(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Signed', 1.0e-2, 'm')

    def __init__(self, arg : Variation_459_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_460_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_460(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Unsigned', 1.0e-2, 'm')

    def __init__(self, arg : Variation_460_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_461_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_461(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 12
    quantity = Quantity('Unsigned', 16.0, 'm')

    def __init__(self, arg : Variation_461_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_462_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_462(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 12
    quantity = Quantity('Unsigned', 16.0, 'm')

    def __init__(self, arg : Variation_462_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_463_Arg_Group = TypedDict('Variation_463_Arg_Group', {
    'UCI6': Union[Variation_461, Variation_461_Arg],
    'LCI6': Union[Variation_462, Variation_462_Arg],
})
Variation_463_Arg : TypeAlias = Union[Raw, Variation_463_Arg_Group]
class Variation_463(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('UCI6', Variation_461),
        ('LCI6', Variation_462),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'UCI6': ('', Variation_461, 0, 12),
        'LCI6': ('', Variation_462, 12, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['UCI6']) -> Type[Variation_461]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LCI6']) -> Type[Variation_462]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['UCI6'], Literal['LCI6']]) -> Union[Type['Variation_461'], Type['Variation_462']]:
        if key == 'UCI6':
            return Variation_461
        if key == 'LCI6':
            return Variation_462
        assert_never(key)

    def __init__(self, arg : Variation_463_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['UCI6']) -> Variation_461:
        ...

    @overload
    def get_item(self, name : Literal['LCI6']) -> Variation_462:
        ...

    def get_item(self, name : Union[Literal['UCI6'], Literal['LCI6']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['UCI6'], val : Union[Variation_461, Variation_461_Arg]) -> 'Variation_463':
        ...

    @overload
    def set_item(self, name : Literal['LCI6'], val : Union[Variation_462, Variation_462_Arg]) -> 'Variation_463':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['UCI6'], f : Any) -> 'Variation_463':
        ...

    @overload
    def modify_item(self, name : Literal['LCI6'], f : Any) -> 'Variation_463':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_464_Arg_Group = TypedDict('Variation_464_Arg_Group', {
    'UCI9': Union[Variation_461, Variation_461_Arg],
    'LCI9': Union[Variation_462, Variation_462_Arg],
})
Variation_464_Arg : TypeAlias = Union[Raw, Variation_464_Arg_Group]
class Variation_464(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('UCI9', Variation_461),
        ('LCI9', Variation_462),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'UCI9': ('', Variation_461, 0, 12),
        'LCI9': ('', Variation_462, 12, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['UCI9']) -> Type[Variation_461]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LCI9']) -> Type[Variation_462]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['UCI9'], Literal['LCI9']]) -> Union[Type['Variation_461'], Type['Variation_462']]:
        if key == 'UCI9':
            return Variation_461
        if key == 'LCI9':
            return Variation_462
        assert_never(key)

    def __init__(self, arg : Variation_464_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['UCI9']) -> Variation_461:
        ...

    @overload
    def get_item(self, name : Literal['LCI9']) -> Variation_462:
        ...

    def get_item(self, name : Union[Literal['UCI9'], Literal['LCI9']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['UCI9'], val : Union[Variation_461, Variation_461_Arg]) -> 'Variation_464':
        ...

    @overload
    def set_item(self, name : Literal['LCI9'], val : Union[Variation_462, Variation_462_Arg]) -> 'Variation_464':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['UCI9'], f : Any) -> 'Variation_464':
        ...

    @overload
    def modify_item(self, name : Literal['LCI9'], f : Any) -> 'Variation_464':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_465_Arg_Group = TypedDict('Variation_465_Arg_Group', {
    'X': Union[Variation_454, Variation_454_Arg],
    'Y': Union[Variation_454, Variation_454_Arg],
})
Variation_465_Arg : TypeAlias = Union[Raw, Variation_465_Arg_Group]
class Variation_465(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('X', Variation_454),
        ('Y', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('', Variation_454, 0, 8),
        'Y': ('', Variation_454, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_454'], Type['Variation_454']]:
        if key == 'X':
            return Variation_454
        if key == 'Y':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_465_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_465':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_465':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_465':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_465':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_466_Arg = TypedDict('Variation_466_Arg', {
    'GH': Union[Variation_459, Variation_459_Arg],
    'RSGH': Union[Variation_460, Variation_460_Arg],
    'SDGH': Union[Variation_460, Variation_460_Arg],
    'CI6': Union[Variation_463, Variation_463_Arg],
    'CI9': Union[Variation_464, Variation_464_Arg],
    'COGHHP': Union[Variation_465, Variation_465_Arg],
    'COGHHV': Union[Variation_465, Variation_465_Arg],
    'COGHHA': Union[Variation_465, Variation_465_Arg],
}, total=False)
class Variation_466(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('GH', Variation_459),
        ('RSGH', Variation_460),
        ('SDGH', Variation_460),
        ('CI6', Variation_463),
        ('CI9', Variation_464),
        ('COGHHP', Variation_465),
        ('COGHHV', Variation_465),
        ('COGHHA', Variation_465),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'GH': ('Geometric Height (WGS-84)', Variation_459, 0x8000),
        'RSGH': ('Geometric Height Resolution', Variation_460, 0x4000),
        'SDGH': ('Geometric Height Precision', Variation_460, 0x2000),
        'CI6': ('Confidence Interval for Geometric Height (67%)', Variation_463, 0x1000),
        'CI9': ('Confidence Interval for Geometric Height (95%)', Variation_464, 0x0800),
        'COGHHP': ('Correlation of Geometric Height and Horizontal Position', Variation_465, 0x0400),
        'COGHHV': ('Correlation of Geometric Height and Horizontal Velocity', Variation_465, 0x0200),
        'COGHHA': ('Correlation of Geometric Height and Horizontal Acceleration', Variation_465, 0x0180),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['GH']) -> Type[Variation_459]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSGH']) -> Type[Variation_460]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDGH']) -> Type[Variation_460]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CI6']) -> Type[Variation_463]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CI9']) -> Type[Variation_464]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COGHHP']) -> Type[Variation_465]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COGHHV']) -> Type[Variation_465]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COGHHA']) -> Type[Variation_465]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['GH'], Literal['RSGH'], Literal['SDGH'], Literal['CI6'], Literal['CI9'], Literal['COGHHP'], Literal['COGHHV'], Literal['COGHHA']]) -> Union[Type['Variation_459'], Type['Variation_460'], Type['Variation_460'], Type['Variation_463'], Type['Variation_464'], Type['Variation_465'], Type['Variation_465'], Type['Variation_465']]:
        if key == 'GH':
            return Variation_459
        if key == 'RSGH':
            return Variation_460
        if key == 'SDGH':
            return Variation_460
        if key == 'CI6':
            return Variation_463
        if key == 'CI9':
            return Variation_464
        if key == 'COGHHP':
            return Variation_465
        if key == 'COGHHV':
            return Variation_465
        if key == 'COGHHA':
            return Variation_465
        assert_never(key)

    def __init__(self, arg : Optional[Variation_466_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['GH'], val : Union[Variation_459, Variation_459_Arg]) -> 'Variation_466':
        ...

    @overload
    def set_item(self, name : Literal['RSGH'], val : Union[Variation_460, Variation_460_Arg]) -> 'Variation_466':
        ...

    @overload
    def set_item(self, name : Literal['SDGH'], val : Union[Variation_460, Variation_460_Arg]) -> 'Variation_466':
        ...

    @overload
    def set_item(self, name : Literal['CI6'], val : Union[Variation_463, Variation_463_Arg]) -> 'Variation_466':
        ...

    @overload
    def set_item(self, name : Literal['CI9'], val : Union[Variation_464, Variation_464_Arg]) -> 'Variation_466':
        ...

    @overload
    def set_item(self, name : Literal['COGHHP'], val : Union[Variation_465, Variation_465_Arg]) -> 'Variation_466':
        ...

    @overload
    def set_item(self, name : Literal['COGHHV'], val : Union[Variation_465, Variation_465_Arg]) -> 'Variation_466':
        ...

    @overload
    def set_item(self, name : Literal['COGHHA'], val : Union[Variation_465, Variation_465_Arg]) -> 'Variation_466':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['GH']) -> 'Variation_466':
        ...

    @overload
    def del_item(self, name : Literal['RSGH']) -> 'Variation_466':
        ...

    @overload
    def del_item(self, name : Literal['SDGH']) -> 'Variation_466':
        ...

    @overload
    def del_item(self, name : Literal['CI6']) -> 'Variation_466':
        ...

    @overload
    def del_item(self, name : Literal['CI9']) -> 'Variation_466':
        ...

    @overload
    def del_item(self, name : Literal['COGHHP']) -> 'Variation_466':
        ...

    @overload
    def del_item(self, name : Literal['COGHHV']) -> 'Variation_466':
        ...

    @overload
    def del_item(self, name : Literal['COGHHA']) -> 'Variation_466':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['GH']) -> Variation_459:
        ...

    @overload
    def get_item(self, name : Literal['RSGH']) -> Variation_460:
        ...

    @overload
    def get_item(self, name : Literal['SDGH']) -> Variation_460:
        ...

    @overload
    def get_item(self, name : Literal['CI6']) -> Variation_463:
        ...

    @overload
    def get_item(self, name : Literal['CI9']) -> Variation_464:
        ...

    @overload
    def get_item(self, name : Literal['COGHHP']) -> Variation_465:
        ...

    @overload
    def get_item(self, name : Literal['COGHHV']) -> Variation_465:
        ...

    @overload
    def get_item(self, name : Literal['COGHHA']) -> Variation_465:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['GH'], f : Any) -> 'Variation_466':
        ...

    @overload
    def modify_item(self, name : Literal['RSGH'], f : Any) -> 'Variation_466':
        ...

    @overload
    def modify_item(self, name : Literal['SDGH'], f : Any) -> 'Variation_466':
        ...

    @overload
    def modify_item(self, name : Literal['CI6'], f : Any) -> 'Variation_466':
        ...

    @overload
    def modify_item(self, name : Literal['CI9'], f : Any) -> 'Variation_466':
        ...

    @overload
    def modify_item(self, name : Literal['COGHHP'], f : Any) -> 'Variation_466':
        ...

    @overload
    def modify_item(self, name : Literal['COGHHV'], f : Any) -> 'Variation_466':
        ...

    @overload
    def modify_item(self, name : Literal['COGHHA'], f : Any) -> 'Variation_466':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_467_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_467(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 20
    quantity = Quantity('Signed', 1.0e-2, 'm/s')

    def __init__(self, arg : Variation_467_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_468_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_468(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 20
    quantity = Quantity('Signed', 1.0e-2, 'm/s')

    def __init__(self, arg : Variation_468_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_469_Arg_Group = TypedDict('Variation_469_Arg_Group', {
    'X': Union[Variation_467, Variation_467_Arg],
    'Y': Union[Variation_468, Variation_468_Arg],
})
Variation_469_Arg : TypeAlias = Union[Raw, Variation_469_Arg_Group]
class Variation_469(Group):
    variation = 'Group'

    bit_size = 40

    subitems_list = [
        ('X', Variation_467),
        ('Y', Variation_468),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('', Variation_467, 0, 20),
        'Y': ('', Variation_468, 20, 20),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_467]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_468]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_467'], Type['Variation_468']]:
        if key == 'X':
            return Variation_467
        if key == 'Y':
            return Variation_468
        assert_never(key)

    def __init__(self, arg : Variation_469_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_467:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_468:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_467, Variation_467_Arg]) -> 'Variation_469':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_468, Variation_468_Arg]) -> 'Variation_469':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_469':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_469':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_470_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_470(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0e-2, 'm/s')

    def __init__(self, arg : Variation_470_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_471_Arg_Group = TypedDict('Variation_471_Arg_Group', {
    'X': Union[Variation_470, Variation_470_Arg],
    'Y': Union[Variation_470, Variation_470_Arg],
    'CORSHVXY': Union[Variation_454, Variation_454_Arg],
})
Variation_471_Arg : TypeAlias = Union[Raw, Variation_471_Arg_Group]
class Variation_471(Group):
    variation = 'Group'

    bit_size = 40

    subitems_list = [
        ('X', Variation_470),
        ('Y', Variation_470),
        ('CORSHVXY', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('', Variation_470, 0, 16),
        'Y': ('', Variation_470, 16, 16),
        'CORSHVXY': ('', Variation_454, 32, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_470]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_470]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CORSHVXY']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y'], Literal['CORSHVXY']]) -> Union[Type['Variation_470'], Type['Variation_470'], Type['Variation_454']]:
        if key == 'X':
            return Variation_470
        if key == 'Y':
            return Variation_470
        if key == 'CORSHVXY':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_471_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_470:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_470:
        ...

    @overload
    def get_item(self, name : Literal['CORSHVXY']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y'], Literal['CORSHVXY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_470, Variation_470_Arg]) -> 'Variation_471':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_470, Variation_470_Arg]) -> 'Variation_471':
        ...

    @overload
    def set_item(self, name : Literal['CORSHVXY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_471':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_471':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_471':
        ...

    @overload
    def modify_item(self, name : Literal['CORSHVXY'], f : Any) -> 'Variation_471':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_472_Arg_Group = TypedDict('Variation_472_Arg_Group', {
    'X': Union[Variation_470, Variation_470_Arg],
    'Y': Union[Variation_470, Variation_470_Arg],
    'COHVXY': Union[Variation_454, Variation_454_Arg],
})
Variation_472_Arg : TypeAlias = Union[Raw, Variation_472_Arg_Group]
class Variation_472(Group):
    variation = 'Group'

    bit_size = 40

    subitems_list = [
        ('X', Variation_470),
        ('Y', Variation_470),
        ('COHVXY', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('', Variation_470, 0, 16),
        'Y': ('', Variation_470, 16, 16),
        'COHVXY': ('', Variation_454, 32, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_470]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_470]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHVXY']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y'], Literal['COHVXY']]) -> Union[Type['Variation_470'], Type['Variation_470'], Type['Variation_454']]:
        if key == 'X':
            return Variation_470
        if key == 'Y':
            return Variation_470
        if key == 'COHVXY':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_472_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_470:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_470:
        ...

    @overload
    def get_item(self, name : Literal['COHVXY']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y'], Literal['COHVXY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_470, Variation_470_Arg]) -> 'Variation_472':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_470, Variation_470_Arg]) -> 'Variation_472':
        ...

    @overload
    def set_item(self, name : Literal['COHVXY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_472':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_472':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_472':
        ...

    @overload
    def modify_item(self, name : Literal['COHVXY'], f : Any) -> 'Variation_472':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_473_Arg_Group = TypedDict('Variation_473_Arg_Group', {
    'COHVXHPX': Union[Variation_454, Variation_454_Arg],
    'COHVXHPY': Union[Variation_454, Variation_454_Arg],
    'COHVYHPX': Union[Variation_454, Variation_454_Arg],
    'COHVYHPY': Union[Variation_454, Variation_454_Arg],
})
Variation_473_Arg : TypeAlias = Union[Raw, Variation_473_Arg_Group]
class Variation_473(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('COHVXHPX', Variation_454),
        ('COHVXHPY', Variation_454),
        ('COHVYHPX', Variation_454),
        ('COHVYHPY', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COHVXHPX': ('', Variation_454, 0, 8),
        'COHVXHPY': ('', Variation_454, 8, 8),
        'COHVYHPX': ('', Variation_454, 16, 8),
        'COHVYHPY': ('', Variation_454, 24, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COHVXHPX']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHVXHPY']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHVYHPX']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHVYHPY']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COHVXHPX'], Literal['COHVXHPY'], Literal['COHVYHPX'], Literal['COHVYHPY']]) -> Union[Type['Variation_454'], Type['Variation_454'], Type['Variation_454'], Type['Variation_454']]:
        if key == 'COHVXHPX':
            return Variation_454
        if key == 'COHVXHPY':
            return Variation_454
        if key == 'COHVYHPX':
            return Variation_454
        if key == 'COHVYHPY':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_473_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['COHVXHPX']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COHVXHPY']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COHVYHPX']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COHVYHPY']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['COHVXHPX'], Literal['COHVXHPY'], Literal['COHVYHPX'], Literal['COHVYHPY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['COHVXHPX'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_473':
        ...

    @overload
    def set_item(self, name : Literal['COHVXHPY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_473':
        ...

    @overload
    def set_item(self, name : Literal['COHVYHPX'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_473':
        ...

    @overload
    def set_item(self, name : Literal['COHVYHPY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_473':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['COHVXHPX'], f : Any) -> 'Variation_473':
        ...

    @overload
    def modify_item(self, name : Literal['COHVXHPY'], f : Any) -> 'Variation_473':
        ...

    @overload
    def modify_item(self, name : Literal['COHVYHPX'], f : Any) -> 'Variation_473':
        ...

    @overload
    def modify_item(self, name : Literal['COHVYHPY'], f : Any) -> 'Variation_473':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_474_Arg = TypedDict('Variation_474_Arg', {
    'HV': Union[Variation_469, Variation_469_Arg],
    'RSHV': Union[Variation_471, Variation_471_Arg],
    'SDHV': Union[Variation_472, Variation_472_Arg],
    'COHVHP': Union[Variation_473, Variation_473_Arg],
}, total=False)
class Variation_474(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('HV', Variation_469),
        ('RSHV', Variation_471),
        ('SDHV', Variation_472),
        ('COHVHP', Variation_473),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'HV': ('Horizontal Velocity Vector', Variation_469, 0x80),
        'RSHV': ('Horizontal Velocity Resolution', Variation_471, 0x40),
        'SDHV': ('Horizontal Velocity Precision', Variation_472, 0x20),
        'COHVHP': ('Correlation of Horizontal Velocity and Horizontal Position', Variation_473, 0x10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['HV']) -> Type[Variation_469]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSHV']) -> Type[Variation_471]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDHV']) -> Type[Variation_472]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHVHP']) -> Type[Variation_473]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['HV'], Literal['RSHV'], Literal['SDHV'], Literal['COHVHP']]) -> Union[Type['Variation_469'], Type['Variation_471'], Type['Variation_472'], Type['Variation_473']]:
        if key == 'HV':
            return Variation_469
        if key == 'RSHV':
            return Variation_471
        if key == 'SDHV':
            return Variation_472
        if key == 'COHVHP':
            return Variation_473
        assert_never(key)

    def __init__(self, arg : Optional[Variation_474_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['HV'], val : Union[Variation_469, Variation_469_Arg]) -> 'Variation_474':
        ...

    @overload
    def set_item(self, name : Literal['RSHV'], val : Union[Variation_471, Variation_471_Arg]) -> 'Variation_474':
        ...

    @overload
    def set_item(self, name : Literal['SDHV'], val : Union[Variation_472, Variation_472_Arg]) -> 'Variation_474':
        ...

    @overload
    def set_item(self, name : Literal['COHVHP'], val : Union[Variation_473, Variation_473_Arg]) -> 'Variation_474':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['HV']) -> 'Variation_474':
        ...

    @overload
    def del_item(self, name : Literal['RSHV']) -> 'Variation_474':
        ...

    @overload
    def del_item(self, name : Literal['SDHV']) -> 'Variation_474':
        ...

    @overload
    def del_item(self, name : Literal['COHVHP']) -> 'Variation_474':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['HV']) -> Variation_469:
        ...

    @overload
    def get_item(self, name : Literal['RSHV']) -> Variation_471:
        ...

    @overload
    def get_item(self, name : Literal['SDHV']) -> Variation_472:
        ...

    @overload
    def get_item(self, name : Literal['COHVHP']) -> Variation_473:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['HV'], f : Any) -> 'Variation_474':
        ...

    @overload
    def modify_item(self, name : Literal['RSHV'], f : Any) -> 'Variation_474':
        ...

    @overload
    def modify_item(self, name : Literal['SDHV'], f : Any) -> 'Variation_474':
        ...

    @overload
    def modify_item(self, name : Literal['COHVHP'], f : Any) -> 'Variation_474':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_475_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_475(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 12
    quantity = Quantity('Signed', 6.25e-2, 'm/s²')

    def __init__(self, arg : Variation_475_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_476_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_476(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 12
    quantity = Quantity('Signed', 6.25e-2, 'm/s²')

    def __init__(self, arg : Variation_476_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_477_Arg_Group = TypedDict('Variation_477_Arg_Group', {
    'X': Union[Variation_475, Variation_475_Arg],
    'Y': Union[Variation_476, Variation_476_Arg],
})
Variation_477_Arg : TypeAlias = Union[Raw, Variation_477_Arg_Group]
class Variation_477(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('X', Variation_475),
        ('Y', Variation_476),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('', Variation_475, 0, 12),
        'Y': ('', Variation_476, 12, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_475]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_476]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_475'], Type['Variation_476']]:
        if key == 'X':
            return Variation_475
        if key == 'Y':
            return Variation_476
        assert_never(key)

    def __init__(self, arg : Variation_477_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_475:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_476:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_475, Variation_475_Arg]) -> 'Variation_477':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_476, Variation_476_Arg]) -> 'Variation_477':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_477':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_477':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_478_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_478(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 12
    quantity = Quantity('Unsigned', 6.25e-2, 'm/s²')

    def __init__(self, arg : Variation_478_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_479_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_479(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 12
    quantity = Quantity('Unsigned', 6.25e-2, 'm/s²')

    def __init__(self, arg : Variation_479_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_480_Arg_Group = TypedDict('Variation_480_Arg_Group', {
    'X': Union[Variation_478, Variation_478_Arg],
    'Y': Union[Variation_479, Variation_479_Arg],
    'COHAXY': Union[Variation_454, Variation_454_Arg],
})
Variation_480_Arg : TypeAlias = Union[Raw, Variation_480_Arg_Group]
class Variation_480(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('X', Variation_478),
        ('Y', Variation_479),
        ('COHAXY', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('', Variation_478, 0, 12),
        'Y': ('', Variation_479, 12, 12),
        'COHAXY': ('', Variation_454, 24, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_478]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_479]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAXY']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y'], Literal['COHAXY']]) -> Union[Type['Variation_478'], Type['Variation_479'], Type['Variation_454']]:
        if key == 'X':
            return Variation_478
        if key == 'Y':
            return Variation_479
        if key == 'COHAXY':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_480_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_478:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_479:
        ...

    @overload
    def get_item(self, name : Literal['COHAXY']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y'], Literal['COHAXY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_478, Variation_478_Arg]) -> 'Variation_480':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_479, Variation_479_Arg]) -> 'Variation_480':
        ...

    @overload
    def set_item(self, name : Literal['COHAXY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_480':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_480':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_480':
        ...

    @overload
    def modify_item(self, name : Literal['COHAXY'], f : Any) -> 'Variation_480':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_481_Arg_Group = TypedDict('Variation_481_Arg_Group', {
    'COHAXHPX': Union[Variation_454, Variation_454_Arg],
    'COHAXHPY': Union[Variation_454, Variation_454_Arg],
    'COHAYHPX': Union[Variation_454, Variation_454_Arg],
    'COAYHPY': Union[Variation_454, Variation_454_Arg],
})
Variation_481_Arg : TypeAlias = Union[Raw, Variation_481_Arg_Group]
class Variation_481(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('COHAXHPX', Variation_454),
        ('COHAXHPY', Variation_454),
        ('COHAYHPX', Variation_454),
        ('COAYHPY', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COHAXHPX': ('', Variation_454, 0, 8),
        'COHAXHPY': ('', Variation_454, 8, 8),
        'COHAYHPX': ('', Variation_454, 16, 8),
        'COAYHPY': ('', Variation_454, 24, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAXHPX']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAXHPY']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAYHPX']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COAYHPY']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COHAXHPX'], Literal['COHAXHPY'], Literal['COHAYHPX'], Literal['COAYHPY']]) -> Union[Type['Variation_454'], Type['Variation_454'], Type['Variation_454'], Type['Variation_454']]:
        if key == 'COHAXHPX':
            return Variation_454
        if key == 'COHAXHPY':
            return Variation_454
        if key == 'COHAYHPX':
            return Variation_454
        if key == 'COAYHPY':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_481_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['COHAXHPX']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COHAXHPY']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COHAYHPX']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COAYHPY']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['COHAXHPX'], Literal['COHAXHPY'], Literal['COHAYHPX'], Literal['COAYHPY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['COHAXHPX'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_481':
        ...

    @overload
    def set_item(self, name : Literal['COHAXHPY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_481':
        ...

    @overload
    def set_item(self, name : Literal['COHAYHPX'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_481':
        ...

    @overload
    def set_item(self, name : Literal['COAYHPY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_481':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['COHAXHPX'], f : Any) -> 'Variation_481':
        ...

    @overload
    def modify_item(self, name : Literal['COHAXHPY'], f : Any) -> 'Variation_481':
        ...

    @overload
    def modify_item(self, name : Literal['COHAYHPX'], f : Any) -> 'Variation_481':
        ...

    @overload
    def modify_item(self, name : Literal['COAYHPY'], f : Any) -> 'Variation_481':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_482_Arg_Group = TypedDict('Variation_482_Arg_Group', {
    'COHAXHVX': Union[Variation_454, Variation_454_Arg],
    'COHAXHVY': Union[Variation_454, Variation_454_Arg],
    'COHAYHVX': Union[Variation_454, Variation_454_Arg],
    'COHAYHVY': Union[Variation_454, Variation_454_Arg],
})
Variation_482_Arg : TypeAlias = Union[Raw, Variation_482_Arg_Group]
class Variation_482(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('COHAXHVX', Variation_454),
        ('COHAXHVY', Variation_454),
        ('COHAYHVX', Variation_454),
        ('COHAYHVY', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COHAXHVX': ('', Variation_454, 0, 8),
        'COHAXHVY': ('', Variation_454, 8, 8),
        'COHAYHVX': ('', Variation_454, 16, 8),
        'COHAYHVY': ('', Variation_454, 24, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAXHVX']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAXHVY']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAYHVX']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAYHVY']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COHAXHVX'], Literal['COHAXHVY'], Literal['COHAYHVX'], Literal['COHAYHVY']]) -> Union[Type['Variation_454'], Type['Variation_454'], Type['Variation_454'], Type['Variation_454']]:
        if key == 'COHAXHVX':
            return Variation_454
        if key == 'COHAXHVY':
            return Variation_454
        if key == 'COHAYHVX':
            return Variation_454
        if key == 'COHAYHVY':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_482_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['COHAXHVX']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COHAXHVY']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COHAYHVX']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COHAYHVY']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['COHAXHVX'], Literal['COHAXHVY'], Literal['COHAYHVX'], Literal['COHAYHVY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['COHAXHVX'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_482':
        ...

    @overload
    def set_item(self, name : Literal['COHAXHVY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_482':
        ...

    @overload
    def set_item(self, name : Literal['COHAYHVX'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_482':
        ...

    @overload
    def set_item(self, name : Literal['COHAYHVY'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_482':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['COHAXHVX'], f : Any) -> 'Variation_482':
        ...

    @overload
    def modify_item(self, name : Literal['COHAXHVY'], f : Any) -> 'Variation_482':
        ...

    @overload
    def modify_item(self, name : Literal['COHAYHVX'], f : Any) -> 'Variation_482':
        ...

    @overload
    def modify_item(self, name : Literal['COHAYHVY'], f : Any) -> 'Variation_482':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_483_Arg = TypedDict('Variation_483_Arg', {
    'HA': Union[Variation_477, Variation_477_Arg],
    'SDHA': Union[Variation_480, Variation_480_Arg],
    'COHAHP': Union[Variation_481, Variation_481_Arg],
    'COHAHV': Union[Variation_482, Variation_482_Arg],
}, total=False)
class Variation_483(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('HA', Variation_477),
        ('SDHA', Variation_480),
        ('COHAHP', Variation_481),
        ('COHAHV', Variation_482),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'HA': ('Horizontal Acceleration Vector', Variation_477, 0x80),
        'SDHA': ('Horizontal Acceleration Precision', Variation_480, 0x40),
        'COHAHP': ('Correlation of Horizontal Acceleration and Horizontal Position', Variation_481, 0x20),
        'COHAHV': ('Correlation of Horizontal Acceleration and Horizontal Velocity', Variation_482, 0x10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['HA']) -> Type[Variation_477]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDHA']) -> Type[Variation_480]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAHP']) -> Type[Variation_481]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COHAHV']) -> Type[Variation_482]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['HA'], Literal['SDHA'], Literal['COHAHP'], Literal['COHAHV']]) -> Union[Type['Variation_477'], Type['Variation_480'], Type['Variation_481'], Type['Variation_482']]:
        if key == 'HA':
            return Variation_477
        if key == 'SDHA':
            return Variation_480
        if key == 'COHAHP':
            return Variation_481
        if key == 'COHAHV':
            return Variation_482
        assert_never(key)

    def __init__(self, arg : Optional[Variation_483_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['HA'], val : Union[Variation_477, Variation_477_Arg]) -> 'Variation_483':
        ...

    @overload
    def set_item(self, name : Literal['SDHA'], val : Union[Variation_480, Variation_480_Arg]) -> 'Variation_483':
        ...

    @overload
    def set_item(self, name : Literal['COHAHP'], val : Union[Variation_481, Variation_481_Arg]) -> 'Variation_483':
        ...

    @overload
    def set_item(self, name : Literal['COHAHV'], val : Union[Variation_482, Variation_482_Arg]) -> 'Variation_483':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['HA']) -> 'Variation_483':
        ...

    @overload
    def del_item(self, name : Literal['SDHA']) -> 'Variation_483':
        ...

    @overload
    def del_item(self, name : Literal['COHAHP']) -> 'Variation_483':
        ...

    @overload
    def del_item(self, name : Literal['COHAHV']) -> 'Variation_483':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['HA']) -> Variation_477:
        ...

    @overload
    def get_item(self, name : Literal['SDHA']) -> Variation_480:
        ...

    @overload
    def get_item(self, name : Literal['COHAHP']) -> Variation_481:
        ...

    @overload
    def get_item(self, name : Literal['COHAHV']) -> Variation_482:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['HA'], f : Any) -> 'Variation_483':
        ...

    @overload
    def modify_item(self, name : Literal['SDHA'], f : Any) -> 'Variation_483':
        ...

    @overload
    def modify_item(self, name : Literal['COHAHP'], f : Any) -> 'Variation_483':
        ...

    @overload
    def modify_item(self, name : Literal['COHAHV'], f : Any) -> 'Variation_483':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_484_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_484(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Signed', 1.0e-2, 'm/s')

    def __init__(self, arg : Variation_484_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_485_Arg_Group = TypedDict('Variation_485_Arg_Group', {
    'SDVV': Union[Variation_470, Variation_470_Arg],
    'COVVGH': Union[Variation_454, Variation_454_Arg],
})
Variation_485_Arg : TypeAlias = Union[Raw, Variation_485_Arg_Group]
class Variation_485(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('SDVV', Variation_470),
        ('COVVGH', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SDVV': ('', Variation_470, 0, 16),
        'COVVGH': ('', Variation_454, 16, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SDVV']) -> Type[Variation_470]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVVGH']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SDVV'], Literal['COVVGH']]) -> Union[Type['Variation_470'], Type['Variation_454']]:
        if key == 'SDVV':
            return Variation_470
        if key == 'COVVGH':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_485_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SDVV']) -> Variation_470:
        ...

    @overload
    def get_item(self, name : Literal['COVVGH']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['SDVV'], Literal['COVVGH']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SDVV'], val : Union[Variation_470, Variation_470_Arg]) -> 'Variation_485':
        ...

    @overload
    def set_item(self, name : Literal['COVVGH'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_485':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SDVV'], f : Any) -> 'Variation_485':
        ...

    @overload
    def modify_item(self, name : Literal['COVVGH'], f : Any) -> 'Variation_485':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_486_Arg = TypedDict('Variation_486_Arg', {
    'VV': Union[Variation_484, Variation_484_Arg],
    'RSVV': Union[Variation_470, Variation_470_Arg],
    'SDVV': Union[Variation_485, Variation_485_Arg],
    'COVVHP': Union[Variation_465, Variation_465_Arg],
    'COVVHV': Union[Variation_465, Variation_465_Arg],
    'COVVHA': Union[Variation_465, Variation_465_Arg],
}, total=False)
class Variation_486(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('VV', Variation_484),
        ('RSVV', Variation_470),
        ('SDVV', Variation_485),
        ('COVVHP', Variation_465),
        ('COVVHV', Variation_465),
        ('COVVHA', Variation_465),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'VV': ('Vertical Velocity', Variation_484, 0x80),
        'RSVV': ('Vertical Velocity Resolution', Variation_470, 0x40),
        'SDVV': ('Vertical Velocity Precision', Variation_485, 0x20),
        'COVVHP': ('Correlation of Vertical Velocity and Horizontal Position', Variation_465, 0x10),
        'COVVHV': ('Correlation of Vertical Velocity and Horizontal Velocity', Variation_465, 0x08),
        'COVVHA': ('Correlation of Vertical Velocity and Horizontal Acceleration', Variation_465, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VV']) -> Type[Variation_484]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSVV']) -> Type[Variation_470]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDVV']) -> Type[Variation_485]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVVHP']) -> Type[Variation_465]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVVHV']) -> Type[Variation_465]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVVHA']) -> Type[Variation_465]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VV'], Literal['RSVV'], Literal['SDVV'], Literal['COVVHP'], Literal['COVVHV'], Literal['COVVHA']]) -> Union[Type['Variation_484'], Type['Variation_470'], Type['Variation_485'], Type['Variation_465'], Type['Variation_465'], Type['Variation_465']]:
        if key == 'VV':
            return Variation_484
        if key == 'RSVV':
            return Variation_470
        if key == 'SDVV':
            return Variation_485
        if key == 'COVVHP':
            return Variation_465
        if key == 'COVVHV':
            return Variation_465
        if key == 'COVVHA':
            return Variation_465
        assert_never(key)

    def __init__(self, arg : Optional[Variation_486_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['VV'], val : Union[Variation_484, Variation_484_Arg]) -> 'Variation_486':
        ...

    @overload
    def set_item(self, name : Literal['RSVV'], val : Union[Variation_470, Variation_470_Arg]) -> 'Variation_486':
        ...

    @overload
    def set_item(self, name : Literal['SDVV'], val : Union[Variation_485, Variation_485_Arg]) -> 'Variation_486':
        ...

    @overload
    def set_item(self, name : Literal['COVVHP'], val : Union[Variation_465, Variation_465_Arg]) -> 'Variation_486':
        ...

    @overload
    def set_item(self, name : Literal['COVVHV'], val : Union[Variation_465, Variation_465_Arg]) -> 'Variation_486':
        ...

    @overload
    def set_item(self, name : Literal['COVVHA'], val : Union[Variation_465, Variation_465_Arg]) -> 'Variation_486':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['VV']) -> 'Variation_486':
        ...

    @overload
    def del_item(self, name : Literal['RSVV']) -> 'Variation_486':
        ...

    @overload
    def del_item(self, name : Literal['SDVV']) -> 'Variation_486':
        ...

    @overload
    def del_item(self, name : Literal['COVVHP']) -> 'Variation_486':
        ...

    @overload
    def del_item(self, name : Literal['COVVHV']) -> 'Variation_486':
        ...

    @overload
    def del_item(self, name : Literal['COVVHA']) -> 'Variation_486':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['VV']) -> Variation_484:
        ...

    @overload
    def get_item(self, name : Literal['RSVV']) -> Variation_470:
        ...

    @overload
    def get_item(self, name : Literal['SDVV']) -> Variation_485:
        ...

    @overload
    def get_item(self, name : Literal['COVVHP']) -> Variation_465:
        ...

    @overload
    def get_item(self, name : Literal['COVVHV']) -> Variation_465:
        ...

    @overload
    def get_item(self, name : Literal['COVVHA']) -> Variation_465:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['VV'], f : Any) -> 'Variation_486':
        ...

    @overload
    def modify_item(self, name : Literal['RSVV'], f : Any) -> 'Variation_486':
        ...

    @overload
    def modify_item(self, name : Literal['SDVV'], f : Any) -> 'Variation_486':
        ...

    @overload
    def modify_item(self, name : Literal['COVVHP'], f : Any) -> 'Variation_486':
        ...

    @overload
    def modify_item(self, name : Literal['COVVHV'], f : Any) -> 'Variation_486':
        ...

    @overload
    def modify_item(self, name : Literal['COVVHA'], f : Any) -> 'Variation_486':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_487_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_487(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 1.0e-2, 'm/s²')

    def __init__(self, arg : Variation_487_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_488_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_488(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0e-2, 'm/s²')

    def __init__(self, arg : Variation_488_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_489_Arg_Group = TypedDict('Variation_489_Arg_Group', {
    'SDVA': Union[Variation_488, Variation_488_Arg],
    'COVAGH': Union[Variation_454, Variation_454_Arg],
    'COVAVV': Union[Variation_454, Variation_454_Arg],
})
Variation_489_Arg : TypeAlias = Union[Raw, Variation_489_Arg_Group]
class Variation_489(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('SDVA', Variation_488),
        ('COVAGH', Variation_454),
        ('COVAVV', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SDVA': ('', Variation_488, 0, 16),
        'COVAGH': ('', Variation_454, 16, 8),
        'COVAVV': ('', Variation_454, 24, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SDVA']) -> Type[Variation_488]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVAGH']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVAVV']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SDVA'], Literal['COVAGH'], Literal['COVAVV']]) -> Union[Type['Variation_488'], Type['Variation_454'], Type['Variation_454']]:
        if key == 'SDVA':
            return Variation_488
        if key == 'COVAGH':
            return Variation_454
        if key == 'COVAVV':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_489_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SDVA']) -> Variation_488:
        ...

    @overload
    def get_item(self, name : Literal['COVAGH']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['COVAVV']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['SDVA'], Literal['COVAGH'], Literal['COVAVV']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SDVA'], val : Union[Variation_488, Variation_488_Arg]) -> 'Variation_489':
        ...

    @overload
    def set_item(self, name : Literal['COVAGH'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_489':
        ...

    @overload
    def set_item(self, name : Literal['COVAVV'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_489':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SDVA'], f : Any) -> 'Variation_489':
        ...

    @overload
    def modify_item(self, name : Literal['COVAGH'], f : Any) -> 'Variation_489':
        ...

    @overload
    def modify_item(self, name : Literal['COVAVV'], f : Any) -> 'Variation_489':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_490_Arg = TypedDict('Variation_490_Arg', {
    'VA': Union[Variation_487, Variation_487_Arg],
    'RSVA': Union[Variation_489, Variation_489_Arg],
    'COVAHP': Union[Variation_465, Variation_465_Arg],
    'COVAHV': Union[Variation_465, Variation_465_Arg],
    'COVAHA': Union[Variation_465, Variation_465_Arg],
}, total=False)
class Variation_490(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('VA', Variation_487),
        ('RSVA', Variation_489),
        ('COVAHP', Variation_465),
        ('COVAHV', Variation_465),
        ('COVAHA', Variation_465),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'VA': ('Vertical Acceleration', Variation_487, 0x80),
        'RSVA': ('Vertical Acceleration Precision', Variation_489, 0x40),
        'COVAHP': ('Correlation of Vertical Acceleration and Horizontal Position', Variation_465, 0x20),
        'COVAHV': ('Correlation of Vertical Acceleration and Horizontal Velocity', Variation_465, 0x10),
        'COVAHA': ('Correlation of Vertical Acceleration and Horizontal Acceleration', Variation_465, 0x08),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VA']) -> Type[Variation_487]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSVA']) -> Type[Variation_489]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVAHP']) -> Type[Variation_465]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVAHV']) -> Type[Variation_465]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVAHA']) -> Type[Variation_465]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VA'], Literal['RSVA'], Literal['COVAHP'], Literal['COVAHV'], Literal['COVAHA']]) -> Union[Type['Variation_487'], Type['Variation_489'], Type['Variation_465'], Type['Variation_465'], Type['Variation_465']]:
        if key == 'VA':
            return Variation_487
        if key == 'RSVA':
            return Variation_489
        if key == 'COVAHP':
            return Variation_465
        if key == 'COVAHV':
            return Variation_465
        if key == 'COVAHA':
            return Variation_465
        assert_never(key)

    def __init__(self, arg : Optional[Variation_490_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['VA'], val : Union[Variation_487, Variation_487_Arg]) -> 'Variation_490':
        ...

    @overload
    def set_item(self, name : Literal['RSVA'], val : Union[Variation_489, Variation_489_Arg]) -> 'Variation_490':
        ...

    @overload
    def set_item(self, name : Literal['COVAHP'], val : Union[Variation_465, Variation_465_Arg]) -> 'Variation_490':
        ...

    @overload
    def set_item(self, name : Literal['COVAHV'], val : Union[Variation_465, Variation_465_Arg]) -> 'Variation_490':
        ...

    @overload
    def set_item(self, name : Literal['COVAHA'], val : Union[Variation_465, Variation_465_Arg]) -> 'Variation_490':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['VA']) -> 'Variation_490':
        ...

    @overload
    def del_item(self, name : Literal['RSVA']) -> 'Variation_490':
        ...

    @overload
    def del_item(self, name : Literal['COVAHP']) -> 'Variation_490':
        ...

    @overload
    def del_item(self, name : Literal['COVAHV']) -> 'Variation_490':
        ...

    @overload
    def del_item(self, name : Literal['COVAHA']) -> 'Variation_490':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['VA']) -> Variation_487:
        ...

    @overload
    def get_item(self, name : Literal['RSVA']) -> Variation_489:
        ...

    @overload
    def get_item(self, name : Literal['COVAHP']) -> Variation_465:
        ...

    @overload
    def get_item(self, name : Literal['COVAHV']) -> Variation_465:
        ...

    @overload
    def get_item(self, name : Literal['COVAHA']) -> Variation_465:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['VA'], f : Any) -> 'Variation_490':
        ...

    @overload
    def modify_item(self, name : Literal['RSVA'], f : Any) -> 'Variation_490':
        ...

    @overload
    def modify_item(self, name : Literal['COVAHP'], f : Any) -> 'Variation_490':
        ...

    @overload
    def modify_item(self, name : Literal['COVAHV'], f : Any) -> 'Variation_490':
        ...

    @overload
    def modify_item(self, name : Literal['COVAHA'], f : Any) -> 'Variation_490':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_491_Arg : TypeAlias = Raw
class Variation_491(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 40

    def __init__(self, arg : Variation_491_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_492_Arg : TypeAlias = Union[Variation_491, Variation_491_Arg]
class Variation_492(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 40
    variation_type = Variation_491

    @classmethod
    def spec(cls) -> Type[Variation_491]:
        return Variation_491

    def __init__(self, arg : List[Union[Variation_491, Variation_491_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_491, Variation_491_Arg]) -> 'Variation_492':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_491, Variation_491_Arg]) -> 'Variation_492':
        return self._prepend_item(arg) # type: ignore

Variation_493_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_493(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Signed', 0.1, 'm')

    def __init__(self, arg : Variation_493_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_494_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_494(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Unsigned', 0.1, 'm')

    def __init__(self, arg : Variation_494_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_495_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_495(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Signed', 0.1, 'm/s')

    def __init__(self, arg : Variation_495_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_496_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_496(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Unsigned', 0.1, 'm/s')

    def __init__(self, arg : Variation_496_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_497_Arg_Group = TypedDict('Variation_497_Arg_Group', {
    'SDRR': Union[Variation_496, Variation_496_Arg],
    'CORRR': Union[Variation_454, Variation_454_Arg],
})
Variation_497_Arg : TypeAlias = Union[Raw, Variation_497_Arg_Group]
class Variation_497(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('SDRR', Variation_496),
        ('CORRR', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SDRR': ('', Variation_496, 0, 24),
        'CORRR': ('', Variation_454, 24, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SDRR']) -> Type[Variation_496]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CORRR']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SDRR'], Literal['CORRR']]) -> Union[Type['Variation_496'], Type['Variation_454']]:
        if key == 'SDRR':
            return Variation_496
        if key == 'CORRR':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_497_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SDRR']) -> Variation_496:
        ...

    @overload
    def get_item(self, name : Literal['CORRR']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['SDRR'], Literal['CORRR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SDRR'], val : Union[Variation_496, Variation_496_Arg]) -> 'Variation_497':
        ...

    @overload
    def set_item(self, name : Literal['CORRR'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_497':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SDRR'], f : Any) -> 'Variation_497':
        ...

    @overload
    def modify_item(self, name : Literal['CORRR'], f : Any) -> 'Variation_497':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_498_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_498(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 1.5625e-2, 'm/s²')

    def __init__(self, arg : Variation_498_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_499_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_499(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 7.8125e-3, 'm/s²')

    def __init__(self, arg : Variation_499_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_500_Arg_Group = TypedDict('Variation_500_Arg_Group', {
    'SDRA': Union[Variation_499, Variation_499_Arg],
    'CORAR': Union[Variation_454, Variation_454_Arg],
    'CORARR': Union[Variation_454, Variation_454_Arg],
})
Variation_500_Arg : TypeAlias = Union[Raw, Variation_500_Arg_Group]
class Variation_500(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('SDRA', Variation_499),
        ('CORAR', Variation_454),
        ('CORARR', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SDRA': ('', Variation_499, 0, 16),
        'CORAR': ('', Variation_454, 16, 8),
        'CORARR': ('', Variation_454, 24, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SDRA']) -> Type[Variation_499]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CORAR']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CORARR']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SDRA'], Literal['CORAR'], Literal['CORARR']]) -> Union[Type['Variation_499'], Type['Variation_454'], Type['Variation_454']]:
        if key == 'SDRA':
            return Variation_499
        if key == 'CORAR':
            return Variation_454
        if key == 'CORARR':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_500_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SDRA']) -> Variation_499:
        ...

    @overload
    def get_item(self, name : Literal['CORAR']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['CORARR']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['SDRA'], Literal['CORAR'], Literal['CORARR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SDRA'], val : Union[Variation_499, Variation_499_Arg]) -> 'Variation_500':
        ...

    @overload
    def set_item(self, name : Literal['CORAR'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_500':
        ...

    @overload
    def set_item(self, name : Literal['CORARR'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_500':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SDRA'], f : Any) -> 'Variation_500':
        ...

    @overload
    def modify_item(self, name : Literal['CORAR'], f : Any) -> 'Variation_500':
        ...

    @overload
    def modify_item(self, name : Literal['CORARR'], f : Any) -> 'Variation_500':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_501_Arg = TypedDict('Variation_501_Arg', {
    'R': Union[Variation_493, Variation_493_Arg],
    'RSR': Union[Variation_494, Variation_494_Arg],
    'SDR': Union[Variation_494, Variation_494_Arg],
    'RR': Union[Variation_495, Variation_495_Arg],
    'RSRR': Union[Variation_496, Variation_496_Arg],
    'SDRR': Union[Variation_497, Variation_497_Arg],
    'RA': Union[Variation_498, Variation_498_Arg],
    'SDRA': Union[Variation_500, Variation_500_Arg],
}, total=False)
class Variation_501(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('R', Variation_493),
        ('RSR', Variation_494),
        ('SDR', Variation_494),
        ('RR', Variation_495),
        ('RSRR', Variation_496),
        ('SDRR', Variation_497),
        ('RA', Variation_498),
        ('SDRA', Variation_500),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'R': ('Range', Variation_493, 0x8000),
        'RSR': ('Range Resolution', Variation_494, 0x4000),
        'SDR': ('Range Precision', Variation_494, 0x2000),
        'RR': ('Range Rate', Variation_495, 0x1000),
        'RSRR': ('Range Rate Resolution', Variation_496, 0x0800),
        'SDRR': ('Range Rate Precision', Variation_497, 0x0400),
        'RA': ('Range Acceleration', Variation_498, 0x0200),
        'SDRA': ('Range Acceleration Precision', Variation_500, 0x0180),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['R']) -> Type[Variation_493]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSR']) -> Type[Variation_494]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDR']) -> Type[Variation_494]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RR']) -> Type[Variation_495]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSRR']) -> Type[Variation_496]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDRR']) -> Type[Variation_497]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RA']) -> Type[Variation_498]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDRA']) -> Type[Variation_500]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['R'], Literal['RSR'], Literal['SDR'], Literal['RR'], Literal['RSRR'], Literal['SDRR'], Literal['RA'], Literal['SDRA']]) -> Union[Type['Variation_493'], Type['Variation_494'], Type['Variation_494'], Type['Variation_495'], Type['Variation_496'], Type['Variation_497'], Type['Variation_498'], Type['Variation_500']]:
        if key == 'R':
            return Variation_493
        if key == 'RSR':
            return Variation_494
        if key == 'SDR':
            return Variation_494
        if key == 'RR':
            return Variation_495
        if key == 'RSRR':
            return Variation_496
        if key == 'SDRR':
            return Variation_497
        if key == 'RA':
            return Variation_498
        if key == 'SDRA':
            return Variation_500
        assert_never(key)

    def __init__(self, arg : Optional[Variation_501_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['R'], val : Union[Variation_493, Variation_493_Arg]) -> 'Variation_501':
        ...

    @overload
    def set_item(self, name : Literal['RSR'], val : Union[Variation_494, Variation_494_Arg]) -> 'Variation_501':
        ...

    @overload
    def set_item(self, name : Literal['SDR'], val : Union[Variation_494, Variation_494_Arg]) -> 'Variation_501':
        ...

    @overload
    def set_item(self, name : Literal['RR'], val : Union[Variation_495, Variation_495_Arg]) -> 'Variation_501':
        ...

    @overload
    def set_item(self, name : Literal['RSRR'], val : Union[Variation_496, Variation_496_Arg]) -> 'Variation_501':
        ...

    @overload
    def set_item(self, name : Literal['SDRR'], val : Union[Variation_497, Variation_497_Arg]) -> 'Variation_501':
        ...

    @overload
    def set_item(self, name : Literal['RA'], val : Union[Variation_498, Variation_498_Arg]) -> 'Variation_501':
        ...

    @overload
    def set_item(self, name : Literal['SDRA'], val : Union[Variation_500, Variation_500_Arg]) -> 'Variation_501':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['R']) -> 'Variation_501':
        ...

    @overload
    def del_item(self, name : Literal['RSR']) -> 'Variation_501':
        ...

    @overload
    def del_item(self, name : Literal['SDR']) -> 'Variation_501':
        ...

    @overload
    def del_item(self, name : Literal['RR']) -> 'Variation_501':
        ...

    @overload
    def del_item(self, name : Literal['RSRR']) -> 'Variation_501':
        ...

    @overload
    def del_item(self, name : Literal['SDRR']) -> 'Variation_501':
        ...

    @overload
    def del_item(self, name : Literal['RA']) -> 'Variation_501':
        ...

    @overload
    def del_item(self, name : Literal['SDRA']) -> 'Variation_501':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['R']) -> Variation_493:
        ...

    @overload
    def get_item(self, name : Literal['RSR']) -> Variation_494:
        ...

    @overload
    def get_item(self, name : Literal['SDR']) -> Variation_494:
        ...

    @overload
    def get_item(self, name : Literal['RR']) -> Variation_495:
        ...

    @overload
    def get_item(self, name : Literal['RSRR']) -> Variation_496:
        ...

    @overload
    def get_item(self, name : Literal['SDRR']) -> Variation_497:
        ...

    @overload
    def get_item(self, name : Literal['RA']) -> Variation_498:
        ...

    @overload
    def get_item(self, name : Literal['SDRA']) -> Variation_500:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['R'], f : Any) -> 'Variation_501':
        ...

    @overload
    def modify_item(self, name : Literal['RSR'], f : Any) -> 'Variation_501':
        ...

    @overload
    def modify_item(self, name : Literal['SDR'], f : Any) -> 'Variation_501':
        ...

    @overload
    def modify_item(self, name : Literal['RR'], f : Any) -> 'Variation_501':
        ...

    @overload
    def modify_item(self, name : Literal['RSRR'], f : Any) -> 'Variation_501':
        ...

    @overload
    def modify_item(self, name : Literal['SDRR'], f : Any) -> 'Variation_501':
        ...

    @overload
    def modify_item(self, name : Literal['RA'], f : Any) -> 'Variation_501':
        ...

    @overload
    def modify_item(self, name : Literal['SDRA'], f : Any) -> 'Variation_501':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_502_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_502(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.5625e-2, 'm/s')

    def __init__(self, arg : Variation_502_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_503_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_503(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.5625e-2, 'm/s²')

    def __init__(self, arg : Variation_503_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_504_Arg_Group = TypedDict('Variation_504_Arg_Group', {
    'SDDA': Union[Variation_503, Variation_503_Arg],
    'CODADV': Union[Variation_454, Variation_454_Arg],
})
Variation_504_Arg : TypeAlias = Union[Raw, Variation_504_Arg_Group]
class Variation_504(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('SDDA', Variation_503),
        ('CODADV', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SDDA': ('', Variation_503, 0, 16),
        'CODADV': ('', Variation_454, 16, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SDDA']) -> Type[Variation_503]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CODADV']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SDDA'], Literal['CODADV']]) -> Union[Type['Variation_503'], Type['Variation_454']]:
        if key == 'SDDA':
            return Variation_503
        if key == 'CODADV':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_504_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SDDA']) -> Variation_503:
        ...

    @overload
    def get_item(self, name : Literal['CODADV']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['SDDA'], Literal['CODADV']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SDDA'], val : Union[Variation_503, Variation_503_Arg]) -> 'Variation_504':
        ...

    @overload
    def set_item(self, name : Literal['CODADV'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_504':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SDDA'], f : Any) -> 'Variation_504':
        ...

    @overload
    def modify_item(self, name : Literal['CODADV'], f : Any) -> 'Variation_504':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_505_Arg = TypedDict('Variation_505_Arg', {
    'DV': Union[Variation_484, Variation_484_Arg],
    'SDDV': Union[Variation_502, Variation_502_Arg],
    'DA': Union[Variation_498, Variation_498_Arg],
    'SDDA': Union[Variation_504, Variation_504_Arg],
    'CODVR': Union[Variation_454, Variation_454_Arg],
    'CODVRR': Union[Variation_454, Variation_454_Arg],
    'CODVRA': Union[Variation_454, Variation_454_Arg],
    'CODAR': Union[Variation_454, Variation_454_Arg],
    'CODARR': Union[Variation_454, Variation_454_Arg],
    'CODARA': Union[Variation_454, Variation_454_Arg],
}, total=False)
class Variation_505(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('DV', Variation_484),
        ('SDDV', Variation_502),
        ('DA', Variation_498),
        ('SDDA', Variation_504),
        ('CODVR', Variation_454),
        ('CODVRR', Variation_454),
        ('CODVRA', Variation_454),
        ('CODAR', Variation_454),
        ('CODARR', Variation_454),
        ('CODARA', Variation_454),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'DV': ('Doppler Velocity', Variation_484, 0x8000),
        'SDDV': ('Precision of Doppler Velocity', Variation_502, 0x4000),
        'DA': ('Doppler Acceleration', Variation_498, 0x2000),
        'SDDA': ('Precision of Doppler Acceleration', Variation_504, 0x1000),
        'CODVR': ('Correlation of Doppler Velocity and Range', Variation_454, 0x0800),
        'CODVRR': ('Correlation of Doppler Velocity and Range Rate', Variation_454, 0x0400),
        'CODVRA': ('Correlation of Doppler Velocity and Range Acceleration', Variation_454, 0x0200),
        'CODAR': ('Correlation of Doppler Acceleration and Range', Variation_454, 0x0180),
        'CODARR': ('Correlation of Doppler Acceleration and Range Rate', Variation_454, 0x0140),
        'CODARA': ('Correlation of Doppler Acceleration and Range Acceleration', Variation_454, 0x0120),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['DV']) -> Type[Variation_484]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDDV']) -> Type[Variation_502]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DA']) -> Type[Variation_498]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDDA']) -> Type[Variation_504]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CODVR']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CODVRR']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CODVRA']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CODAR']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CODARR']) -> Type[Variation_454]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CODARA']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['DV'], Literal['SDDV'], Literal['DA'], Literal['SDDA'], Literal['CODVR'], Literal['CODVRR'], Literal['CODVRA'], Literal['CODAR'], Literal['CODARR'], Literal['CODARA']]) -> Union[Type['Variation_484'], Type['Variation_502'], Type['Variation_498'], Type['Variation_504'], Type['Variation_454'], Type['Variation_454'], Type['Variation_454'], Type['Variation_454'], Type['Variation_454'], Type['Variation_454']]:
        if key == 'DV':
            return Variation_484
        if key == 'SDDV':
            return Variation_502
        if key == 'DA':
            return Variation_498
        if key == 'SDDA':
            return Variation_504
        if key == 'CODVR':
            return Variation_454
        if key == 'CODVRR':
            return Variation_454
        if key == 'CODVRA':
            return Variation_454
        if key == 'CODAR':
            return Variation_454
        if key == 'CODARR':
            return Variation_454
        if key == 'CODARA':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Optional[Variation_505_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['DV'], val : Union[Variation_484, Variation_484_Arg]) -> 'Variation_505':
        ...

    @overload
    def set_item(self, name : Literal['SDDV'], val : Union[Variation_502, Variation_502_Arg]) -> 'Variation_505':
        ...

    @overload
    def set_item(self, name : Literal['DA'], val : Union[Variation_498, Variation_498_Arg]) -> 'Variation_505':
        ...

    @overload
    def set_item(self, name : Literal['SDDA'], val : Union[Variation_504, Variation_504_Arg]) -> 'Variation_505':
        ...

    @overload
    def set_item(self, name : Literal['CODVR'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_505':
        ...

    @overload
    def set_item(self, name : Literal['CODVRR'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_505':
        ...

    @overload
    def set_item(self, name : Literal['CODVRA'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_505':
        ...

    @overload
    def set_item(self, name : Literal['CODAR'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_505':
        ...

    @overload
    def set_item(self, name : Literal['CODARR'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_505':
        ...

    @overload
    def set_item(self, name : Literal['CODARA'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_505':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['DV']) -> 'Variation_505':
        ...

    @overload
    def del_item(self, name : Literal['SDDV']) -> 'Variation_505':
        ...

    @overload
    def del_item(self, name : Literal['DA']) -> 'Variation_505':
        ...

    @overload
    def del_item(self, name : Literal['SDDA']) -> 'Variation_505':
        ...

    @overload
    def del_item(self, name : Literal['CODVR']) -> 'Variation_505':
        ...

    @overload
    def del_item(self, name : Literal['CODVRR']) -> 'Variation_505':
        ...

    @overload
    def del_item(self, name : Literal['CODVRA']) -> 'Variation_505':
        ...

    @overload
    def del_item(self, name : Literal['CODAR']) -> 'Variation_505':
        ...

    @overload
    def del_item(self, name : Literal['CODARR']) -> 'Variation_505':
        ...

    @overload
    def del_item(self, name : Literal['CODARA']) -> 'Variation_505':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['DV']) -> Variation_484:
        ...

    @overload
    def get_item(self, name : Literal['SDDV']) -> Variation_502:
        ...

    @overload
    def get_item(self, name : Literal['DA']) -> Variation_498:
        ...

    @overload
    def get_item(self, name : Literal['SDDA']) -> Variation_504:
        ...

    @overload
    def get_item(self, name : Literal['CODVR']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['CODVRR']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['CODVRA']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['CODAR']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['CODARR']) -> Variation_454:
        ...

    @overload
    def get_item(self, name : Literal['CODARA']) -> Variation_454:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['DV'], f : Any) -> 'Variation_505':
        ...

    @overload
    def modify_item(self, name : Literal['SDDV'], f : Any) -> 'Variation_505':
        ...

    @overload
    def modify_item(self, name : Literal['DA'], f : Any) -> 'Variation_505':
        ...

    @overload
    def modify_item(self, name : Literal['SDDA'], f : Any) -> 'Variation_505':
        ...

    @overload
    def modify_item(self, name : Literal['CODVR'], f : Any) -> 'Variation_505':
        ...

    @overload
    def modify_item(self, name : Literal['CODVRR'], f : Any) -> 'Variation_505':
        ...

    @overload
    def modify_item(self, name : Literal['CODVRA'], f : Any) -> 'Variation_505':
        ...

    @overload
    def modify_item(self, name : Literal['CODAR'], f : Any) -> 'Variation_505':
        ...

    @overload
    def modify_item(self, name : Literal['CODARR'], f : Any) -> 'Variation_505':
        ...

    @overload
    def modify_item(self, name : Literal['CODARA'], f : Any) -> 'Variation_505':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_506_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_506(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 6.866455078125e-4, '°')

    def __init__(self, arg : Variation_506_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_507_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_507(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 2.74658203125e-3, '°')

    def __init__(self, arg : Variation_507_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_508_Arg_Group = TypedDict('Variation_508_Arg_Group', {
    'SDAZR': Union[Variation_506, Variation_506_Arg],
    'COAZRAZ': Union[Variation_454, Variation_454_Arg],
})
Variation_508_Arg : TypeAlias = Union[Raw, Variation_508_Arg_Group]
class Variation_508(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('SDAZR', Variation_506),
        ('COAZRAZ', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SDAZR': ('', Variation_506, 0, 16),
        'COAZRAZ': ('', Variation_454, 16, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SDAZR']) -> Type[Variation_506]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COAZRAZ']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SDAZR'], Literal['COAZRAZ']]) -> Union[Type['Variation_506'], Type['Variation_454']]:
        if key == 'SDAZR':
            return Variation_506
        if key == 'COAZRAZ':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_508_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SDAZR']) -> Variation_506:
        ...

    @overload
    def get_item(self, name : Literal['COAZRAZ']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['SDAZR'], Literal['COAZRAZ']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SDAZR'], val : Union[Variation_506, Variation_506_Arg]) -> 'Variation_508':
        ...

    @overload
    def set_item(self, name : Literal['COAZRAZ'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_508':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SDAZR'], f : Any) -> 'Variation_508':
        ...

    @overload
    def modify_item(self, name : Literal['COAZRAZ'], f : Any) -> 'Variation_508':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_509_Arg_Group = TypedDict('Variation_509_Arg_Group', {
    'S': Union[Variation_14, Variation_14_Arg],
    'E': Union[Variation_14, Variation_14_Arg],
})
Variation_509_Arg : TypeAlias = Union[Raw, Variation_509_Arg_Group]
class Variation_509(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('S', Variation_14),
        ('E', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'S': ('', Variation_14, 0, 16),
        'E': ('', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['S']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['E']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['S'], Literal['E']]) -> Union[Type['Variation_14'], Type['Variation_14']]:
        if key == 'S':
            return Variation_14
        if key == 'E':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_509_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['S']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['E']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['S'], Literal['E']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['S'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_509':
        ...

    @overload
    def set_item(self, name : Literal['E'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_509':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['S'], f : Any) -> 'Variation_509':
        ...

    @overload
    def modify_item(self, name : Literal['E'], f : Any) -> 'Variation_509':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_510_Arg = TypedDict('Variation_510_Arg', {
    'AZ': Union[Variation_14, Variation_14_Arg],
    'RSAZ': Union[Variation_506, Variation_506_Arg],
    'SDASZ': Union[Variation_506, Variation_506_Arg],
    'AZR': Union[Variation_507, Variation_507_Arg],
    'SDAZR': Union[Variation_508, Variation_508_Arg],
    'AZEX': Union[Variation_509, Variation_509_Arg],
}, total=False)
class Variation_510(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('AZ', Variation_14),
        ('RSAZ', Variation_506),
        ('SDASZ', Variation_506),
        ('AZR', Variation_507),
        ('SDAZR', Variation_508),
        ('AZEX', Variation_509),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'AZ': ('Azimuth', Variation_14, 0x80),
        'RSAZ': ('Azimuth Resolution', Variation_506, 0x40),
        'SDASZ': ('Standard Deviation of Azimuth', Variation_506, 0x20),
        'AZR': ('Azimuth Rate', Variation_507, 0x10),
        'SDAZR': ('Standard Deviation of Azimuth Rate', Variation_508, 0x08),
        'AZEX': ('Azimuth Extent', Variation_509, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AZ']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSAZ']) -> Type[Variation_506]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDASZ']) -> Type[Variation_506]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AZR']) -> Type[Variation_507]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDAZR']) -> Type[Variation_508]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AZEX']) -> Type[Variation_509]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AZ'], Literal['RSAZ'], Literal['SDASZ'], Literal['AZR'], Literal['SDAZR'], Literal['AZEX']]) -> Union[Type['Variation_14'], Type['Variation_506'], Type['Variation_506'], Type['Variation_507'], Type['Variation_508'], Type['Variation_509']]:
        if key == 'AZ':
            return Variation_14
        if key == 'RSAZ':
            return Variation_506
        if key == 'SDASZ':
            return Variation_506
        if key == 'AZR':
            return Variation_507
        if key == 'SDAZR':
            return Variation_508
        if key == 'AZEX':
            return Variation_509
        assert_never(key)

    def __init__(self, arg : Optional[Variation_510_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['AZ'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_510':
        ...

    @overload
    def set_item(self, name : Literal['RSAZ'], val : Union[Variation_506, Variation_506_Arg]) -> 'Variation_510':
        ...

    @overload
    def set_item(self, name : Literal['SDASZ'], val : Union[Variation_506, Variation_506_Arg]) -> 'Variation_510':
        ...

    @overload
    def set_item(self, name : Literal['AZR'], val : Union[Variation_507, Variation_507_Arg]) -> 'Variation_510':
        ...

    @overload
    def set_item(self, name : Literal['SDAZR'], val : Union[Variation_508, Variation_508_Arg]) -> 'Variation_510':
        ...

    @overload
    def set_item(self, name : Literal['AZEX'], val : Union[Variation_509, Variation_509_Arg]) -> 'Variation_510':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['AZ']) -> 'Variation_510':
        ...

    @overload
    def del_item(self, name : Literal['RSAZ']) -> 'Variation_510':
        ...

    @overload
    def del_item(self, name : Literal['SDASZ']) -> 'Variation_510':
        ...

    @overload
    def del_item(self, name : Literal['AZR']) -> 'Variation_510':
        ...

    @overload
    def del_item(self, name : Literal['SDAZR']) -> 'Variation_510':
        ...

    @overload
    def del_item(self, name : Literal['AZEX']) -> 'Variation_510':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['AZ']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['RSAZ']) -> Variation_506:
        ...

    @overload
    def get_item(self, name : Literal['SDASZ']) -> Variation_506:
        ...

    @overload
    def get_item(self, name : Literal['AZR']) -> Variation_507:
        ...

    @overload
    def get_item(self, name : Literal['SDAZR']) -> Variation_508:
        ...

    @overload
    def get_item(self, name : Literal['AZEX']) -> Variation_509:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['AZ'], f : Any) -> 'Variation_510':
        ...

    @overload
    def modify_item(self, name : Literal['RSAZ'], f : Any) -> 'Variation_510':
        ...

    @overload
    def modify_item(self, name : Literal['SDASZ'], f : Any) -> 'Variation_510':
        ...

    @overload
    def modify_item(self, name : Literal['AZR'], f : Any) -> 'Variation_510':
        ...

    @overload
    def modify_item(self, name : Literal['SDAZR'], f : Any) -> 'Variation_510':
        ...

    @overload
    def modify_item(self, name : Literal['AZEX'], f : Any) -> 'Variation_510':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_511_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°/s']]]
class Variation_511(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 2.74658203125e-3, '°/s')

    def __init__(self, arg : Variation_511_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_512_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°/s']]]
class Variation_512(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 6.866455078125e-4, '°/s')

    def __init__(self, arg : Variation_512_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_513_Arg_Group = TypedDict('Variation_513_Arg_Group', {
    'SDELR': Union[Variation_512, Variation_512_Arg],
    'COELREL': Union[Variation_454, Variation_454_Arg],
})
Variation_513_Arg : TypeAlias = Union[Raw, Variation_513_Arg_Group]
class Variation_513(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('SDELR', Variation_512),
        ('COELREL', Variation_454),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SDELR': ('', Variation_512, 0, 16),
        'COELREL': ('', Variation_454, 16, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SDELR']) -> Type[Variation_512]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COELREL']) -> Type[Variation_454]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SDELR'], Literal['COELREL']]) -> Union[Type['Variation_512'], Type['Variation_454']]:
        if key == 'SDELR':
            return Variation_512
        if key == 'COELREL':
            return Variation_454
        assert_never(key)

    def __init__(self, arg : Variation_513_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SDELR']) -> Variation_512:
        ...

    @overload
    def get_item(self, name : Literal['COELREL']) -> Variation_454:
        ...

    def get_item(self, name : Union[Literal['SDELR'], Literal['COELREL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SDELR'], val : Union[Variation_512, Variation_512_Arg]) -> 'Variation_513':
        ...

    @overload
    def set_item(self, name : Literal['COELREL'], val : Union[Variation_454, Variation_454_Arg]) -> 'Variation_513':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SDELR'], f : Any) -> 'Variation_513':
        ...

    @overload
    def modify_item(self, name : Literal['COELREL'], f : Any) -> 'Variation_513':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_514_Arg_Group = TypedDict('Variation_514_Arg_Group', {
    'S': Union[Variation_507, Variation_507_Arg],
    'E': Union[Variation_507, Variation_507_Arg],
})
Variation_514_Arg : TypeAlias = Union[Raw, Variation_514_Arg_Group]
class Variation_514(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('S', Variation_507),
        ('E', Variation_507),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'S': ('', Variation_507, 0, 16),
        'E': ('', Variation_507, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['S']) -> Type[Variation_507]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['E']) -> Type[Variation_507]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['S'], Literal['E']]) -> Union[Type['Variation_507'], Type['Variation_507']]:
        if key == 'S':
            return Variation_507
        if key == 'E':
            return Variation_507
        assert_never(key)

    def __init__(self, arg : Variation_514_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['S']) -> Variation_507:
        ...

    @overload
    def get_item(self, name : Literal['E']) -> Variation_507:
        ...

    def get_item(self, name : Union[Literal['S'], Literal['E']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['S'], val : Union[Variation_507, Variation_507_Arg]) -> 'Variation_514':
        ...

    @overload
    def set_item(self, name : Literal['E'], val : Union[Variation_507, Variation_507_Arg]) -> 'Variation_514':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['S'], f : Any) -> 'Variation_514':
        ...

    @overload
    def modify_item(self, name : Literal['E'], f : Any) -> 'Variation_514':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_515_Arg = TypedDict('Variation_515_Arg', {
    'EL': Union[Variation_507, Variation_507_Arg],
    'RSEL': Union[Variation_506, Variation_506_Arg],
    'SDEL': Union[Variation_506, Variation_506_Arg],
    'ER': Union[Variation_511, Variation_511_Arg],
    'SDER': Union[Variation_513, Variation_513_Arg],
    'ELEX': Union[Variation_514, Variation_514_Arg],
}, total=False)
class Variation_515(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('EL', Variation_507),
        ('RSEL', Variation_506),
        ('SDEL', Variation_506),
        ('ER', Variation_511),
        ('SDER', Variation_513),
        ('ELEX', Variation_514),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'EL': ('Elevation', Variation_507, 0x80),
        'RSEL': ('Elevation Resolution', Variation_506, 0x40),
        'SDEL': ('Standard Deviation of Elevation', Variation_506, 0x20),
        'ER': ('Elevation Rate', Variation_511, 0x10),
        'SDER': ('Standard Deviation of Elevation Rate', Variation_513, 0x08),
        'ELEX': ('Elevation Extent', Variation_514, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EL']) -> Type[Variation_507]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSEL']) -> Type[Variation_506]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDEL']) -> Type[Variation_506]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ER']) -> Type[Variation_511]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDER']) -> Type[Variation_513]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ELEX']) -> Type[Variation_514]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EL'], Literal['RSEL'], Literal['SDEL'], Literal['ER'], Literal['SDER'], Literal['ELEX']]) -> Union[Type['Variation_507'], Type['Variation_506'], Type['Variation_506'], Type['Variation_511'], Type['Variation_513'], Type['Variation_514']]:
        if key == 'EL':
            return Variation_507
        if key == 'RSEL':
            return Variation_506
        if key == 'SDEL':
            return Variation_506
        if key == 'ER':
            return Variation_511
        if key == 'SDER':
            return Variation_513
        if key == 'ELEX':
            return Variation_514
        assert_never(key)

    def __init__(self, arg : Optional[Variation_515_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['EL'], val : Union[Variation_507, Variation_507_Arg]) -> 'Variation_515':
        ...

    @overload
    def set_item(self, name : Literal['RSEL'], val : Union[Variation_506, Variation_506_Arg]) -> 'Variation_515':
        ...

    @overload
    def set_item(self, name : Literal['SDEL'], val : Union[Variation_506, Variation_506_Arg]) -> 'Variation_515':
        ...

    @overload
    def set_item(self, name : Literal['ER'], val : Union[Variation_511, Variation_511_Arg]) -> 'Variation_515':
        ...

    @overload
    def set_item(self, name : Literal['SDER'], val : Union[Variation_513, Variation_513_Arg]) -> 'Variation_515':
        ...

    @overload
    def set_item(self, name : Literal['ELEX'], val : Union[Variation_514, Variation_514_Arg]) -> 'Variation_515':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['EL']) -> 'Variation_515':
        ...

    @overload
    def del_item(self, name : Literal['RSEL']) -> 'Variation_515':
        ...

    @overload
    def del_item(self, name : Literal['SDEL']) -> 'Variation_515':
        ...

    @overload
    def del_item(self, name : Literal['ER']) -> 'Variation_515':
        ...

    @overload
    def del_item(self, name : Literal['SDER']) -> 'Variation_515':
        ...

    @overload
    def del_item(self, name : Literal['ELEX']) -> 'Variation_515':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['EL']) -> Variation_507:
        ...

    @overload
    def get_item(self, name : Literal['RSEL']) -> Variation_506:
        ...

    @overload
    def get_item(self, name : Literal['SDEL']) -> Variation_506:
        ...

    @overload
    def get_item(self, name : Literal['ER']) -> Variation_511:
        ...

    @overload
    def get_item(self, name : Literal['SDER']) -> Variation_513:
        ...

    @overload
    def get_item(self, name : Literal['ELEX']) -> Variation_514:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['EL'], f : Any) -> 'Variation_515':
        ...

    @overload
    def modify_item(self, name : Literal['RSEL'], f : Any) -> 'Variation_515':
        ...

    @overload
    def modify_item(self, name : Literal['SDEL'], f : Any) -> 'Variation_515':
        ...

    @overload
    def modify_item(self, name : Literal['ER'], f : Any) -> 'Variation_515':
        ...

    @overload
    def modify_item(self, name : Literal['SDER'], f : Any) -> 'Variation_515':
        ...

    @overload
    def modify_item(self, name : Literal['ELEX'], f : Any) -> 'Variation_515':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_516_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['dB']]]
class Variation_516(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 1.0, 'dB')

    def __init__(self, arg : Variation_516_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_517_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['dB']]]
class Variation_517(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 9
    quantity = Quantity('Signed', 1.0, 'dB')

    def __init__(self, arg : Variation_517_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_518_Arg_Group = TypedDict('Variation_518_Arg_Group', {
    'RPP': Union[Variation_517, Variation_517_Arg],
})
Variation_518_Arg : TypeAlias = Union[Raw, Variation_518_Arg_Group]
class Variation_518(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 7),
        ('RPP', Variation_517),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RPP': ('', Variation_517, 7, 9),
    }


    @classmethod
    def spec(cls, key : Union[Literal['RPP']]) -> Union[Type['Variation_517']]:
        if key == 'RPP':
            return Variation_517
        assert_never(key)

    def __init__(self, arg : Variation_518_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['RPP']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['RPP'], val : Union[Variation_517, Variation_517_Arg]) -> 'Variation_518':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['RPP'], f : Any) -> 'Variation_518':
        return self._modify_item(name, f) # type: ignore

Variation_519_Arg = TypedDict('Variation_519_Arg', {
    'DPP': Union[Variation_516, Variation_516_Arg],
    'DPS': Union[Variation_516, Variation_516_Arg],
    'RPP': Union[Variation_518, Variation_518_Arg],
    'RPS': Union[Variation_516, Variation_516_Arg],
}, total=False)
class Variation_519(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('DPP', Variation_516),
        ('DPS', Variation_516),
        ('RPP', Variation_518),
        ('RPS', Variation_516),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'DPP': ('Direct Path - Power', Variation_516, 0x80),
        'DPS': ('Direct Path - Signal to Noise Ratio (SNR)', Variation_516, 0x40),
        'RPP': ('Reflected Path - Power', Variation_518, 0x20),
        'RPS': ('Reflected Path - Signal to Noise Ratio (SNR)', Variation_516, 0x10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['DPP']) -> Type[Variation_516]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DPS']) -> Type[Variation_516]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RPP']) -> Type[Variation_518]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RPS']) -> Type[Variation_516]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['DPP'], Literal['DPS'], Literal['RPP'], Literal['RPS']]) -> Union[Type['Variation_516'], Type['Variation_516'], Type['Variation_518'], Type['Variation_516']]:
        if key == 'DPP':
            return Variation_516
        if key == 'DPS':
            return Variation_516
        if key == 'RPP':
            return Variation_518
        if key == 'RPS':
            return Variation_516
        assert_never(key)

    def __init__(self, arg : Optional[Variation_519_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['DPP'], val : Union[Variation_516, Variation_516_Arg]) -> 'Variation_519':
        ...

    @overload
    def set_item(self, name : Literal['DPS'], val : Union[Variation_516, Variation_516_Arg]) -> 'Variation_519':
        ...

    @overload
    def set_item(self, name : Literal['RPP'], val : Union[Variation_518, Variation_518_Arg]) -> 'Variation_519':
        ...

    @overload
    def set_item(self, name : Literal['RPS'], val : Union[Variation_516, Variation_516_Arg]) -> 'Variation_519':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['DPP']) -> 'Variation_519':
        ...

    @overload
    def del_item(self, name : Literal['DPS']) -> 'Variation_519':
        ...

    @overload
    def del_item(self, name : Literal['RPP']) -> 'Variation_519':
        ...

    @overload
    def del_item(self, name : Literal['RPS']) -> 'Variation_519':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['DPP']) -> Variation_516:
        ...

    @overload
    def get_item(self, name : Literal['DPS']) -> Variation_516:
        ...

    @overload
    def get_item(self, name : Literal['RPP']) -> Variation_518:
        ...

    @overload
    def get_item(self, name : Literal['RPS']) -> Variation_516:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['DPP'], f : Any) -> 'Variation_519':
        ...

    @overload
    def modify_item(self, name : Literal['DPS'], f : Any) -> 'Variation_519':
        ...

    @overload
    def modify_item(self, name : Literal['RPP'], f : Any) -> 'Variation_519':
        ...

    @overload
    def modify_item(self, name : Literal['RPS'], f : Any) -> 'Variation_519':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_520_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_520(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 0.152587890625, 'm')

    def __init__(self, arg : Variation_520_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_521_Arg_Group = TypedDict('Variation_521_Arg_Group', {
    'AZCON': Union[Variation_14, Variation_14_Arg],
    'ELCON': Union[Variation_507, Variation_507_Arg],
    'RGCONSTOP': Union[Variation_520, Variation_520_Arg],
    'RGCONSTART': Union[Variation_520, Variation_520_Arg],
})
Variation_521_Arg : TypeAlias = Union[Raw, Variation_521_Arg_Group]
class Variation_521(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('AZCON', Variation_14),
        ('ELCON', Variation_507),
        ('RGCONSTOP', Variation_520),
        ('RGCONSTART', Variation_520),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'AZCON': ('', Variation_14, 0, 16),
        'ELCON': ('', Variation_507, 16, 16),
        'RGCONSTOP': ('', Variation_520, 32, 16),
        'RGCONSTART': ('', Variation_520, 48, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AZCON']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ELCON']) -> Type[Variation_507]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RGCONSTOP']) -> Type[Variation_520]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RGCONSTART']) -> Type[Variation_520]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AZCON'], Literal['ELCON'], Literal['RGCONSTOP'], Literal['RGCONSTART']]) -> Union[Type['Variation_14'], Type['Variation_507'], Type['Variation_520'], Type['Variation_520']]:
        if key == 'AZCON':
            return Variation_14
        if key == 'ELCON':
            return Variation_507
        if key == 'RGCONSTOP':
            return Variation_520
        if key == 'RGCONSTART':
            return Variation_520
        assert_never(key)

    def __init__(self, arg : Variation_521_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['AZCON']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['ELCON']) -> Variation_507:
        ...

    @overload
    def get_item(self, name : Literal['RGCONSTOP']) -> Variation_520:
        ...

    @overload
    def get_item(self, name : Literal['RGCONSTART']) -> Variation_520:
        ...

    def get_item(self, name : Union[Literal['AZCON'], Literal['ELCON'], Literal['RGCONSTOP'], Literal['RGCONSTART']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['AZCON'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_521':
        ...

    @overload
    def set_item(self, name : Literal['ELCON'], val : Union[Variation_507, Variation_507_Arg]) -> 'Variation_521':
        ...

    @overload
    def set_item(self, name : Literal['RGCONSTOP'], val : Union[Variation_520, Variation_520_Arg]) -> 'Variation_521':
        ...

    @overload
    def set_item(self, name : Literal['RGCONSTART'], val : Union[Variation_520, Variation_520_Arg]) -> 'Variation_521':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['AZCON'], f : Any) -> 'Variation_521':
        ...

    @overload
    def modify_item(self, name : Literal['ELCON'], f : Any) -> 'Variation_521':
        ...

    @overload
    def modify_item(self, name : Literal['RGCONSTOP'], f : Any) -> 'Variation_521':
        ...

    @overload
    def modify_item(self, name : Literal['RGCONSTART'], f : Any) -> 'Variation_521':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_522_Arg : TypeAlias = Union[Variation_521, Variation_521_Arg]
class Variation_522(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 64
    variation_type = Variation_521

    @classmethod
    def spec(cls) -> Type[Variation_521]:
        return Variation_521

    def __init__(self, arg : List[Union[Variation_521, Variation_521_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_521, Variation_521_Arg]) -> 'Variation_522':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_521, Variation_521_Arg]) -> 'Variation_522':
        return self._prepend_item(arg) # type: ignore

Variation_523_Arg = TypedDict('Variation_523_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_432, Variation_432_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '020': Union[Variation_436, Variation_436_Arg],
    '030': Union[Variation_24, Variation_24_Arg],
    '145': Union[Variation_80, Variation_80_Arg],
    '161': Union[Variation_64, Variation_64_Arg],
    '170': Union[Variation_443, Variation_443_Arg],
    '050': Union[Variation_445, Variation_445_Arg],
    '270': Union[Variation_447, Variation_447_Arg],
    '300': Union[Variation_451, Variation_451_Arg],
    '400': Union[Variation_452, Variation_452_Arg],
    '600': Union[Variation_458, Variation_458_Arg],
    '601': Union[Variation_466, Variation_466_Arg],
    '602': Union[Variation_474, Variation_474_Arg],
    '603': Union[Variation_483, Variation_483_Arg],
    '604': Union[Variation_486, Variation_486_Arg],
    '605': Union[Variation_490, Variation_490_Arg],
    '480': Union[Variation_492, Variation_492_Arg],
    '625': Union[Variation_501, Variation_501_Arg],
    '626': Union[Variation_505, Variation_505_Arg],
    '627': Union[Variation_510, Variation_510_Arg],
    '628': Union[Variation_515, Variation_515_Arg],
    '630': Union[Variation_519, Variation_519_Arg],
    '631': Union[Variation_522, Variation_522_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_523(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_432),
        ('015', Variation_0),
        ('020', Variation_436),
        ('030', Variation_24),
        ('145', Variation_80),
        ('161', Variation_64),
        ('170', Variation_443),
        ('050', Variation_445),
        ('270', Variation_447),
        ('300', Variation_451),
        ('400', Variation_452),
        ('600', Variation_458),
        ('601', Variation_466),
        ('602', Variation_474),
        ('603', Variation_483),
        ('604', Variation_486),
        ('605', Variation_490),
        ('480', Variation_492),
        ('625', Variation_501),
        ('626', Variation_505),
        ('627', Variation_510),
        ('628', Variation_515),
        ('630', Variation_519),
        ('631', Variation_522),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '000': ('Message Type', Variation_432, 0x40000000),
        '015': ('Service Identification', Variation_0, 0x20000000),
        '020': ('Target Report Descriptor', Variation_436, 0x10000000),
        '030': ('Warning/Error Conditions', Variation_24, 0x08000000),
        '145': ('Time of Applicability', Variation_80, 0x04000000),
        '161': ('Track/Plot Number', Variation_64, 0x02000000),
        '170': ('Track/Plot Status', Variation_443, 0x01800000),
        '050': ('Update Period', Variation_445, 0x01400000),
        '270': ('Target Size & Orientation', Variation_447, 0x01200000),
        '300': ('Object Classification', Variation_451, 0x01100000),
        '400': ('Measurement Identifier', Variation_452, 0x01080000),
        '600': ('Horizontal Position Information', Variation_458, 0x01040000),
        '601': ('Geometric Height Information', Variation_466, 0x01020000),
        '602': ('Horizontal Velocity Information', Variation_474, 0x01018000),
        '603': ('Horizontal Acceleration Information', Variation_483, 0x01014000),
        '604': ('Vertical Velocity Information', Variation_486, 0x01012000),
        '605': ('Vertical Velocity Information', Variation_490, 0x01011000),
        '480': ('Associations', Variation_492, 0x01010800),
        '625': ('Range Information', Variation_501, 0x01010400),
        '626': ('Doppler Information', Variation_505, 0x01010200),
        '627': ('Azimuth Information', Variation_510, 0x01010180),
        '628': ('Elevation Information', Variation_515, 0x01010140),
        '630': ('Path Quality', Variation_519, 0x01010120),
        '631': ('Contour (Azimuth, Elevation Angle, Range Extent)', Variation_522, 0x01010110),
        'SP': ('Special Purpose Field', Variation_62, 0x01010108),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_432]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_436]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_24]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['145']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_443]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_445]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['270']) -> Type[Variation_447]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_451]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_452]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['600']) -> Type[Variation_458]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['601']) -> Type[Variation_466]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['602']) -> Type[Variation_474]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['603']) -> Type[Variation_483]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['604']) -> Type[Variation_486]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['605']) -> Type[Variation_490]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['480']) -> Type[Variation_492]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['625']) -> Type[Variation_501]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['626']) -> Type[Variation_505]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['627']) -> Type[Variation_510]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['628']) -> Type[Variation_515]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['630']) -> Type[Variation_519]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['631']) -> Type[Variation_522]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['015'], Literal['020'], Literal['030'], Literal['145'], Literal['161'], Literal['170'], Literal['050'], Literal['270'], Literal['300'], Literal['400'], Literal['600'], Literal['601'], Literal['602'], Literal['603'], Literal['604'], Literal['605'], Literal['480'], Literal['625'], Literal['626'], Literal['627'], Literal['628'], Literal['630'], Literal['631'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_432'], Type['Variation_0'], Type['Variation_436'], Type['Variation_24'], Type['Variation_80'], Type['Variation_64'], Type['Variation_443'], Type['Variation_445'], Type['Variation_447'], Type['Variation_451'], Type['Variation_452'], Type['Variation_458'], Type['Variation_466'], Type['Variation_474'], Type['Variation_483'], Type['Variation_486'], Type['Variation_490'], Type['Variation_492'], Type['Variation_501'], Type['Variation_505'], Type['Variation_510'], Type['Variation_515'], Type['Variation_519'], Type['Variation_522'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_432
        if key == '015':
            return Variation_0
        if key == '020':
            return Variation_436
        if key == '030':
            return Variation_24
        if key == '145':
            return Variation_80
        if key == '161':
            return Variation_64
        if key == '170':
            return Variation_443
        if key == '050':
            return Variation_445
        if key == '270':
            return Variation_447
        if key == '300':
            return Variation_451
        if key == '400':
            return Variation_452
        if key == '600':
            return Variation_458
        if key == '601':
            return Variation_466
        if key == '602':
            return Variation_474
        if key == '603':
            return Variation_483
        if key == '604':
            return Variation_486
        if key == '605':
            return Variation_490
        if key == '480':
            return Variation_492
        if key == '625':
            return Variation_501
        if key == '626':
            return Variation_505
        if key == '627':
            return Variation_510
        if key == '628':
            return Variation_515
        if key == '630':
            return Variation_519
        if key == '631':
            return Variation_522
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_523_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_432, Variation_432_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_436, Variation_436_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_24, Variation_24_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['145'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_443, Variation_443_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_445, Variation_445_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['270'], val : Union[Variation_447, Variation_447_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_451, Variation_451_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_452, Variation_452_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['600'], val : Union[Variation_458, Variation_458_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['601'], val : Union[Variation_466, Variation_466_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['602'], val : Union[Variation_474, Variation_474_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['603'], val : Union[Variation_483, Variation_483_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['604'], val : Union[Variation_486, Variation_486_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['605'], val : Union[Variation_490, Variation_490_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['480'], val : Union[Variation_492, Variation_492_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['625'], val : Union[Variation_501, Variation_501_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['626'], val : Union[Variation_505, Variation_505_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['627'], val : Union[Variation_510, Variation_510_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['628'], val : Union[Variation_515, Variation_515_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['630'], val : Union[Variation_519, Variation_519_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['631'], val : Union[Variation_522, Variation_522_Arg]) -> 'Variation_523':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_523':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['145']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['270']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['600']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['601']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['602']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['603']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['604']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['605']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['480']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['625']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['626']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['627']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['628']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['630']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['631']) -> 'Variation_523':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_523':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_432:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_436:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_24:
        ...

    @overload
    def get_item(self, name : Literal['145']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_443:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_445:
        ...

    @overload
    def get_item(self, name : Literal['270']) -> Variation_447:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_451:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_452:
        ...

    @overload
    def get_item(self, name : Literal['600']) -> Variation_458:
        ...

    @overload
    def get_item(self, name : Literal['601']) -> Variation_466:
        ...

    @overload
    def get_item(self, name : Literal['602']) -> Variation_474:
        ...

    @overload
    def get_item(self, name : Literal['603']) -> Variation_483:
        ...

    @overload
    def get_item(self, name : Literal['604']) -> Variation_486:
        ...

    @overload
    def get_item(self, name : Literal['605']) -> Variation_490:
        ...

    @overload
    def get_item(self, name : Literal['480']) -> Variation_492:
        ...

    @overload
    def get_item(self, name : Literal['625']) -> Variation_501:
        ...

    @overload
    def get_item(self, name : Literal['626']) -> Variation_505:
        ...

    @overload
    def get_item(self, name : Literal['627']) -> Variation_510:
        ...

    @overload
    def get_item(self, name : Literal['628']) -> Variation_515:
        ...

    @overload
    def get_item(self, name : Literal['630']) -> Variation_519:
        ...

    @overload
    def get_item(self, name : Literal['631']) -> Variation_522:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['145'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['270'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['600'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['601'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['602'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['603'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['604'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['605'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['480'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['625'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['626'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['627'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['628'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['630'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['631'], f : Any) -> 'Variation_523':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_523':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_524_Arg : TypeAlias = Raw
class Variation_524(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'System Configuration',
        2: 'Transmitter / Receiver Configuration',
    }

    def __init__(self, arg : Variation_524_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_525_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_525(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 1.0, 's')

    def __init__(self, arg : Variation_525_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_526_Arg_Group = TypedDict('Variation_526_Arg_Group', {
    'PID': Union[Variation_64, Variation_64_Arg],
    'TID': Union[Variation_64, Variation_64_Arg],
    'RID': Union[Variation_64, Variation_64_Arg],
})
Variation_526_Arg : TypeAlias = Union[Raw, Variation_526_Arg_Group]
class Variation_526(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('PID', Variation_64),
        ('TID', Variation_64),
        ('RID', Variation_64),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PID': ('Pair Identification', Variation_64, 0, 16),
        'TID': ('Transmitter Identification', Variation_64, 16, 16),
        'RID': ('Receiver Identification', Variation_64, 32, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PID']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RID']) -> Type[Variation_64]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PID'], Literal['TID'], Literal['RID']]) -> Union[Type['Variation_64'], Type['Variation_64'], Type['Variation_64']]:
        if key == 'PID':
            return Variation_64
        if key == 'TID':
            return Variation_64
        if key == 'RID':
            return Variation_64
        assert_never(key)

    def __init__(self, arg : Variation_526_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PID']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['RID']) -> Variation_64:
        ...

    def get_item(self, name : Union[Literal['PID'], Literal['TID'], Literal['RID']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PID'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_526':
        ...

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_526':
        ...

    @overload
    def set_item(self, name : Literal['RID'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_526':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PID'], f : Any) -> 'Variation_526':
        ...

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_526':
        ...

    @overload
    def modify_item(self, name : Literal['RID'], f : Any) -> 'Variation_526':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_527_Arg : TypeAlias = Union[Variation_526, Variation_526_Arg]
class Variation_527(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 48
    variation_type = Variation_526

    @classmethod
    def spec(cls) -> Type[Variation_526]:
        return Variation_526

    def __init__(self, arg : List[Union[Variation_526, Variation_526_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_526, Variation_526_Arg]) -> 'Variation_527':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_526, Variation_526_Arg]) -> 'Variation_527':
        return self._prepend_item(arg) # type: ignore

Variation_528_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ns']]]
class Variation_528(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 32
    quantity = Quantity('Signed', 2.0, 'ns')

    def __init__(self, arg : Variation_528_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_529_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ns']]]
class Variation_529(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 20
    quantity = Quantity('Unsigned', 1.0, 'ns')

    def __init__(self, arg : Variation_529_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_530_Arg_Group = TypedDict('Variation_530_Arg_Group', {
    'TID': Union[Variation_64, Variation_64_Arg],
    'LAT': Union[Variation_255, Variation_255_Arg],
    'LON': Union[Variation_255, Variation_255_Arg],
    'ALT': Union[Variation_301, Variation_301_Arg],
    'TTO': Union[Variation_528, Variation_528_Arg],
    'ATO': Union[Variation_529, Variation_529_Arg],
    'PCI': Union[Variation_64, Variation_64_Arg],
})
Variation_530_Arg : TypeAlias = Union[Raw, Variation_530_Arg_Group]
class Variation_530(Group):
    variation = 'Group'

    bit_size = 168

    subitems_list = [
        ('TID', Variation_64),
        ('LAT', Variation_255),
        ('LON', Variation_255),
        ('ALT', Variation_301),
        ('TTO', Variation_528),
        Spare(0, 4),
        ('ATO', Variation_529),
        ('PCI', Variation_64),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TID': ('Transmitter ID', Variation_64, 0, 16),
        'LAT': ('Latitude', Variation_255, 16, 32),
        'LON': ('Longitude', Variation_255, 48, 32),
        'ALT': ('Altitude', Variation_301, 80, 16),
        'TTO': ('Transmission Time Offset', Variation_528, 96, 32),
        'ATO': ('Accuracy of Transmission Time Offset', Variation_529, 132, 20),
        'PCI': ('Parallel Transmitter Index', Variation_64, 152, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_301]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TTO']) -> Type[Variation_528]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ATO']) -> Type[Variation_529]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PCI']) -> Type[Variation_64]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TID'], Literal['LAT'], Literal['LON'], Literal['ALT'], Literal['TTO'], Literal['ATO'], Literal['PCI']]) -> Union[Type['Variation_64'], Type['Variation_255'], Type['Variation_255'], Type['Variation_301'], Type['Variation_528'], Type['Variation_529'], Type['Variation_64']]:
        if key == 'TID':
            return Variation_64
        if key == 'LAT':
            return Variation_255
        if key == 'LON':
            return Variation_255
        if key == 'ALT':
            return Variation_301
        if key == 'TTO':
            return Variation_528
        if key == 'ATO':
            return Variation_529
        if key == 'PCI':
            return Variation_64
        assert_never(key)

    def __init__(self, arg : Variation_530_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_255:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_255:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_301:
        ...

    @overload
    def get_item(self, name : Literal['TTO']) -> Variation_528:
        ...

    @overload
    def get_item(self, name : Literal['ATO']) -> Variation_529:
        ...

    @overload
    def get_item(self, name : Literal['PCI']) -> Variation_64:
        ...

    def get_item(self, name : Union[Literal['TID'], Literal['LAT'], Literal['LON'], Literal['ALT'], Literal['TTO'], Literal['ATO'], Literal['PCI']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_530':
        ...

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_530':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_530':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_301, Variation_301_Arg]) -> 'Variation_530':
        ...

    @overload
    def set_item(self, name : Literal['TTO'], val : Union[Variation_528, Variation_528_Arg]) -> 'Variation_530':
        ...

    @overload
    def set_item(self, name : Literal['ATO'], val : Union[Variation_529, Variation_529_Arg]) -> 'Variation_530':
        ...

    @overload
    def set_item(self, name : Literal['PCI'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_530':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_530':
        ...

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_530':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_530':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_530':
        ...

    @overload
    def modify_item(self, name : Literal['TTO'], f : Any) -> 'Variation_530':
        ...

    @overload
    def modify_item(self, name : Literal['ATO'], f : Any) -> 'Variation_530':
        ...

    @overload
    def modify_item(self, name : Literal['PCI'], f : Any) -> 'Variation_530':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_531_Arg : TypeAlias = Union[Variation_530, Variation_530_Arg]
class Variation_531(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 168
    variation_type = Variation_530

    @classmethod
    def spec(cls) -> Type[Variation_530]:
        return Variation_530

    def __init__(self, arg : List[Union[Variation_530, Variation_530_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_530, Variation_530_Arg]) -> 'Variation_531':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_530, Variation_530_Arg]) -> 'Variation_531':
        return self._prepend_item(arg) # type: ignore

Variation_532_Arg_Group = TypedDict('Variation_532_Arg_Group', {
    'RID': Union[Variation_64, Variation_64_Arg],
    'LAT': Union[Variation_255, Variation_255_Arg],
    'LON': Union[Variation_255, Variation_255_Arg],
    'ALT': Union[Variation_301, Variation_301_Arg],
})
Variation_532_Arg : TypeAlias = Union[Raw, Variation_532_Arg_Group]
class Variation_532(Group):
    variation = 'Group'

    bit_size = 96

    subitems_list = [
        ('RID', Variation_64),
        ('LAT', Variation_255),
        ('LON', Variation_255),
        ('ALT', Variation_301),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RID': ('Receiver Component ID', Variation_64, 0, 16),
        'LAT': ('Latitude', Variation_255, 16, 32),
        'LON': ('Longitude', Variation_255, 48, 32),
        'ALT': ('Altitude', Variation_301, 80, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RID']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_301]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RID'], Literal['LAT'], Literal['LON'], Literal['ALT']]) -> Union[Type['Variation_64'], Type['Variation_255'], Type['Variation_255'], Type['Variation_301']]:
        if key == 'RID':
            return Variation_64
        if key == 'LAT':
            return Variation_255
        if key == 'LON':
            return Variation_255
        if key == 'ALT':
            return Variation_301
        assert_never(key)

    def __init__(self, arg : Variation_532_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RID']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_255:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_255:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_301:
        ...

    def get_item(self, name : Union[Literal['RID'], Literal['LAT'], Literal['LON'], Literal['ALT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RID'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_532':
        ...

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_532':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_255, Variation_255_Arg]) -> 'Variation_532':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_301, Variation_301_Arg]) -> 'Variation_532':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RID'], f : Any) -> 'Variation_532':
        ...

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_532':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_532':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_532':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_533_Arg : TypeAlias = Union[Variation_532, Variation_532_Arg]
class Variation_533(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 96
    variation_type = Variation_532

    @classmethod
    def spec(cls) -> Type[Variation_532]:
        return Variation_532

    def __init__(self, arg : List[Union[Variation_532, Variation_532_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_532, Variation_532_Arg]) -> 'Variation_533':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_532, Variation_532_Arg]) -> 'Variation_533':
        return self._prepend_item(arg) # type: ignore

Variation_534_Arg = TypedDict('Variation_534_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '000': Union[Variation_524, Variation_524_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '200': Union[Variation_525, Variation_525_Arg],
    '300': Union[Variation_527, Variation_527_Arg],
    '400': Union[Variation_256, Variation_256_Arg],
    '405': Union[Variation_301, Variation_301_Arg],
    '410': Union[Variation_531, Variation_531_Arg],
    '420': Union[Variation_533, Variation_533_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_534(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('015', Variation_0),
        ('000', Variation_524),
        ('140', Variation_80),
        ('200', Variation_525),
        ('300', Variation_527),
        ('400', Variation_256),
        ('405', Variation_301),
        ('410', Variation_531),
        ('420', Variation_533),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '015': ('Service Identification', Variation_0, 0x4000),
        '000': ('Message Type', Variation_524, 0x2000),
        '140': ('Time of Day', Variation_80, 0x1000),
        '200': ('System Configuration Reporting Period', Variation_525, 0x0800),
        '300': ('Pair Identification', Variation_527, 0x0400),
        '400': ('Position of the System Reference Point', Variation_256, 0x0200),
        '405': ('Height of System Reference Point', Variation_301, 0x0180),
        '410': ('Transmitter Properties', Variation_531, 0x0140),
        '420': ('Receiver Properties', Variation_533, 0x0120),
        'SP': ('Special Purpose Field', Variation_62, 0x0110),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_524]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_525]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_527]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_256]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['405']) -> Type[Variation_301]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['410']) -> Type[Variation_531]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['420']) -> Type[Variation_533]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['015'], Literal['000'], Literal['140'], Literal['200'], Literal['300'], Literal['400'], Literal['405'], Literal['410'], Literal['420'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_0'], Type['Variation_524'], Type['Variation_80'], Type['Variation_525'], Type['Variation_527'], Type['Variation_256'], Type['Variation_301'], Type['Variation_531'], Type['Variation_533'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '015':
            return Variation_0
        if key == '000':
            return Variation_524
        if key == '140':
            return Variation_80
        if key == '200':
            return Variation_525
        if key == '300':
            return Variation_527
        if key == '400':
            return Variation_256
        if key == '405':
            return Variation_301
        if key == '410':
            return Variation_531
        if key == '420':
            return Variation_533
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_534_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_524, Variation_524_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_525, Variation_525_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_527, Variation_527_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_256, Variation_256_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['405'], val : Union[Variation_301, Variation_301_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['410'], val : Union[Variation_531, Variation_531_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['420'], val : Union[Variation_533, Variation_533_Arg]) -> 'Variation_534':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_534':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['405']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['410']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['420']) -> 'Variation_534':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_534':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_524:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_525:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_527:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_256:
        ...

    @overload
    def get_item(self, name : Literal['405']) -> Variation_301:
        ...

    @overload
    def get_item(self, name : Literal['410']) -> Variation_531:
        ...

    @overload
    def get_item(self, name : Literal['420']) -> Variation_533:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['405'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['410'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['420'], f : Any) -> 'Variation_534':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_534':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_535_Arg : TypeAlias = Raw
class Variation_535(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'Network information',
        10: 'Track data',
        20: 'Track data request',
        21: 'Track data stop',
        22: 'Cancel track data request',
        23: 'Track data stop acknowledgement',
        30: 'New Node / Change-over Initial or intermediate message segment',
        31: 'New Node / Change-over Final or only message segment',
        32: 'New Node / Change-over Initial or intermediate message segment reply',
        33: 'New Node / Change-over Final or only message segment reply',
        110: 'Move node to new cluster state;',
        111: 'Move node to new cluster state acknowledgement',
    }

    def __init__(self, arg : Variation_535_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_536_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_536(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Signed', 5.364418029785156e-6, '°')

    def __init__(self, arg : Variation_536_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_537_Arg_Group = TypedDict('Variation_537_Arg_Group', {
    'LAT': Union[Variation_536, Variation_536_Arg],
    'LON': Union[Variation_536, Variation_536_Arg],
})
Variation_537_Arg : TypeAlias = Union[Raw, Variation_537_Arg_Group]
class Variation_537(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('LAT', Variation_536),
        ('LON', Variation_536),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude', Variation_536, 0, 24),
        'LON': ('Longitude', Variation_536, 24, 24),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_536]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_536]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_536'], Type['Variation_536']]:
        if key == 'LAT':
            return Variation_536
        if key == 'LON':
            return Variation_536
        assert_never(key)

    def __init__(self, arg : Variation_537_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_536:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_536:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_536, Variation_536_Arg]) -> 'Variation_537':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_536, Variation_536_Arg]) -> 'Variation_537':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_537':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_537':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_538_Arg : TypeAlias = Raw
class Variation_538(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode-3/A code derived from the reply of the transponder',
        1: 'Smoothed Mode-3/A code not extracted during the last scan',
    }

    def __init__(self, arg : Variation_538_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_539_Arg_Group = TypedDict('Variation_539_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_538, Variation_538_Arg],
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_539_Arg : TypeAlias = Union[Raw, Variation_539_Arg_Group]
class Variation_539(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_538),
        Spare(3, 1),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'L': ('', Variation_538, 2, 1),
        'MODE3A': ('Mode 3/A Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_538]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_538'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_538
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_539_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_538:
        ...

    @overload
    def get_item(self, name : Literal['MODE3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_539':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_539':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_538, Variation_538_Arg]) -> 'Variation_539':
        ...

    @overload
    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_539':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_539':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_539':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_539':
        ...

    @overload
    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_539':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_540_Arg : TypeAlias = Raw
class Variation_540(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Garbled code / Error correction applied',
    }

    def __init__(self, arg : Variation_540_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_541_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['FL']]]
class Variation_541(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 14
    quantity = Quantity('Unsigned', 0.25, 'FL')

    def __init__(self, arg : Variation_541_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_542_Arg_Group = TypedDict('Variation_542_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_540, Variation_540_Arg],
    'ALT': Union[Variation_541, Variation_541_Arg],
})
Variation_542_Arg : TypeAlias = Union[Raw, Variation_542_Arg_Group]
class Variation_542(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_540),
        ('ALT', Variation_541),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_540, 1, 1),
        'ALT': ('Altitude', Variation_541, 2, 14),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_540]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_541]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['ALT']]) -> Union[Type['Variation_16'], Type['Variation_540'], Type['Variation_541']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_540
        if key == 'ALT':
            return Variation_541
        assert_never(key)

    def __init__(self, arg : Variation_542_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_540:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_541:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['ALT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_542':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_540, Variation_540_Arg]) -> 'Variation_542':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_541, Variation_541_Arg]) -> 'Variation_542':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_542':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_542':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_542':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_543_Arg : TypeAlias = Raw
class Variation_543(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: 'No communications capability (surveillance only), no ability to set CA code 7 either airborne or on the ground',
        1: 'Reserved',
        2: 'Reserved',
        3: 'Reserved',
        4: 'At Least Comm. A and Comm. B capability and the ability to set CA code 7 and on the ground',
        5: 'At Least Comm. A and Comm. B capability and the ability to set CA code 7 and airborne',
        6: 'At Least Comm. A and Comm. B capability and the ability to set CA code 7 and either airborne or on the ground',
        7: 'Signifies the DR field is not equal to 0 or the FS field equals 2, 3, 4 or 5 and either airborne or on the ground SI/II-capabilities of the Transponder',
    }

    def __init__(self, arg : Variation_543_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_544_Arg : TypeAlias = Raw
class Variation_544(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Transponder SI capable',
        1: 'Transponder not SI capable',
    }

    def __init__(self, arg : Variation_544_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_545_Arg_Group = TypedDict('Variation_545_Arg_Group', {
    'CA': Union[Variation_543, Variation_543_Arg],
    'SI': Union[Variation_544, Variation_544_Arg],
})
Variation_545_Arg : TypeAlias = Union[Raw, Variation_545_Arg_Group]
class Variation_545(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('CA', Variation_543),
        ('SI', Variation_544),
        Spare(4, 4),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CA': ('Communications Capability of the Transponder', Variation_543, 0, 3),
        'SI': ('SI/II-capabilities of the Transponder', Variation_544, 3, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CA']) -> Type[Variation_543]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SI']) -> Type[Variation_544]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CA'], Literal['SI']]) -> Union[Type['Variation_543'], Type['Variation_544']]:
        if key == 'CA':
            return Variation_543
        if key == 'SI':
            return Variation_544
        assert_never(key)

    def __init__(self, arg : Variation_545_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CA']) -> Variation_543:
        ...

    @overload
    def get_item(self, name : Literal['SI']) -> Variation_544:
        ...

    def get_item(self, name : Union[Literal['CA'], Literal['SI']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CA'], val : Union[Variation_543, Variation_543_Arg]) -> 'Variation_545':
        ...

    @overload
    def set_item(self, name : Literal['SI'], val : Union[Variation_544, Variation_544_Arg]) -> 'Variation_545':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CA'], f : Any) -> 'Variation_545':
        ...

    @overload
    def modify_item(self, name : Literal['SI'], f : Any) -> 'Variation_545':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_546_Arg : TypeAlias = Raw
class Variation_546(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Measured position',
        1: 'No measured position (coasted)',
    }

    def __init__(self, arg : Variation_546_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_547_Arg : TypeAlias = Raw
class Variation_547(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Last Measured Flight Level',
        1: 'Predicted Flight Level',
    }

    def __init__(self, arg : Variation_547_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_548_Arg_Group = TypedDict('Variation_548_Arg_Group', {
    'CST': Union[Variation_546, Variation_546_Arg],
    'FLT': Union[Variation_547, Variation_547_Arg],
})
Variation_548_Arg : TypeAlias = Union[Raw, Variation_548_Arg_Group]
class Variation_548(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('CST', Variation_546),
        ('FLT', Variation_547),
        Spare(2, 6),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CST': ('Track Coasted', Variation_546, 0, 1),
        'FLT': ('Flight Level Tracking', Variation_547, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_546]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FLT']) -> Type[Variation_547]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CST'], Literal['FLT']]) -> Union[Type['Variation_546'], Type['Variation_547']]:
        if key == 'CST':
            return Variation_546
        if key == 'FLT':
            return Variation_547
        assert_never(key)

    def __init__(self, arg : Variation_548_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_546:
        ...

    @overload
    def get_item(self, name : Literal['FLT']) -> Variation_547:
        ...

    def get_item(self, name : Union[Literal['CST'], Literal['FLT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CST'], val : Union[Variation_546, Variation_546_Arg]) -> 'Variation_548':
        ...

    @overload
    def set_item(self, name : Literal['FLT'], val : Union[Variation_547, Variation_547_Arg]) -> 'Variation_548':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_548':
        ...

    @overload
    def modify_item(self, name : Literal['FLT'], f : Any) -> 'Variation_548':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_549_Arg : TypeAlias = Union[Variation_278, Variation_278_Arg]
class Variation_549(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 24
    variation_type = Variation_278

    @classmethod
    def spec(cls) -> Type[Variation_278]:
        return Variation_278

    def __init__(self, arg : List[Union[Variation_278, Variation_278_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_278, Variation_278_Arg]) -> 'Variation_549':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_278, Variation_278_Arg]) -> 'Variation_549':
        return self._prepend_item(arg) # type: ignore

Variation_550_Arg = TypedDict('Variation_550_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '012': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_535, Variation_535_Arg],
    '350': Union[Variation_92, Variation_92_Arg],
    '220': Union[Variation_278, Variation_278_Arg],
    '221': Union[Variation_64, Variation_64_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '045': Union[Variation_537, Variation_537_Arg],
    '070': Union[Variation_539, Variation_539_Arg],
    '050': Union[Variation_542, Variation_542_Arg],
    '200': Union[Variation_68, Variation_68_Arg],
    '230': Union[Variation_545, Variation_545_Arg],
    '240': Union[Variation_548, Variation_548_Arg],
    '210': Union[Variation_549, Variation_549_Arg],
    '360': Union[Variation_0, Variation_0_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_550(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 3

    subitems_list = [
        ('010', Variation_1),
        ('012', Variation_1),
        ('000', Variation_535),
        ('350', Variation_92),
        ('220', Variation_278),
        ('221', Variation_64),
        ('140', Variation_80),
        ('045', Variation_537),
        ('070', Variation_539),
        ('050', Variation_542),
        ('200', Variation_68),
        ('230', Variation_545),
        ('240', Variation_548),
        ('210', Variation_549),
        ('360', Variation_0),
        None,
        None,
        None,
        None,
        None,
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x800000),
        '012': ('Data Destination Identifier', Variation_1, 0x400000),
        '000': ('Message Type', Variation_535, 0x200000),
        '350': ('Cluster Station/Node List', Variation_92, 0x100000),
        '220': ('Aircraft Address', Variation_278, 0x080000),
        '221': ('Duplicate Address Reference Number (DRN)', Variation_64, 0x040000),
        '140': ('Time of Day', Variation_80, 0x020000),
        '045': ('Calculated Position in WGS-84 Coordinates', Variation_537, 0x018000),
        '070': ('Mode 3/A Code in Octal Representation', Variation_539, 0x014000),
        '050': ('Flight Level in Binary Representation', Variation_542, 0x012000),
        '200': ('Track Velocity in Polar Co-ordinates', Variation_68, 0x011000),
        '230': ('Transponder Capability', Variation_545, 0x010800),
        '240': ('Track Status', Variation_548, 0x010400),
        '210': ('Mode S Address List', Variation_549, 0x010200),
        '360': ('Cluster Controller Command State', Variation_0, 0x010180),
        'SP': ('Special Purpose Field', Variation_62, 0x010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['012']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_535]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['350']) -> Type[Variation_92]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['221']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['045']) -> Type[Variation_537]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_539]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_542]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_68]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_545]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['240']) -> Type[Variation_548]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_549]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['360']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['012'], Literal['000'], Literal['350'], Literal['220'], Literal['221'], Literal['140'], Literal['045'], Literal['070'], Literal['050'], Literal['200'], Literal['230'], Literal['240'], Literal['210'], Literal['360'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_1'], Type['Variation_535'], Type['Variation_92'], Type['Variation_278'], Type['Variation_64'], Type['Variation_80'], Type['Variation_537'], Type['Variation_539'], Type['Variation_542'], Type['Variation_68'], Type['Variation_545'], Type['Variation_548'], Type['Variation_549'], Type['Variation_0'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '012':
            return Variation_1
        if key == '000':
            return Variation_535
        if key == '350':
            return Variation_92
        if key == '220':
            return Variation_278
        if key == '221':
            return Variation_64
        if key == '140':
            return Variation_80
        if key == '045':
            return Variation_537
        if key == '070':
            return Variation_539
        if key == '050':
            return Variation_542
        if key == '200':
            return Variation_68
        if key == '230':
            return Variation_545
        if key == '240':
            return Variation_548
        if key == '210':
            return Variation_549
        if key == '360':
            return Variation_0
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_550_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['012'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_535, Variation_535_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['350'], val : Union[Variation_92, Variation_92_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['221'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['045'], val : Union[Variation_537, Variation_537_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_539, Variation_539_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_542, Variation_542_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_68, Variation_68_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_545, Variation_545_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['240'], val : Union[Variation_548, Variation_548_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_549, Variation_549_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['360'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_550':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_550':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['012']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['350']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['221']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['045']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['240']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['360']) -> 'Variation_550':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_550':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['012']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_535:
        ...

    @overload
    def get_item(self, name : Literal['350']) -> Variation_92:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['221']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['045']) -> Variation_537:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_539:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_542:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_68:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_545:
        ...

    @overload
    def get_item(self, name : Literal['240']) -> Variation_548:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_549:
        ...

    @overload
    def get_item(self, name : Literal['360']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['012'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['350'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['221'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['045'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['240'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['360'], f : Any) -> 'Variation_550':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_550':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_551_Arg : TypeAlias = Raw
class Variation_551(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'Associate_req',
        1: 'Associate_resp',
        2: 'Release_req',
        3: 'Release_resp',
        4: 'Abort_req',
        5: 'Keep_alive',
        16: 'Aircraft_report',
        17: 'Aircraft_command',
        18: 'II_code_change',
        32: 'Uplink_packet',
        33: 'Cancel_uplink_packet',
        34: 'Uplink_packet_ack',
        35: 'Downlink_packet',
        38: 'Data_XON',
        39: 'Data_XOFF',
        48: 'Uplink_broadcast',
        49: 'Cancel_uplink_broadcast',
        50: 'Uplink_broadcast_ack',
        52: 'Downlink_broadcast',
        64: 'GICB_extraction',
        65: 'Cancel_GICB_extraction',
        66: 'GICB_extraction_ack',
        67: 'GICB_response',
    }

    def __init__(self, arg : Variation_551_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_552_Arg : TypeAlias = Raw
class Variation_552(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 4
    table = {
        0: 'Accepted, the request is accepted and is under processing',
        1: 'Rejected, the request has not been accepted',
        2: 'Cancelled, the request has been cancelled',
        3: 'Finished, the request has been accepted and successfully processed',
        4: 'Delayed, the request processing is temporarily delayed but the request is still valid',
        5: 'In Progress, the request is being successfully processed',
        6: 'In Progress, the request is being successfully processed',
    }

    def __init__(self, arg : Variation_552_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_553_Arg : TypeAlias = Raw
class Variation_553(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 4
    table = {
        0: 'No diagnostic available',
        1: 'Aircraft Exit',
        2: 'Incorrect aircraft address',
        3: 'Impossibility to process the message',
        4: 'Insufficient or change in data link capability',
        5: 'Invalid LV field',
        6: 'Duplicate request number',
        7: 'Unknown request number',
        8: 'Timer T3 expiry',
        9: 'Expiry of I/R delivery timer',
        10: 'Uplink flow disabled by UC',
    }

    def __init__(self, arg : Variation_553_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_554_Arg_Group = TypedDict('Variation_554_Arg_Group', {
    'CAUSE': Union[Variation_552, Variation_552_Arg],
    'DIAG': Union[Variation_553, Variation_553_Arg],
})
Variation_554_Arg : TypeAlias = Union[Raw, Variation_554_Arg_Group]
class Variation_554(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('CAUSE', Variation_552),
        ('DIAG', Variation_553),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CAUSE': ('Cause', Variation_552, 0, 4),
        'DIAG': ('Diagnostic', Variation_553, 4, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CAUSE']) -> Type[Variation_552]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DIAG']) -> Type[Variation_553]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CAUSE'], Literal['DIAG']]) -> Union[Type['Variation_552'], Type['Variation_553']]:
        if key == 'CAUSE':
            return Variation_552
        if key == 'DIAG':
            return Variation_553
        assert_never(key)

    def __init__(self, arg : Variation_554_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CAUSE']) -> Variation_552:
        ...

    @overload
    def get_item(self, name : Literal['DIAG']) -> Variation_553:
        ...

    def get_item(self, name : Union[Literal['CAUSE'], Literal['DIAG']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CAUSE'], val : Union[Variation_552, Variation_552_Arg]) -> 'Variation_554':
        ...

    @overload
    def set_item(self, name : Literal['DIAG'], val : Union[Variation_553, Variation_553_Arg]) -> 'Variation_554':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CAUSE'], f : Any) -> 'Variation_554':
        ...

    @overload
    def modify_item(self, name : Literal['DIAG'], f : Any) -> 'Variation_554':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_555_Arg : TypeAlias = Raw
class Variation_555(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 32

    def __init__(self, arg : Variation_555_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_556_Arg : TypeAlias = Union[Variation_555, Variation_555_Arg]
class Variation_556(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 32
    variation_type = Variation_555

    @classmethod
    def spec(cls) -> Type[Variation_555]:
        return Variation_555

    def __init__(self, arg : List[Union[Variation_555, Variation_555_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_555, Variation_555_Arg]) -> 'Variation_556':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_555, Variation_555_Arg]) -> 'Variation_556':
        return self._prepend_item(arg) # type: ignore

Variation_557_Arg : TypeAlias = Raw
class Variation_557(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 5

    def __init__(self, arg : Variation_557_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_558_Arg : TypeAlias = Raw
class Variation_558(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 2
    table = {
        0: 'SVC packets',
        1: 'MSP packets',
        2: 'Route packets',
    }

    def __init__(self, arg : Variation_558_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_559_Arg_Group = TypedDict('Variation_559_Arg_Group', {
    'PR': Union[Variation_557, Variation_557_Arg],
    'PT': Union[Variation_558, Variation_558_Arg],
})
Variation_559_Arg : TypeAlias = Union[Raw, Variation_559_Arg_Group]
class Variation_559(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 1),
        ('PR', Variation_557),
        ('PT', Variation_558),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PR': ('Mode S Packet Internal Priority', Variation_557, 1, 5),
        'PT': ('Packet Type', Variation_558, 6, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PR']) -> Type[Variation_557]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PT']) -> Type[Variation_558]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PR'], Literal['PT']]) -> Union[Type['Variation_557'], Type['Variation_558']]:
        if key == 'PR':
            return Variation_557
        if key == 'PT':
            return Variation_558
        assert_never(key)

    def __init__(self, arg : Variation_559_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PR']) -> Variation_557:
        ...

    @overload
    def get_item(self, name : Literal['PT']) -> Variation_558:
        ...

    def get_item(self, name : Union[Literal['PR'], Literal['PT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PR'], val : Union[Variation_557, Variation_557_Arg]) -> 'Variation_559':
        ...

    @overload
    def set_item(self, name : Literal['PT'], val : Union[Variation_558, Variation_558_Arg]) -> 'Variation_559':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PR'], f : Any) -> 'Variation_559':
        ...

    @overload
    def modify_item(self, name : Literal['PT'], f : Any) -> 'Variation_559':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_560_Arg : TypeAlias = bytes
class Variation_560(Explicit):
    variation = 'Explicit'

    explicit_type = None

    def __init__(self, arg : bytes) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, bytes):
            super().__init__(*self._from_bytes(arg)); return
        assert_never(arg)

Variation_561_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_561(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0, 's')

    def __init__(self, arg : Variation_561_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_562_Arg : TypeAlias = Raw
class Variation_562(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'The periodicity may not be strictly respected',
        1: 'The periodicity shall be strictly respected',
    }

    def __init__(self, arg : Variation_562_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_563_Arg : TypeAlias = Raw
class Variation_563(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'GICB extractions should be sent only when required by the periodicity',
        1: 'If a GICB extraction is done due to external conditions, an update will also be sent, even if it does not match the expected periodicity',
    }

    def __init__(self, arg : Variation_563_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_564_Arg : TypeAlias = Raw
class Variation_564(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'The GICB extraction is attempted according to the periodicity',
        1: 'There will no GICB attempts',
    }

    def __init__(self, arg : Variation_564_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_565_Arg : TypeAlias = Raw
class Variation_565(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 2
    table = {
        0: 'The extracted GICB must be sent only on the Data Link line',
        1: 'The extracted GICB must be sent only on the Surveillance line',
        2: 'The extracted GICB must be sent both on the Data Link and on the Surveillance lines',
    }

    def __init__(self, arg : Variation_565_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_566_Arg_Group = TypedDict('Variation_566_Arg_Group', {
    'PRIORITY': Union[Variation_222, Variation_222_Arg],
    'PC': Union[Variation_562, Variation_562_Arg],
    'AU': Union[Variation_563, Variation_563_Arg],
    'NE': Union[Variation_564, Variation_564_Arg],
    'RD': Union[Variation_565, Variation_565_Arg],
})
Variation_566_Arg : TypeAlias = Union[Raw, Variation_566_Arg_Group]
class Variation_566(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('PRIORITY', Variation_222),
        Spare(5, 3),
        ('PC', Variation_562),
        ('AU', Variation_563),
        ('NE', Variation_564),
        ('RD', Variation_565),
        Spare(5, 3),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PRIORITY': ('GICB Priority', Variation_222, 0, 5),
        'PC': ('Periodicity Constraint', Variation_562, 8, 1),
        'AU': ('Asynchronous Update', Variation_563, 9, 1),
        'NE': ('Non Extraction', Variation_564, 10, 1),
        'RD': ('Reply Destination', Variation_565, 11, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PRIORITY']) -> Type[Variation_222]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PC']) -> Type[Variation_562]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AU']) -> Type[Variation_563]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NE']) -> Type[Variation_564]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RD']) -> Type[Variation_565]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PRIORITY'], Literal['PC'], Literal['AU'], Literal['NE'], Literal['RD']]) -> Union[Type['Variation_222'], Type['Variation_562'], Type['Variation_563'], Type['Variation_564'], Type['Variation_565']]:
        if key == 'PRIORITY':
            return Variation_222
        if key == 'PC':
            return Variation_562
        if key == 'AU':
            return Variation_563
        if key == 'NE':
            return Variation_564
        if key == 'RD':
            return Variation_565
        assert_never(key)

    def __init__(self, arg : Variation_566_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PRIORITY']) -> Variation_222:
        ...

    @overload
    def get_item(self, name : Literal['PC']) -> Variation_562:
        ...

    @overload
    def get_item(self, name : Literal['AU']) -> Variation_563:
        ...

    @overload
    def get_item(self, name : Literal['NE']) -> Variation_564:
        ...

    @overload
    def get_item(self, name : Literal['RD']) -> Variation_565:
        ...

    def get_item(self, name : Union[Literal['PRIORITY'], Literal['PC'], Literal['AU'], Literal['NE'], Literal['RD']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PRIORITY'], val : Union[Variation_222, Variation_222_Arg]) -> 'Variation_566':
        ...

    @overload
    def set_item(self, name : Literal['PC'], val : Union[Variation_562, Variation_562_Arg]) -> 'Variation_566':
        ...

    @overload
    def set_item(self, name : Literal['AU'], val : Union[Variation_563, Variation_563_Arg]) -> 'Variation_566':
        ...

    @overload
    def set_item(self, name : Literal['NE'], val : Union[Variation_564, Variation_564_Arg]) -> 'Variation_566':
        ...

    @overload
    def set_item(self, name : Literal['RD'], val : Union[Variation_565, Variation_565_Arg]) -> 'Variation_566':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PRIORITY'], f : Any) -> 'Variation_566':
        ...

    @overload
    def modify_item(self, name : Literal['PC'], f : Any) -> 'Variation_566':
        ...

    @overload
    def modify_item(self, name : Literal['AU'], f : Any) -> 'Variation_566':
        ...

    @overload
    def modify_item(self, name : Literal['NE'], f : Any) -> 'Variation_566':
        ...

    @overload
    def modify_item(self, name : Literal['RD'], f : Any) -> 'Variation_566':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_567_Arg : TypeAlias = Raw
class Variation_567(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'UC shall be ignored',
        1: 'UC shall be taken into account',
    }

    def __init__(self, arg : Variation_567_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_568_Arg : TypeAlias = Raw
class Variation_568(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'DC shall be ignored',
        1: 'DC shall be taken into account',
    }

    def __init__(self, arg : Variation_568_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_569_Arg : TypeAlias = Raw
class Variation_569(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'the uplink flow shall be enabled',
        1: 'the uplink flow shall be stopped',
    }

    def __init__(self, arg : Variation_569_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_570_Arg : TypeAlias = Raw
class Variation_570(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'the downlink flow shall be enabled',
        1: 'the downlink flow shall be stopped',
    }

    def __init__(self, arg : Variation_570_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_571_Arg_Group = TypedDict('Variation_571_Arg_Group', {
    'UM': Union[Variation_567, Variation_567_Arg],
    'DM': Union[Variation_568, Variation_568_Arg],
    'UC': Union[Variation_569, Variation_569_Arg],
    'DC': Union[Variation_570, Variation_570_Arg],
})
Variation_571_Arg : TypeAlias = Union[Raw, Variation_571_Arg_Group]
class Variation_571(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('UM', Variation_567),
        ('DM', Variation_568),
        ('UC', Variation_569),
        ('DC', Variation_570),
        Spare(4, 4),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'UM': ('Uplink Mask', Variation_567, 0, 1),
        'DM': ('Downlink Mask', Variation_568, 1, 1),
        'UC': ('Uplink Command', Variation_569, 2, 1),
        'DC': ('Downlink Command', Variation_570, 3, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['UM']) -> Type[Variation_567]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DM']) -> Type[Variation_568]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['UC']) -> Type[Variation_569]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DC']) -> Type[Variation_570]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['UM'], Literal['DM'], Literal['UC'], Literal['DC']]) -> Union[Type['Variation_567'], Type['Variation_568'], Type['Variation_569'], Type['Variation_570']]:
        if key == 'UM':
            return Variation_567
        if key == 'DM':
            return Variation_568
        if key == 'UC':
            return Variation_569
        if key == 'DC':
            return Variation_570
        assert_never(key)

    def __init__(self, arg : Variation_571_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['UM']) -> Variation_567:
        ...

    @overload
    def get_item(self, name : Literal['DM']) -> Variation_568:
        ...

    @overload
    def get_item(self, name : Literal['UC']) -> Variation_569:
        ...

    @overload
    def get_item(self, name : Literal['DC']) -> Variation_570:
        ...

    def get_item(self, name : Union[Literal['UM'], Literal['DM'], Literal['UC'], Literal['DC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['UM'], val : Union[Variation_567, Variation_567_Arg]) -> 'Variation_571':
        ...

    @overload
    def set_item(self, name : Literal['DM'], val : Union[Variation_568, Variation_568_Arg]) -> 'Variation_571':
        ...

    @overload
    def set_item(self, name : Literal['UC'], val : Union[Variation_569, Variation_569_Arg]) -> 'Variation_571':
        ...

    @overload
    def set_item(self, name : Literal['DC'], val : Union[Variation_570, Variation_570_Arg]) -> 'Variation_571':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['UM'], f : Any) -> 'Variation_571':
        ...

    @overload
    def modify_item(self, name : Literal['DM'], f : Any) -> 'Variation_571':
        ...

    @overload
    def modify_item(self, name : Literal['UC'], f : Any) -> 'Variation_571':
        ...

    @overload
    def modify_item(self, name : Literal['DC'], f : Any) -> 'Variation_571':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_572_Arg : TypeAlias = Raw
class Variation_572(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'The interrogator is enabled to uplink frames',
        1: 'The interrogator is disabled to uplink frames',
    }

    def __init__(self, arg : Variation_572_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_573_Arg : TypeAlias = Raw
class Variation_573(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'The interrogator is enabled to extract frames',
        1: 'The interrogator is disabled to extract frames',
    }

    def __init__(self, arg : Variation_573_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_574_Arg : TypeAlias = Raw
class Variation_574(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'The interrogator is enabled to uplink frames',
        1: 'The interrogator is disabled to uplink frames',
    }

    def __init__(self, arg : Variation_574_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_575_Arg : TypeAlias = Raw
class Variation_575(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'The interrogator is enabled to extract frames',
        1: 'The interrogator is disabled to extract frames',
    }

    def __init__(self, arg : Variation_575_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_576_Arg : TypeAlias = Raw
class Variation_576(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'The aircraft is in the Datalink coverage map of the interrogator',
        1: 'The aircraft is not in the Datalink coverage map of the interrogator',
    }

    def __init__(self, arg : Variation_576_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_577_Arg : TypeAlias = Raw
class Variation_577(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'The interrogators current ability to uplink/downlink frames (UCS/DCS) and the content of the Aircraft_report could be changed using D_Data_link_command',
        1: 'The interrogators current ability to uplink/downlink frames (UCS/DCS) and the content of the Aircraft_report cannot be changed using D_Data_link_command',
    }

    def __init__(self, arg : Variation_577_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_578_Arg_Group_1 = TypedDict('Variation_578_Arg_Group_1', {
    'UDS': Union[Variation_572, Variation_572_Arg],
    'DDS': Union[Variation_573, Variation_573_Arg],
    'UCS': Union[Variation_574, Variation_574_Arg],
    'DCS': Union[Variation_575, Variation_575_Arg],
    'EI': Union[Variation_576, Variation_576_Arg],
})
Variation_578_Arg_Group_2 = TypedDict('Variation_578_Arg_Group_2', {
    'UDS': Union[Variation_572, Variation_572_Arg],
    'DDS': Union[Variation_573, Variation_573_Arg],
    'UCS': Union[Variation_574, Variation_574_Arg],
    'DCS': Union[Variation_575, Variation_575_Arg],
    'EI': Union[Variation_576, Variation_576_Arg],
    'IC': Union[Variation_577, Variation_577_Arg],
})
Variation_578_Arg : TypeAlias = Union[
    int,
    Variation_578_Arg_Group_1,
    Tuple[int],
    Variation_578_Arg_Group_2,
    Tuple[int,int],
]
class Variation_578(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('UDS', Variation_572),
            ('DDS', Variation_573),
            ('UCS', Variation_574),
            ('DCS', Variation_575),
            Spare(4, 2),
            ('EI', Variation_576),
        ],
        [
            ('IC', Variation_577),
            Spare(1, 6),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'UDS': ('Uplink Default Status', Variation_572, 0, 1),
        'DDS': ('Downlink Default Status', Variation_573, 1, 1),
        'UCS': ('Uplink Current Status', Variation_574, 2, 1),
        'DCS': ('Downlink Current Status', Variation_575, 3, 1),
        'EI': ('Exit Indication', Variation_576, 6, 1),
        'IC': ('Interrogator Control', Variation_577, 0, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['UDS']) -> Type[Variation_572]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DDS']) -> Type[Variation_573]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['UCS']) -> Type[Variation_574]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DCS']) -> Type[Variation_575]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EI']) -> Type[Variation_576]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IC']) -> Type[Variation_577]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['UDS'], Literal['DDS'], Literal['UCS'], Literal['DCS'], Literal['EI'], Literal['IC']]) -> Union[Type['Variation_572'], Type['Variation_573'], Type['Variation_574'], Type['Variation_575'], Type['Variation_576'], Type['Variation_577']]:
        if key == 'UDS':
            return Variation_572
        if key == 'DDS':
            return Variation_573
        if key == 'UCS':
            return Variation_574
        if key == 'DCS':
            return Variation_575
        if key == 'EI':
            return Variation_576
        if key == 'IC':
            return Variation_577
        assert_never(key)

    def __init__(self, arg : Variation_578_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_578_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_578_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['UDS']) -> Variation_572:
        ...

    @overload
    def get_item(self, name : Literal['DDS']) -> Variation_573:
        ...

    @overload
    def get_item(self, name : Literal['UCS']) -> Variation_574:
        ...

    @overload
    def get_item(self, name : Literal['DCS']) -> Variation_575:
        ...

    @overload
    def get_item(self, name : Literal['EI']) -> Variation_576:
        ...

    @overload
    def get_item(self, name : Literal['IC']) -> Variation_577:
        ...

    def get_item(self, name : Union[Literal['UDS'], Literal['DDS'], Literal['UCS'], Literal['DCS'], Literal['EI'], Literal['IC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['UDS'], val : Union[Variation_572, Variation_572_Arg]) -> 'Variation_578':
        ...

    @overload
    def set_item(self, name : Literal['DDS'], val : Union[Variation_573, Variation_573_Arg]) -> 'Variation_578':
        ...

    @overload
    def set_item(self, name : Literal['UCS'], val : Union[Variation_574, Variation_574_Arg]) -> 'Variation_578':
        ...

    @overload
    def set_item(self, name : Literal['DCS'], val : Union[Variation_575, Variation_575_Arg]) -> 'Variation_578':
        ...

    @overload
    def set_item(self, name : Literal['EI'], val : Union[Variation_576, Variation_576_Arg]) -> 'Variation_578':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['UDS'], f : Any) -> 'Variation_578':
        ...

    @overload
    def modify_item(self, name : Literal['DDS'], f : Any) -> 'Variation_578':
        ...

    @overload
    def modify_item(self, name : Literal['UCS'], f : Any) -> 'Variation_578':
        ...

    @overload
    def modify_item(self, name : Literal['DCS'], f : Any) -> 'Variation_578':
        ...

    @overload
    def modify_item(self, name : Literal['EI'], f : Any) -> 'Variation_578':
        ...

    @overload
    def modify_item(self, name : Literal['IC'], f : Any) -> 'Variation_578':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_579_Arg : TypeAlias = Raw
class Variation_579(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include D_Data_link_status',
        1: 'The next Aircraft_report shall include D_Data_link_status',
    }

    def __init__(self, arg : Variation_579_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_580_Arg : TypeAlias = Raw
class Variation_580(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include D_COM',
        1: 'The next Aircraft_report shall include D_COM',
    }

    def __init__(self, arg : Variation_580_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_581_Arg : TypeAlias = Raw
class Variation_581(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include D_ECA',
        1: 'The next Aircraft_report shall include D_ECA',
    }

    def __init__(self, arg : Variation_581_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_582_Arg : TypeAlias = Raw
class Variation_582(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include D_CQF',
        1: 'The next Aircraft_report shall include D_CQF',
    }

    def __init__(self, arg : Variation_582_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_583_Arg : TypeAlias = Raw
class Variation_583(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include D_CQF_method',
        1: 'The next Aircraft_report shall include D_CQF_method',
    }

    def __init__(self, arg : Variation_583_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_584_Arg : TypeAlias = Raw
class Variation_584(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include D_Polar_position',
        1: 'The next Aircraft_report shall include D_Polar_position',
    }

    def __init__(self, arg : Variation_584_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_585_Arg : TypeAlias = Raw
class Variation_585(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include D_Cartesian_position',
        1: 'The next Aircraft_report shall include D_Cartesian_position',
    }

    def __init__(self, arg : Variation_585_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_586_Arg : TypeAlias = Raw
class Variation_586(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include Aircraft_ID',
        1: 'The next Aircraft_report shall include Aircraft_ID',
    }

    def __init__(self, arg : Variation_586_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_587_Arg : TypeAlias = Raw
class Variation_587(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include Mode_A',
        1: 'The next Aircraft_report shall include Mode_A',
    }

    def __init__(self, arg : Variation_587_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_588_Arg : TypeAlias = Raw
class Variation_588(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include Speed',
        1: 'The next Aircraft_report shall include Speed',
    }

    def __init__(self, arg : Variation_588_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_589_Arg : TypeAlias = Raw
class Variation_589(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include Height',
        1: 'The next Aircraft_report shall include Height',
    }

    def __init__(self, arg : Variation_589_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_590_Arg : TypeAlias = Raw
class Variation_590(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'The next Aircraft_report may not include Heading',
        1: 'The next Aircraft_report shall include Heading',
    }

    def __init__(self, arg : Variation_590_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_591_Arg_Group_1 = TypedDict('Variation_591_Arg_Group_1', {
    'SR': Union[Variation_579, Variation_579_Arg],
    'AR': Union[Variation_580, Variation_580_Arg],
    'ER': Union[Variation_581, Variation_581_Arg],
    'FR': Union[Variation_582, Variation_582_Arg],
    'MR': Union[Variation_583, Variation_583_Arg],
    'PR': Union[Variation_584, Variation_584_Arg],
    'CR': Union[Variation_585, Variation_585_Arg],
})
Variation_591_Arg_Group_2 = TypedDict('Variation_591_Arg_Group_2', {
    'SR': Union[Variation_579, Variation_579_Arg],
    'AR': Union[Variation_580, Variation_580_Arg],
    'ER': Union[Variation_581, Variation_581_Arg],
    'FR': Union[Variation_582, Variation_582_Arg],
    'MR': Union[Variation_583, Variation_583_Arg],
    'PR': Union[Variation_584, Variation_584_Arg],
    'CR': Union[Variation_585, Variation_585_Arg],
    'ID': Union[Variation_586, Variation_586_Arg],
    'MA': Union[Variation_587, Variation_587_Arg],
    'SP': Union[Variation_588, Variation_588_Arg],
    'HG': Union[Variation_589, Variation_589_Arg],
    'HD': Union[Variation_590, Variation_590_Arg],
})
Variation_591_Arg : TypeAlias = Union[
    int,
    Variation_591_Arg_Group_1,
    Tuple[int],
    Variation_591_Arg_Group_2,
    Tuple[int,int],
]
class Variation_591(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('SR', Variation_579),
            ('AR', Variation_580),
            ('ER', Variation_581),
            ('FR', Variation_582),
            ('MR', Variation_583),
            ('PR', Variation_584),
            ('CR', Variation_585),
        ],
        [
            ('ID', Variation_586),
            ('MA', Variation_587),
            ('SP', Variation_588),
            ('HG', Variation_589),
            ('HD', Variation_590),
            Spare(5, 2),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SR': ('', Variation_579, 0, 1),
        'AR': ('', Variation_580, 1, 1),
        'ER': ('', Variation_581, 2, 1),
        'FR': ('', Variation_582, 3, 1),
        'MR': ('', Variation_583, 4, 1),
        'PR': ('', Variation_584, 5, 1),
        'CR': ('', Variation_585, 6, 1),
        'ID': ('', Variation_586, 0, 1),
        'MA': ('', Variation_587, 1, 1),
        'SP': ('', Variation_588, 2, 1),
        'HG': ('', Variation_589, 3, 1),
        'HD': ('', Variation_590, 4, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SR']) -> Type[Variation_579]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AR']) -> Type[Variation_580]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ER']) -> Type[Variation_581]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FR']) -> Type[Variation_582]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MR']) -> Type[Variation_583]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PR']) -> Type[Variation_584]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CR']) -> Type[Variation_585]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ID']) -> Type[Variation_586]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MA']) -> Type[Variation_587]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_588]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HG']) -> Type[Variation_589]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HD']) -> Type[Variation_590]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SR'], Literal['AR'], Literal['ER'], Literal['FR'], Literal['MR'], Literal['PR'], Literal['CR'], Literal['ID'], Literal['MA'], Literal['SP'], Literal['HG'], Literal['HD']]) -> Union[Type['Variation_579'], Type['Variation_580'], Type['Variation_581'], Type['Variation_582'], Type['Variation_583'], Type['Variation_584'], Type['Variation_585'], Type['Variation_586'], Type['Variation_587'], Type['Variation_588'], Type['Variation_589'], Type['Variation_590']]:
        if key == 'SR':
            return Variation_579
        if key == 'AR':
            return Variation_580
        if key == 'ER':
            return Variation_581
        if key == 'FR':
            return Variation_582
        if key == 'MR':
            return Variation_583
        if key == 'PR':
            return Variation_584
        if key == 'CR':
            return Variation_585
        if key == 'ID':
            return Variation_586
        if key == 'MA':
            return Variation_587
        if key == 'SP':
            return Variation_588
        if key == 'HG':
            return Variation_589
        if key == 'HD':
            return Variation_590
        assert_never(key)

    def __init__(self, arg : Variation_591_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_591_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_591_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SR']) -> Variation_579:
        ...

    @overload
    def get_item(self, name : Literal['AR']) -> Variation_580:
        ...

    @overload
    def get_item(self, name : Literal['ER']) -> Variation_581:
        ...

    @overload
    def get_item(self, name : Literal['FR']) -> Variation_582:
        ...

    @overload
    def get_item(self, name : Literal['MR']) -> Variation_583:
        ...

    @overload
    def get_item(self, name : Literal['PR']) -> Variation_584:
        ...

    @overload
    def get_item(self, name : Literal['CR']) -> Variation_585:
        ...

    @overload
    def get_item(self, name : Literal['ID']) -> Variation_586:
        ...

    @overload
    def get_item(self, name : Literal['MA']) -> Variation_587:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_588:
        ...

    @overload
    def get_item(self, name : Literal['HG']) -> Variation_589:
        ...

    @overload
    def get_item(self, name : Literal['HD']) -> Variation_590:
        ...

    def get_item(self, name : Union[Literal['SR'], Literal['AR'], Literal['ER'], Literal['FR'], Literal['MR'], Literal['PR'], Literal['CR'], Literal['ID'], Literal['MA'], Literal['SP'], Literal['HG'], Literal['HD']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SR'], val : Union[Variation_579, Variation_579_Arg]) -> 'Variation_591':
        ...

    @overload
    def set_item(self, name : Literal['AR'], val : Union[Variation_580, Variation_580_Arg]) -> 'Variation_591':
        ...

    @overload
    def set_item(self, name : Literal['ER'], val : Union[Variation_581, Variation_581_Arg]) -> 'Variation_591':
        ...

    @overload
    def set_item(self, name : Literal['FR'], val : Union[Variation_582, Variation_582_Arg]) -> 'Variation_591':
        ...

    @overload
    def set_item(self, name : Literal['MR'], val : Union[Variation_583, Variation_583_Arg]) -> 'Variation_591':
        ...

    @overload
    def set_item(self, name : Literal['PR'], val : Union[Variation_584, Variation_584_Arg]) -> 'Variation_591':
        ...

    @overload
    def set_item(self, name : Literal['CR'], val : Union[Variation_585, Variation_585_Arg]) -> 'Variation_591':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SR'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['AR'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['ER'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['FR'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['MR'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['PR'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['CR'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['ID'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['MA'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['HG'], f : Any) -> 'Variation_591':
        ...

    @overload
    def modify_item(self, name : Literal['HD'], f : Any) -> 'Variation_591':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_592_Arg : TypeAlias = Raw
class Variation_592(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 3
    table = {
        0: 'No communications capability (surveillance only)',
        1: 'Comm. A and Comm. B capability',
        2: 'Comm. A, Comm. B and Uplink ELM',
        3: 'Comm. A, Comm. B and Uplink ELM and Downlink ELM',
        4: 'Level 5 Transponder capability',
    }

    def __init__(self, arg : Variation_592_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_593_Arg_Group = TypedDict('Variation_593_Arg_Group', {
    'COM': Union[Variation_592, Variation_592_Arg],
})
Variation_593_Arg : TypeAlias = Union[Raw, Variation_593_Arg_Group]
class Variation_593(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 5),
        ('COM', Variation_592),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COM': ('Communications Capability of the Transponder', Variation_592, 5, 3),
    }


    @classmethod
    def spec(cls, key : Union[Literal['COM']]) -> Union[Type['Variation_592']]:
        if key == 'COM':
            return Variation_592
        assert_never(key)

    def __init__(self, arg : Variation_593_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['COM']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['COM'], val : Union[Variation_592, Variation_592_Arg]) -> 'Variation_593':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_593':
        return self._modify_item(name, f) # type: ignore

Variation_594_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_594(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 3.90625e-3, 'NM')

    def __init__(self, arg : Variation_594_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_595_Arg_Group = TypedDict('Variation_595_Arg_Group', {
    'RHO': Union[Variation_594, Variation_594_Arg],
    'THETA': Union[Variation_14, Variation_14_Arg],
})
Variation_595_Arg : TypeAlias = Union[Raw, Variation_595_Arg_Group]
class Variation_595(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('RHO', Variation_594),
        ('THETA', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RHO': ('', Variation_594, 0, 16),
        'THETA': ('', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RHO']) -> Type[Variation_594]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['THETA']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RHO'], Literal['THETA']]) -> Union[Type['Variation_594'], Type['Variation_14']]:
        if key == 'RHO':
            return Variation_594
        if key == 'THETA':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_595_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RHO']) -> Variation_594:
        ...

    @overload
    def get_item(self, name : Literal['THETA']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['RHO'], Literal['THETA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RHO'], val : Union[Variation_594, Variation_594_Arg]) -> 'Variation_595':
        ...

    @overload
    def set_item(self, name : Literal['THETA'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_595':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RHO'], f : Any) -> 'Variation_595':
        ...

    @overload
    def modify_item(self, name : Literal['THETA'], f : Any) -> 'Variation_595':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_596_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_596(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 7.8125e-3, 'NM')

    def __init__(self, arg : Variation_596_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_597_Arg_Group = TypedDict('Variation_597_Arg_Group', {
    'X': Union[Variation_596, Variation_596_Arg],
    'Y': Union[Variation_596, Variation_596_Arg],
})
Variation_597_Arg : TypeAlias = Union[Raw, Variation_597_Arg_Group]
class Variation_597(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('X', Variation_596),
        ('Y', Variation_596),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('X-Component', Variation_596, 0, 16),
        'Y': ('Y-Component', Variation_596, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_596]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_596]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_596'], Type['Variation_596']]:
        if key == 'X':
            return Variation_596
        if key == 'Y':
            return Variation_596
        assert_never(key)

    def __init__(self, arg : Variation_597_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_596:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_596:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_596, Variation_596_Arg]) -> 'Variation_597':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_596, Variation_596_Arg]) -> 'Variation_597':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_597':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_597':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_598_Arg_Group = TypedDict('Variation_598_Arg_Group', {
    'PRIORITY': Union[Variation_187, Variation_187_Arg],
    'POWER': Union[Variation_282, Variation_282_Arg],
    'DURATION': Union[Variation_525, Variation_525_Arg],
    'COVERAGE': Union[Variation_555, Variation_555_Arg],
})
Variation_598_Arg : TypeAlias = Union[Raw, Variation_598_Arg_Group]
class Variation_598(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('PRIORITY', Variation_187),
        ('POWER', Variation_282),
        ('DURATION', Variation_525),
        ('COVERAGE', Variation_555),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PRIORITY': ('Priority', Variation_187, 0, 4),
        'POWER': ('Power', Variation_282, 4, 4),
        'DURATION': ('Duration', Variation_525, 8, 8),
        'COVERAGE': ('Coverage', Variation_555, 16, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PRIORITY']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POWER']) -> Type[Variation_282]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DURATION']) -> Type[Variation_525]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COVERAGE']) -> Type[Variation_555]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PRIORITY'], Literal['POWER'], Literal['DURATION'], Literal['COVERAGE']]) -> Union[Type['Variation_187'], Type['Variation_282'], Type['Variation_525'], Type['Variation_555']]:
        if key == 'PRIORITY':
            return Variation_187
        if key == 'POWER':
            return Variation_282
        if key == 'DURATION':
            return Variation_525
        if key == 'COVERAGE':
            return Variation_555
        assert_never(key)

    def __init__(self, arg : Variation_598_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PRIORITY']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['POWER']) -> Variation_282:
        ...

    @overload
    def get_item(self, name : Literal['DURATION']) -> Variation_525:
        ...

    @overload
    def get_item(self, name : Literal['COVERAGE']) -> Variation_555:
        ...

    def get_item(self, name : Union[Literal['PRIORITY'], Literal['POWER'], Literal['DURATION'], Literal['COVERAGE']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PRIORITY'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_598':
        ...

    @overload
    def set_item(self, name : Literal['POWER'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_598':
        ...

    @overload
    def set_item(self, name : Literal['DURATION'], val : Union[Variation_525, Variation_525_Arg]) -> 'Variation_598':
        ...

    @overload
    def set_item(self, name : Literal['COVERAGE'], val : Union[Variation_555, Variation_555_Arg]) -> 'Variation_598':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PRIORITY'], f : Any) -> 'Variation_598':
        ...

    @overload
    def modify_item(self, name : Literal['POWER'], f : Any) -> 'Variation_598':
        ...

    @overload
    def modify_item(self, name : Literal['DURATION'], f : Any) -> 'Variation_598':
        ...

    @overload
    def modify_item(self, name : Literal['COVERAGE'], f : Any) -> 'Variation_598':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_599_Arg_Group = TypedDict('Variation_599_Arg_Group', {
    'PREFIX': Union[Variation_367, Variation_367_Arg],
})
Variation_599_Arg : TypeAlias = Union[Raw, Variation_599_Arg_Group]
class Variation_599(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        Spare(0, 5),
        ('PREFIX', Variation_367),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PREFIX': ('Prefix Field', Variation_367, 5, 27),
    }


    @classmethod
    def spec(cls, key : Union[Literal['PREFIX']]) -> Union[Type['Variation_367']]:
        if key == 'PREFIX':
            return Variation_367
        assert_never(key)

    def __init__(self, arg : Variation_599_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['PREFIX']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['PREFIX'], val : Union[Variation_367, Variation_367_Arg]) -> 'Variation_599':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['PREFIX'], f : Any) -> 'Variation_599':
        return self._modify_item(name, f) # type: ignore

Variation_600_Arg_Group = TypedDict('Variation_600_Arg_Group', {
    'PREVIOUSII': Union[Variation_187, Variation_187_Arg],
    'CURRENTII': Union[Variation_282, Variation_282_Arg],
})
Variation_600_Arg : TypeAlias = Union[Raw, Variation_600_Arg_Group]
class Variation_600(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('PREVIOUSII', Variation_187),
        ('CURRENTII', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PREVIOUSII': ('Former II Code', Variation_187, 0, 4),
        'CURRENTII': ('Current II Code', Variation_282, 4, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PREVIOUSII']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CURRENTII']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PREVIOUSII'], Literal['CURRENTII']]) -> Union[Type['Variation_187'], Type['Variation_282']]:
        if key == 'PREVIOUSII':
            return Variation_187
        if key == 'CURRENTII':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_600_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PREVIOUSII']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['CURRENTII']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['PREVIOUSII'], Literal['CURRENTII']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PREVIOUSII'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_600':
        ...

    @overload
    def set_item(self, name : Literal['CURRENTII'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_600':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PREVIOUSII'], f : Any) -> 'Variation_600':
        ...

    @overload
    def modify_item(self, name : Literal['CURRENTII'], f : Any) -> 'Variation_600':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_601_Arg : TypeAlias = Raw
class Variation_601(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 48

    def __init__(self, arg : Variation_601_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_602_Arg_Group = TypedDict('Variation_602_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_276, Variation_276_Arg],
    'MOD3A': Union[Variation_19, Variation_19_Arg],
})
Variation_602_Arg : TypeAlias = Union[Raw, Variation_602_Arg_Group]
class Variation_602(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_276),
        Spare(3, 1),
        ('MOD3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'L': ('', Variation_276, 2, 1),
        'MOD3A': ('', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_276]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MOD3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MOD3A']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_276'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_276
        if key == 'MOD3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_602_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_276:
        ...

    @overload
    def get_item(self, name : Literal['MOD3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MOD3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_602':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_602':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_276, Variation_276_Arg]) -> 'Variation_602':
        ...

    @overload
    def set_item(self, name : Literal['MOD3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_602':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_602':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_602':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_602':
        ...

    @overload
    def modify_item(self, name : Literal['MOD3A'], f : Any) -> 'Variation_602':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_603_Arg_Group = TypedDict('Variation_603_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'FL': Union[Variation_21, Variation_21_Arg],
})
Variation_603_Arg : TypeAlias = Union[Raw, Variation_603_Arg_Group]
class Variation_603(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('FL', Variation_21),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'FL': ('Flight Level', Variation_21, 2, 14),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FL']) -> Type[Variation_21]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['FL']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_21']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'FL':
            return Variation_21
        assert_never(key)

    def __init__(self, arg : Variation_603_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['FL']) -> Variation_21:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['FL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_603':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_603':
        ...

    @overload
    def set_item(self, name : Literal['FL'], val : Union[Variation_21, Variation_21_Arg]) -> 'Variation_603':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_603':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_603':
        ...

    @overload
    def modify_item(self, name : Literal['FL'], f : Any) -> 'Variation_603':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_604_Arg : TypeAlias = Raw
class Variation_604(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Aircraft is airborne',
        1: 'Aircraft is on the ground',
    }

    def __init__(self, arg : Variation_604_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_605_Arg : TypeAlias = Raw
class Variation_605(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 7
    table = {
        0: 'The CQF calculation method is not supported',
        1: 'The CQF is minimum',
        126: 'The CQF is maximum',
        127: 'The CQF is undefined according to the calculation method',
    }

    def __init__(self, arg : Variation_605_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_606_Arg_Group = TypedDict('Variation_606_Arg_Group', {
    'FS': Union[Variation_604, Variation_604_Arg],
    'CQF': Union[Variation_605, Variation_605_Arg],
})
Variation_606_Arg : TypeAlias = Union[Raw, Variation_606_Arg_Group]
class Variation_606(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('FS', Variation_604),
        ('CQF', Variation_605),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FS': ('Flight Status', Variation_604, 0, 1),
        'CQF': ('Aircraft CQF', Variation_605, 1, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['FS']) -> Type[Variation_604]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CQF']) -> Type[Variation_605]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['FS'], Literal['CQF']]) -> Union[Type['Variation_604'], Type['Variation_605']]:
        if key == 'FS':
            return Variation_604
        if key == 'CQF':
            return Variation_605
        assert_never(key)

    def __init__(self, arg : Variation_606_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['FS']) -> Variation_604:
        ...

    @overload
    def get_item(self, name : Literal['CQF']) -> Variation_605:
        ...

    def get_item(self, name : Union[Literal['FS'], Literal['CQF']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['FS'], val : Union[Variation_604, Variation_604_Arg]) -> 'Variation_606':
        ...

    @overload
    def set_item(self, name : Literal['CQF'], val : Union[Variation_605, Variation_605_Arg]) -> 'Variation_606':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['FS'], f : Any) -> 'Variation_606':
        ...

    @overload
    def modify_item(self, name : Literal['CQF'], f : Any) -> 'Variation_606':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_607_Arg = TypedDict('Variation_607_Arg', {
    '036': Union[Variation_1, Variation_1_Arg],
    '037': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_551, Variation_551_Arg],
    '001': Union[Variation_554, Variation_554_Arg],
    '005': Union[Variation_278, Variation_278_Arg],
    '016': Union[Variation_555, Variation_555_Arg],
    '017': Union[Variation_556, Variation_556_Arg],
    '018': Union[Variation_559, Variation_559_Arg],
    '019': Union[Variation_560, Variation_560_Arg],
    '028': Union[Variation_561, Variation_561_Arg],
    '030': Union[Variation_566, Variation_566_Arg],
    '025': Union[Variation_555, Variation_555_Arg],
    '027': Union[Variation_0, Variation_0_Arg],
    '029': Union[Variation_281, Variation_281_Arg],
    '002': Union[Variation_80, Variation_80_Arg],
    '006': Union[Variation_549, Variation_549_Arg],
    '007': Union[Variation_571, Variation_571_Arg],
    '008': Union[Variation_578, Variation_578_Arg],
    '009': Union[Variation_591, Variation_591_Arg],
    '010': Union[Variation_593, Variation_593_Arg],
    '011': Union[Variation_281, Variation_281_Arg],
    '014': Union[Variation_595, Variation_595_Arg],
    '015': Union[Variation_597, Variation_597_Arg],
    '020': Union[Variation_555, Variation_555_Arg],
    '021': Union[Variation_598, Variation_598_Arg],
    '022': Union[Variation_599, Variation_599_Arg],
    '023': Union[Variation_281, Variation_281_Arg],
    '004': Union[Variation_600, Variation_600_Arg],
    '031': Union[Variation_601, Variation_601_Arg],
    '032': Union[Variation_602, Variation_602_Arg],
    '033': Union[Variation_603, Variation_603_Arg],
    '034': Union[Variation_67, Variation_67_Arg],
    '035': Union[Variation_14, Variation_14_Arg],
    '012': Union[Variation_606, Variation_606_Arg],
    '013': Union[Variation_0, Variation_0_Arg],
}, total=False)
class Variation_607(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('036', Variation_1),
        ('037', Variation_1),
        ('000', Variation_551),
        ('001', Variation_554),
        ('005', Variation_278),
        ('016', Variation_555),
        ('017', Variation_556),
        ('018', Variation_559),
        ('019', Variation_560),
        ('028', Variation_561),
        ('030', Variation_566),
        ('025', Variation_555),
        ('027', Variation_0),
        ('029', Variation_281),
        ('002', Variation_80),
        ('006', Variation_549),
        ('007', Variation_571),
        ('008', Variation_578),
        ('009', Variation_591),
        ('010', Variation_593),
        ('011', Variation_281),
        ('014', Variation_595),
        ('015', Variation_597),
        ('020', Variation_555),
        ('021', Variation_598),
        ('022', Variation_599),
        ('023', Variation_281),
        ('004', Variation_600),
        ('031', Variation_601),
        ('032', Variation_602),
        ('033', Variation_603),
        ('034', Variation_67),
        ('035', Variation_14),
        ('012', Variation_606),
        ('013', Variation_0),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '036': ('Data Source Identifier', Variation_1, 0x8000000000),
        '037': ('Data Destination Identifier', Variation_1, 0x4000000000),
        '000': ('Message Type', Variation_551, 0x2000000000),
        '001': ('Result', Variation_554, 0x1000000000),
        '005': ('Mode S Address', Variation_278, 0x0800000000),
        '016': ('Packet Number', Variation_555, 0x0400000000),
        '017': ('Packet Number List', Variation_556, 0x0200000000),
        '018': ('Mode S Packet Properties', Variation_559, 0x0180000000),
        '019': ('Mode S Packet', Variation_560, 0x0140000000),
        '028': ('GICB Extraction Periodicity', Variation_561, 0x0120000000),
        '030': ('GICB Properties', Variation_566, 0x0110000000),
        '025': ('GICB Number', Variation_555, 0x0108000000),
        '027': ('BDS Code', Variation_0, 0x0104000000),
        '029': ('GICB Extracted', Variation_281, 0x0102000000),
        '002': ('Time of Day', Variation_80, 0x0101800000),
        '006': ('Mode S Address List', Variation_549, 0x0101400000),
        '007': ('Aircraft Data Link Command', Variation_571, 0x0101200000),
        '008': ('Aircraft Data Link Status', Variation_578, 0x0101100000),
        '009': ('Aircraft Data Link Report Request', Variation_591, 0x0101080000),
        '010': ('Transponder Communications Capability', Variation_593, 0x0101040000),
        '011': ('Capability Report', Variation_281, 0x0101020000),
        '014': ('Aircraft Position in Polar Co-ordinates', Variation_595, 0x0101018000),
        '015': ('Aircraft Position in Cartesian Co-ordinates', Variation_597, 0x0101014000),
        '020': ('Broadcast Number', Variation_555, 0x0101012000),
        '021': ('Broadcast Properties', Variation_598, 0x0101011000),
        '022': ('Broadcast Prefix', Variation_599, 0x0101010800),
        '023': ('Uplink or Downlink Broadcast', Variation_281, 0x0101010400),
        '004': ('II Code', Variation_600, 0x0101010200),
        '031': ('Aircraft Identity', Variation_601, 0x0101010180),
        '032': ('Aircraft Mode A', Variation_602, 0x0101010140),
        '033': ('Aircraft Height', Variation_603, 0x0101010120),
        '034': ('Aircraft Speed', Variation_67, 0x0101010110),
        '035': ('Aircraft Heading', Variation_14, 0x0101010108),
        '012': ('Aircraft Coverage Quality Factor', Variation_606, 0x0101010104),
        '013': ('Aircraft CQF Calculation Method', Variation_0, 0x0101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['036']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['037']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_551]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['001']) -> Type[Variation_554]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['005']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['016']) -> Type[Variation_555]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['017']) -> Type[Variation_556]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['018']) -> Type[Variation_559]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['019']) -> Type[Variation_560]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['028']) -> Type[Variation_561]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_566]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['025']) -> Type[Variation_555]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['027']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['029']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['002']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['006']) -> Type[Variation_549]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['007']) -> Type[Variation_571]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['008']) -> Type[Variation_578]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['009']) -> Type[Variation_591]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_593]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['011']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['014']) -> Type[Variation_595]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_597]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_555]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['021']) -> Type[Variation_598]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['022']) -> Type[Variation_599]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['023']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['004']) -> Type[Variation_600]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['031']) -> Type[Variation_601]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['032']) -> Type[Variation_602]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['033']) -> Type[Variation_603]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['034']) -> Type[Variation_67]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['035']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['012']) -> Type[Variation_606]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['013']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['036'], Literal['037'], Literal['000'], Literal['001'], Literal['005'], Literal['016'], Literal['017'], Literal['018'], Literal['019'], Literal['028'], Literal['030'], Literal['025'], Literal['027'], Literal['029'], Literal['002'], Literal['006'], Literal['007'], Literal['008'], Literal['009'], Literal['010'], Literal['011'], Literal['014'], Literal['015'], Literal['020'], Literal['021'], Literal['022'], Literal['023'], Literal['004'], Literal['031'], Literal['032'], Literal['033'], Literal['034'], Literal['035'], Literal['012'], Literal['013']]) -> Union[Type['Variation_1'], Type['Variation_1'], Type['Variation_551'], Type['Variation_554'], Type['Variation_278'], Type['Variation_555'], Type['Variation_556'], Type['Variation_559'], Type['Variation_560'], Type['Variation_561'], Type['Variation_566'], Type['Variation_555'], Type['Variation_0'], Type['Variation_281'], Type['Variation_80'], Type['Variation_549'], Type['Variation_571'], Type['Variation_578'], Type['Variation_591'], Type['Variation_593'], Type['Variation_281'], Type['Variation_595'], Type['Variation_597'], Type['Variation_555'], Type['Variation_598'], Type['Variation_599'], Type['Variation_281'], Type['Variation_600'], Type['Variation_601'], Type['Variation_602'], Type['Variation_603'], Type['Variation_67'], Type['Variation_14'], Type['Variation_606'], Type['Variation_0']]:
        if key == '036':
            return Variation_1
        if key == '037':
            return Variation_1
        if key == '000':
            return Variation_551
        if key == '001':
            return Variation_554
        if key == '005':
            return Variation_278
        if key == '016':
            return Variation_555
        if key == '017':
            return Variation_556
        if key == '018':
            return Variation_559
        if key == '019':
            return Variation_560
        if key == '028':
            return Variation_561
        if key == '030':
            return Variation_566
        if key == '025':
            return Variation_555
        if key == '027':
            return Variation_0
        if key == '029':
            return Variation_281
        if key == '002':
            return Variation_80
        if key == '006':
            return Variation_549
        if key == '007':
            return Variation_571
        if key == '008':
            return Variation_578
        if key == '009':
            return Variation_591
        if key == '010':
            return Variation_593
        if key == '011':
            return Variation_281
        if key == '014':
            return Variation_595
        if key == '015':
            return Variation_597
        if key == '020':
            return Variation_555
        if key == '021':
            return Variation_598
        if key == '022':
            return Variation_599
        if key == '023':
            return Variation_281
        if key == '004':
            return Variation_600
        if key == '031':
            return Variation_601
        if key == '032':
            return Variation_602
        if key == '033':
            return Variation_603
        if key == '034':
            return Variation_67
        if key == '035':
            return Variation_14
        if key == '012':
            return Variation_606
        if key == '013':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Optional[Variation_607_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['036'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['037'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_551, Variation_551_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['001'], val : Union[Variation_554, Variation_554_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['005'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['016'], val : Union[Variation_555, Variation_555_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['017'], val : Union[Variation_556, Variation_556_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['018'], val : Union[Variation_559, Variation_559_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['019'], val : Union[Variation_560, Variation_560_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['028'], val : Union[Variation_561, Variation_561_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_566, Variation_566_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['025'], val : Union[Variation_555, Variation_555_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['027'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['029'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['002'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['006'], val : Union[Variation_549, Variation_549_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['007'], val : Union[Variation_571, Variation_571_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['008'], val : Union[Variation_578, Variation_578_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['009'], val : Union[Variation_591, Variation_591_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_593, Variation_593_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['011'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['014'], val : Union[Variation_595, Variation_595_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_597, Variation_597_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_555, Variation_555_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['021'], val : Union[Variation_598, Variation_598_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['022'], val : Union[Variation_599, Variation_599_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['023'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['004'], val : Union[Variation_600, Variation_600_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['031'], val : Union[Variation_601, Variation_601_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['032'], val : Union[Variation_602, Variation_602_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['033'], val : Union[Variation_603, Variation_603_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['034'], val : Union[Variation_67, Variation_67_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['035'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['012'], val : Union[Variation_606, Variation_606_Arg]) -> 'Variation_607':
        ...

    @overload
    def set_item(self, name : Literal['013'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_607':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['036']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['037']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['001']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['005']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['016']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['017']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['018']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['019']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['028']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['025']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['027']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['029']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['002']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['006']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['007']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['008']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['009']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['011']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['014']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['021']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['022']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['023']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['004']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['031']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['032']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['033']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['034']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['035']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['012']) -> 'Variation_607':
        ...

    @overload
    def del_item(self, name : Literal['013']) -> 'Variation_607':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['036']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['037']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_551:
        ...

    @overload
    def get_item(self, name : Literal['001']) -> Variation_554:
        ...

    @overload
    def get_item(self, name : Literal['005']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['016']) -> Variation_555:
        ...

    @overload
    def get_item(self, name : Literal['017']) -> Variation_556:
        ...

    @overload
    def get_item(self, name : Literal['018']) -> Variation_559:
        ...

    @overload
    def get_item(self, name : Literal['019']) -> Variation_560:
        ...

    @overload
    def get_item(self, name : Literal['028']) -> Variation_561:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_566:
        ...

    @overload
    def get_item(self, name : Literal['025']) -> Variation_555:
        ...

    @overload
    def get_item(self, name : Literal['027']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['029']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['002']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['006']) -> Variation_549:
        ...

    @overload
    def get_item(self, name : Literal['007']) -> Variation_571:
        ...

    @overload
    def get_item(self, name : Literal['008']) -> Variation_578:
        ...

    @overload
    def get_item(self, name : Literal['009']) -> Variation_591:
        ...

    @overload
    def get_item(self, name : Literal['010']) -> Variation_593:
        ...

    @overload
    def get_item(self, name : Literal['011']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['014']) -> Variation_595:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_597:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_555:
        ...

    @overload
    def get_item(self, name : Literal['021']) -> Variation_598:
        ...

    @overload
    def get_item(self, name : Literal['022']) -> Variation_599:
        ...

    @overload
    def get_item(self, name : Literal['023']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['004']) -> Variation_600:
        ...

    @overload
    def get_item(self, name : Literal['031']) -> Variation_601:
        ...

    @overload
    def get_item(self, name : Literal['032']) -> Variation_602:
        ...

    @overload
    def get_item(self, name : Literal['033']) -> Variation_603:
        ...

    @overload
    def get_item(self, name : Literal['034']) -> Variation_67:
        ...

    @overload
    def get_item(self, name : Literal['035']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['012']) -> Variation_606:
        ...

    @overload
    def get_item(self, name : Literal['013']) -> Variation_0:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['036'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['037'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['001'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['005'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['016'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['017'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['018'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['019'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['028'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['025'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['027'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['029'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['002'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['006'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['007'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['008'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['009'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['011'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['014'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['021'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['022'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['023'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['004'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['031'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['032'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['033'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['034'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['035'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['012'], f : Any) -> 'Variation_607':
        ...

    @overload
    def modify_item(self, name : Literal['013'], f : Any) -> 'Variation_607':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_608_Arg : TypeAlias = Raw
class Variation_608(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Start of Update Cycle',
        2: 'Periodic Status Message',
        3: 'Event-triggered Status Message',
    }

    def __init__(self, arg : Variation_608_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_609_Arg : TypeAlias = Raw
class Variation_609(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Operational',
        1: 'Degraded',
        2: 'NOGO',
        3: 'Undefined',
    }

    def __init__(self, arg : Variation_609_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_610_Arg : TypeAlias = Raw
class Variation_610(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Test Target Operative',
        1: 'Test Target Failure',
    }

    def __init__(self, arg : Variation_610_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_611_Arg_Group = TypedDict('Variation_611_Arg_Group', {
    'NOGO': Union[Variation_609, Variation_609_Arg],
    'OVL': Union[Variation_292, Variation_292_Arg],
    'TSV': Union[Variation_293, Variation_293_Arg],
    'TTF': Union[Variation_610, Variation_610_Arg],
})
Variation_611_Arg : TypeAlias = Union[Raw, Variation_611_Arg_Group]
class Variation_611(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('NOGO', Variation_609),
        ('OVL', Variation_292),
        ('TSV', Variation_293),
        ('TTF', Variation_610),
        Spare(5, 3),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NOGO': ('Operational Release Status of the System', Variation_609, 0, 2),
        'OVL': ('Overload Indicator', Variation_292, 2, 1),
        'TSV': ('Time Source Validity', Variation_293, 3, 1),
        'TTF': ('Test Target', Variation_610, 4, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NOGO']) -> Type[Variation_609]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVL']) -> Type[Variation_292]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSV']) -> Type[Variation_293]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TTF']) -> Type[Variation_610]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NOGO'], Literal['OVL'], Literal['TSV'], Literal['TTF']]) -> Union[Type['Variation_609'], Type['Variation_292'], Type['Variation_293'], Type['Variation_610']]:
        if key == 'NOGO':
            return Variation_609
        if key == 'OVL':
            return Variation_292
        if key == 'TSV':
            return Variation_293
        if key == 'TTF':
            return Variation_610
        assert_never(key)

    def __init__(self, arg : Variation_611_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NOGO']) -> Variation_609:
        ...

    @overload
    def get_item(self, name : Literal['OVL']) -> Variation_292:
        ...

    @overload
    def get_item(self, name : Literal['TSV']) -> Variation_293:
        ...

    @overload
    def get_item(self, name : Literal['TTF']) -> Variation_610:
        ...

    def get_item(self, name : Union[Literal['NOGO'], Literal['OVL'], Literal['TSV'], Literal['TTF']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NOGO'], val : Union[Variation_609, Variation_609_Arg]) -> 'Variation_611':
        ...

    @overload
    def set_item(self, name : Literal['OVL'], val : Union[Variation_292, Variation_292_Arg]) -> 'Variation_611':
        ...

    @overload
    def set_item(self, name : Literal['TSV'], val : Union[Variation_293, Variation_293_Arg]) -> 'Variation_611':
        ...

    @overload
    def set_item(self, name : Literal['TTF'], val : Union[Variation_610, Variation_610_Arg]) -> 'Variation_611':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NOGO'], f : Any) -> 'Variation_611':
        ...

    @overload
    def modify_item(self, name : Literal['OVL'], f : Any) -> 'Variation_611':
        ...

    @overload
    def modify_item(self, name : Literal['TSV'], f : Any) -> 'Variation_611':
        ...

    @overload
    def modify_item(self, name : Literal['TTF'], f : Any) -> 'Variation_611':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_612_Arg : TypeAlias = Raw
class Variation_612(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Standby',
        1: 'Exec',
    }

    def __init__(self, arg : Variation_612_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_613_Arg : TypeAlias = Raw
class Variation_613(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Faulted',
        1: 'Good',
    }

    def __init__(self, arg : Variation_613_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_614_Arg : TypeAlias = Raw
class Variation_614(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Standby',
        1: 'Exec',
    }

    def __init__(self, arg : Variation_614_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_615_Arg : TypeAlias = Raw
class Variation_615(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Faulted',
        1: 'Good',
    }

    def __init__(self, arg : Variation_615_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_616_Arg : TypeAlias = Raw
class Variation_616(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Standby',
        1: 'Exec',
    }

    def __init__(self, arg : Variation_616_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_617_Arg : TypeAlias = Raw
class Variation_617(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Faulted',
        1: 'Good',
    }

    def __init__(self, arg : Variation_617_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_618_Arg : TypeAlias = Raw
class Variation_618(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Standby',
        1: 'Exec',
    }

    def __init__(self, arg : Variation_618_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_619_Arg : TypeAlias = Raw
class Variation_619(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'Faulted',
        1: 'Good',
    }

    def __init__(self, arg : Variation_619_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_620_Arg_Group = TypedDict('Variation_620_Arg_Group', {
    'TP1A': Union[Variation_612, Variation_612_Arg],
    'TP1B': Union[Variation_613, Variation_613_Arg],
    'TP2A': Union[Variation_614, Variation_614_Arg],
    'TP2B': Union[Variation_615, Variation_615_Arg],
    'TP3A': Union[Variation_616, Variation_616_Arg],
    'TP3B': Union[Variation_617, Variation_617_Arg],
    'TP4A': Union[Variation_618, Variation_618_Arg],
    'TP4B': Union[Variation_619, Variation_619_Arg],
})
Variation_620_Arg : TypeAlias = Union[Raw, Variation_620_Arg_Group]
class Variation_620(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('TP1A', Variation_612),
        ('TP1B', Variation_613),
        ('TP2A', Variation_614),
        ('TP2B', Variation_615),
        ('TP3A', Variation_616),
        ('TP3B', Variation_617),
        ('TP4A', Variation_618),
        ('TP4B', Variation_619),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TP1A': ('', Variation_612, 0, 1),
        'TP1B': ('', Variation_613, 1, 1),
        'TP2A': ('', Variation_614, 2, 1),
        'TP2B': ('', Variation_615, 3, 1),
        'TP3A': ('', Variation_616, 4, 1),
        'TP3B': ('', Variation_617, 5, 1),
        'TP4A': ('', Variation_618, 6, 1),
        'TP4B': ('', Variation_619, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TP1A']) -> Type[Variation_612]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TP1B']) -> Type[Variation_613]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TP2A']) -> Type[Variation_614]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TP2B']) -> Type[Variation_615]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TP3A']) -> Type[Variation_616]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TP3B']) -> Type[Variation_617]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TP4A']) -> Type[Variation_618]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TP4B']) -> Type[Variation_619]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TP1A'], Literal['TP1B'], Literal['TP2A'], Literal['TP2B'], Literal['TP3A'], Literal['TP3B'], Literal['TP4A'], Literal['TP4B']]) -> Union[Type['Variation_612'], Type['Variation_613'], Type['Variation_614'], Type['Variation_615'], Type['Variation_616'], Type['Variation_617'], Type['Variation_618'], Type['Variation_619']]:
        if key == 'TP1A':
            return Variation_612
        if key == 'TP1B':
            return Variation_613
        if key == 'TP2A':
            return Variation_614
        if key == 'TP2B':
            return Variation_615
        if key == 'TP3A':
            return Variation_616
        if key == 'TP3B':
            return Variation_617
        if key == 'TP4A':
            return Variation_618
        if key == 'TP4B':
            return Variation_619
        assert_never(key)

    def __init__(self, arg : Variation_620_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TP1A']) -> Variation_612:
        ...

    @overload
    def get_item(self, name : Literal['TP1B']) -> Variation_613:
        ...

    @overload
    def get_item(self, name : Literal['TP2A']) -> Variation_614:
        ...

    @overload
    def get_item(self, name : Literal['TP2B']) -> Variation_615:
        ...

    @overload
    def get_item(self, name : Literal['TP3A']) -> Variation_616:
        ...

    @overload
    def get_item(self, name : Literal['TP3B']) -> Variation_617:
        ...

    @overload
    def get_item(self, name : Literal['TP4A']) -> Variation_618:
        ...

    @overload
    def get_item(self, name : Literal['TP4B']) -> Variation_619:
        ...

    def get_item(self, name : Union[Literal['TP1A'], Literal['TP1B'], Literal['TP2A'], Literal['TP2B'], Literal['TP3A'], Literal['TP3B'], Literal['TP4A'], Literal['TP4B']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TP1A'], val : Union[Variation_612, Variation_612_Arg]) -> 'Variation_620':
        ...

    @overload
    def set_item(self, name : Literal['TP1B'], val : Union[Variation_613, Variation_613_Arg]) -> 'Variation_620':
        ...

    @overload
    def set_item(self, name : Literal['TP2A'], val : Union[Variation_614, Variation_614_Arg]) -> 'Variation_620':
        ...

    @overload
    def set_item(self, name : Literal['TP2B'], val : Union[Variation_615, Variation_615_Arg]) -> 'Variation_620':
        ...

    @overload
    def set_item(self, name : Literal['TP3A'], val : Union[Variation_616, Variation_616_Arg]) -> 'Variation_620':
        ...

    @overload
    def set_item(self, name : Literal['TP3B'], val : Union[Variation_617, Variation_617_Arg]) -> 'Variation_620':
        ...

    @overload
    def set_item(self, name : Literal['TP4A'], val : Union[Variation_618, Variation_618_Arg]) -> 'Variation_620':
        ...

    @overload
    def set_item(self, name : Literal['TP4B'], val : Union[Variation_619, Variation_619_Arg]) -> 'Variation_620':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TP1A'], f : Any) -> 'Variation_620':
        ...

    @overload
    def modify_item(self, name : Literal['TP1B'], f : Any) -> 'Variation_620':
        ...

    @overload
    def modify_item(self, name : Literal['TP2A'], f : Any) -> 'Variation_620':
        ...

    @overload
    def modify_item(self, name : Literal['TP2B'], f : Any) -> 'Variation_620':
        ...

    @overload
    def modify_item(self, name : Literal['TP3A'], f : Any) -> 'Variation_620':
        ...

    @overload
    def modify_item(self, name : Literal['TP3B'], f : Any) -> 'Variation_620':
        ...

    @overload
    def modify_item(self, name : Literal['TP4A'], f : Any) -> 'Variation_620':
        ...

    @overload
    def modify_item(self, name : Literal['TP4B'], f : Any) -> 'Variation_620':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_621_Arg : TypeAlias = Raw
class Variation_621(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Not present',
        1: 'Present',
    }

    def __init__(self, arg : Variation_621_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_622_Arg : TypeAlias = Raw
class Variation_622(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Not present',
        1: 'Present',
    }

    def __init__(self, arg : Variation_622_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_623_Arg : TypeAlias = Raw
class Variation_623(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Not present',
        1: 'Present',
    }

    def __init__(self, arg : Variation_623_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_624_Arg : TypeAlias = Raw
class Variation_624(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Faulted',
        1: 'Good',
    }

    def __init__(self, arg : Variation_624_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_625_Arg : TypeAlias = Raw
class Variation_625(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Offline',
        1: 'Online',
    }

    def __init__(self, arg : Variation_625_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_626_Arg_Group = TypedDict('Variation_626_Arg_Group', {
    'RSI': Union[Variation_0, Variation_0_Arg],
    'RS1090': Union[Variation_621, Variation_621_Arg],
    'TX1030': Union[Variation_622, Variation_622_Arg],
    'TX1090': Union[Variation_623, Variation_623_Arg],
    'RSS': Union[Variation_624, Variation_624_Arg],
    'RSO': Union[Variation_625, Variation_625_Arg],
})
Variation_626_Arg : TypeAlias = Union[Raw, Variation_626_Arg_Group]
class Variation_626(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('RSI', Variation_0),
        Spare(0, 1),
        ('RS1090', Variation_621),
        ('TX1030', Variation_622),
        ('TX1090', Variation_623),
        ('RSS', Variation_624),
        ('RSO', Variation_625),
        Spare(6, 2),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RSI': ('8-bit Identification Number of RS', Variation_0, 0, 8),
        'RS1090': ('Receiver 1090 MHz', Variation_621, 9, 1),
        'TX1030': ('Transmitter 1030 MHz', Variation_622, 10, 1),
        'TX1090': ('Transmitter 1090 MHz', Variation_623, 11, 1),
        'RSS': ('RS Status', Variation_624, 12, 1),
        'RSO': ('RS Operational', Variation_625, 13, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RSI']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RS1090']) -> Type[Variation_621]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TX1030']) -> Type[Variation_622]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TX1090']) -> Type[Variation_623]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSS']) -> Type[Variation_624]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RSO']) -> Type[Variation_625]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RSI'], Literal['RS1090'], Literal['TX1030'], Literal['TX1090'], Literal['RSS'], Literal['RSO']]) -> Union[Type['Variation_0'], Type['Variation_621'], Type['Variation_622'], Type['Variation_623'], Type['Variation_624'], Type['Variation_625']]:
        if key == 'RSI':
            return Variation_0
        if key == 'RS1090':
            return Variation_621
        if key == 'TX1030':
            return Variation_622
        if key == 'TX1090':
            return Variation_623
        if key == 'RSS':
            return Variation_624
        if key == 'RSO':
            return Variation_625
        assert_never(key)

    def __init__(self, arg : Variation_626_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RSI']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['RS1090']) -> Variation_621:
        ...

    @overload
    def get_item(self, name : Literal['TX1030']) -> Variation_622:
        ...

    @overload
    def get_item(self, name : Literal['TX1090']) -> Variation_623:
        ...

    @overload
    def get_item(self, name : Literal['RSS']) -> Variation_624:
        ...

    @overload
    def get_item(self, name : Literal['RSO']) -> Variation_625:
        ...

    def get_item(self, name : Union[Literal['RSI'], Literal['RS1090'], Literal['TX1030'], Literal['TX1090'], Literal['RSS'], Literal['RSO']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RSI'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_626':
        ...

    @overload
    def set_item(self, name : Literal['RS1090'], val : Union[Variation_621, Variation_621_Arg]) -> 'Variation_626':
        ...

    @overload
    def set_item(self, name : Literal['TX1030'], val : Union[Variation_622, Variation_622_Arg]) -> 'Variation_626':
        ...

    @overload
    def set_item(self, name : Literal['TX1090'], val : Union[Variation_623, Variation_623_Arg]) -> 'Variation_626':
        ...

    @overload
    def set_item(self, name : Literal['RSS'], val : Union[Variation_624, Variation_624_Arg]) -> 'Variation_626':
        ...

    @overload
    def set_item(self, name : Literal['RSO'], val : Union[Variation_625, Variation_625_Arg]) -> 'Variation_626':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RSI'], f : Any) -> 'Variation_626':
        ...

    @overload
    def modify_item(self, name : Literal['RS1090'], f : Any) -> 'Variation_626':
        ...

    @overload
    def modify_item(self, name : Literal['TX1030'], f : Any) -> 'Variation_626':
        ...

    @overload
    def modify_item(self, name : Literal['TX1090'], f : Any) -> 'Variation_626':
        ...

    @overload
    def modify_item(self, name : Literal['RSS'], f : Any) -> 'Variation_626':
        ...

    @overload
    def modify_item(self, name : Literal['RSO'], f : Any) -> 'Variation_626':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_627_Arg : TypeAlias = Union[Variation_626, Variation_626_Arg]
class Variation_627(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_626

    @classmethod
    def spec(cls) -> Type[Variation_626]:
        return Variation_626

    def __init__(self, arg : List[Union[Variation_626, Variation_626_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_626, Variation_626_Arg]) -> 'Variation_627':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_626, Variation_626_Arg]) -> 'Variation_627':
        return self._prepend_item(arg) # type: ignore

Variation_628_Arg : TypeAlias = Raw
class Variation_628(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        1: 'Warning',
        2: 'Faulted',
        3: 'Good',
    }

    def __init__(self, arg : Variation_628_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_629_Arg : TypeAlias = Raw
class Variation_629(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        1: 'Warning',
        2: 'Faulted',
        3: 'Good',
    }

    def __init__(self, arg : Variation_629_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_630_Arg_Group_1 = TypedDict('Variation_630_Arg_Group_1', {
    'REFTR1': Union[Variation_628, Variation_628_Arg],
    'REFTR2': Union[Variation_629, Variation_629_Arg],
})
Variation_630_Arg_Group_2 = TypedDict('Variation_630_Arg_Group_2', {
    'REFTR1': Union[Variation_628, Variation_628_Arg],
    'REFTR2': Union[Variation_629, Variation_629_Arg],
    'REFTR3': Union[Variation_628, Variation_628_Arg],
    'REFTR4': Union[Variation_629, Variation_629_Arg],
})
Variation_630_Arg : TypeAlias = Union[
    int,
    Variation_630_Arg_Group_1,
    Tuple[int],
    Variation_630_Arg_Group_2,
    Tuple[int,int],
]
class Variation_630(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('REFTR1', Variation_628),
            Spare(2, 2),
            ('REFTR2', Variation_629),
            Spare(6, 1),
        ],
        [
            ('REFTR3', Variation_628),
            Spare(2, 2),
            ('REFTR4', Variation_629),
            Spare(6, 1),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'REFTR1': ('Ref Trans 1 Status', Variation_628, 0, 2),
        'REFTR2': ('Ref Trans 2 Status', Variation_629, 4, 2),
        'REFTR3': ('Ref Trans 3 Status', Variation_628, 0, 2),
        'REFTR4': ('Ref Trans 4 Status', Variation_629, 4, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['REFTR1']) -> Type[Variation_628]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['REFTR2']) -> Type[Variation_629]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['REFTR3']) -> Type[Variation_628]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['REFTR4']) -> Type[Variation_629]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['REFTR1'], Literal['REFTR2'], Literal['REFTR3'], Literal['REFTR4']]) -> Union[Type['Variation_628'], Type['Variation_629'], Type['Variation_628'], Type['Variation_629']]:
        if key == 'REFTR1':
            return Variation_628
        if key == 'REFTR2':
            return Variation_629
        if key == 'REFTR3':
            return Variation_628
        if key == 'REFTR4':
            return Variation_629
        assert_never(key)

    def __init__(self, arg : Variation_630_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_630_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_630_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['REFTR1']) -> Variation_628:
        ...

    @overload
    def get_item(self, name : Literal['REFTR2']) -> Variation_629:
        ...

    @overload
    def get_item(self, name : Literal['REFTR3']) -> Variation_628:
        ...

    @overload
    def get_item(self, name : Literal['REFTR4']) -> Variation_629:
        ...

    def get_item(self, name : Union[Literal['REFTR1'], Literal['REFTR2'], Literal['REFTR3'], Literal['REFTR4']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['REFTR1'], val : Union[Variation_628, Variation_628_Arg]) -> 'Variation_630':
        ...

    @overload
    def set_item(self, name : Literal['REFTR2'], val : Union[Variation_629, Variation_629_Arg]) -> 'Variation_630':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['REFTR1'], f : Any) -> 'Variation_630':
        ...

    @overload
    def modify_item(self, name : Literal['REFTR2'], f : Any) -> 'Variation_630':
        ...

    @overload
    def modify_item(self, name : Literal['REFTR3'], f : Any) -> 'Variation_630':
        ...

    @overload
    def modify_item(self, name : Literal['REFTR4'], f : Any) -> 'Variation_630':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_631_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_631(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 32
    quantity = Quantity('Signed', 1.6763806343078613e-7, '°')

    def __init__(self, arg : Variation_631_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_632_Arg_Group = TypedDict('Variation_632_Arg_Group', {
    'LAT': Union[Variation_631, Variation_631_Arg],
    'LON': Union[Variation_631, Variation_631_Arg],
})
Variation_632_Arg : TypeAlias = Union[Raw, Variation_632_Arg_Group]
class Variation_632(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('LAT', Variation_631),
        ('LON', Variation_631),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude', Variation_631, 0, 32),
        'LON': ('Longitude', Variation_631, 32, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_631]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_631]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_631'], Type['Variation_631']]:
        if key == 'LAT':
            return Variation_631
        if key == 'LON':
            return Variation_631
        assert_never(key)

    def __init__(self, arg : Variation_632_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_631:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_631:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_631, Variation_631_Arg]) -> 'Variation_632':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_631, Variation_631_Arg]) -> 'Variation_632':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_632':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_632':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_633_Arg = TypedDict('Variation_633_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_608, Variation_608_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '550': Union[Variation_611, Variation_611_Arg],
    '551': Union[Variation_620, Variation_620_Arg],
    '552': Union[Variation_627, Variation_627_Arg],
    '553': Union[Variation_630, Variation_630_Arg],
    '600': Union[Variation_632, Variation_632_Arg],
    '610': Union[Variation_301, Variation_301_Arg],
    '620': Union[Variation_303, Variation_303_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_633(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_608),
        ('140', Variation_80),
        ('550', Variation_611),
        ('551', Variation_620),
        ('552', Variation_627),
        ('553', Variation_630),
        ('600', Variation_632),
        ('610', Variation_301),
        ('620', Variation_303),
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Message Type', Variation_608, 0x4000),
        '140': ('Time of Day', Variation_80, 0x2000),
        '550': ('System Status', Variation_611, 0x1000),
        '551': ('Tracking Processor Detailed Status', Variation_620, 0x0800),
        '552': ('Remote Sensor Detailed Status', Variation_627, 0x0400),
        '553': ('Reference Transponder Detailed Status', Variation_630, 0x0200),
        '600': ('Position of the MLT System Reference Point', Variation_632, 0x0180),
        '610': ('Height of the MLT System Reference Point', Variation_301, 0x0140),
        '620': ('WGS-84 Undulation', Variation_303, 0x0120),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0104),
        'SP': ('Special Purpose Field', Variation_62, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_608]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['550']) -> Type[Variation_611]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['551']) -> Type[Variation_620]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['552']) -> Type[Variation_627]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['553']) -> Type[Variation_630]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['600']) -> Type[Variation_632]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['610']) -> Type[Variation_301]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['620']) -> Type[Variation_303]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['140'], Literal['550'], Literal['551'], Literal['552'], Literal['553'], Literal['600'], Literal['610'], Literal['620'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_608'], Type['Variation_80'], Type['Variation_611'], Type['Variation_620'], Type['Variation_627'], Type['Variation_630'], Type['Variation_632'], Type['Variation_301'], Type['Variation_303'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_608
        if key == '140':
            return Variation_80
        if key == '550':
            return Variation_611
        if key == '551':
            return Variation_620
        if key == '552':
            return Variation_627
        if key == '553':
            return Variation_630
        if key == '600':
            return Variation_632
        if key == '610':
            return Variation_301
        if key == '620':
            return Variation_303
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_633_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_608, Variation_608_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['550'], val : Union[Variation_611, Variation_611_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['551'], val : Union[Variation_620, Variation_620_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['552'], val : Union[Variation_627, Variation_627_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['553'], val : Union[Variation_630, Variation_630_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['600'], val : Union[Variation_632, Variation_632_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['610'], val : Union[Variation_301, Variation_301_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['620'], val : Union[Variation_303, Variation_303_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_633':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_633':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['550']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['551']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['552']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['553']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['600']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['610']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['620']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_633':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_633':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_608:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['550']) -> Variation_611:
        ...

    @overload
    def get_item(self, name : Literal['551']) -> Variation_620:
        ...

    @overload
    def get_item(self, name : Literal['552']) -> Variation_627:
        ...

    @overload
    def get_item(self, name : Literal['553']) -> Variation_630:
        ...

    @overload
    def get_item(self, name : Literal['600']) -> Variation_632:
        ...

    @overload
    def get_item(self, name : Literal['610']) -> Variation_301:
        ...

    @overload
    def get_item(self, name : Literal['620']) -> Variation_303:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['550'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['551'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['552'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['553'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['600'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['610'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['620'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_633':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_633':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_634_Arg : TypeAlias = Raw
class Variation_634(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Non-Mode S 1090MHz multilateration',
        1: 'No Non-Mode S 1090MHz multilat',
    }

    def __init__(self, arg : Variation_634_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_635_Arg : TypeAlias = Raw
class Variation_635(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Mode-S 1090 MHz multilateration',
        1: 'No Mode-S 1090 MHz multilateration',
    }

    def __init__(self, arg : Variation_635_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_636_Arg : TypeAlias = Raw
class Variation_636(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'HF multilateration',
        1: 'No HF multilateration',
    }

    def __init__(self, arg : Variation_636_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_637_Arg : TypeAlias = Raw
class Variation_637(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'VDL Mode 4 multilateration',
        1: 'No VDL Mode 4 multilateration',
    }

    def __init__(self, arg : Variation_637_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_638_Arg : TypeAlias = Raw
class Variation_638(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'UAT multilateration',
        1: 'No UAT multilateration',
    }

    def __init__(self, arg : Variation_638_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_639_Arg : TypeAlias = Raw
class Variation_639(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'DME/TACAN multilateration',
        1: 'No DME/TACAN multilateration',
    }

    def __init__(self, arg : Variation_639_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_640_Arg : TypeAlias = Raw
class Variation_640(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Other Technology Multilateration',
        1: 'No Other Technology Multilateration',
    }

    def __init__(self, arg : Variation_640_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_641_Arg : TypeAlias = Raw
class Variation_641(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Report from target transponder',
        1: 'Report from field monitor (element transponder)',
    }

    def __init__(self, arg : Variation_641_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_642_Arg : TypeAlias = Raw
class Variation_642(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Absence of SPI',
        1: 'Special Position Identification',
    }

    def __init__(self, arg : Variation_642_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_643_Arg : TypeAlias = Raw
class Variation_643(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Chain 1',
        1: 'Chain 2',
    }

    def __init__(self, arg : Variation_643_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_644_Arg : TypeAlias = Raw
class Variation_644(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Transponder Ground bit not set',
        1: 'Transponder Ground bit set',
    }

    def __init__(self, arg : Variation_644_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_645_Arg : TypeAlias = Raw
class Variation_645(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'No Corrupted reply in multilateration',
        1: 'Corrupted replies in multilateration',
    }

    def __init__(self, arg : Variation_645_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_646_Arg : TypeAlias = Raw
class Variation_646(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Actual target report',
        1: 'Simulated target report',
    }

    def __init__(self, arg : Variation_646_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_647_Arg : TypeAlias = Raw
class Variation_647(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Test Target',
    }

    def __init__(self, arg : Variation_647_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_648_Arg_Group_1 = TypedDict('Variation_648_Arg_Group_1', {
    'SSR': Union[Variation_634, Variation_634_Arg],
    'MS': Union[Variation_635, Variation_635_Arg],
    'HF': Union[Variation_636, Variation_636_Arg],
    'VDL4': Union[Variation_637, Variation_637_Arg],
    'UAT': Union[Variation_638, Variation_638_Arg],
    'DME': Union[Variation_639, Variation_639_Arg],
    'OT': Union[Variation_640, Variation_640_Arg],
})
Variation_648_Arg_Group_2 = TypedDict('Variation_648_Arg_Group_2', {
    'SSR': Union[Variation_634, Variation_634_Arg],
    'MS': Union[Variation_635, Variation_635_Arg],
    'HF': Union[Variation_636, Variation_636_Arg],
    'VDL4': Union[Variation_637, Variation_637_Arg],
    'UAT': Union[Variation_638, Variation_638_Arg],
    'DME': Union[Variation_639, Variation_639_Arg],
    'OT': Union[Variation_640, Variation_640_Arg],
    'RAB': Union[Variation_641, Variation_641_Arg],
    'SPI': Union[Variation_642, Variation_642_Arg],
    'CHN': Union[Variation_643, Variation_643_Arg],
    'GBS': Union[Variation_644, Variation_644_Arg],
    'CRT': Union[Variation_645, Variation_645_Arg],
    'SIM': Union[Variation_646, Variation_646_Arg],
    'TST': Union[Variation_647, Variation_647_Arg],
})
Variation_648_Arg : TypeAlias = Union[
    int,
    Variation_648_Arg_Group_1,
    Tuple[int],
    Variation_648_Arg_Group_2,
    Tuple[int,int],
]
class Variation_648(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('SSR', Variation_634),
            ('MS', Variation_635),
            ('HF', Variation_636),
            ('VDL4', Variation_637),
            ('UAT', Variation_638),
            ('DME', Variation_639),
            ('OT', Variation_640),
        ],
        [
            ('RAB', Variation_641),
            ('SPI', Variation_642),
            ('CHN', Variation_643),
            ('GBS', Variation_644),
            ('CRT', Variation_645),
            ('SIM', Variation_646),
            ('TST', Variation_647),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SSR': ('', Variation_634, 0, 1),
        'MS': ('', Variation_635, 1, 1),
        'HF': ('', Variation_636, 2, 1),
        'VDL4': ('', Variation_637, 3, 1),
        'UAT': ('', Variation_638, 4, 1),
        'DME': ('', Variation_639, 5, 1),
        'OT': ('', Variation_640, 6, 1),
        'RAB': ('', Variation_641, 0, 1),
        'SPI': ('', Variation_642, 1, 1),
        'CHN': ('', Variation_643, 2, 1),
        'GBS': ('', Variation_644, 3, 1),
        'CRT': ('', Variation_645, 4, 1),
        'SIM': ('', Variation_646, 5, 1),
        'TST': ('', Variation_647, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_634]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MS']) -> Type[Variation_635]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HF']) -> Type[Variation_636]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VDL4']) -> Type[Variation_637]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['UAT']) -> Type[Variation_638]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DME']) -> Type[Variation_639]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OT']) -> Type[Variation_640]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_641]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_642]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHN']) -> Type[Variation_643]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GBS']) -> Type[Variation_644]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CRT']) -> Type[Variation_645]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_646]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_647]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SSR'], Literal['MS'], Literal['HF'], Literal['VDL4'], Literal['UAT'], Literal['DME'], Literal['OT'], Literal['RAB'], Literal['SPI'], Literal['CHN'], Literal['GBS'], Literal['CRT'], Literal['SIM'], Literal['TST']]) -> Union[Type['Variation_634'], Type['Variation_635'], Type['Variation_636'], Type['Variation_637'], Type['Variation_638'], Type['Variation_639'], Type['Variation_640'], Type['Variation_641'], Type['Variation_642'], Type['Variation_643'], Type['Variation_644'], Type['Variation_645'], Type['Variation_646'], Type['Variation_647']]:
        if key == 'SSR':
            return Variation_634
        if key == 'MS':
            return Variation_635
        if key == 'HF':
            return Variation_636
        if key == 'VDL4':
            return Variation_637
        if key == 'UAT':
            return Variation_638
        if key == 'DME':
            return Variation_639
        if key == 'OT':
            return Variation_640
        if key == 'RAB':
            return Variation_641
        if key == 'SPI':
            return Variation_642
        if key == 'CHN':
            return Variation_643
        if key == 'GBS':
            return Variation_644
        if key == 'CRT':
            return Variation_645
        if key == 'SIM':
            return Variation_646
        if key == 'TST':
            return Variation_647
        assert_never(key)

    def __init__(self, arg : Variation_648_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_648_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_648_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_634:
        ...

    @overload
    def get_item(self, name : Literal['MS']) -> Variation_635:
        ...

    @overload
    def get_item(self, name : Literal['HF']) -> Variation_636:
        ...

    @overload
    def get_item(self, name : Literal['VDL4']) -> Variation_637:
        ...

    @overload
    def get_item(self, name : Literal['UAT']) -> Variation_638:
        ...

    @overload
    def get_item(self, name : Literal['DME']) -> Variation_639:
        ...

    @overload
    def get_item(self, name : Literal['OT']) -> Variation_640:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_641:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_642:
        ...

    @overload
    def get_item(self, name : Literal['CHN']) -> Variation_643:
        ...

    @overload
    def get_item(self, name : Literal['GBS']) -> Variation_644:
        ...

    @overload
    def get_item(self, name : Literal['CRT']) -> Variation_645:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_646:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_647:
        ...

    def get_item(self, name : Union[Literal['SSR'], Literal['MS'], Literal['HF'], Literal['VDL4'], Literal['UAT'], Literal['DME'], Literal['OT'], Literal['RAB'], Literal['SPI'], Literal['CHN'], Literal['GBS'], Literal['CRT'], Literal['SIM'], Literal['TST']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SSR'], val : Union[Variation_634, Variation_634_Arg]) -> 'Variation_648':
        ...

    @overload
    def set_item(self, name : Literal['MS'], val : Union[Variation_635, Variation_635_Arg]) -> 'Variation_648':
        ...

    @overload
    def set_item(self, name : Literal['HF'], val : Union[Variation_636, Variation_636_Arg]) -> 'Variation_648':
        ...

    @overload
    def set_item(self, name : Literal['VDL4'], val : Union[Variation_637, Variation_637_Arg]) -> 'Variation_648':
        ...

    @overload
    def set_item(self, name : Literal['UAT'], val : Union[Variation_638, Variation_638_Arg]) -> 'Variation_648':
        ...

    @overload
    def set_item(self, name : Literal['DME'], val : Union[Variation_639, Variation_639_Arg]) -> 'Variation_648':
        ...

    @overload
    def set_item(self, name : Literal['OT'], val : Union[Variation_640, Variation_640_Arg]) -> 'Variation_648':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['MS'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['HF'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['VDL4'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['UAT'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['DME'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['OT'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['CHN'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['GBS'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['CRT'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_648':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_648':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_649_Arg_Group = TypedDict('Variation_649_Arg_Group', {
    'LAT': Union[Variation_147, Variation_147_Arg],
    'LON': Union[Variation_147, Variation_147_Arg],
})
Variation_649_Arg : TypeAlias = Union[Raw, Variation_649_Arg_Group]
class Variation_649(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('LAT', Variation_147),
        ('LON', Variation_147),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude', Variation_147, 0, 32),
        'LON': ('Longitude', Variation_147, 32, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_147]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_147]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_147'], Type['Variation_147']]:
        if key == 'LAT':
            return Variation_147
        if key == 'LON':
            return Variation_147
        assert_never(key)

    def __init__(self, arg : Variation_649_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_147:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_147:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_147, Variation_147_Arg]) -> 'Variation_649':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_147, Variation_147_Arg]) -> 'Variation_649':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_649':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_649':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_650_Arg_Group = TypedDict('Variation_650_Arg_Group', {
    'X': Union[Variation_150, Variation_150_Arg],
    'Y': Union[Variation_150, Variation_150_Arg],
})
Variation_650_Arg : TypeAlias = Union[Raw, Variation_650_Arg_Group]
class Variation_650(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('X', Variation_150),
        ('Y', Variation_150),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('X-coordinate', Variation_150, 0, 24),
        'Y': ('Y-coordinate', Variation_150, 24, 24),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_150]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_150]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_150'], Type['Variation_150']]:
        if key == 'X':
            return Variation_150
        if key == 'Y':
            return Variation_150
        assert_never(key)

    def __init__(self, arg : Variation_650_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_150:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_150:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_150, Variation_150_Arg]) -> 'Variation_650':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_150, Variation_150_Arg]) -> 'Variation_650':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_650':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_650':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_651_Arg_Group = TypedDict('Variation_651_Arg_Group', {
    'TRN': Union[Variation_43, Variation_43_Arg],
})
Variation_651_Arg : TypeAlias = Union[Raw, Variation_651_Arg_Group]
class Variation_651(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('TRN', Variation_43),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TRN': ('Track Number', Variation_43, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['TRN']]) -> Union[Type['Variation_43']]:
        if key == 'TRN':
            return Variation_43
        assert_never(key)

    def __init__(self, arg : Variation_651_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['TRN']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['TRN'], val : Union[Variation_43, Variation_43_Arg]) -> 'Variation_651':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['TRN'], f : Any) -> 'Variation_651':
        return self._modify_item(name, f) # type: ignore

Variation_652_Arg : TypeAlias = Raw
class Variation_652(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Confirmed track',
        1: 'Track in initiation phase',
    }

    def __init__(self, arg : Variation_652_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_653_Arg : TypeAlias = Raw
class Variation_653(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Not extrapolated',
        1: 'Extrapolated',
    }

    def __init__(self, arg : Variation_653_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_654_Arg : TypeAlias = Raw
class Variation_654(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 2
    table = {
        0: 'Maintaining',
        1: 'Climbing',
        2: 'Descending',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_654_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_655_Arg : TypeAlias = Raw
class Variation_655(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Horizontal manoeuvre',
    }

    def __init__(self, arg : Variation_655_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_656_Arg_Group_1 = TypedDict('Variation_656_Arg_Group_1', {
    'CNF': Union[Variation_652, Variation_652_Arg],
    'TRE': Union[Variation_266, Variation_266_Arg],
    'CST': Union[Variation_653, Variation_653_Arg],
    'CDM': Union[Variation_654, Variation_654_Arg],
    'MAH': Union[Variation_655, Variation_655_Arg],
    'STH': Union[Variation_270, Variation_270_Arg],
})
Variation_656_Arg_Group_2 = TypedDict('Variation_656_Arg_Group_2', {
    'CNF': Union[Variation_652, Variation_652_Arg],
    'TRE': Union[Variation_266, Variation_266_Arg],
    'CST': Union[Variation_653, Variation_653_Arg],
    'CDM': Union[Variation_654, Variation_654_Arg],
    'MAH': Union[Variation_655, Variation_655_Arg],
    'STH': Union[Variation_270, Variation_270_Arg],
    'GHO': Union[Variation_274, Variation_274_Arg],
})
Variation_656_Arg : TypeAlias = Union[
    int,
    Variation_656_Arg_Group_1,
    Tuple[int],
    Variation_656_Arg_Group_2,
    Tuple[int,int],
]
class Variation_656(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('CNF', Variation_652),
            ('TRE', Variation_266),
            ('CST', Variation_653),
            ('CDM', Variation_654),
            ('MAH', Variation_655),
            ('STH', Variation_270),
        ],
        [
            ('GHO', Variation_274),
            Spare(1, 6),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CNF': ('', Variation_652, 0, 1),
        'TRE': ('', Variation_266, 1, 1),
        'CST': ('', Variation_653, 2, 1),
        'CDM': ('', Variation_654, 3, 2),
        'MAH': ('', Variation_655, 5, 1),
        'STH': ('', Variation_270, 6, 1),
        'GHO': ('', Variation_274, 0, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_652]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRE']) -> Type[Variation_266]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_653]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CDM']) -> Type[Variation_654]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAH']) -> Type[Variation_655]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STH']) -> Type[Variation_270]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GHO']) -> Type[Variation_274]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CNF'], Literal['TRE'], Literal['CST'], Literal['CDM'], Literal['MAH'], Literal['STH'], Literal['GHO']]) -> Union[Type['Variation_652'], Type['Variation_266'], Type['Variation_653'], Type['Variation_654'], Type['Variation_655'], Type['Variation_270'], Type['Variation_274']]:
        if key == 'CNF':
            return Variation_652
        if key == 'TRE':
            return Variation_266
        if key == 'CST':
            return Variation_653
        if key == 'CDM':
            return Variation_654
        if key == 'MAH':
            return Variation_655
        if key == 'STH':
            return Variation_270
        if key == 'GHO':
            return Variation_274
        assert_never(key)

    def __init__(self, arg : Variation_656_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_656_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_656_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_652:
        ...

    @overload
    def get_item(self, name : Literal['TRE']) -> Variation_266:
        ...

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_653:
        ...

    @overload
    def get_item(self, name : Literal['CDM']) -> Variation_654:
        ...

    @overload
    def get_item(self, name : Literal['MAH']) -> Variation_655:
        ...

    @overload
    def get_item(self, name : Literal['STH']) -> Variation_270:
        ...

    @overload
    def get_item(self, name : Literal['GHO']) -> Variation_274:
        ...

    def get_item(self, name : Union[Literal['CNF'], Literal['TRE'], Literal['CST'], Literal['CDM'], Literal['MAH'], Literal['STH'], Literal['GHO']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_652, Variation_652_Arg]) -> 'Variation_656':
        ...

    @overload
    def set_item(self, name : Literal['TRE'], val : Union[Variation_266, Variation_266_Arg]) -> 'Variation_656':
        ...

    @overload
    def set_item(self, name : Literal['CST'], val : Union[Variation_653, Variation_653_Arg]) -> 'Variation_656':
        ...

    @overload
    def set_item(self, name : Literal['CDM'], val : Union[Variation_654, Variation_654_Arg]) -> 'Variation_656':
        ...

    @overload
    def set_item(self, name : Literal['MAH'], val : Union[Variation_655, Variation_655_Arg]) -> 'Variation_656':
        ...

    @overload
    def set_item(self, name : Literal['STH'], val : Union[Variation_270, Variation_270_Arg]) -> 'Variation_656':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_656':
        ...

    @overload
    def modify_item(self, name : Literal['TRE'], f : Any) -> 'Variation_656':
        ...

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_656':
        ...

    @overload
    def modify_item(self, name : Literal['CDM'], f : Any) -> 'Variation_656':
        ...

    @overload
    def modify_item(self, name : Literal['MAH'], f : Any) -> 'Variation_656':
        ...

    @overload
    def modify_item(self, name : Literal['STH'], f : Any) -> 'Variation_656':
        ...

    @overload
    def modify_item(self, name : Literal['GHO'], f : Any) -> 'Variation_656':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_657_Arg : TypeAlias = Raw
class Variation_657(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode-3/A code derived from the reply of the transponder',
        1: 'Mode-3/A code not extracted during the last update period',
    }

    def __init__(self, arg : Variation_657_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_658_Arg_Group = TypedDict('Variation_658_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_657, Variation_657_Arg],
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_658_Arg : TypeAlias = Union[Raw, Variation_658_Arg_Group]
class Variation_658(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_657),
        Spare(3, 1),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('Validated', Variation_16, 0, 1),
        'G': ('Garbled', Variation_17, 1, 1),
        'L': ('', Variation_657, 2, 1),
        'MODE3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_657]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_657'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_657
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_658_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_657:
        ...

    @overload
    def get_item(self, name : Literal['MODE3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_658':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_658':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_657, Variation_657_Arg]) -> 'Variation_658':
        ...

    @overload
    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_658':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_658':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_658':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_658':
        ...

    @overload
    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_658':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_659_Arg_Group = TypedDict('Variation_659_Arg_Group', {
    'VX': Union[Variation_314, Variation_314_Arg],
    'VY': Union[Variation_314, Variation_314_Arg],
})
Variation_659_Arg : TypeAlias = Union[Raw, Variation_659_Arg_Group]
class Variation_659(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('VX', Variation_314),
        ('VY', Variation_314),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'VX': ('', Variation_314, 0, 16),
        'VY': ('', Variation_314, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VX']) -> Type[Variation_314]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VY']) -> Type[Variation_314]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VX'], Literal['VY']]) -> Union[Type['Variation_314'], Type['Variation_314']]:
        if key == 'VX':
            return Variation_314
        if key == 'VY':
            return Variation_314
        assert_never(key)

    def __init__(self, arg : Variation_659_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['VX']) -> Variation_314:
        ...

    @overload
    def get_item(self, name : Literal['VY']) -> Variation_314:
        ...

    def get_item(self, name : Union[Literal['VX'], Literal['VY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['VX'], val : Union[Variation_314, Variation_314_Arg]) -> 'Variation_659':
        ...

    @overload
    def set_item(self, name : Literal['VY'], val : Union[Variation_314, Variation_314_Arg]) -> 'Variation_659':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['VX'], f : Any) -> 'Variation_659':
        ...

    @overload
    def modify_item(self, name : Literal['VY'], f : Any) -> 'Variation_659':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_660_Arg : TypeAlias = Raw
class Variation_660(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'High quality pulse B2',
        1: 'Low quality pulse B2',
    }

    def __init__(self, arg : Variation_660_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_661_Arg_Group = TypedDict('Variation_661_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'MODEC': Union[Variation_43, Variation_43_Arg],
    'QC1': Union[Variation_38, Variation_38_Arg],
    'QA1': Union[Variation_44, Variation_44_Arg],
    'QC2': Union[Variation_45, Variation_45_Arg],
    'QA2': Union[Variation_46, Variation_46_Arg],
    'QC4': Union[Variation_47, Variation_47_Arg],
    'QA4': Union[Variation_48, Variation_48_Arg],
    'QB1': Union[Variation_49, Variation_49_Arg],
    'QD1': Union[Variation_50, Variation_50_Arg],
    'QB2': Union[Variation_51, Variation_51_Arg],
    'QD2': Union[Variation_660, Variation_660_Arg],
    'QB4': Union[Variation_53, Variation_53_Arg],
    'QD4': Union[Variation_54, Variation_54_Arg],
})
Variation_661_Arg : TypeAlias = Union[Raw, Variation_661_Arg_Group]
class Variation_661(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        Spare(2, 2),
        ('MODEC', Variation_43),
        Spare(0, 4),
        ('QC1', Variation_38),
        ('QA1', Variation_44),
        ('QC2', Variation_45),
        ('QA2', Variation_46),
        ('QC4', Variation_47),
        ('QA4', Variation_48),
        ('QB1', Variation_49),
        ('QD1', Variation_50),
        ('QB2', Variation_51),
        ('QD2', Variation_660),
        ('QB4', Variation_53),
        ('QD4', Variation_54),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('Validated', Variation_16, 0, 1),
        'G': ('Garbled', Variation_17, 1, 1),
        'MODEC': ('Mode-C Reply in Gray Notation', Variation_43, 4, 12),
        'QC1': ('Quality Pulse C1', Variation_38, 20, 1),
        'QA1': ('Quality Pulse A1', Variation_44, 21, 1),
        'QC2': ('Quality Pulse C2', Variation_45, 22, 1),
        'QA2': ('Quality Pulse A2', Variation_46, 23, 1),
        'QC4': ('Quality Pulse C4', Variation_47, 24, 1),
        'QA4': ('Quality Pulse A4', Variation_48, 25, 1),
        'QB1': ('Quality Pulse B1', Variation_49, 26, 1),
        'QD1': ('Quality Pulse D1', Variation_50, 27, 1),
        'QB2': ('Quality Pulse B2', Variation_51, 28, 1),
        'QD2': ('Quality Pulse D2', Variation_660, 29, 1),
        'QB4': ('Quality Pulse B4', Variation_53, 30, 1),
        'QD4': ('Quality Pulse D4', Variation_54, 31, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODEC']) -> Type[Variation_43]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QC1']) -> Type[Variation_38]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA1']) -> Type[Variation_44]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QC2']) -> Type[Variation_45]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA2']) -> Type[Variation_46]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QC4']) -> Type[Variation_47]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA4']) -> Type[Variation_48]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB1']) -> Type[Variation_49]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QD1']) -> Type[Variation_50]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB2']) -> Type[Variation_51]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QD2']) -> Type[Variation_660]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB4']) -> Type[Variation_53]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QD4']) -> Type[Variation_54]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['MODEC'], Literal['QC1'], Literal['QA1'], Literal['QC2'], Literal['QA2'], Literal['QC4'], Literal['QA4'], Literal['QB1'], Literal['QD1'], Literal['QB2'], Literal['QD2'], Literal['QB4'], Literal['QD4']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_43'], Type['Variation_38'], Type['Variation_44'], Type['Variation_45'], Type['Variation_46'], Type['Variation_47'], Type['Variation_48'], Type['Variation_49'], Type['Variation_50'], Type['Variation_51'], Type['Variation_660'], Type['Variation_53'], Type['Variation_54']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'MODEC':
            return Variation_43
        if key == 'QC1':
            return Variation_38
        if key == 'QA1':
            return Variation_44
        if key == 'QC2':
            return Variation_45
        if key == 'QA2':
            return Variation_46
        if key == 'QC4':
            return Variation_47
        if key == 'QA4':
            return Variation_48
        if key == 'QB1':
            return Variation_49
        if key == 'QD1':
            return Variation_50
        if key == 'QB2':
            return Variation_51
        if key == 'QD2':
            return Variation_660
        if key == 'QB4':
            return Variation_53
        if key == 'QD4':
            return Variation_54
        assert_never(key)

    def __init__(self, arg : Variation_661_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['MODEC']) -> Variation_43:
        ...

    @overload
    def get_item(self, name : Literal['QC1']) -> Variation_38:
        ...

    @overload
    def get_item(self, name : Literal['QA1']) -> Variation_44:
        ...

    @overload
    def get_item(self, name : Literal['QC2']) -> Variation_45:
        ...

    @overload
    def get_item(self, name : Literal['QA2']) -> Variation_46:
        ...

    @overload
    def get_item(self, name : Literal['QC4']) -> Variation_47:
        ...

    @overload
    def get_item(self, name : Literal['QA4']) -> Variation_48:
        ...

    @overload
    def get_item(self, name : Literal['QB1']) -> Variation_49:
        ...

    @overload
    def get_item(self, name : Literal['QD1']) -> Variation_50:
        ...

    @overload
    def get_item(self, name : Literal['QB2']) -> Variation_51:
        ...

    @overload
    def get_item(self, name : Literal['QD2']) -> Variation_660:
        ...

    @overload
    def get_item(self, name : Literal['QB4']) -> Variation_53:
        ...

    @overload
    def get_item(self, name : Literal['QD4']) -> Variation_54:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['MODEC'], Literal['QC1'], Literal['QA1'], Literal['QC2'], Literal['QA2'], Literal['QC4'], Literal['QA4'], Literal['QB1'], Literal['QD1'], Literal['QB2'], Literal['QD2'], Literal['QB4'], Literal['QD4']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['MODEC'], val : Union[Variation_43, Variation_43_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QC1'], val : Union[Variation_38, Variation_38_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QA1'], val : Union[Variation_44, Variation_44_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QC2'], val : Union[Variation_45, Variation_45_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QA2'], val : Union[Variation_46, Variation_46_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QC4'], val : Union[Variation_47, Variation_47_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QA4'], val : Union[Variation_48, Variation_48_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QB1'], val : Union[Variation_49, Variation_49_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QD1'], val : Union[Variation_50, Variation_50_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QB2'], val : Union[Variation_51, Variation_51_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QD2'], val : Union[Variation_660, Variation_660_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QB4'], val : Union[Variation_53, Variation_53_Arg]) -> 'Variation_661':
        ...

    @overload
    def set_item(self, name : Literal['QD4'], val : Union[Variation_54, Variation_54_Arg]) -> 'Variation_661':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['MODEC'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QC1'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QA1'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QC2'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QA2'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QC4'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QA4'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QB1'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QD1'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QB2'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QD2'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QB4'], f : Any) -> 'Variation_661':
        ...

    @overload
    def modify_item(self, name : Literal['QD4'], f : Any) -> 'Variation_661':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_662_Arg : TypeAlias = Raw
class Variation_662(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Callsign or registration not downlinked from transponder',
        1: 'Registration downlinked from transponder',
        2: 'Callsign downlinked from transponder',
        3: 'Not defined',
    }

    def __init__(self, arg : Variation_662_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_663_Arg_Group = TypedDict('Variation_663_Arg_Group', {
    'STI': Union[Variation_662, Variation_662_Arg],
    'CHR': Union[Variation_196, Variation_196_Arg],
})
Variation_663_Arg : TypeAlias = Union[Raw, Variation_663_Arg_Group]
class Variation_663(Group):
    variation = 'Group'

    bit_size = 56

    subitems_list = [
        ('STI', Variation_662),
        Spare(2, 6),
        ('CHR', Variation_196),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STI': ('', Variation_662, 0, 2),
        'CHR': ('Characters 1-8 (coded on 6 Bits Each) Defining Target Identification', Variation_196, 8, 48),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['STI']) -> Type[Variation_662]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHR']) -> Type[Variation_196]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['STI'], Literal['CHR']]) -> Union[Type['Variation_662'], Type['Variation_196']]:
        if key == 'STI':
            return Variation_662
        if key == 'CHR':
            return Variation_196
        assert_never(key)

    def __init__(self, arg : Variation_663_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['STI']) -> Variation_662:
        ...

    @overload
    def get_item(self, name : Literal['CHR']) -> Variation_196:
        ...

    def get_item(self, name : Union[Literal['STI'], Literal['CHR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['STI'], val : Union[Variation_662, Variation_662_Arg]) -> 'Variation_663':
        ...

    @overload
    def set_item(self, name : Literal['CHR'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_663':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['STI'], f : Any) -> 'Variation_663':
        ...

    @overload
    def modify_item(self, name : Literal['CHR'], f : Any) -> 'Variation_663':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_664_Arg_Group = TypedDict('Variation_664_Arg_Group', {
    'AX': Union[Variation_316, Variation_316_Arg],
    'AY': Union[Variation_316, Variation_316_Arg],
})
Variation_664_Arg : TypeAlias = Union[Raw, Variation_664_Arg_Group]
class Variation_664(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('AX', Variation_316),
        ('AY', Variation_316),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'AX': ('', Variation_316, 0, 8),
        'AY': ('', Variation_316, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AX']) -> Type[Variation_316]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AY']) -> Type[Variation_316]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AX'], Literal['AY']]) -> Union[Type['Variation_316'], Type['Variation_316']]:
        if key == 'AX':
            return Variation_316
        if key == 'AY':
            return Variation_316
        assert_never(key)

    def __init__(self, arg : Variation_664_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['AX']) -> Variation_316:
        ...

    @overload
    def get_item(self, name : Literal['AY']) -> Variation_316:
        ...

    def get_item(self, name : Union[Literal['AX'], Literal['AY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['AX'], val : Union[Variation_316, Variation_316_Arg]) -> 'Variation_664':
        ...

    @overload
    def set_item(self, name : Literal['AY'], val : Union[Variation_316, Variation_316_Arg]) -> 'Variation_664':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['AX'], f : Any) -> 'Variation_664':
        ...

    @overload
    def modify_item(self, name : Literal['AY'], f : Any) -> 'Variation_664':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_665_Arg_Group = TypedDict('Variation_665_Arg_Group', {
    'TRB': Union[Variation_297, Variation_297_Arg],
    'MSG': Union[Variation_385, Variation_385_Arg],
})
Variation_665_Arg : TypeAlias = Union[Raw, Variation_665_Arg_Group]
class Variation_665(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('TRB', Variation_297),
        ('MSG', Variation_385),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TRB': ('', Variation_297, 0, 1),
        'MSG': ('', Variation_385, 1, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TRB']) -> Type[Variation_297]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSG']) -> Type[Variation_385]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TRB'], Literal['MSG']]) -> Union[Type['Variation_297'], Type['Variation_385']]:
        if key == 'TRB':
            return Variation_297
        if key == 'MSG':
            return Variation_385
        assert_never(key)

    def __init__(self, arg : Variation_665_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TRB']) -> Variation_297:
        ...

    @overload
    def get_item(self, name : Literal['MSG']) -> Variation_385:
        ...

    def get_item(self, name : Union[Literal['TRB'], Literal['MSG']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TRB'], val : Union[Variation_297, Variation_297_Arg]) -> 'Variation_665':
        ...

    @overload
    def set_item(self, name : Literal['MSG'], val : Union[Variation_385, Variation_385_Arg]) -> 'Variation_665':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TRB'], f : Any) -> 'Variation_665':
        ...

    @overload
    def modify_item(self, name : Literal['MSG'], f : Any) -> 'Variation_665':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_666_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['']]]
class Variation_666(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 0.25, '')

    def __init__(self, arg : Variation_666_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_667_Arg_Group = TypedDict('Variation_667_Arg_Group', {
    'X': Union[Variation_666, Variation_666_Arg],
    'Y': Union[Variation_666, Variation_666_Arg],
    'XY': Union[Variation_666, Variation_666_Arg],
})
Variation_667_Arg : TypeAlias = Union[Raw, Variation_667_Arg_Group]
class Variation_667(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('X', Variation_666),
        ('Y', Variation_666),
        ('XY', Variation_666),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('DOP (X-Component)', Variation_666, 0, 16),
        'Y': ('DOP (Y-Component)', Variation_666, 16, 16),
        'XY': ('DOP (Correlation XY)', Variation_666, 32, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_666]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_666]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XY']) -> Type[Variation_666]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y'], Literal['XY']]) -> Union[Type['Variation_666'], Type['Variation_666'], Type['Variation_666']]:
        if key == 'X':
            return Variation_666
        if key == 'Y':
            return Variation_666
        if key == 'XY':
            return Variation_666
        assert_never(key)

    def __init__(self, arg : Variation_667_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_666:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_666:
        ...

    @overload
    def get_item(self, name : Literal['XY']) -> Variation_666:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y'], Literal['XY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_666, Variation_666_Arg]) -> 'Variation_667':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_666, Variation_666_Arg]) -> 'Variation_667':
        ...

    @overload
    def set_item(self, name : Literal['XY'], val : Union[Variation_666, Variation_666_Arg]) -> 'Variation_667':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_667':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_667':
        ...

    @overload
    def modify_item(self, name : Literal['XY'], f : Any) -> 'Variation_667':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_668_Arg_Group = TypedDict('Variation_668_Arg_Group', {
    'X': Union[Variation_456, Variation_456_Arg],
    'Y': Union[Variation_456, Variation_456_Arg],
    'XY': Union[Variation_666, Variation_666_Arg],
})
Variation_668_Arg : TypeAlias = Union[Raw, Variation_668_Arg_Group]
class Variation_668(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('X', Variation_456),
        ('Y', Variation_456),
        ('XY', Variation_666),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('SDP (X-Component)', Variation_456, 0, 16),
        'Y': ('SDP (Y-Component)', Variation_456, 16, 16),
        'XY': ('SDP (Correlation XY)', Variation_666, 32, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_456]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_456]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XY']) -> Type[Variation_666]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y'], Literal['XY']]) -> Union[Type['Variation_456'], Type['Variation_456'], Type['Variation_666']]:
        if key == 'X':
            return Variation_456
        if key == 'Y':
            return Variation_456
        if key == 'XY':
            return Variation_666
        assert_never(key)

    def __init__(self, arg : Variation_668_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_456:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_456:
        ...

    @overload
    def get_item(self, name : Literal['XY']) -> Variation_666:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y'], Literal['XY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_456, Variation_456_Arg]) -> 'Variation_668':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_456, Variation_456_Arg]) -> 'Variation_668':
        ...

    @overload
    def set_item(self, name : Literal['XY'], val : Union[Variation_666, Variation_666_Arg]) -> 'Variation_668':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_668':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_668':
        ...

    @overload
    def modify_item(self, name : Literal['XY'], f : Any) -> 'Variation_668':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_669_Arg = TypedDict('Variation_669_Arg', {
    'DOP': Union[Variation_667, Variation_667_Arg],
    'SDP': Union[Variation_668, Variation_668_Arg],
    'SDH': Union[Variation_152, Variation_152_Arg],
}, total=False)
class Variation_669(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('DOP', Variation_667),
        ('SDP', Variation_668),
        ('SDH', Variation_152),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'DOP': ('DOP of Position', Variation_667, 0x80),
        'SDP': ('Standard Deviation of Position', Variation_668, 0x40),
        'SDH': ('Standard Deviation of Geometric Height (WGS 84)', Variation_152, 0x20),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['DOP']) -> Type[Variation_667]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDP']) -> Type[Variation_668]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDH']) -> Type[Variation_152]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['DOP'], Literal['SDP'], Literal['SDH']]) -> Union[Type['Variation_667'], Type['Variation_668'], Type['Variation_152']]:
        if key == 'DOP':
            return Variation_667
        if key == 'SDP':
            return Variation_668
        if key == 'SDH':
            return Variation_152
        assert_never(key)

    def __init__(self, arg : Optional[Variation_669_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['DOP'], val : Union[Variation_667, Variation_667_Arg]) -> 'Variation_669':
        ...

    @overload
    def set_item(self, name : Literal['SDP'], val : Union[Variation_668, Variation_668_Arg]) -> 'Variation_669':
        ...

    @overload
    def set_item(self, name : Literal['SDH'], val : Union[Variation_152, Variation_152_Arg]) -> 'Variation_669':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['DOP']) -> 'Variation_669':
        ...

    @overload
    def del_item(self, name : Literal['SDP']) -> 'Variation_669':
        ...

    @overload
    def del_item(self, name : Literal['SDH']) -> 'Variation_669':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['DOP']) -> Variation_667:
        ...

    @overload
    def get_item(self, name : Literal['SDP']) -> Variation_668:
        ...

    @overload
    def get_item(self, name : Literal['SDH']) -> Variation_152:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['DOP'], f : Any) -> 'Variation_669':
        ...

    @overload
    def modify_item(self, name : Literal['SDP'], f : Any) -> 'Variation_669':
        ...

    @overload
    def modify_item(self, name : Literal['SDH'], f : Any) -> 'Variation_669':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_670_Arg : TypeAlias = Raw
class Variation_670(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'TU1/RU1 has NOT contributed to the target detection',
        1: 'TU1/RU1 has contributed to the target detection',
    }

    def __init__(self, arg : Variation_670_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_671_Arg : TypeAlias = Raw
class Variation_671(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'TU2/RU2 has NOT contributed to the target detection',
        1: 'TU2/RU2 has contributed to the target detection',
    }

    def __init__(self, arg : Variation_671_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_672_Arg : TypeAlias = Raw
class Variation_672(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'TU3/RU3 has NOT contributed to the target detection',
        1: 'TU3/RU3 has contributed to the target detection',
    }

    def __init__(self, arg : Variation_672_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_673_Arg : TypeAlias = Raw
class Variation_673(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'TU4/RU4 has NOT contributed to the target detection',
        1: 'TU4/RU4 has contributed to the target detection',
    }

    def __init__(self, arg : Variation_673_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_674_Arg : TypeAlias = Raw
class Variation_674(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'TU5/RU5 has NOT contributed to the target detection',
        1: 'TU5/RU5 has contributed to the target detection',
    }

    def __init__(self, arg : Variation_674_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_675_Arg : TypeAlias = Raw
class Variation_675(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'TU6/RU6 has NOT contributed to the target detection',
        1: 'TU6/RU6 has contributed to the target detection',
    }

    def __init__(self, arg : Variation_675_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_676_Arg : TypeAlias = Raw
class Variation_676(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'TU7/RU7 has NOT contributed to the target detection',
        1: 'TU7/RU7 has contributed to the target detection',
    }

    def __init__(self, arg : Variation_676_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_677_Arg : TypeAlias = Raw
class Variation_677(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'TU8/RU8 has NOT contributed to the target detection',
        1: 'TU8/RU8 has contributed to the target detection',
    }

    def __init__(self, arg : Variation_677_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_678_Arg_Group = TypedDict('Variation_678_Arg_Group', {
    'BIT1': Union[Variation_670, Variation_670_Arg],
    'BIT2': Union[Variation_671, Variation_671_Arg],
    'BIT3': Union[Variation_672, Variation_672_Arg],
    'BIT4': Union[Variation_673, Variation_673_Arg],
    'BIT5': Union[Variation_674, Variation_674_Arg],
    'BIT6': Union[Variation_675, Variation_675_Arg],
    'BIT7': Union[Variation_676, Variation_676_Arg],
    'BIT8': Union[Variation_677, Variation_677_Arg],
})
Variation_678_Arg : TypeAlias = Union[Raw, Variation_678_Arg_Group]
class Variation_678(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('BIT1', Variation_670),
        ('BIT2', Variation_671),
        ('BIT3', Variation_672),
        ('BIT4', Variation_673),
        ('BIT5', Variation_674),
        ('BIT6', Variation_675),
        ('BIT7', Variation_676),
        ('BIT8', Variation_677),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'BIT1': ('TU1/RU1 Contribution', Variation_670, 0, 1),
        'BIT2': ('TU2/RU2 Contribution', Variation_671, 1, 1),
        'BIT3': ('TU3/RU3 Contribution', Variation_672, 2, 1),
        'BIT4': ('TU4/RU4 Contribution', Variation_673, 3, 1),
        'BIT5': ('TU5/RU5 Contribution', Variation_674, 4, 1),
        'BIT6': ('TU6/RU6 Contribution', Variation_675, 5, 1),
        'BIT7': ('TU7/RU7 Contribution', Variation_676, 6, 1),
        'BIT8': ('TU8/RU8 Contribution', Variation_677, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['BIT1']) -> Type[Variation_670]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BIT2']) -> Type[Variation_671]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BIT3']) -> Type[Variation_672]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BIT4']) -> Type[Variation_673]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BIT5']) -> Type[Variation_674]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BIT6']) -> Type[Variation_675]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BIT7']) -> Type[Variation_676]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BIT8']) -> Type[Variation_677]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['BIT1'], Literal['BIT2'], Literal['BIT3'], Literal['BIT4'], Literal['BIT5'], Literal['BIT6'], Literal['BIT7'], Literal['BIT8']]) -> Union[Type['Variation_670'], Type['Variation_671'], Type['Variation_672'], Type['Variation_673'], Type['Variation_674'], Type['Variation_675'], Type['Variation_676'], Type['Variation_677']]:
        if key == 'BIT1':
            return Variation_670
        if key == 'BIT2':
            return Variation_671
        if key == 'BIT3':
            return Variation_672
        if key == 'BIT4':
            return Variation_673
        if key == 'BIT5':
            return Variation_674
        if key == 'BIT6':
            return Variation_675
        if key == 'BIT7':
            return Variation_676
        if key == 'BIT8':
            return Variation_677
        assert_never(key)

    def __init__(self, arg : Variation_678_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['BIT1']) -> Variation_670:
        ...

    @overload
    def get_item(self, name : Literal['BIT2']) -> Variation_671:
        ...

    @overload
    def get_item(self, name : Literal['BIT3']) -> Variation_672:
        ...

    @overload
    def get_item(self, name : Literal['BIT4']) -> Variation_673:
        ...

    @overload
    def get_item(self, name : Literal['BIT5']) -> Variation_674:
        ...

    @overload
    def get_item(self, name : Literal['BIT6']) -> Variation_675:
        ...

    @overload
    def get_item(self, name : Literal['BIT7']) -> Variation_676:
        ...

    @overload
    def get_item(self, name : Literal['BIT8']) -> Variation_677:
        ...

    def get_item(self, name : Union[Literal['BIT1'], Literal['BIT2'], Literal['BIT3'], Literal['BIT4'], Literal['BIT5'], Literal['BIT6'], Literal['BIT7'], Literal['BIT8']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['BIT1'], val : Union[Variation_670, Variation_670_Arg]) -> 'Variation_678':
        ...

    @overload
    def set_item(self, name : Literal['BIT2'], val : Union[Variation_671, Variation_671_Arg]) -> 'Variation_678':
        ...

    @overload
    def set_item(self, name : Literal['BIT3'], val : Union[Variation_672, Variation_672_Arg]) -> 'Variation_678':
        ...

    @overload
    def set_item(self, name : Literal['BIT4'], val : Union[Variation_673, Variation_673_Arg]) -> 'Variation_678':
        ...

    @overload
    def set_item(self, name : Literal['BIT5'], val : Union[Variation_674, Variation_674_Arg]) -> 'Variation_678':
        ...

    @overload
    def set_item(self, name : Literal['BIT6'], val : Union[Variation_675, Variation_675_Arg]) -> 'Variation_678':
        ...

    @overload
    def set_item(self, name : Literal['BIT7'], val : Union[Variation_676, Variation_676_Arg]) -> 'Variation_678':
        ...

    @overload
    def set_item(self, name : Literal['BIT8'], val : Union[Variation_677, Variation_677_Arg]) -> 'Variation_678':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['BIT1'], f : Any) -> 'Variation_678':
        ...

    @overload
    def modify_item(self, name : Literal['BIT2'], f : Any) -> 'Variation_678':
        ...

    @overload
    def modify_item(self, name : Literal['BIT3'], f : Any) -> 'Variation_678':
        ...

    @overload
    def modify_item(self, name : Literal['BIT4'], f : Any) -> 'Variation_678':
        ...

    @overload
    def modify_item(self, name : Literal['BIT5'], f : Any) -> 'Variation_678':
        ...

    @overload
    def modify_item(self, name : Literal['BIT6'], f : Any) -> 'Variation_678':
        ...

    @overload
    def modify_item(self, name : Literal['BIT7'], f : Any) -> 'Variation_678':
        ...

    @overload
    def modify_item(self, name : Literal['BIT8'], f : Any) -> 'Variation_678':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_679_Arg : TypeAlias = Union[Variation_678, Variation_678_Arg]
class Variation_679(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 8
    variation_type = Variation_678

    @classmethod
    def spec(cls) -> Type[Variation_678]:
        return Variation_678

    def __init__(self, arg : List[Union[Variation_678, Variation_678_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_678, Variation_678_Arg]) -> 'Variation_679':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_678, Variation_678_Arg]) -> 'Variation_679':
        return self._prepend_item(arg) # type: ignore

Variation_680_Arg_Group = TypedDict('Variation_680_Arg_Group', {
    'MBDATA': Union[Variation_281, Variation_281_Arg],
    'BDS1': Union[Variation_187, Variation_187_Arg],
    'BDS2': Union[Variation_282, Variation_282_Arg],
})
Variation_680_Arg : TypeAlias = Union[Raw, Variation_680_Arg_Group]
class Variation_680(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('MBDATA', Variation_281),
        ('BDS1', Variation_187),
        ('BDS2', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MBDATA': ('56-bit Message Conveying Mode S Comm B Message Data', Variation_281, 0, 56),
        'BDS1': ('Comm B Data Buffer Store 1 Address', Variation_187, 56, 4),
        'BDS2': ('Comm B Data Buffer Store 2 Address', Variation_282, 60, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MBDATA']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BDS1']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BDS2']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MBDATA'], Literal['BDS1'], Literal['BDS2']]) -> Union[Type['Variation_281'], Type['Variation_187'], Type['Variation_282']]:
        if key == 'MBDATA':
            return Variation_281
        if key == 'BDS1':
            return Variation_187
        if key == 'BDS2':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_680_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MBDATA']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['BDS1']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['BDS2']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['MBDATA'], Literal['BDS1'], Literal['BDS2']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MBDATA'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_680':
        ...

    @overload
    def set_item(self, name : Literal['BDS1'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_680':
        ...

    @overload
    def set_item(self, name : Literal['BDS2'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_680':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MBDATA'], f : Any) -> 'Variation_680':
        ...

    @overload
    def modify_item(self, name : Literal['BDS1'], f : Any) -> 'Variation_680':
        ...

    @overload
    def modify_item(self, name : Literal['BDS2'], f : Any) -> 'Variation_680':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_681_Arg : TypeAlias = Union[Variation_680, Variation_680_Arg]
class Variation_681(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 64
    variation_type = Variation_680

    @classmethod
    def spec(cls) -> Type[Variation_680]:
        return Variation_680

    def __init__(self, arg : List[Union[Variation_680, Variation_680_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_680, Variation_680_Arg]) -> 'Variation_681':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_680, Variation_680_Arg]) -> 'Variation_681':
        return self._prepend_item(arg) # type: ignore

Variation_682_Arg : TypeAlias = Raw
class Variation_682(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 3
    table = {
        0: 'No alert, no SPI, aircraft airborne',
        1: 'No alert, no SPI, aircraft on ground',
        2: 'Alert, no SPI, aircraft airborne',
        3: 'Alert, no SPI, aircraft on ground',
        4: 'Alert, SPI, aircraft airborne or on ground',
        5: 'No alert, SPI, aircraft airborne or on ground',
        6: 'Not assigned',
        7: 'Information not yet extracted',
    }

    def __init__(self, arg : Variation_682_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_683_Arg_Group = TypedDict('Variation_683_Arg_Group', {
    'COM': Union[Variation_322, Variation_322_Arg],
    'STAT': Union[Variation_682, Variation_682_Arg],
    'MSSC': Union[Variation_324, Variation_324_Arg],
    'ARC': Union[Variation_325, Variation_325_Arg],
    'AIC': Union[Variation_326, Variation_326_Arg],
    'B1A': Union[Variation_237, Variation_237_Arg],
    'B1B': Union[Variation_282, Variation_282_Arg],
})
Variation_683_Arg : TypeAlias = Union[Raw, Variation_683_Arg_Group]
class Variation_683(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('COM', Variation_322),
        ('STAT', Variation_682),
        Spare(6, 2),
        ('MSSC', Variation_324),
        ('ARC', Variation_325),
        ('AIC', Variation_326),
        ('B1A', Variation_237),
        ('B1B', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COM': ('Communications Capability of the Transponder', Variation_322, 0, 3),
        'STAT': ('Flight Status', Variation_682, 3, 3),
        'MSSC': ('Mode-S Specific Service Capability', Variation_324, 8, 1),
        'ARC': ('Altitude Reporting Capability', Variation_325, 9, 1),
        'AIC': ('Aircraft Identification Capability', Variation_326, 10, 1),
        'B1A': ('BDS 1,0 Bit 16', Variation_237, 11, 1),
        'B1B': ('BDS 1,0 Bits 37/40', Variation_282, 12, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_322]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STAT']) -> Type[Variation_682]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSSC']) -> Type[Variation_324]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_325]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AIC']) -> Type[Variation_326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1A']) -> Type[Variation_237]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1B']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COM'], Literal['STAT'], Literal['MSSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B']]) -> Union[Type['Variation_322'], Type['Variation_682'], Type['Variation_324'], Type['Variation_325'], Type['Variation_326'], Type['Variation_237'], Type['Variation_282']]:
        if key == 'COM':
            return Variation_322
        if key == 'STAT':
            return Variation_682
        if key == 'MSSC':
            return Variation_324
        if key == 'ARC':
            return Variation_325
        if key == 'AIC':
            return Variation_326
        if key == 'B1A':
            return Variation_237
        if key == 'B1B':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_683_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_322:
        ...

    @overload
    def get_item(self, name : Literal['STAT']) -> Variation_682:
        ...

    @overload
    def get_item(self, name : Literal['MSSC']) -> Variation_324:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_325:
        ...

    @overload
    def get_item(self, name : Literal['AIC']) -> Variation_326:
        ...

    @overload
    def get_item(self, name : Literal['B1A']) -> Variation_237:
        ...

    @overload
    def get_item(self, name : Literal['B1B']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['COM'], Literal['STAT'], Literal['MSSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_322, Variation_322_Arg]) -> 'Variation_683':
        ...

    @overload
    def set_item(self, name : Literal['STAT'], val : Union[Variation_682, Variation_682_Arg]) -> 'Variation_683':
        ...

    @overload
    def set_item(self, name : Literal['MSSC'], val : Union[Variation_324, Variation_324_Arg]) -> 'Variation_683':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_325, Variation_325_Arg]) -> 'Variation_683':
        ...

    @overload
    def set_item(self, name : Literal['AIC'], val : Union[Variation_326, Variation_326_Arg]) -> 'Variation_683':
        ...

    @overload
    def set_item(self, name : Literal['B1A'], val : Union[Variation_237, Variation_237_Arg]) -> 'Variation_683':
        ...

    @overload
    def set_item(self, name : Literal['B1B'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_683':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_683':
        ...

    @overload
    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_683':
        ...

    @overload
    def modify_item(self, name : Literal['MSSC'], f : Any) -> 'Variation_683':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_683':
        ...

    @overload
    def modify_item(self, name : Literal['AIC'], f : Any) -> 'Variation_683':
        ...

    @overload
    def modify_item(self, name : Literal['B1A'], f : Any) -> 'Variation_683':
        ...

    @overload
    def modify_item(self, name : Literal['B1B'], f : Any) -> 'Variation_683':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_684_Arg : TypeAlias = Raw
class Variation_684(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    table = {
        0: 'Not defined; never used',
        1: 'Multipath Reply (Reflection)',
        3: 'Split plot',
        10: 'Phantom SSR plot',
        11: 'Non-Matching Mode-3/A Code',
        12: 'Mode C code / Mode S altitude code abnormal value compared to the track',
        15: 'Transponder anomaly detected',
        16: 'Duplicated or Illegal Mode S Aircraft Address',
        17: 'Mode S error correction applied',
        18: 'Undecodable Mode C code / Mode S altitude code',
    }

    def __init__(self, arg : Variation_684_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_685_Arg : TypeAlias = Union[Variation_684, Variation_684_Arg]
class Variation_685(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = None
    variation_bit_size = 7
    variation_type = Variation_684

    @classmethod
    def spec(cls) -> Type[Variation_684]:
        return Variation_684

    def __init__(self, arg : List[Union[Variation_684, Variation_684_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_684, Variation_684_Arg]) -> 'Variation_685':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_684, Variation_684_Arg]) -> 'Variation_685':
        return self._prepend_item(arg) # type: ignore

Variation_686_Arg : TypeAlias = Raw
class Variation_686(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode-1 code derived from the reply of the transponder',
        1: 'Smoothed Mode-1 code as provided by a local tracker',
    }

    def __init__(self, arg : Variation_686_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_687_Arg_Group = TypedDict('Variation_687_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_686, Variation_686_Arg],
    'MODE1': Union[Variation_375, Variation_375_Arg],
})
Variation_687_Arg : TypeAlias = Union[Raw, Variation_687_Arg_Group]
class Variation_687(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_686),
        ('MODE1', Variation_375),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('Validated', Variation_16, 0, 1),
        'G': ('Garbled', Variation_17, 1, 1),
        'L': ('', Variation_686, 2, 1),
        'MODE1': ('Mode-1 Code in Octal Representation', Variation_375, 3, 5),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_686]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE1']) -> Type[Variation_375]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE1']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_686'], Type['Variation_375']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_686
        if key == 'MODE1':
            return Variation_375
        assert_never(key)

    def __init__(self, arg : Variation_687_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_686:
        ...

    @overload
    def get_item(self, name : Literal['MODE1']) -> Variation_375:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_687':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_687':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_686, Variation_686_Arg]) -> 'Variation_687':
        ...

    @overload
    def set_item(self, name : Literal['MODE1'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_687':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_687':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_687':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_687':
        ...

    @overload
    def modify_item(self, name : Literal['MODE1'], f : Any) -> 'Variation_687':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_688_Arg : TypeAlias = Raw
class Variation_688(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode-2 code derived from the reply of the transponder',
        1: 'Smoothed Mode-2 code as provided by a local tracker n',
    }

    def __init__(self, arg : Variation_688_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_689_Arg_Group = TypedDict('Variation_689_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_688, Variation_688_Arg],
    'MODE2': Union[Variation_19, Variation_19_Arg],
})
Variation_689_Arg : TypeAlias = Union[Raw, Variation_689_Arg_Group]
class Variation_689(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_688),
        Spare(3, 1),
        ('MODE2', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('Validated', Variation_16, 0, 1),
        'G': ('Garbled', Variation_17, 1, 1),
        'L': ('', Variation_688, 2, 1),
        'MODE2': ('Mode-2 Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_688]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE2']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE2']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_688'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_688
        if key == 'MODE2':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_689_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_688:
        ...

    @overload
    def get_item(self, name : Literal['MODE2']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE2']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_689':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_689':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_688, Variation_688_Arg]) -> 'Variation_689':
        ...

    @overload
    def set_item(self, name : Literal['MODE2'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_689':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_689':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_689':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_689':
        ...

    @overload
    def modify_item(self, name : Literal['MODE2'], f : Any) -> 'Variation_689':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_690_Arg = TypedDict('Variation_690_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '020': Union[Variation_648, Variation_648_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '041': Union[Variation_649, Variation_649_Arg],
    '042': Union[Variation_650, Variation_650_Arg],
    '161': Union[Variation_651, Variation_651_Arg],
    '170': Union[Variation_656, Variation_656_Arg],
    '070': Union[Variation_658, Variation_658_Arg],
    '202': Union[Variation_659, Variation_659_Arg],
    '090': Union[Variation_286, Variation_286_Arg],
    '100': Union[Variation_661, Variation_661_Arg],
    '220': Union[Variation_278, Variation_278_Arg],
    '245': Union[Variation_663, Variation_663_Arg],
    '110': Union[Variation_287, Variation_287_Arg],
    '105': Union[Variation_287, Variation_287_Arg],
    '210': Union[Variation_664, Variation_664_Arg],
    '300': Union[Variation_285, Variation_285_Arg],
    '310': Union[Variation_665, Variation_665_Arg],
    '500': Union[Variation_669, Variation_669_Arg],
    '400': Union[Variation_679, Variation_679_Arg],
    '250': Union[Variation_681, Variation_681_Arg],
    '230': Union[Variation_683, Variation_683_Arg],
    '260': Union[Variation_281, Variation_281_Arg],
    '030': Union[Variation_685, Variation_685_Arg],
    '055': Union[Variation_687, Variation_687_Arg],
    '050': Union[Variation_689, Variation_689_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_690(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('020', Variation_648),
        ('140', Variation_80),
        ('041', Variation_649),
        ('042', Variation_650),
        ('161', Variation_651),
        ('170', Variation_656),
        ('070', Variation_658),
        ('202', Variation_659),
        ('090', Variation_286),
        ('100', Variation_661),
        ('220', Variation_278),
        ('245', Variation_663),
        ('110', Variation_287),
        ('105', Variation_287),
        ('210', Variation_664),
        ('300', Variation_285),
        ('310', Variation_665),
        ('500', Variation_669),
        ('400', Variation_679),
        ('250', Variation_681),
        ('230', Variation_683),
        ('260', Variation_281),
        ('030', Variation_685),
        ('055', Variation_687),
        ('050', Variation_689),
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '020': ('Target Report Descriptor', Variation_648, 0x40000000),
        '140': ('Time of Day', Variation_80, 0x20000000),
        '041': ('Position In WGS-84 Coordinates', Variation_649, 0x10000000),
        '042': ('Position in Cartesian Coordinates', Variation_650, 0x08000000),
        '161': ('Track Number', Variation_651, 0x04000000),
        '170': ('Track Status', Variation_656, 0x02000000),
        '070': ('Mode-3/A Code in Octal Representation', Variation_658, 0x01800000),
        '202': ('Calculated Track Velocity in Cartesian Coordinates', Variation_659, 0x01400000),
        '090': ('Flight Level in Binary Representation', Variation_286, 0x01200000),
        '100': ('Mode C Code', Variation_661, 0x01100000),
        '220': ('Target Address', Variation_278, 0x01080000),
        '245': ('Target Identification', Variation_663, 0x01040000),
        '110': ('Measured Height (Local Cartesian Coordinates)', Variation_287, 0x01020000),
        '105': ('Geometric Height (WGS-84)', Variation_287, 0x01018000),
        '210': ('Calculated Acceleration', Variation_664, 0x01014000),
        '300': ('Vehicle Fleet Identification', Variation_285, 0x01012000),
        '310': ('Pre-programmed Message', Variation_665, 0x01011000),
        '500': ('Position Accuracy', Variation_669, 0x01010800),
        '400': ('Contributing Devices', Variation_679, 0x01010400),
        '250': ('Mode S MB Data', Variation_681, 0x01010200),
        '230': ('Communications/ACAS Capability and Flight Status', Variation_683, 0x01010180),
        '260': ('ACAS Resolution Advisory Report', Variation_281, 0x01010140),
        '030': ('Warning/Error Conditions', Variation_685, 0x01010120),
        '055': ('Mode-1 Code in Octal Representation', Variation_687, 0x01010110),
        '050': ('Mode-2 Code in Octal Representation', Variation_689, 0x01010108),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010104),
        'SP': ('Special Purpose Field', Variation_62, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_648]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_649]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_650]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_651]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_656]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_658]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['202']) -> Type[Variation_659]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_286]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_661]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['245']) -> Type[Variation_663]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['105']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_664]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_285]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['310']) -> Type[Variation_665]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_669]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_679]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_681]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_683]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_685]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['055']) -> Type[Variation_687]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_689]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['020'], Literal['140'], Literal['041'], Literal['042'], Literal['161'], Literal['170'], Literal['070'], Literal['202'], Literal['090'], Literal['100'], Literal['220'], Literal['245'], Literal['110'], Literal['105'], Literal['210'], Literal['300'], Literal['310'], Literal['500'], Literal['400'], Literal['250'], Literal['230'], Literal['260'], Literal['030'], Literal['055'], Literal['050'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_648'], Type['Variation_80'], Type['Variation_649'], Type['Variation_650'], Type['Variation_651'], Type['Variation_656'], Type['Variation_658'], Type['Variation_659'], Type['Variation_286'], Type['Variation_661'], Type['Variation_278'], Type['Variation_663'], Type['Variation_287'], Type['Variation_287'], Type['Variation_664'], Type['Variation_285'], Type['Variation_665'], Type['Variation_669'], Type['Variation_679'], Type['Variation_681'], Type['Variation_683'], Type['Variation_281'], Type['Variation_685'], Type['Variation_687'], Type['Variation_689'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '020':
            return Variation_648
        if key == '140':
            return Variation_80
        if key == '041':
            return Variation_649
        if key == '042':
            return Variation_650
        if key == '161':
            return Variation_651
        if key == '170':
            return Variation_656
        if key == '070':
            return Variation_658
        if key == '202':
            return Variation_659
        if key == '090':
            return Variation_286
        if key == '100':
            return Variation_661
        if key == '220':
            return Variation_278
        if key == '245':
            return Variation_663
        if key == '110':
            return Variation_287
        if key == '105':
            return Variation_287
        if key == '210':
            return Variation_664
        if key == '300':
            return Variation_285
        if key == '310':
            return Variation_665
        if key == '500':
            return Variation_669
        if key == '400':
            return Variation_679
        if key == '250':
            return Variation_681
        if key == '230':
            return Variation_683
        if key == '260':
            return Variation_281
        if key == '030':
            return Variation_685
        if key == '055':
            return Variation_687
        if key == '050':
            return Variation_689
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_690_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_648, Variation_648_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_649, Variation_649_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_650, Variation_650_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_651, Variation_651_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_656, Variation_656_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_658, Variation_658_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['202'], val : Union[Variation_659, Variation_659_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_286, Variation_286_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_661, Variation_661_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['245'], val : Union[Variation_663, Variation_663_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['105'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_664, Variation_664_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_285, Variation_285_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['310'], val : Union[Variation_665, Variation_665_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_669, Variation_669_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_679, Variation_679_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_681, Variation_681_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_683, Variation_683_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_685, Variation_685_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['055'], val : Union[Variation_687, Variation_687_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_689, Variation_689_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_690':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_690':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['202']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['245']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['105']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['310']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['055']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_690':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_690':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_648:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_649:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_650:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_651:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_656:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_658:
        ...

    @overload
    def get_item(self, name : Literal['202']) -> Variation_659:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_286:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_661:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['245']) -> Variation_663:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['105']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_664:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_285:
        ...

    @overload
    def get_item(self, name : Literal['310']) -> Variation_665:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_669:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_679:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_681:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_683:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_685:
        ...

    @overload
    def get_item(self, name : Literal['055']) -> Variation_687:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_689:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['202'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['245'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['105'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['310'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['055'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_690':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_690':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_691_Arg : TypeAlias = Raw
class Variation_691(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Not Coasted',
        1: 'Coasted',
    }

    def __init__(self, arg : Variation_691_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_692_Arg_Group_1 = TypedDict('Variation_692_Arg_Group_1', {
    'CNF': Union[Variation_652, Variation_652_Arg],
    'TRE': Union[Variation_266, Variation_266_Arg],
    'CST': Union[Variation_691, Variation_691_Arg],
    'CDM': Union[Variation_654, Variation_654_Arg],
    'MAH': Union[Variation_655, Variation_655_Arg],
    'STH': Union[Variation_270, Variation_270_Arg],
})
Variation_692_Arg_Group_2 = TypedDict('Variation_692_Arg_Group_2', {
    'CNF': Union[Variation_652, Variation_652_Arg],
    'TRE': Union[Variation_266, Variation_266_Arg],
    'CST': Union[Variation_691, Variation_691_Arg],
    'CDM': Union[Variation_654, Variation_654_Arg],
    'MAH': Union[Variation_655, Variation_655_Arg],
    'STH': Union[Variation_270, Variation_270_Arg],
    'GHO': Union[Variation_274, Variation_274_Arg],
})
Variation_692_Arg : TypeAlias = Union[
    int,
    Variation_692_Arg_Group_1,
    Tuple[int],
    Variation_692_Arg_Group_2,
    Tuple[int,int],
]
class Variation_692(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('CNF', Variation_652),
            ('TRE', Variation_266),
            ('CST', Variation_691),
            ('CDM', Variation_654),
            ('MAH', Variation_655),
            ('STH', Variation_270),
        ],
        [
            ('GHO', Variation_274),
            Spare(1, 6),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CNF': ('', Variation_652, 0, 1),
        'TRE': ('', Variation_266, 1, 1),
        'CST': ('', Variation_691, 2, 1),
        'CDM': ('', Variation_654, 3, 2),
        'MAH': ('', Variation_655, 5, 1),
        'STH': ('', Variation_270, 6, 1),
        'GHO': ('', Variation_274, 0, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_652]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRE']) -> Type[Variation_266]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_691]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CDM']) -> Type[Variation_654]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAH']) -> Type[Variation_655]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STH']) -> Type[Variation_270]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GHO']) -> Type[Variation_274]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CNF'], Literal['TRE'], Literal['CST'], Literal['CDM'], Literal['MAH'], Literal['STH'], Literal['GHO']]) -> Union[Type['Variation_652'], Type['Variation_266'], Type['Variation_691'], Type['Variation_654'], Type['Variation_655'], Type['Variation_270'], Type['Variation_274']]:
        if key == 'CNF':
            return Variation_652
        if key == 'TRE':
            return Variation_266
        if key == 'CST':
            return Variation_691
        if key == 'CDM':
            return Variation_654
        if key == 'MAH':
            return Variation_655
        if key == 'STH':
            return Variation_270
        if key == 'GHO':
            return Variation_274
        assert_never(key)

    def __init__(self, arg : Variation_692_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_692_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_692_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_652:
        ...

    @overload
    def get_item(self, name : Literal['TRE']) -> Variation_266:
        ...

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_691:
        ...

    @overload
    def get_item(self, name : Literal['CDM']) -> Variation_654:
        ...

    @overload
    def get_item(self, name : Literal['MAH']) -> Variation_655:
        ...

    @overload
    def get_item(self, name : Literal['STH']) -> Variation_270:
        ...

    @overload
    def get_item(self, name : Literal['GHO']) -> Variation_274:
        ...

    def get_item(self, name : Union[Literal['CNF'], Literal['TRE'], Literal['CST'], Literal['CDM'], Literal['MAH'], Literal['STH'], Literal['GHO']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_652, Variation_652_Arg]) -> 'Variation_692':
        ...

    @overload
    def set_item(self, name : Literal['TRE'], val : Union[Variation_266, Variation_266_Arg]) -> 'Variation_692':
        ...

    @overload
    def set_item(self, name : Literal['CST'], val : Union[Variation_691, Variation_691_Arg]) -> 'Variation_692':
        ...

    @overload
    def set_item(self, name : Literal['CDM'], val : Union[Variation_654, Variation_654_Arg]) -> 'Variation_692':
        ...

    @overload
    def set_item(self, name : Literal['MAH'], val : Union[Variation_655, Variation_655_Arg]) -> 'Variation_692':
        ...

    @overload
    def set_item(self, name : Literal['STH'], val : Union[Variation_270, Variation_270_Arg]) -> 'Variation_692':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_692':
        ...

    @overload
    def modify_item(self, name : Literal['TRE'], f : Any) -> 'Variation_692':
        ...

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_692':
        ...

    @overload
    def modify_item(self, name : Literal['CDM'], f : Any) -> 'Variation_692':
        ...

    @overload
    def modify_item(self, name : Literal['MAH'], f : Any) -> 'Variation_692':
        ...

    @overload
    def modify_item(self, name : Literal['STH'], f : Any) -> 'Variation_692':
        ...

    @overload
    def modify_item(self, name : Literal['GHO'], f : Any) -> 'Variation_692':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_693_Arg = TypedDict('Variation_693_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '020': Union[Variation_648, Variation_648_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '041': Union[Variation_649, Variation_649_Arg],
    '042': Union[Variation_650, Variation_650_Arg],
    '161': Union[Variation_651, Variation_651_Arg],
    '170': Union[Variation_692, Variation_692_Arg],
    '070': Union[Variation_658, Variation_658_Arg],
    '202': Union[Variation_659, Variation_659_Arg],
    '090': Union[Variation_286, Variation_286_Arg],
    '100': Union[Variation_661, Variation_661_Arg],
    '220': Union[Variation_278, Variation_278_Arg],
    '245': Union[Variation_663, Variation_663_Arg],
    '110': Union[Variation_287, Variation_287_Arg],
    '105': Union[Variation_287, Variation_287_Arg],
    '210': Union[Variation_664, Variation_664_Arg],
    '300': Union[Variation_285, Variation_285_Arg],
    '310': Union[Variation_665, Variation_665_Arg],
    '500': Union[Variation_669, Variation_669_Arg],
    '400': Union[Variation_679, Variation_679_Arg],
    '250': Union[Variation_681, Variation_681_Arg],
    '230': Union[Variation_683, Variation_683_Arg],
    '260': Union[Variation_281, Variation_281_Arg],
    '030': Union[Variation_685, Variation_685_Arg],
    '055': Union[Variation_687, Variation_687_Arg],
    '050': Union[Variation_689, Variation_689_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_693(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('020', Variation_648),
        ('140', Variation_80),
        ('041', Variation_649),
        ('042', Variation_650),
        ('161', Variation_651),
        ('170', Variation_692),
        ('070', Variation_658),
        ('202', Variation_659),
        ('090', Variation_286),
        ('100', Variation_661),
        ('220', Variation_278),
        ('245', Variation_663),
        ('110', Variation_287),
        ('105', Variation_287),
        ('210', Variation_664),
        ('300', Variation_285),
        ('310', Variation_665),
        ('500', Variation_669),
        ('400', Variation_679),
        ('250', Variation_681),
        ('230', Variation_683),
        ('260', Variation_281),
        ('030', Variation_685),
        ('055', Variation_687),
        ('050', Variation_689),
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '020': ('Target Report Descriptor', Variation_648, 0x40000000),
        '140': ('Time of Day', Variation_80, 0x20000000),
        '041': ('Position In WGS-84 Coordinates', Variation_649, 0x10000000),
        '042': ('Position in Cartesian Coordinates', Variation_650, 0x08000000),
        '161': ('Track Number', Variation_651, 0x04000000),
        '170': ('Track Status', Variation_692, 0x02000000),
        '070': ('Mode-3/A Code in Octal Representation', Variation_658, 0x01800000),
        '202': ('Calculated Track Velocity in Cartesian Coordinates', Variation_659, 0x01400000),
        '090': ('Flight Level in Binary Representation', Variation_286, 0x01200000),
        '100': ('Mode C Code', Variation_661, 0x01100000),
        '220': ('Target Address', Variation_278, 0x01080000),
        '245': ('Target Identification', Variation_663, 0x01040000),
        '110': ('Measured Height (Local Cartesian Coordinates)', Variation_287, 0x01020000),
        '105': ('Geometric Height (WGS-84)', Variation_287, 0x01018000),
        '210': ('Calculated Acceleration', Variation_664, 0x01014000),
        '300': ('Vehicle Fleet Identification', Variation_285, 0x01012000),
        '310': ('Pre-programmed Message', Variation_665, 0x01011000),
        '500': ('Position Accuracy', Variation_669, 0x01010800),
        '400': ('Contributing Devices', Variation_679, 0x01010400),
        '250': ('BDS Register Data', Variation_681, 0x01010200),
        '230': ('Communications/ACAS Capability and Flight Status', Variation_683, 0x01010180),
        '260': ('ACAS Resolution Advisory Report', Variation_281, 0x01010140),
        '030': ('Warning/Error Conditions', Variation_685, 0x01010120),
        '055': ('Mode-1 Code in Octal Representation', Variation_687, 0x01010110),
        '050': ('Mode-2 Code in Octal Representation', Variation_689, 0x01010108),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010104),
        'SP': ('Special Purpose Field', Variation_62, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_648]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_649]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_650]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_651]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_692]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_658]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['202']) -> Type[Variation_659]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_286]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_661]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['245']) -> Type[Variation_663]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['105']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_664]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_285]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['310']) -> Type[Variation_665]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_669]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_679]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_681]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_683]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_685]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['055']) -> Type[Variation_687]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_689]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['020'], Literal['140'], Literal['041'], Literal['042'], Literal['161'], Literal['170'], Literal['070'], Literal['202'], Literal['090'], Literal['100'], Literal['220'], Literal['245'], Literal['110'], Literal['105'], Literal['210'], Literal['300'], Literal['310'], Literal['500'], Literal['400'], Literal['250'], Literal['230'], Literal['260'], Literal['030'], Literal['055'], Literal['050'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_648'], Type['Variation_80'], Type['Variation_649'], Type['Variation_650'], Type['Variation_651'], Type['Variation_692'], Type['Variation_658'], Type['Variation_659'], Type['Variation_286'], Type['Variation_661'], Type['Variation_278'], Type['Variation_663'], Type['Variation_287'], Type['Variation_287'], Type['Variation_664'], Type['Variation_285'], Type['Variation_665'], Type['Variation_669'], Type['Variation_679'], Type['Variation_681'], Type['Variation_683'], Type['Variation_281'], Type['Variation_685'], Type['Variation_687'], Type['Variation_689'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '020':
            return Variation_648
        if key == '140':
            return Variation_80
        if key == '041':
            return Variation_649
        if key == '042':
            return Variation_650
        if key == '161':
            return Variation_651
        if key == '170':
            return Variation_692
        if key == '070':
            return Variation_658
        if key == '202':
            return Variation_659
        if key == '090':
            return Variation_286
        if key == '100':
            return Variation_661
        if key == '220':
            return Variation_278
        if key == '245':
            return Variation_663
        if key == '110':
            return Variation_287
        if key == '105':
            return Variation_287
        if key == '210':
            return Variation_664
        if key == '300':
            return Variation_285
        if key == '310':
            return Variation_665
        if key == '500':
            return Variation_669
        if key == '400':
            return Variation_679
        if key == '250':
            return Variation_681
        if key == '230':
            return Variation_683
        if key == '260':
            return Variation_281
        if key == '030':
            return Variation_685
        if key == '055':
            return Variation_687
        if key == '050':
            return Variation_689
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_693_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_648, Variation_648_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_649, Variation_649_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_650, Variation_650_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_651, Variation_651_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_692, Variation_692_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_658, Variation_658_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['202'], val : Union[Variation_659, Variation_659_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_286, Variation_286_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_661, Variation_661_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['245'], val : Union[Variation_663, Variation_663_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['105'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_664, Variation_664_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_285, Variation_285_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['310'], val : Union[Variation_665, Variation_665_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_669, Variation_669_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_679, Variation_679_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_681, Variation_681_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_683, Variation_683_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_685, Variation_685_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['055'], val : Union[Variation_687, Variation_687_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_689, Variation_689_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_693':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_693':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['202']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['245']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['105']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['310']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['055']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_693':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_693':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_648:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_649:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_650:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_651:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_692:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_658:
        ...

    @overload
    def get_item(self, name : Literal['202']) -> Variation_659:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_286:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_661:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['245']) -> Variation_663:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['105']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_664:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_285:
        ...

    @overload
    def get_item(self, name : Literal['310']) -> Variation_665:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_669:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_679:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_681:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_683:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_685:
        ...

    @overload
    def get_item(self, name : Literal['055']) -> Variation_687:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_689:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['202'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['245'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['105'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['310'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['055'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_693':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_693':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_694_Arg : TypeAlias = Raw
class Variation_694(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No differential correction (ADS-B)',
        1: 'Differential correction (ADS-B)',
    }

    def __init__(self, arg : Variation_694_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_695_Arg : TypeAlias = Raw
class Variation_695(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Ground Bit not set',
        1: 'Ground Bit set',
    }

    def __init__(self, arg : Variation_695_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_696_Arg : TypeAlias = Raw
class Variation_696(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Actual target report',
        1: 'Simulated target report',
    }

    def __init__(self, arg : Variation_696_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_697_Arg : TypeAlias = Raw
class Variation_697(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Test Target',
    }

    def __init__(self, arg : Variation_697_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_698_Arg : TypeAlias = Raw
class Variation_698(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Report from target transponder',
        1: 'Report from field monitor (fixed transponder)',
    }

    def __init__(self, arg : Variation_698_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_699_Arg : TypeAlias = Raw
class Variation_699(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Equipment capable to provide Selected Altitude',
        1: 'Equipment not capable to provide Selected Altitude',
    }

    def __init__(self, arg : Variation_699_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_700_Arg : TypeAlias = Raw
class Variation_700(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Absence of SPI',
        1: 'Special Position Identification',
    }

    def __init__(self, arg : Variation_700_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_701_Arg : TypeAlias = Raw
class Variation_701(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: 'Non unique address',
        1: '24-Bit ICAO address',
        2: 'Surface vehicle address',
        3: 'Anonymous address',
        4: 'Reserved for future use',
        5: 'Reserved for future use',
        6: 'Reserved for future use',
        7: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_701_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_702_Arg : TypeAlias = Raw
class Variation_702(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 2
    table = {
        0: 'Unknown',
        1: '25 ft',
        2: '100 ft',
    }

    def __init__(self, arg : Variation_702_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_703_Arg_Group = TypedDict('Variation_703_Arg_Group', {
    'DCR': Union[Variation_694, Variation_694_Arg],
    'GBS': Union[Variation_695, Variation_695_Arg],
    'SIM': Union[Variation_696, Variation_696_Arg],
    'TST': Union[Variation_697, Variation_697_Arg],
    'RAB': Union[Variation_698, Variation_698_Arg],
    'SAA': Union[Variation_699, Variation_699_Arg],
    'SPI': Union[Variation_700, Variation_700_Arg],
    'ATP': Union[Variation_701, Variation_701_Arg],
    'ARC': Union[Variation_702, Variation_702_Arg],
})
Variation_703_Arg : TypeAlias = Union[Raw, Variation_703_Arg_Group]
class Variation_703(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('DCR', Variation_694),
        ('GBS', Variation_695),
        ('SIM', Variation_696),
        ('TST', Variation_697),
        ('RAB', Variation_698),
        ('SAA', Variation_699),
        ('SPI', Variation_700),
        Spare(7, 1),
        ('ATP', Variation_701),
        ('ARC', Variation_702),
        Spare(5, 3),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'DCR': ('Differential Correction', Variation_694, 0, 1),
        'GBS': ('Ground Bit Setting', Variation_695, 1, 1),
        'SIM': ('Simulated Target', Variation_696, 2, 1),
        'TST': ('Test Target', Variation_697, 3, 1),
        'RAB': ('Report Type', Variation_698, 4, 1),
        'SAA': ('Selected Altitude Available', Variation_699, 5, 1),
        'SPI': ('Special Position Identification', Variation_700, 6, 1),
        'ATP': ('Address Type', Variation_701, 8, 3),
        'ARC': ('Altitude Reporting Capability', Variation_702, 11, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['DCR']) -> Type[Variation_694]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GBS']) -> Type[Variation_695]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_696]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_697]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_698]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAA']) -> Type[Variation_699]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_700]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ATP']) -> Type[Variation_701]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_702]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['DCR'], Literal['GBS'], Literal['SIM'], Literal['TST'], Literal['RAB'], Literal['SAA'], Literal['SPI'], Literal['ATP'], Literal['ARC']]) -> Union[Type['Variation_694'], Type['Variation_695'], Type['Variation_696'], Type['Variation_697'], Type['Variation_698'], Type['Variation_699'], Type['Variation_700'], Type['Variation_701'], Type['Variation_702']]:
        if key == 'DCR':
            return Variation_694
        if key == 'GBS':
            return Variation_695
        if key == 'SIM':
            return Variation_696
        if key == 'TST':
            return Variation_697
        if key == 'RAB':
            return Variation_698
        if key == 'SAA':
            return Variation_699
        if key == 'SPI':
            return Variation_700
        if key == 'ATP':
            return Variation_701
        if key == 'ARC':
            return Variation_702
        assert_never(key)

    def __init__(self, arg : Variation_703_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['DCR']) -> Variation_694:
        ...

    @overload
    def get_item(self, name : Literal['GBS']) -> Variation_695:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_696:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_697:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_698:
        ...

    @overload
    def get_item(self, name : Literal['SAA']) -> Variation_699:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_700:
        ...

    @overload
    def get_item(self, name : Literal['ATP']) -> Variation_701:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_702:
        ...

    def get_item(self, name : Union[Literal['DCR'], Literal['GBS'], Literal['SIM'], Literal['TST'], Literal['RAB'], Literal['SAA'], Literal['SPI'], Literal['ATP'], Literal['ARC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['DCR'], val : Union[Variation_694, Variation_694_Arg]) -> 'Variation_703':
        ...

    @overload
    def set_item(self, name : Literal['GBS'], val : Union[Variation_695, Variation_695_Arg]) -> 'Variation_703':
        ...

    @overload
    def set_item(self, name : Literal['SIM'], val : Union[Variation_696, Variation_696_Arg]) -> 'Variation_703':
        ...

    @overload
    def set_item(self, name : Literal['TST'], val : Union[Variation_697, Variation_697_Arg]) -> 'Variation_703':
        ...

    @overload
    def set_item(self, name : Literal['RAB'], val : Union[Variation_698, Variation_698_Arg]) -> 'Variation_703':
        ...

    @overload
    def set_item(self, name : Literal['SAA'], val : Union[Variation_699, Variation_699_Arg]) -> 'Variation_703':
        ...

    @overload
    def set_item(self, name : Literal['SPI'], val : Union[Variation_700, Variation_700_Arg]) -> 'Variation_703':
        ...

    @overload
    def set_item(self, name : Literal['ATP'], val : Union[Variation_701, Variation_701_Arg]) -> 'Variation_703':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_702, Variation_702_Arg]) -> 'Variation_703':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['DCR'], f : Any) -> 'Variation_703':
        ...

    @overload
    def modify_item(self, name : Literal['GBS'], f : Any) -> 'Variation_703':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_703':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_703':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_703':
        ...

    @overload
    def modify_item(self, name : Literal['SAA'], f : Any) -> 'Variation_703':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_703':
        ...

    @overload
    def modify_item(self, name : Literal['ATP'], f : Any) -> 'Variation_703':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_703':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_704_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_704(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Signed', 2.1457672119140625e-5, '°')

    def __init__(self, arg : Variation_704_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_705_Arg_Group = TypedDict('Variation_705_Arg_Group', {
    'LAT': Union[Variation_704, Variation_704_Arg],
    'LON': Union[Variation_704, Variation_704_Arg],
})
Variation_705_Arg : TypeAlias = Union[Raw, Variation_705_Arg_Group]
class Variation_705(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('LAT', Variation_704),
        ('LON', Variation_704),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude', Variation_704, 0, 24),
        'LON': ('Longitude', Variation_704, 24, 24),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_704]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_704]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_704'], Type['Variation_704']]:
        if key == 'LAT':
            return Variation_704
        if key == 'LON':
            return Variation_704
        assert_never(key)

    def __init__(self, arg : Variation_705_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_704:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_704:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_705':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_705':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_705':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_705':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_706_Arg : TypeAlias = Raw
class Variation_706(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'ACAS not operational',
        2: 'ACAS operartional',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_706_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_707_Arg : TypeAlias = Raw
class Variation_707(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Multiple Navigation not operational',
        2: 'Multiple Navigation operartional',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_707_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_708_Arg : TypeAlias = Raw
class Variation_708(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Differencial Correction',
        2: 'NO Differencial Correction',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_708_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_709_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['']]]
class Variation_709(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 4
    quantity = Quantity('Signed', 1.0, '')

    def __init__(self, arg : Variation_709_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_710_Arg_Group = TypedDict('Variation_710_Arg_Group', {
    'AC': Union[Variation_706, Variation_706_Arg],
    'MN': Union[Variation_707, Variation_707_Arg],
    'DC': Union[Variation_708, Variation_708_Arg],
    'PA': Union[Variation_709, Variation_709_Arg],
})
Variation_710_Arg : TypeAlias = Union[Raw, Variation_710_Arg_Group]
class Variation_710(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('AC', Variation_706),
        ('MN', Variation_707),
        ('DC', Variation_708),
        Spare(6, 6),
        ('PA', Variation_709),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'AC': ('ACAS Capabilities', Variation_706, 0, 2),
        'MN': ('Multiple Navigation Aids', Variation_707, 2, 2),
        'DC': ('Differencial Correction', Variation_708, 4, 2),
        'PA': ('Position Accuracy', Variation_709, 12, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AC']) -> Type[Variation_706]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MN']) -> Type[Variation_707]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DC']) -> Type[Variation_708]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PA']) -> Type[Variation_709]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AC'], Literal['MN'], Literal['DC'], Literal['PA']]) -> Union[Type['Variation_706'], Type['Variation_707'], Type['Variation_708'], Type['Variation_709']]:
        if key == 'AC':
            return Variation_706
        if key == 'MN':
            return Variation_707
        if key == 'DC':
            return Variation_708
        if key == 'PA':
            return Variation_709
        assert_never(key)

    def __init__(self, arg : Variation_710_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['AC']) -> Variation_706:
        ...

    @overload
    def get_item(self, name : Literal['MN']) -> Variation_707:
        ...

    @overload
    def get_item(self, name : Literal['DC']) -> Variation_708:
        ...

    @overload
    def get_item(self, name : Literal['PA']) -> Variation_709:
        ...

    def get_item(self, name : Union[Literal['AC'], Literal['MN'], Literal['DC'], Literal['PA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['AC'], val : Union[Variation_706, Variation_706_Arg]) -> 'Variation_710':
        ...

    @overload
    def set_item(self, name : Literal['MN'], val : Union[Variation_707, Variation_707_Arg]) -> 'Variation_710':
        ...

    @overload
    def set_item(self, name : Literal['DC'], val : Union[Variation_708, Variation_708_Arg]) -> 'Variation_710':
        ...

    @overload
    def set_item(self, name : Literal['PA'], val : Union[Variation_709, Variation_709_Arg]) -> 'Variation_710':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['AC'], f : Any) -> 'Variation_710':
        ...

    @overload
    def modify_item(self, name : Literal['MN'], f : Any) -> 'Variation_710':
        ...

    @overload
    def modify_item(self, name : Literal['DC'], f : Any) -> 'Variation_710':
        ...

    @overload
    def modify_item(self, name : Literal['PA'], f : Any) -> 'Variation_710':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_711_Arg : TypeAlias = Raw
class Variation_711(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Unknown',
        1: 'Aircraft equiped with CDTI',
    }

    def __init__(self, arg : Variation_711_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_712_Arg : TypeAlias = Raw
class Variation_712(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Not used',
        1: 'Used',
    }

    def __init__(self, arg : Variation_712_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_713_Arg : TypeAlias = Raw
class Variation_713(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Not used',
        1: 'Used',
    }

    def __init__(self, arg : Variation_713_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_714_Arg : TypeAlias = Raw
class Variation_714(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Not used',
        1: 'Used',
    }

    def __init__(self, arg : Variation_714_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_715_Arg : TypeAlias = Raw
class Variation_715(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'Not used',
        1: 'Used',
    }

    def __init__(self, arg : Variation_715_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_716_Arg_Group = TypedDict('Variation_716_Arg_Group', {
    'DTI': Union[Variation_711, Variation_711_Arg],
    'MDS': Union[Variation_712, Variation_712_Arg],
    'UAT': Union[Variation_713, Variation_713_Arg],
    'VDL': Union[Variation_714, Variation_714_Arg],
    'OTR': Union[Variation_715, Variation_715_Arg],
})
Variation_716_Arg : TypeAlias = Union[Raw, Variation_716_Arg_Group]
class Variation_716(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 3),
        ('DTI', Variation_711),
        ('MDS', Variation_712),
        ('UAT', Variation_713),
        ('VDL', Variation_714),
        ('OTR', Variation_715),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'DTI': ('Cockpit Display of Traffic Information', Variation_711, 3, 1),
        'MDS': ('Mode-S Extended Squitter', Variation_712, 4, 1),
        'UAT': ('UAT', Variation_713, 5, 1),
        'VDL': ('VDL Mode 4', Variation_714, 6, 1),
        'OTR': ('Other Technology', Variation_715, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['DTI']) -> Type[Variation_711]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_712]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['UAT']) -> Type[Variation_713]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VDL']) -> Type[Variation_714]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OTR']) -> Type[Variation_715]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['DTI'], Literal['MDS'], Literal['UAT'], Literal['VDL'], Literal['OTR']]) -> Union[Type['Variation_711'], Type['Variation_712'], Type['Variation_713'], Type['Variation_714'], Type['Variation_715']]:
        if key == 'DTI':
            return Variation_711
        if key == 'MDS':
            return Variation_712
        if key == 'UAT':
            return Variation_713
        if key == 'VDL':
            return Variation_714
        if key == 'OTR':
            return Variation_715
        assert_never(key)

    def __init__(self, arg : Variation_716_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['DTI']) -> Variation_711:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_712:
        ...

    @overload
    def get_item(self, name : Literal['UAT']) -> Variation_713:
        ...

    @overload
    def get_item(self, name : Literal['VDL']) -> Variation_714:
        ...

    @overload
    def get_item(self, name : Literal['OTR']) -> Variation_715:
        ...

    def get_item(self, name : Union[Literal['DTI'], Literal['MDS'], Literal['UAT'], Literal['VDL'], Literal['OTR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['DTI'], val : Union[Variation_711, Variation_711_Arg]) -> 'Variation_716':
        ...

    @overload
    def set_item(self, name : Literal['MDS'], val : Union[Variation_712, Variation_712_Arg]) -> 'Variation_716':
        ...

    @overload
    def set_item(self, name : Literal['UAT'], val : Union[Variation_713, Variation_713_Arg]) -> 'Variation_716':
        ...

    @overload
    def set_item(self, name : Literal['VDL'], val : Union[Variation_714, Variation_714_Arg]) -> 'Variation_716':
        ...

    @overload
    def set_item(self, name : Literal['OTR'], val : Union[Variation_715, Variation_715_Arg]) -> 'Variation_716':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['DTI'], f : Any) -> 'Variation_716':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_716':
        ...

    @overload
    def modify_item(self, name : Literal['UAT'], f : Any) -> 'Variation_716':
        ...

    @overload
    def modify_item(self, name : Literal['VDL'], f : Any) -> 'Variation_716':
        ...

    @overload
    def modify_item(self, name : Literal['OTR'], f : Any) -> 'Variation_716':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_717_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_717(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 1.0e-2, '°')

    def __init__(self, arg : Variation_717_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_718_Arg : TypeAlias = Raw
class Variation_718(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Air Speed = IAS, LSB (Bit-1) = 2 -14 NM/s',
        1: 'Air Speed = Mach, LSB (Bit-1) = 0.001',
    }

    def __init__(self, arg : Variation_718_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_719_Arg_Group = TypedDict('Variation_719_Arg_Group', {
    'IM': Union[Variation_718, Variation_718_Arg],
    'AS': Union[Variation_337, Variation_337_Arg],
})
Variation_719_Arg : TypeAlias = Union[Raw, Variation_719_Arg_Group]
class Variation_719(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('IM', Variation_718),
        ('AS', Variation_337),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'IM': ('', Variation_718, 0, 1),
        'AS': ('Air Speed (IAS or Mach)', Variation_337, 1, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['IM']) -> Type[Variation_718]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AS']) -> Type[Variation_337]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['IM'], Literal['AS']]) -> Union[Type['Variation_718'], Type['Variation_337']]:
        if key == 'IM':
            return Variation_718
        if key == 'AS':
            return Variation_337
        assert_never(key)

    def __init__(self, arg : Variation_719_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['IM']) -> Variation_718:
        ...

    @overload
    def get_item(self, name : Literal['AS']) -> Variation_337:
        ...

    def get_item(self, name : Union[Literal['IM'], Literal['AS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['IM'], val : Union[Variation_718, Variation_718_Arg]) -> 'Variation_719':
        ...

    @overload
    def set_item(self, name : Literal['AS'], val : Union[Variation_337, Variation_337_Arg]) -> 'Variation_719':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['IM'], f : Any) -> 'Variation_719':
        ...

    @overload
    def modify_item(self, name : Literal['AS'], f : Any) -> 'Variation_719':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_720_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['kt']]]
class Variation_720(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0, 'kt')

    def __init__(self, arg : Variation_720_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_721_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM/s']]]
class Variation_721(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 6.103515625e-5, 'NM/s')

    def __init__(self, arg : Variation_721_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_722_Arg_Group = TypedDict('Variation_722_Arg_Group', {
    'GS': Union[Variation_721, Variation_721_Arg],
    'TA': Union[Variation_14, Variation_14_Arg],
})
Variation_722_Arg : TypeAlias = Union[Raw, Variation_722_Arg_Group]
class Variation_722(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('GS', Variation_721),
        ('TA', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'GS': ('Ground Speed in Two\'s Complement Form Referenced to WGS84', Variation_721, 0, 16),
        'TA': ('Track Angle', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['GS']) -> Type[Variation_721]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TA']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['GS'], Literal['TA']]) -> Union[Type['Variation_721'], Type['Variation_14']]:
        if key == 'GS':
            return Variation_721
        if key == 'TA':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_722_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['GS']) -> Variation_721:
        ...

    @overload
    def get_item(self, name : Literal['TA']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['GS'], Literal['TA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['GS'], val : Union[Variation_721, Variation_721_Arg]) -> 'Variation_722':
        ...

    @overload
    def set_item(self, name : Literal['TA'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_722':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['GS'], f : Any) -> 'Variation_722':
        ...

    @overload
    def modify_item(self, name : Literal['TA'], f : Any) -> 'Variation_722':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_723_Arg : TypeAlias = Raw
class Variation_723(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Not available',
        1: 'Left',
        2: 'Right',
        3: 'Straight',
    }

    def __init__(self, arg : Variation_723_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_724_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°/s']]]
class Variation_724(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    quantity = Quantity('Signed', 0.25, '°/s')

    def __init__(self, arg : Variation_724_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_725_Arg_Group_1 = TypedDict('Variation_725_Arg_Group_1', {
    'TI': Union[Variation_723, Variation_723_Arg],
})
Variation_725_Arg_Group_2 = TypedDict('Variation_725_Arg_Group_2', {
    'TI': Union[Variation_723, Variation_723_Arg],
    'ROT': Union[Variation_724, Variation_724_Arg],
})
Variation_725_Arg : TypeAlias = Union[
    int,
    Variation_725_Arg_Group_1,
    Tuple[int],
    Variation_725_Arg_Group_2,
    Tuple[int,int],
]
class Variation_725(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('TI', Variation_723),
            Spare(2, 5),
        ],
        [
            ('ROT', Variation_724),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TI': ('Turn Indicator', Variation_723, 0, 2),
        'ROT': ('Rate of Turn', Variation_724, 0, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TI']) -> Type[Variation_723]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ROT']) -> Type[Variation_724]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TI'], Literal['ROT']]) -> Union[Type['Variation_723'], Type['Variation_724']]:
        if key == 'TI':
            return Variation_723
        if key == 'ROT':
            return Variation_724
        assert_never(key)

    def __init__(self, arg : Variation_725_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_725_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_725_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TI']) -> Variation_723:
        ...

    @overload
    def get_item(self, name : Literal['ROT']) -> Variation_724:
        ...

    def get_item(self, name : Union[Literal['TI'], Literal['ROT']]) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['TI'], val : Union[Variation_723, Variation_723_Arg]) -> 'Variation_725':
        return self._set_item(name, val) # type: ignore

    @overload
    def modify_item(self, name : Literal['TI'], f : Any) -> 'Variation_725':
        ...

    @overload
    def modify_item(self, name : Literal['ROT'], f : Any) -> 'Variation_725':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_726_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_726(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 3.90625e-3, 's')

    def __init__(self, arg : Variation_726_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_727_Arg : TypeAlias = Raw
class Variation_727(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'No emergency / not reported',
        1: 'General emergency',
        2: 'Lifeguard / medical',
        3: 'Minimum fuel',
        4: 'No communications',
        5: 'Unlawful interference',
    }

    def __init__(self, arg : Variation_727_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_728_Arg : TypeAlias = Raw
class Variation_728(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Light aircraft <= 7000 kg',
        2: 'Reserved',
        3: '7000 kg < Medium aircraft < 136000 kg',
        4: 'Reserved',
        5: '136000 kg <= Heavy aircraft',
        6: 'Highly manoeuvrable (5g acceleration capability) and high speed (>400 knots cruise)',
        7: 'Reserved',
        8: 'Reserved',
        9: 'Reserved',
        10: 'Rotocraft',
        11: 'Glider / sailplane',
        12: 'Lighter-than-air',
        13: 'Unmanned aerial vehicle',
        14: 'Space / transatmospheric vehicle',
        15: 'Ultralight / handglider / paraglider',
        16: 'Parachutist / skydiver',
        17: 'Reserved',
        18: 'Reserved',
        19: 'Reserved',
        20: 'Surface emergency vehicle',
        21: 'Surface service vehicle',
        22: 'Fixed ground or tethered obstruction',
        23: 'Reserved',
        24: 'Reserved',
    }

    def __init__(self, arg : Variation_728_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_729_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_729(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0, '°')

    def __init__(self, arg : Variation_729_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_730_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°C']]]
class Variation_730(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 0.25, '°C')

    def __init__(self, arg : Variation_730_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_731_Arg = TypedDict('Variation_731_Arg', {
    'WS': Union[Variation_720, Variation_720_Arg],
    'WD': Union[Variation_729, Variation_729_Arg],
    'TMP': Union[Variation_730, Variation_730_Arg],
    'TRB': Union[Variation_0, Variation_0_Arg],
}, total=False)
class Variation_731(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('WS', Variation_720),
        ('WD', Variation_729),
        ('TMP', Variation_730),
        ('TRB', Variation_0),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'WS': ('Wind Speed', Variation_720, 0x80),
        'WD': ('Wind Direction', Variation_729, 0x40),
        'TMP': ('Temperature', Variation_730, 0x20),
        'TRB': ('Turbulence', Variation_0, 0x10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['WS']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WD']) -> Type[Variation_729]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TMP']) -> Type[Variation_730]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRB']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['WS'], Literal['WD'], Literal['TMP'], Literal['TRB']]) -> Union[Type['Variation_720'], Type['Variation_729'], Type['Variation_730'], Type['Variation_0']]:
        if key == 'WS':
            return Variation_720
        if key == 'WD':
            return Variation_729
        if key == 'TMP':
            return Variation_730
        if key == 'TRB':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Optional[Variation_731_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['WS'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_731':
        ...

    @overload
    def set_item(self, name : Literal['WD'], val : Union[Variation_729, Variation_729_Arg]) -> 'Variation_731':
        ...

    @overload
    def set_item(self, name : Literal['TMP'], val : Union[Variation_730, Variation_730_Arg]) -> 'Variation_731':
        ...

    @overload
    def set_item(self, name : Literal['TRB'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_731':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['WS']) -> 'Variation_731':
        ...

    @overload
    def del_item(self, name : Literal['WD']) -> 'Variation_731':
        ...

    @overload
    def del_item(self, name : Literal['TMP']) -> 'Variation_731':
        ...

    @overload
    def del_item(self, name : Literal['TRB']) -> 'Variation_731':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['WS']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['WD']) -> Variation_729:
        ...

    @overload
    def get_item(self, name : Literal['TMP']) -> Variation_730:
        ...

    @overload
    def get_item(self, name : Literal['TRB']) -> Variation_0:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['WS'], f : Any) -> 'Variation_731':
        ...

    @overload
    def modify_item(self, name : Literal['WD'], f : Any) -> 'Variation_731':
        ...

    @overload
    def modify_item(self, name : Literal['TMP'], f : Any) -> 'Variation_731':
        ...

    @overload
    def modify_item(self, name : Literal['TRB'], f : Any) -> 'Variation_731':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_732_Arg : TypeAlias = Raw
class Variation_732(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No source information provided',
        1: 'Source Information provided',
    }

    def __init__(self, arg : Variation_732_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_733_Arg : TypeAlias = Raw
class Variation_733(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Aircraft Altitude (Holding Altitude)',
        2: 'MCP/FCU Selected Altitude',
        3: 'FMS Selected Altitude',
    }

    def __init__(self, arg : Variation_733_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_734_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft']]]
class Variation_734(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 13
    quantity = Quantity('Signed', 25.0, 'ft')

    def __init__(self, arg : Variation_734_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_735_Arg_Group = TypedDict('Variation_735_Arg_Group', {
    'SAS': Union[Variation_732, Variation_732_Arg],
    'SRC': Union[Variation_733, Variation_733_Arg],
    'ALT': Union[Variation_734, Variation_734_Arg],
})
Variation_735_Arg : TypeAlias = Union[Raw, Variation_735_Arg_Group]
class Variation_735(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('SAS', Variation_732),
        ('SRC', Variation_733),
        ('ALT', Variation_734),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SAS': ('Source Availability', Variation_732, 0, 1),
        'SRC': ('Source', Variation_733, 1, 2),
        'ALT': ('Altitude', Variation_734, 3, 13),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SAS']) -> Type[Variation_732]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRC']) -> Type[Variation_733]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_734]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SAS'], Literal['SRC'], Literal['ALT']]) -> Union[Type['Variation_732'], Type['Variation_733'], Type['Variation_734']]:
        if key == 'SAS':
            return Variation_732
        if key == 'SRC':
            return Variation_733
        if key == 'ALT':
            return Variation_734
        assert_never(key)

    def __init__(self, arg : Variation_735_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SAS']) -> Variation_732:
        ...

    @overload
    def get_item(self, name : Literal['SRC']) -> Variation_733:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_734:
        ...

    def get_item(self, name : Union[Literal['SAS'], Literal['SRC'], Literal['ALT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SAS'], val : Union[Variation_732, Variation_732_Arg]) -> 'Variation_735':
        ...

    @overload
    def set_item(self, name : Literal['SRC'], val : Union[Variation_733, Variation_733_Arg]) -> 'Variation_735':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_734, Variation_734_Arg]) -> 'Variation_735':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SAS'], f : Any) -> 'Variation_735':
        ...

    @overload
    def modify_item(self, name : Literal['SRC'], f : Any) -> 'Variation_735':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_735':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_736_Arg : TypeAlias = Raw
class Variation_736(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Not active',
        1: 'Active',
    }

    def __init__(self, arg : Variation_736_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_737_Arg : TypeAlias = Raw
class Variation_737(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Not active',
        1: 'Active',
    }

    def __init__(self, arg : Variation_737_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_738_Arg : TypeAlias = Raw
class Variation_738(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Not active',
        1: 'Active',
    }

    def __init__(self, arg : Variation_738_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_739_Arg_Group = TypedDict('Variation_739_Arg_Group', {
    'MV': Union[Variation_736, Variation_736_Arg],
    'AH': Union[Variation_737, Variation_737_Arg],
    'AM': Union[Variation_738, Variation_738_Arg],
    'ALT': Union[Variation_734, Variation_734_Arg],
})
Variation_739_Arg : TypeAlias = Union[Raw, Variation_739_Arg_Group]
class Variation_739(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('MV', Variation_736),
        ('AH', Variation_737),
        ('AM', Variation_738),
        ('ALT', Variation_734),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MV': ('Manage Vertical Mode', Variation_736, 0, 1),
        'AH': ('Altitude Hold Mode', Variation_737, 1, 1),
        'AM': ('Approach Mode', Variation_738, 2, 1),
        'ALT': ('Altitude', Variation_734, 3, 13),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MV']) -> Type[Variation_736]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AH']) -> Type[Variation_737]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AM']) -> Type[Variation_738]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_734]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MV'], Literal['AH'], Literal['AM'], Literal['ALT']]) -> Union[Type['Variation_736'], Type['Variation_737'], Type['Variation_738'], Type['Variation_734']]:
        if key == 'MV':
            return Variation_736
        if key == 'AH':
            return Variation_737
        if key == 'AM':
            return Variation_738
        if key == 'ALT':
            return Variation_734
        assert_never(key)

    def __init__(self, arg : Variation_739_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MV']) -> Variation_736:
        ...

    @overload
    def get_item(self, name : Literal['AH']) -> Variation_737:
        ...

    @overload
    def get_item(self, name : Literal['AM']) -> Variation_738:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_734:
        ...

    def get_item(self, name : Union[Literal['MV'], Literal['AH'], Literal['AM'], Literal['ALT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MV'], val : Union[Variation_736, Variation_736_Arg]) -> 'Variation_739':
        ...

    @overload
    def set_item(self, name : Literal['AH'], val : Union[Variation_737, Variation_737_Arg]) -> 'Variation_739':
        ...

    @overload
    def set_item(self, name : Literal['AM'], val : Union[Variation_738, Variation_738_Arg]) -> 'Variation_739':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_734, Variation_734_Arg]) -> 'Variation_739':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MV'], f : Any) -> 'Variation_739':
        ...

    @overload
    def modify_item(self, name : Literal['AH'], f : Any) -> 'Variation_739':
        ...

    @overload
    def modify_item(self, name : Literal['AM'], f : Any) -> 'Variation_739':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_739':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_740_Arg : TypeAlias = Raw
class Variation_740(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Trajectory Intent Data is available for this aircraft',
        1: 'Trajectory Intent Data is not available for this aircraft',
    }

    def __init__(self, arg : Variation_740_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_741_Arg : TypeAlias = Raw
class Variation_741(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Trajectory Intent Data is valid',
        1: 'Trajectory Intent Data is not valid',
    }

    def __init__(self, arg : Variation_741_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_742_Arg_Group_1 = TypedDict('Variation_742_Arg_Group_1', {
    'NAV': Union[Variation_740, Variation_740_Arg],
    'NVB': Union[Variation_741, Variation_741_Arg],
})
Variation_742_Arg : TypeAlias = Union[
    int,
    Variation_742_Arg_Group_1,
    Tuple[int],
]
class Variation_742(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            ('NAV', Variation_740),
            ('NVB', Variation_741),
            Spare(2, 5),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NAV': ('', Variation_740, 0, 1),
        'NVB': ('', Variation_741, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NAV']) -> Type[Variation_740]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NVB']) -> Type[Variation_741]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NAV'], Literal['NVB']]) -> Union[Type['Variation_740'], Type['Variation_741']]:
        if key == 'NAV':
            return Variation_740
        if key == 'NVB':
            return Variation_741
        assert_never(key)

    def __init__(self, arg : Variation_742_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_742_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NAV']) -> Variation_740:
        ...

    @overload
    def get_item(self, name : Literal['NVB']) -> Variation_741:
        ...

    def get_item(self, name : Union[Literal['NAV'], Literal['NVB']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NAV'], val : Union[Variation_740, Variation_740_Arg]) -> 'Variation_742':
        ...

    @overload
    def set_item(self, name : Literal['NVB'], val : Union[Variation_741, Variation_741_Arg]) -> 'Variation_742':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NAV'], f : Any) -> 'Variation_742':
        ...

    @overload
    def modify_item(self, name : Literal['NVB'], f : Any) -> 'Variation_742':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_743_Arg : TypeAlias = Raw
class Variation_743(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'TCP number available',
        1: 'TCP number not available',
    }

    def __init__(self, arg : Variation_743_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_744_Arg : TypeAlias = Raw
class Variation_744(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'TCP compliance',
        1: 'TCP non-compliance',
    }

    def __init__(self, arg : Variation_744_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_745_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft']]]
class Variation_745(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 10.0, 'ft')

    def __init__(self, arg : Variation_745_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_746_Arg : TypeAlias = Raw
class Variation_746(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 4
    table = {
        0: 'Unknown',
        1: 'Fly by waypoint (LT)',
        2: 'Fly over waypoint (LT)',
        3: 'Hold pattern (LT)',
        4: 'Procedure hold (LT)',
        5: 'Procedure turn (LT)',
        6: 'RF leg (LT)',
        7: 'Top of climb (VT)',
        8: 'Top of descent (VT)',
        9: 'Start of level (VT)',
        10: 'Cross-over altitude (VT)',
        11: 'Transition altitude (VT)',
    }

    def __init__(self, arg : Variation_746_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_747_Arg : TypeAlias = Raw
class Variation_747(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        0: 'N/A',
        1: 'Turn right',
        2: 'Turn left',
        3: 'No turn',
    }

    def __init__(self, arg : Variation_747_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_748_Arg : TypeAlias = Raw
class Variation_748(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'TTR not available',
        1: 'TTR available',
    }

    def __init__(self, arg : Variation_748_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_749_Arg : TypeAlias = Raw
class Variation_749(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'TOV available',
        1: 'TOV not available',
    }

    def __init__(self, arg : Variation_749_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_750_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_750(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Unsigned', 1.0, 's')

    def __init__(self, arg : Variation_750_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_751_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_751(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0e-2, 'NM')

    def __init__(self, arg : Variation_751_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_752_Arg_Group = TypedDict('Variation_752_Arg_Group', {
    'TCA': Union[Variation_743, Variation_743_Arg],
    'NC': Union[Variation_744, Variation_744_Arg],
    'TCPN': Union[Variation_376, Variation_376_Arg],
    'ALT': Union[Variation_745, Variation_745_Arg],
    'LAT': Union[Variation_704, Variation_704_Arg],
    'LON': Union[Variation_704, Variation_704_Arg],
    'PT': Union[Variation_746, Variation_746_Arg],
    'TD': Union[Variation_747, Variation_747_Arg],
    'TRA': Union[Variation_748, Variation_748_Arg],
    'TOA': Union[Variation_749, Variation_749_Arg],
    'TOV': Union[Variation_750, Variation_750_Arg],
    'TTR': Union[Variation_751, Variation_751_Arg],
})
Variation_752_Arg : TypeAlias = Union[Raw, Variation_752_Arg_Group]
class Variation_752(Group):
    variation = 'Group'

    bit_size = 120

    subitems_list = [
        ('TCA', Variation_743),
        ('NC', Variation_744),
        ('TCPN', Variation_376),
        ('ALT', Variation_745),
        ('LAT', Variation_704),
        ('LON', Variation_704),
        ('PT', Variation_746),
        ('TD', Variation_747),
        ('TRA', Variation_748),
        ('TOA', Variation_749),
        ('TOV', Variation_750),
        ('TTR', Variation_751),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TCA': ('', Variation_743, 0, 1),
        'NC': ('', Variation_744, 1, 1),
        'TCPN': ('', Variation_376, 2, 6),
        'ALT': ('Altitude in Two\'s Complement Form', Variation_745, 8, 16),
        'LAT': ('In WGS.84 in Two\'s Complement', Variation_704, 24, 24),
        'LON': ('In WGS.84 in Two\'s Complement', Variation_704, 48, 24),
        'PT': ('Point Type', Variation_746, 72, 4),
        'TD': ('', Variation_747, 76, 2),
        'TRA': ('', Variation_748, 78, 1),
        'TOA': ('', Variation_749, 79, 1),
        'TOV': ('Time Over Point', Variation_750, 80, 24),
        'TTR': ('TCP Turn Radius', Variation_751, 104, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TCA']) -> Type[Variation_743]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NC']) -> Type[Variation_744]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCPN']) -> Type[Variation_376]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_745]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_704]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_704]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PT']) -> Type[Variation_746]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TD']) -> Type[Variation_747]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRA']) -> Type[Variation_748]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOA']) -> Type[Variation_749]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOV']) -> Type[Variation_750]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TTR']) -> Type[Variation_751]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TCA'], Literal['NC'], Literal['TCPN'], Literal['ALT'], Literal['LAT'], Literal['LON'], Literal['PT'], Literal['TD'], Literal['TRA'], Literal['TOA'], Literal['TOV'], Literal['TTR']]) -> Union[Type['Variation_743'], Type['Variation_744'], Type['Variation_376'], Type['Variation_745'], Type['Variation_704'], Type['Variation_704'], Type['Variation_746'], Type['Variation_747'], Type['Variation_748'], Type['Variation_749'], Type['Variation_750'], Type['Variation_751']]:
        if key == 'TCA':
            return Variation_743
        if key == 'NC':
            return Variation_744
        if key == 'TCPN':
            return Variation_376
        if key == 'ALT':
            return Variation_745
        if key == 'LAT':
            return Variation_704
        if key == 'LON':
            return Variation_704
        if key == 'PT':
            return Variation_746
        if key == 'TD':
            return Variation_747
        if key == 'TRA':
            return Variation_748
        if key == 'TOA':
            return Variation_749
        if key == 'TOV':
            return Variation_750
        if key == 'TTR':
            return Variation_751
        assert_never(key)

    def __init__(self, arg : Variation_752_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TCA']) -> Variation_743:
        ...

    @overload
    def get_item(self, name : Literal['NC']) -> Variation_744:
        ...

    @overload
    def get_item(self, name : Literal['TCPN']) -> Variation_376:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_745:
        ...

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_704:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_704:
        ...

    @overload
    def get_item(self, name : Literal['PT']) -> Variation_746:
        ...

    @overload
    def get_item(self, name : Literal['TD']) -> Variation_747:
        ...

    @overload
    def get_item(self, name : Literal['TRA']) -> Variation_748:
        ...

    @overload
    def get_item(self, name : Literal['TOA']) -> Variation_749:
        ...

    @overload
    def get_item(self, name : Literal['TOV']) -> Variation_750:
        ...

    @overload
    def get_item(self, name : Literal['TTR']) -> Variation_751:
        ...

    def get_item(self, name : Union[Literal['TCA'], Literal['NC'], Literal['TCPN'], Literal['ALT'], Literal['LAT'], Literal['LON'], Literal['PT'], Literal['TD'], Literal['TRA'], Literal['TOA'], Literal['TOV'], Literal['TTR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TCA'], val : Union[Variation_743, Variation_743_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['NC'], val : Union[Variation_744, Variation_744_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['TCPN'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_745, Variation_745_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['PT'], val : Union[Variation_746, Variation_746_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['TD'], val : Union[Variation_747, Variation_747_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['TRA'], val : Union[Variation_748, Variation_748_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['TOA'], val : Union[Variation_749, Variation_749_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['TOV'], val : Union[Variation_750, Variation_750_Arg]) -> 'Variation_752':
        ...

    @overload
    def set_item(self, name : Literal['TTR'], val : Union[Variation_751, Variation_751_Arg]) -> 'Variation_752':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TCA'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['NC'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['TCPN'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['PT'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['TD'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['TRA'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['TOA'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['TOV'], f : Any) -> 'Variation_752':
        ...

    @overload
    def modify_item(self, name : Literal['TTR'], f : Any) -> 'Variation_752':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_753_Arg : TypeAlias = Union[Variation_752, Variation_752_Arg]
class Variation_753(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 120
    variation_type = Variation_752

    @classmethod
    def spec(cls) -> Type[Variation_752]:
        return Variation_752

    def __init__(self, arg : List[Union[Variation_752, Variation_752_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_752, Variation_752_Arg]) -> 'Variation_753':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_752, Variation_752_Arg]) -> 'Variation_753':
        return self._prepend_item(arg) # type: ignore

Variation_754_Arg = TypedDict('Variation_754_Arg', {
    'TIS': Union[Variation_742, Variation_742_Arg],
    'TID': Union[Variation_753, Variation_753_Arg],
}, total=False)
class Variation_754(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('TIS', Variation_742),
        ('TID', Variation_753),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'TIS': ('Trajectory Intent Status', Variation_742, 0x80),
        'TID': ('Trajectory Intent Data', Variation_753, 0x40),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TIS']) -> Type[Variation_742]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_753]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TIS'], Literal['TID']]) -> Union[Type['Variation_742'], Type['Variation_753']]:
        if key == 'TIS':
            return Variation_742
        if key == 'TID':
            return Variation_753
        assert_never(key)

    def __init__(self, arg : Optional[Variation_754_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['TIS'], val : Union[Variation_742, Variation_742_Arg]) -> 'Variation_754':
        ...

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_753, Variation_753_Arg]) -> 'Variation_754':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['TIS']) -> 'Variation_754':
        ...

    @overload
    def del_item(self, name : Literal['TID']) -> 'Variation_754':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['TIS']) -> Variation_742:
        ...

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_753:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['TIS'], f : Any) -> 'Variation_754':
        ...

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_754':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_755_Arg = TypedDict('Variation_755_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '040': Union[Variation_703, Variation_703_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '130': Union[Variation_705, Variation_705_Arg],
    '080': Union[Variation_278, Variation_278_Arg],
    '140': Union[Variation_287, Variation_287_Arg],
    '090': Union[Variation_710, Variation_710_Arg],
    '210': Union[Variation_716, Variation_716_Arg],
    '230': Union[Variation_717, Variation_717_Arg],
    '145': Union[Variation_360, Variation_360_Arg],
    '150': Union[Variation_719, Variation_719_Arg],
    '151': Union[Variation_720, Variation_720_Arg],
    '152': Union[Variation_14, Variation_14_Arg],
    '155': Union[Variation_364, Variation_364_Arg],
    '157': Union[Variation_364, Variation_364_Arg],
    '160': Union[Variation_722, Variation_722_Arg],
    '165': Union[Variation_725, Variation_725_Arg],
    '170': Union[Variation_196, Variation_196_Arg],
    '095': Union[Variation_0, Variation_0_Arg],
    '032': Union[Variation_726, Variation_726_Arg],
    '200': Union[Variation_727, Variation_727_Arg],
    '020': Union[Variation_728, Variation_728_Arg],
    '220': Union[Variation_731, Variation_731_Arg],
    '146': Union[Variation_735, Variation_735_Arg],
    '148': Union[Variation_739, Variation_739_Arg],
    '110': Union[Variation_754, Variation_754_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_755(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('010', Variation_1),
        ('040', Variation_703),
        ('030', Variation_80),
        ('130', Variation_705),
        ('080', Variation_278),
        ('140', Variation_287),
        ('090', Variation_710),
        ('210', Variation_716),
        ('230', Variation_717),
        ('145', Variation_360),
        ('150', Variation_719),
        ('151', Variation_720),
        ('152', Variation_14),
        ('155', Variation_364),
        ('157', Variation_364),
        ('160', Variation_722),
        ('165', Variation_725),
        ('170', Variation_196),
        ('095', Variation_0),
        ('032', Variation_726),
        ('200', Variation_727),
        ('020', Variation_728),
        ('220', Variation_731),
        ('146', Variation_735),
        ('148', Variation_739),
        ('110', Variation_754),
        None,
        None,
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identification', Variation_1, 0x8000000000),
        '040': ('Target Report Descriptor', Variation_703, 0x4000000000),
        '030': ('Time of Day', Variation_80, 0x2000000000),
        '130': ('Position in WGS-84 Co-ordinates', Variation_705, 0x1000000000),
        '080': ('Target Address', Variation_278, 0x0800000000),
        '140': ('Geometric Altitude', Variation_287, 0x0400000000),
        '090': ('Figure of Merit', Variation_710, 0x0200000000),
        '210': ('Link Technology Indicator', Variation_716, 0x0180000000),
        '230': ('Roll Angle', Variation_717, 0x0140000000),
        '145': ('Flight Level', Variation_360, 0x0120000000),
        '150': ('Air Speed', Variation_719, 0x0110000000),
        '151': ('True Airspeed', Variation_720, 0x0108000000),
        '152': ('Magnetic Heading', Variation_14, 0x0104000000),
        '155': ('Barometric Vertical Rate', Variation_364, 0x0102000000),
        '157': ('Geometric Vertical Rate', Variation_364, 0x0101800000),
        '160': ('Ground Vector', Variation_722, 0x0101400000),
        '165': ('Rate Of Turn', Variation_725, 0x0101200000),
        '170': ('Target Identification', Variation_196, 0x0101100000),
        '095': ('Velocity Accuracy', Variation_0, 0x0101080000),
        '032': ('Time of Day Accuracy', Variation_726, 0x0101040000),
        '200': ('Target Status', Variation_727, 0x0101020000),
        '020': ('Emitter Category', Variation_728, 0x0101018000),
        '220': ('Met Information', Variation_731, 0x0101014000),
        '146': ('Intermediate State Selected Altitude', Variation_735, 0x0101012000),
        '148': ('Final State Selected Altitude', Variation_739, 0x0101011000),
        '110': ('Trajectory Intent', Variation_754, 0x0101010800),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x0101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_703]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_705]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_710]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_716]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['145']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_719]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['151']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['152']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['155']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['157']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['160']) -> Type[Variation_722]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['165']) -> Type[Variation_725]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['095']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['032']) -> Type[Variation_726]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_727]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_728]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_731]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['146']) -> Type[Variation_735]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['148']) -> Type[Variation_739]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_754]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['040'], Literal['030'], Literal['130'], Literal['080'], Literal['140'], Literal['090'], Literal['210'], Literal['230'], Literal['145'], Literal['150'], Literal['151'], Literal['152'], Literal['155'], Literal['157'], Literal['160'], Literal['165'], Literal['170'], Literal['095'], Literal['032'], Literal['200'], Literal['020'], Literal['220'], Literal['146'], Literal['148'], Literal['110'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_703'], Type['Variation_80'], Type['Variation_705'], Type['Variation_278'], Type['Variation_287'], Type['Variation_710'], Type['Variation_716'], Type['Variation_717'], Type['Variation_360'], Type['Variation_719'], Type['Variation_720'], Type['Variation_14'], Type['Variation_364'], Type['Variation_364'], Type['Variation_722'], Type['Variation_725'], Type['Variation_196'], Type['Variation_0'], Type['Variation_726'], Type['Variation_727'], Type['Variation_728'], Type['Variation_731'], Type['Variation_735'], Type['Variation_739'], Type['Variation_754'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '040':
            return Variation_703
        if key == '030':
            return Variation_80
        if key == '130':
            return Variation_705
        if key == '080':
            return Variation_278
        if key == '140':
            return Variation_287
        if key == '090':
            return Variation_710
        if key == '210':
            return Variation_716
        if key == '230':
            return Variation_717
        if key == '145':
            return Variation_360
        if key == '150':
            return Variation_719
        if key == '151':
            return Variation_720
        if key == '152':
            return Variation_14
        if key == '155':
            return Variation_364
        if key == '157':
            return Variation_364
        if key == '160':
            return Variation_722
        if key == '165':
            return Variation_725
        if key == '170':
            return Variation_196
        if key == '095':
            return Variation_0
        if key == '032':
            return Variation_726
        if key == '200':
            return Variation_727
        if key == '020':
            return Variation_728
        if key == '220':
            return Variation_731
        if key == '146':
            return Variation_735
        if key == '148':
            return Variation_739
        if key == '110':
            return Variation_754
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_755_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_703, Variation_703_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_705, Variation_705_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_710, Variation_710_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_716, Variation_716_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['145'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_719, Variation_719_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['151'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['152'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['155'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['157'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['160'], val : Union[Variation_722, Variation_722_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['165'], val : Union[Variation_725, Variation_725_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['095'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['032'], val : Union[Variation_726, Variation_726_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_727, Variation_727_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_728, Variation_728_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_731, Variation_731_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['146'], val : Union[Variation_735, Variation_735_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['148'], val : Union[Variation_739, Variation_739_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_754, Variation_754_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_755':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_755':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['145']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['151']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['152']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['155']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['157']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['160']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['165']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['095']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['032']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['146']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['148']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_755':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_755':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_703:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_705:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_710:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_716:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['145']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_719:
        ...

    @overload
    def get_item(self, name : Literal['151']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['152']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['155']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['157']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['160']) -> Variation_722:
        ...

    @overload
    def get_item(self, name : Literal['165']) -> Variation_725:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['095']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['032']) -> Variation_726:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_727:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_728:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_731:
        ...

    @overload
    def get_item(self, name : Literal['146']) -> Variation_735:
        ...

    @overload
    def get_item(self, name : Literal['148']) -> Variation_739:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_754:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['145'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['151'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['152'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['155'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['157'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['160'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['165'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['095'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['032'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['146'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['148'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_755':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_755':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_756_Arg = TypedDict('Variation_756_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '040': Union[Variation_703, Variation_703_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '130': Union[Variation_649, Variation_649_Arg],
    '080': Union[Variation_278, Variation_278_Arg],
    '140': Union[Variation_287, Variation_287_Arg],
    '090': Union[Variation_710, Variation_710_Arg],
    '210': Union[Variation_716, Variation_716_Arg],
    '230': Union[Variation_717, Variation_717_Arg],
    '145': Union[Variation_360, Variation_360_Arg],
    '150': Union[Variation_719, Variation_719_Arg],
    '151': Union[Variation_720, Variation_720_Arg],
    '152': Union[Variation_14, Variation_14_Arg],
    '155': Union[Variation_364, Variation_364_Arg],
    '157': Union[Variation_364, Variation_364_Arg],
    '160': Union[Variation_722, Variation_722_Arg],
    '165': Union[Variation_725, Variation_725_Arg],
    '170': Union[Variation_196, Variation_196_Arg],
    '095': Union[Variation_0, Variation_0_Arg],
    '032': Union[Variation_726, Variation_726_Arg],
    '200': Union[Variation_727, Variation_727_Arg],
    '020': Union[Variation_728, Variation_728_Arg],
    '220': Union[Variation_731, Variation_731_Arg],
    '146': Union[Variation_735, Variation_735_Arg],
    '148': Union[Variation_739, Variation_739_Arg],
    '110': Union[Variation_754, Variation_754_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_756(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('010', Variation_1),
        ('040', Variation_703),
        ('030', Variation_80),
        ('130', Variation_649),
        ('080', Variation_278),
        ('140', Variation_287),
        ('090', Variation_710),
        ('210', Variation_716),
        ('230', Variation_717),
        ('145', Variation_360),
        ('150', Variation_719),
        ('151', Variation_720),
        ('152', Variation_14),
        ('155', Variation_364),
        ('157', Variation_364),
        ('160', Variation_722),
        ('165', Variation_725),
        ('170', Variation_196),
        ('095', Variation_0),
        ('032', Variation_726),
        ('200', Variation_727),
        ('020', Variation_728),
        ('220', Variation_731),
        ('146', Variation_735),
        ('148', Variation_739),
        ('110', Variation_754),
        None,
        None,
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identification', Variation_1, 0x8000000000),
        '040': ('Target Report Descriptor', Variation_703, 0x4000000000),
        '030': ('Time of Day', Variation_80, 0x2000000000),
        '130': ('Position in WGS-84 Co-ordinates', Variation_649, 0x1000000000),
        '080': ('Target Address', Variation_278, 0x0800000000),
        '140': ('Geometric Altitude', Variation_287, 0x0400000000),
        '090': ('Figure of Merit', Variation_710, 0x0200000000),
        '210': ('Link Technology Indicator', Variation_716, 0x0180000000),
        '230': ('Roll Angle', Variation_717, 0x0140000000),
        '145': ('Flight Level', Variation_360, 0x0120000000),
        '150': ('Air Speed', Variation_719, 0x0110000000),
        '151': ('True Airspeed', Variation_720, 0x0108000000),
        '152': ('Magnetic Heading', Variation_14, 0x0104000000),
        '155': ('Barometric Vertical Rate', Variation_364, 0x0102000000),
        '157': ('Geometric Vertical Rate', Variation_364, 0x0101800000),
        '160': ('Ground Vector', Variation_722, 0x0101400000),
        '165': ('Rate Of Turn', Variation_725, 0x0101200000),
        '170': ('Target Identification', Variation_196, 0x0101100000),
        '095': ('Velocity Accuracy', Variation_0, 0x0101080000),
        '032': ('Time of Day Accuracy', Variation_726, 0x0101040000),
        '200': ('Target Status', Variation_727, 0x0101020000),
        '020': ('Emitter Category', Variation_728, 0x0101018000),
        '220': ('Met Information', Variation_731, 0x0101014000),
        '146': ('Intermediate State Selected Altitude', Variation_735, 0x0101012000),
        '148': ('Final State Selected Altitude', Variation_739, 0x0101011000),
        '110': ('Trajectory Intent', Variation_754, 0x0101010800),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x0101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_703]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_649]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_710]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_716]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['145']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_719]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['151']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['152']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['155']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['157']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['160']) -> Type[Variation_722]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['165']) -> Type[Variation_725]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['095']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['032']) -> Type[Variation_726]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_727]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_728]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_731]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['146']) -> Type[Variation_735]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['148']) -> Type[Variation_739]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_754]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['040'], Literal['030'], Literal['130'], Literal['080'], Literal['140'], Literal['090'], Literal['210'], Literal['230'], Literal['145'], Literal['150'], Literal['151'], Literal['152'], Literal['155'], Literal['157'], Literal['160'], Literal['165'], Literal['170'], Literal['095'], Literal['032'], Literal['200'], Literal['020'], Literal['220'], Literal['146'], Literal['148'], Literal['110'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_703'], Type['Variation_80'], Type['Variation_649'], Type['Variation_278'], Type['Variation_287'], Type['Variation_710'], Type['Variation_716'], Type['Variation_717'], Type['Variation_360'], Type['Variation_719'], Type['Variation_720'], Type['Variation_14'], Type['Variation_364'], Type['Variation_364'], Type['Variation_722'], Type['Variation_725'], Type['Variation_196'], Type['Variation_0'], Type['Variation_726'], Type['Variation_727'], Type['Variation_728'], Type['Variation_731'], Type['Variation_735'], Type['Variation_739'], Type['Variation_754'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '040':
            return Variation_703
        if key == '030':
            return Variation_80
        if key == '130':
            return Variation_649
        if key == '080':
            return Variation_278
        if key == '140':
            return Variation_287
        if key == '090':
            return Variation_710
        if key == '210':
            return Variation_716
        if key == '230':
            return Variation_717
        if key == '145':
            return Variation_360
        if key == '150':
            return Variation_719
        if key == '151':
            return Variation_720
        if key == '152':
            return Variation_14
        if key == '155':
            return Variation_364
        if key == '157':
            return Variation_364
        if key == '160':
            return Variation_722
        if key == '165':
            return Variation_725
        if key == '170':
            return Variation_196
        if key == '095':
            return Variation_0
        if key == '032':
            return Variation_726
        if key == '200':
            return Variation_727
        if key == '020':
            return Variation_728
        if key == '220':
            return Variation_731
        if key == '146':
            return Variation_735
        if key == '148':
            return Variation_739
        if key == '110':
            return Variation_754
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_756_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_703, Variation_703_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_649, Variation_649_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_710, Variation_710_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_716, Variation_716_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['145'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_719, Variation_719_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['151'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['152'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['155'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['157'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['160'], val : Union[Variation_722, Variation_722_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['165'], val : Union[Variation_725, Variation_725_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['095'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['032'], val : Union[Variation_726, Variation_726_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_727, Variation_727_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_728, Variation_728_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_731, Variation_731_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['146'], val : Union[Variation_735, Variation_735_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['148'], val : Union[Variation_739, Variation_739_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_754, Variation_754_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_756':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_756':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['145']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['151']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['152']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['155']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['157']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['160']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['165']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['095']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['032']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['146']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['148']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_756':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_756':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_703:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_649:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_710:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_716:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['145']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_719:
        ...

    @overload
    def get_item(self, name : Literal['151']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['152']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['155']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['157']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['160']) -> Variation_722:
        ...

    @overload
    def get_item(self, name : Literal['165']) -> Variation_725:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['095']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['032']) -> Variation_726:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_727:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_728:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_731:
        ...

    @overload
    def get_item(self, name : Literal['146']) -> Variation_735:
        ...

    @overload
    def get_item(self, name : Literal['148']) -> Variation_739:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_754:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['145'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['151'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['152'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['155'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['157'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['160'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['165'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['095'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['032'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['146'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['148'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_756':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_756':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_757_Arg : TypeAlias = Raw
class Variation_757(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode-3/A code derived during last update',
        1: 'Mode-3/A code not extracted during the last update',
    }

    def __init__(self, arg : Variation_757_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_758_Arg_Group = TypedDict('Variation_758_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_757, Variation_757_Arg],
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_758_Arg : TypeAlias = Union[Raw, Variation_758_Arg_Group]
class Variation_758(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_757),
        Spare(3, 1),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'L': ('', Variation_757, 2, 1),
        'MODE3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_757]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_757'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_757
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_758_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_757:
        ...

    @overload
    def get_item(self, name : Literal['MODE3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_758':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_758':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_757, Variation_757_Arg]) -> 'Variation_758':
        ...

    @overload
    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_758':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_758':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_758':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_758':
        ...

    @overload
    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_758':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_759_Arg = TypedDict('Variation_759_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '040': Union[Variation_703, Variation_703_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '130': Union[Variation_649, Variation_649_Arg],
    '080': Union[Variation_278, Variation_278_Arg],
    '140': Union[Variation_287, Variation_287_Arg],
    '090': Union[Variation_710, Variation_710_Arg],
    '210': Union[Variation_716, Variation_716_Arg],
    '230': Union[Variation_717, Variation_717_Arg],
    '145': Union[Variation_360, Variation_360_Arg],
    '150': Union[Variation_719, Variation_719_Arg],
    '151': Union[Variation_720, Variation_720_Arg],
    '152': Union[Variation_14, Variation_14_Arg],
    '155': Union[Variation_364, Variation_364_Arg],
    '157': Union[Variation_364, Variation_364_Arg],
    '160': Union[Variation_722, Variation_722_Arg],
    '165': Union[Variation_725, Variation_725_Arg],
    '170': Union[Variation_196, Variation_196_Arg],
    '095': Union[Variation_0, Variation_0_Arg],
    '032': Union[Variation_726, Variation_726_Arg],
    '200': Union[Variation_727, Variation_727_Arg],
    '020': Union[Variation_728, Variation_728_Arg],
    '220': Union[Variation_731, Variation_731_Arg],
    '146': Union[Variation_735, Variation_735_Arg],
    '148': Union[Variation_739, Variation_739_Arg],
    '110': Union[Variation_754, Variation_754_Arg],
    '070': Union[Variation_758, Variation_758_Arg],
    '131': Union[Variation_0, Variation_0_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_759(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('010', Variation_1),
        ('040', Variation_703),
        ('030', Variation_80),
        ('130', Variation_649),
        ('080', Variation_278),
        ('140', Variation_287),
        ('090', Variation_710),
        ('210', Variation_716),
        ('230', Variation_717),
        ('145', Variation_360),
        ('150', Variation_719),
        ('151', Variation_720),
        ('152', Variation_14),
        ('155', Variation_364),
        ('157', Variation_364),
        ('160', Variation_722),
        ('165', Variation_725),
        ('170', Variation_196),
        ('095', Variation_0),
        ('032', Variation_726),
        ('200', Variation_727),
        ('020', Variation_728),
        ('220', Variation_731),
        ('146', Variation_735),
        ('148', Variation_739),
        ('110', Variation_754),
        ('070', Variation_758),
        ('131', Variation_0),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identification', Variation_1, 0x8000000000),
        '040': ('Target Report Descriptor', Variation_703, 0x4000000000),
        '030': ('Time of Day', Variation_80, 0x2000000000),
        '130': ('Position in WGS-84 Co-ordinates', Variation_649, 0x1000000000),
        '080': ('Target Address', Variation_278, 0x0800000000),
        '140': ('Geometric Altitude', Variation_287, 0x0400000000),
        '090': ('Figure of Merit', Variation_710, 0x0200000000),
        '210': ('Link Technology Indicator', Variation_716, 0x0180000000),
        '230': ('Roll Angle', Variation_717, 0x0140000000),
        '145': ('Flight Level', Variation_360, 0x0120000000),
        '150': ('Air Speed', Variation_719, 0x0110000000),
        '151': ('True Airspeed', Variation_720, 0x0108000000),
        '152': ('Magnetic Heading', Variation_14, 0x0104000000),
        '155': ('Barometric Vertical Rate', Variation_364, 0x0102000000),
        '157': ('Geometric Vertical Rate', Variation_364, 0x0101800000),
        '160': ('Ground Vector', Variation_722, 0x0101400000),
        '165': ('Rate Of Turn', Variation_725, 0x0101200000),
        '170': ('Target Identification', Variation_196, 0x0101100000),
        '095': ('Velocity Accuracy', Variation_0, 0x0101080000),
        '032': ('Time of Day Accuracy', Variation_726, 0x0101040000),
        '200': ('Target Status', Variation_727, 0x0101020000),
        '020': ('Emitter Category', Variation_728, 0x0101018000),
        '220': ('Met Information', Variation_731, 0x0101014000),
        '146': ('Intermediate State Selected Altitude', Variation_735, 0x0101012000),
        '148': ('Final State Selected Altitude', Variation_739, 0x0101011000),
        '110': ('Trajectory Intent', Variation_754, 0x0101010800),
        '070': ('Mode 3/A Code in Octal Representation', Variation_758, 0x0101010400),
        '131': ('Signal Amplitude', Variation_0, 0x0101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x0101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_703]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_649]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_710]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_716]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['145']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_719]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['151']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['152']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['155']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['157']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['160']) -> Type[Variation_722]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['165']) -> Type[Variation_725]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['095']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['032']) -> Type[Variation_726]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_727]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_728]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_731]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['146']) -> Type[Variation_735]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['148']) -> Type[Variation_739]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_754]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_758]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['131']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['040'], Literal['030'], Literal['130'], Literal['080'], Literal['140'], Literal['090'], Literal['210'], Literal['230'], Literal['145'], Literal['150'], Literal['151'], Literal['152'], Literal['155'], Literal['157'], Literal['160'], Literal['165'], Literal['170'], Literal['095'], Literal['032'], Literal['200'], Literal['020'], Literal['220'], Literal['146'], Literal['148'], Literal['110'], Literal['070'], Literal['131'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_703'], Type['Variation_80'], Type['Variation_649'], Type['Variation_278'], Type['Variation_287'], Type['Variation_710'], Type['Variation_716'], Type['Variation_717'], Type['Variation_360'], Type['Variation_719'], Type['Variation_720'], Type['Variation_14'], Type['Variation_364'], Type['Variation_364'], Type['Variation_722'], Type['Variation_725'], Type['Variation_196'], Type['Variation_0'], Type['Variation_726'], Type['Variation_727'], Type['Variation_728'], Type['Variation_731'], Type['Variation_735'], Type['Variation_739'], Type['Variation_754'], Type['Variation_758'], Type['Variation_0'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '040':
            return Variation_703
        if key == '030':
            return Variation_80
        if key == '130':
            return Variation_649
        if key == '080':
            return Variation_278
        if key == '140':
            return Variation_287
        if key == '090':
            return Variation_710
        if key == '210':
            return Variation_716
        if key == '230':
            return Variation_717
        if key == '145':
            return Variation_360
        if key == '150':
            return Variation_719
        if key == '151':
            return Variation_720
        if key == '152':
            return Variation_14
        if key == '155':
            return Variation_364
        if key == '157':
            return Variation_364
        if key == '160':
            return Variation_722
        if key == '165':
            return Variation_725
        if key == '170':
            return Variation_196
        if key == '095':
            return Variation_0
        if key == '032':
            return Variation_726
        if key == '200':
            return Variation_727
        if key == '020':
            return Variation_728
        if key == '220':
            return Variation_731
        if key == '146':
            return Variation_735
        if key == '148':
            return Variation_739
        if key == '110':
            return Variation_754
        if key == '070':
            return Variation_758
        if key == '131':
            return Variation_0
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_759_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_703, Variation_703_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_649, Variation_649_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_710, Variation_710_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_716, Variation_716_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['145'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_719, Variation_719_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['151'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['152'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['155'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['157'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['160'], val : Union[Variation_722, Variation_722_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['165'], val : Union[Variation_725, Variation_725_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['095'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['032'], val : Union[Variation_726, Variation_726_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_727, Variation_727_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_728, Variation_728_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_731, Variation_731_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['146'], val : Union[Variation_735, Variation_735_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['148'], val : Union[Variation_739, Variation_739_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_754, Variation_754_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_758, Variation_758_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['131'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_759':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_759':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['145']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['151']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['152']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['155']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['157']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['160']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['165']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['095']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['032']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['146']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['148']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['131']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_759':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_759':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_703:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_649:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_710:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_716:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['145']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_719:
        ...

    @overload
    def get_item(self, name : Literal['151']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['152']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['155']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['157']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['160']) -> Variation_722:
        ...

    @overload
    def get_item(self, name : Literal['165']) -> Variation_725:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['095']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['032']) -> Variation_726:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_727:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_728:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_731:
        ...

    @overload
    def get_item(self, name : Literal['146']) -> Variation_735:
        ...

    @overload
    def get_item(self, name : Literal['148']) -> Variation_739:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_754:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_758:
        ...

    @overload
    def get_item(self, name : Literal['131']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['145'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['151'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['152'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['155'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['157'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['160'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['165'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['095'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['032'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['146'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['148'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['131'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_759':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_759':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_760_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['hPa']]]
class Variation_760(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 12
    quantity = Quantity('Unsigned', 0.1, 'hPa')

    def __init__(self, arg : Variation_760_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_761_Arg_Group = TypedDict('Variation_761_Arg_Group', {
    'BPS': Union[Variation_760, Variation_760_Arg],
})
Variation_761_Arg : TypeAlias = Union[Raw, Variation_761_Arg_Group]
class Variation_761(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('BPS', Variation_760),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'BPS': ('Barometric Pressure Setting', Variation_760, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['BPS']]) -> Union[Type['Variation_760']]:
        if key == 'BPS':
            return Variation_760
        assert_never(key)

    def __init__(self, arg : Variation_761_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['BPS']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['BPS'], val : Union[Variation_760, Variation_760_Arg]) -> 'Variation_761':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['BPS'], f : Any) -> 'Variation_761':
        return self._modify_item(name, f) # type: ignore

Variation_762_Arg : TypeAlias = Raw
class Variation_762(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'True North',
        1: 'Magnetic North',
    }

    def __init__(self, arg : Variation_762_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_763_Arg : TypeAlias = Raw
class Variation_763(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Data is either unavailable or invalid',
        1: 'Data is available and valid',
    }

    def __init__(self, arg : Variation_763_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_764_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_764(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 10
    quantity = Quantity('Unsigned', 0.703125, '°')

    def __init__(self, arg : Variation_764_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_765_Arg_Group = TypedDict('Variation_765_Arg_Group', {
    'HDR': Union[Variation_762, Variation_762_Arg],
    'STAT': Union[Variation_763, Variation_763_Arg],
    'SH': Union[Variation_764, Variation_764_Arg],
})
Variation_765_Arg : TypeAlias = Union[Raw, Variation_765_Arg_Group]
class Variation_765(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('HDR', Variation_762),
        ('STAT', Variation_763),
        ('SH', Variation_764),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'HDR': ('Horizontal Reference Direction', Variation_762, 4, 1),
        'STAT': ('Selected Heading Status', Variation_763, 5, 1),
        'SH': ('Selected Heading', Variation_764, 6, 10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['HDR']) -> Type[Variation_762]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STAT']) -> Type[Variation_763]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SH']) -> Type[Variation_764]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['HDR'], Literal['STAT'], Literal['SH']]) -> Union[Type['Variation_762'], Type['Variation_763'], Type['Variation_764']]:
        if key == 'HDR':
            return Variation_762
        if key == 'STAT':
            return Variation_763
        if key == 'SH':
            return Variation_764
        assert_never(key)

    def __init__(self, arg : Variation_765_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['HDR']) -> Variation_762:
        ...

    @overload
    def get_item(self, name : Literal['STAT']) -> Variation_763:
        ...

    @overload
    def get_item(self, name : Literal['SH']) -> Variation_764:
        ...

    def get_item(self, name : Union[Literal['HDR'], Literal['STAT'], Literal['SH']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['HDR'], val : Union[Variation_762, Variation_762_Arg]) -> 'Variation_765':
        ...

    @overload
    def set_item(self, name : Literal['STAT'], val : Union[Variation_763, Variation_763_Arg]) -> 'Variation_765':
        ...

    @overload
    def set_item(self, name : Literal['SH'], val : Union[Variation_764, Variation_764_Arg]) -> 'Variation_765':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['HDR'], f : Any) -> 'Variation_765':
        ...

    @overload
    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_765':
        ...

    @overload
    def modify_item(self, name : Literal['SH'], f : Any) -> 'Variation_765':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_766_Arg : TypeAlias = Raw
class Variation_766(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Autopilot not engaged',
        1: 'Autopilot engaged',
    }

    def __init__(self, arg : Variation_766_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_767_Arg : TypeAlias = Raw
class Variation_767(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Vertical Navigation not active',
        1: 'Vertical Navigation active',
    }

    def __init__(self, arg : Variation_767_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_768_Arg : TypeAlias = Raw
class Variation_768(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Altitude Hold not engaged',
        1: 'Altitude Hold engaged',
    }

    def __init__(self, arg : Variation_768_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_769_Arg : TypeAlias = Raw
class Variation_769(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Approach Mode not active',
        1: 'Approach Mode active',
    }

    def __init__(self, arg : Variation_769_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_770_Arg_Group = TypedDict('Variation_770_Arg_Group', {
    'AP': Union[Variation_766, Variation_766_Arg],
    'VN': Union[Variation_767, Variation_767_Arg],
    'AH': Union[Variation_768, Variation_768_Arg],
    'AM': Union[Variation_769, Variation_769_Arg],
})
Variation_770_Arg : TypeAlias = Union[Raw, Variation_770_Arg_Group]
class Variation_770(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('AP', Variation_766),
        ('VN', Variation_767),
        ('AH', Variation_768),
        ('AM', Variation_769),
        Spare(4, 4),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'AP': ('Autopilot', Variation_766, 0, 1),
        'VN': ('Vertical Navigation', Variation_767, 1, 1),
        'AH': ('Altitude Hold', Variation_768, 2, 1),
        'AM': ('Approach Mode', Variation_769, 3, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AP']) -> Type[Variation_766]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VN']) -> Type[Variation_767]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AH']) -> Type[Variation_768]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AM']) -> Type[Variation_769]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AP'], Literal['VN'], Literal['AH'], Literal['AM']]) -> Union[Type['Variation_766'], Type['Variation_767'], Type['Variation_768'], Type['Variation_769']]:
        if key == 'AP':
            return Variation_766
        if key == 'VN':
            return Variation_767
        if key == 'AH':
            return Variation_768
        if key == 'AM':
            return Variation_769
        assert_never(key)

    def __init__(self, arg : Variation_770_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['AP']) -> Variation_766:
        ...

    @overload
    def get_item(self, name : Literal['VN']) -> Variation_767:
        ...

    @overload
    def get_item(self, name : Literal['AH']) -> Variation_768:
        ...

    @overload
    def get_item(self, name : Literal['AM']) -> Variation_769:
        ...

    def get_item(self, name : Union[Literal['AP'], Literal['VN'], Literal['AH'], Literal['AM']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['AP'], val : Union[Variation_766, Variation_766_Arg]) -> 'Variation_770':
        ...

    @overload
    def set_item(self, name : Literal['VN'], val : Union[Variation_767, Variation_767_Arg]) -> 'Variation_770':
        ...

    @overload
    def set_item(self, name : Literal['AH'], val : Union[Variation_768, Variation_768_Arg]) -> 'Variation_770':
        ...

    @overload
    def set_item(self, name : Literal['AM'], val : Union[Variation_769, Variation_769_Arg]) -> 'Variation_770':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['AP'], f : Any) -> 'Variation_770':
        ...

    @overload
    def modify_item(self, name : Literal['VN'], f : Any) -> 'Variation_770':
        ...

    @overload
    def modify_item(self, name : Literal['AH'], f : Any) -> 'Variation_770':
        ...

    @overload
    def modify_item(self, name : Literal['AM'], f : Any) -> 'Variation_770':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_771_Arg : TypeAlias = Raw
class Variation_771(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Aircraft has not stopped',
        1: 'Aircraft has stopped',
    }

    def __init__(self, arg : Variation_771_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_772_Arg : TypeAlias = Raw
class Variation_772(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Heading/Ground Track data is not valid',
        1: 'Heading/Ground Track data is valid',
    }

    def __init__(self, arg : Variation_772_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_773_Arg : TypeAlias = Raw
class Variation_773(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Heading data provided',
        1: 'Ground Track provided',
    }

    def __init__(self, arg : Variation_773_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_774_Arg : TypeAlias = Raw
class Variation_774(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'True North',
        1: 'Magnetic North',
    }

    def __init__(self, arg : Variation_774_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_775_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['kt']]]
class Variation_775(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 11
    quantity = Quantity('Unsigned', 0.125, 'kt')

    def __init__(self, arg : Variation_775_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_776_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_776(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    quantity = Quantity('Unsigned', 2.8125, '°')

    def __init__(self, arg : Variation_776_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_777_Arg_Group_1 = TypedDict('Variation_777_Arg_Group_1', {
    'STP': Union[Variation_771, Variation_771_Arg],
    'HTS': Union[Variation_772, Variation_772_Arg],
    'HTT': Union[Variation_773, Variation_773_Arg],
    'HRD': Union[Variation_774, Variation_774_Arg],
    'GSS': Union[Variation_775, Variation_775_Arg],
})
Variation_777_Arg_Group_2 = TypedDict('Variation_777_Arg_Group_2', {
    'STP': Union[Variation_771, Variation_771_Arg],
    'HTS': Union[Variation_772, Variation_772_Arg],
    'HTT': Union[Variation_773, Variation_773_Arg],
    'HRD': Union[Variation_774, Variation_774_Arg],
    'GSS': Union[Variation_775, Variation_775_Arg],
    'HGT': Union[Variation_776, Variation_776_Arg],
})
Variation_777_Arg : TypeAlias = Union[
    int,
    Variation_777_Arg_Group_1,
    Tuple[int],
    Variation_777_Arg_Group_2,
    Tuple[int,int],
]
class Variation_777(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        15,
        7,
    ]

    subitems_list = [
        [
            ('STP', Variation_771),
            ('HTS', Variation_772),
            ('HTT', Variation_773),
            ('HRD', Variation_774),
            ('GSS', Variation_775),
        ],
        [
            ('HGT', Variation_776),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STP': ('', Variation_771, 0, 1),
        'HTS': ('', Variation_772, 1, 1),
        'HTT': ('', Variation_773, 2, 1),
        'HRD': ('', Variation_774, 3, 1),
        'GSS': ('Ground Speed', Variation_775, 4, 11),
        'HGT': ('Heading/Ground Track Information', Variation_776, 0, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['STP']) -> Type[Variation_771]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HTS']) -> Type[Variation_772]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HTT']) -> Type[Variation_773]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HRD']) -> Type[Variation_774]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GSS']) -> Type[Variation_775]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HGT']) -> Type[Variation_776]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['STP'], Literal['HTS'], Literal['HTT'], Literal['HRD'], Literal['GSS'], Literal['HGT']]) -> Union[Type['Variation_771'], Type['Variation_772'], Type['Variation_773'], Type['Variation_774'], Type['Variation_775'], Type['Variation_776']]:
        if key == 'STP':
            return Variation_771
        if key == 'HTS':
            return Variation_772
        if key == 'HTT':
            return Variation_773
        if key == 'HRD':
            return Variation_774
        if key == 'GSS':
            return Variation_775
        if key == 'HGT':
            return Variation_776
        assert_never(key)

    def __init__(self, arg : Variation_777_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_777_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_777_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['STP']) -> Variation_771:
        ...

    @overload
    def get_item(self, name : Literal['HTS']) -> Variation_772:
        ...

    @overload
    def get_item(self, name : Literal['HTT']) -> Variation_773:
        ...

    @overload
    def get_item(self, name : Literal['HRD']) -> Variation_774:
        ...

    @overload
    def get_item(self, name : Literal['GSS']) -> Variation_775:
        ...

    @overload
    def get_item(self, name : Literal['HGT']) -> Variation_776:
        ...

    def get_item(self, name : Union[Literal['STP'], Literal['HTS'], Literal['HTT'], Literal['HRD'], Literal['GSS'], Literal['HGT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['STP'], val : Union[Variation_771, Variation_771_Arg]) -> 'Variation_777':
        ...

    @overload
    def set_item(self, name : Literal['HTS'], val : Union[Variation_772, Variation_772_Arg]) -> 'Variation_777':
        ...

    @overload
    def set_item(self, name : Literal['HTT'], val : Union[Variation_773, Variation_773_Arg]) -> 'Variation_777':
        ...

    @overload
    def set_item(self, name : Literal['HRD'], val : Union[Variation_774, Variation_774_Arg]) -> 'Variation_777':
        ...

    @overload
    def set_item(self, name : Literal['GSS'], val : Union[Variation_775, Variation_775_Arg]) -> 'Variation_777':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['STP'], f : Any) -> 'Variation_777':
        ...

    @overload
    def modify_item(self, name : Literal['HTS'], f : Any) -> 'Variation_777':
        ...

    @overload
    def modify_item(self, name : Literal['HTT'], f : Any) -> 'Variation_777':
        ...

    @overload
    def modify_item(self, name : Literal['HRD'], f : Any) -> 'Variation_777':
        ...

    @overload
    def modify_item(self, name : Literal['GSS'], f : Any) -> 'Variation_777':
        ...

    @overload
    def modify_item(self, name : Literal['HGT'], f : Any) -> 'Variation_777':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_778_Arg : TypeAlias = Raw
class Variation_778(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Target is not 1090 ES IN capable',
        1: 'Target is 1090 ES IN capable',
    }

    def __init__(self, arg : Variation_778_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_779_Arg : TypeAlias = Raw
class Variation_779(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Target is not UAT IN capable',
        1: 'Target is UAT IN capable',
    }

    def __init__(self, arg : Variation_779_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_780_Arg_Group_1 = TypedDict('Variation_780_Arg_Group_1', {
    'ES': Union[Variation_778, Variation_778_Arg],
    'UAT': Union[Variation_779, Variation_779_Arg],
})
Variation_780_Arg : TypeAlias = Union[
    int,
    Variation_780_Arg_Group_1,
    Tuple[int],
]
class Variation_780(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            ('ES', Variation_778),
            ('UAT', Variation_779),
            Spare(2, 5),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ES': ('', Variation_778, 0, 1),
        'UAT': ('', Variation_779, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ES']) -> Type[Variation_778]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['UAT']) -> Type[Variation_779]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ES'], Literal['UAT']]) -> Union[Type['Variation_778'], Type['Variation_779']]:
        if key == 'ES':
            return Variation_778
        if key == 'UAT':
            return Variation_779
        assert_never(key)

    def __init__(self, arg : Variation_780_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_780_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ES']) -> Variation_778:
        ...

    @overload
    def get_item(self, name : Literal['UAT']) -> Variation_779:
        ...

    def get_item(self, name : Union[Literal['ES'], Literal['UAT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ES'], val : Union[Variation_778, Variation_778_Arg]) -> 'Variation_780':
        ...

    @overload
    def set_item(self, name : Literal['UAT'], val : Union[Variation_779, Variation_779_Arg]) -> 'Variation_780':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ES'], f : Any) -> 'Variation_780':
        ...

    @overload
    def modify_item(self, name : Literal['UAT'], f : Any) -> 'Variation_780':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_781_Arg : TypeAlias = Raw
class Variation_781(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No Mode 5 interrogation',
        1: 'Mode 5 interrogation',
    }

    def __init__(self, arg : Variation_781_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_782_Arg : TypeAlias = Raw
class Variation_782(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'No authenticated Mode 5 ID reply/report',
        1: 'Authenticated Mode 5 ID reply/report',
    }

    def __init__(self, arg : Variation_782_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_783_Arg : TypeAlias = Raw
class Variation_783(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'No authenticated Mode 5 Data reply or Report',
        1: 'Authenticated Mode 5 Data reply or Report (i.e any valid Mode 5 reply type other than ID)',
    }

    def __init__(self, arg : Variation_783_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_784_Arg : TypeAlias = Raw
class Variation_784(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Mode 1 code not present or not from Mode 5 reply/report',
        1: 'Mode 1 code from Mode 5 reply/report',
    }

    def __init__(self, arg : Variation_784_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_785_Arg : TypeAlias = Raw
class Variation_785(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Mode 2 code not present or not from Mode 5 reply/report',
        1: 'Mode 2 code from Mode 5 reply/report',
    }

    def __init__(self, arg : Variation_785_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_786_Arg : TypeAlias = Raw
class Variation_786(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Mode 3 code not present or not from Mode 5 reply/report',
        1: 'Mode 3 code from Mode 5 reply/report',
    }

    def __init__(self, arg : Variation_786_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_787_Arg : TypeAlias = Raw
class Variation_787(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Flightlevel not present or not from Mode 5 reply/report',
        1: 'Flightlevel from Mode 5 reply/report',
    }

    def __init__(self, arg : Variation_787_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_788_Arg : TypeAlias = Raw
class Variation_788(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'Position not from Mode 5 report (ADS-B report)',
        1: 'Position from Mode 5 report',
    }

    def __init__(self, arg : Variation_788_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_789_Arg_Group = TypedDict('Variation_789_Arg_Group', {
    'M5': Union[Variation_781, Variation_781_Arg],
    'ID': Union[Variation_782, Variation_782_Arg],
    'DA': Union[Variation_783, Variation_783_Arg],
    'M1': Union[Variation_784, Variation_784_Arg],
    'M2': Union[Variation_785, Variation_785_Arg],
    'M3': Union[Variation_786, Variation_786_Arg],
    'MC': Union[Variation_787, Variation_787_Arg],
    'PO': Union[Variation_788, Variation_788_Arg],
})
Variation_789_Arg : TypeAlias = Union[Raw, Variation_789_Arg_Group]
class Variation_789(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('M5', Variation_781),
        ('ID', Variation_782),
        ('DA', Variation_783),
        ('M1', Variation_784),
        ('M2', Variation_785),
        ('M3', Variation_786),
        ('MC', Variation_787),
        ('PO', Variation_788),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'M5': ('', Variation_781, 0, 1),
        'ID': ('', Variation_782, 1, 1),
        'DA': ('', Variation_783, 2, 1),
        'M1': ('', Variation_784, 3, 1),
        'M2': ('', Variation_785, 4, 1),
        'M3': ('', Variation_786, 5, 1),
        'MC': ('', Variation_787, 6, 1),
        'PO': ('', Variation_788, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['M5']) -> Type[Variation_781]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ID']) -> Type[Variation_782]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DA']) -> Type[Variation_783]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M1']) -> Type[Variation_784]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M2']) -> Type[Variation_785]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M3']) -> Type[Variation_786]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MC']) -> Type[Variation_787]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PO']) -> Type[Variation_788]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['M5'], Literal['ID'], Literal['DA'], Literal['M1'], Literal['M2'], Literal['M3'], Literal['MC'], Literal['PO']]) -> Union[Type['Variation_781'], Type['Variation_782'], Type['Variation_783'], Type['Variation_784'], Type['Variation_785'], Type['Variation_786'], Type['Variation_787'], Type['Variation_788']]:
        if key == 'M5':
            return Variation_781
        if key == 'ID':
            return Variation_782
        if key == 'DA':
            return Variation_783
        if key == 'M1':
            return Variation_784
        if key == 'M2':
            return Variation_785
        if key == 'M3':
            return Variation_786
        if key == 'MC':
            return Variation_787
        if key == 'PO':
            return Variation_788
        assert_never(key)

    def __init__(self, arg : Variation_789_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['M5']) -> Variation_781:
        ...

    @overload
    def get_item(self, name : Literal['ID']) -> Variation_782:
        ...

    @overload
    def get_item(self, name : Literal['DA']) -> Variation_783:
        ...

    @overload
    def get_item(self, name : Literal['M1']) -> Variation_784:
        ...

    @overload
    def get_item(self, name : Literal['M2']) -> Variation_785:
        ...

    @overload
    def get_item(self, name : Literal['M3']) -> Variation_786:
        ...

    @overload
    def get_item(self, name : Literal['MC']) -> Variation_787:
        ...

    @overload
    def get_item(self, name : Literal['PO']) -> Variation_788:
        ...

    def get_item(self, name : Union[Literal['M5'], Literal['ID'], Literal['DA'], Literal['M1'], Literal['M2'], Literal['M3'], Literal['MC'], Literal['PO']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['M5'], val : Union[Variation_781, Variation_781_Arg]) -> 'Variation_789':
        ...

    @overload
    def set_item(self, name : Literal['ID'], val : Union[Variation_782, Variation_782_Arg]) -> 'Variation_789':
        ...

    @overload
    def set_item(self, name : Literal['DA'], val : Union[Variation_783, Variation_783_Arg]) -> 'Variation_789':
        ...

    @overload
    def set_item(self, name : Literal['M1'], val : Union[Variation_784, Variation_784_Arg]) -> 'Variation_789':
        ...

    @overload
    def set_item(self, name : Literal['M2'], val : Union[Variation_785, Variation_785_Arg]) -> 'Variation_789':
        ...

    @overload
    def set_item(self, name : Literal['M3'], val : Union[Variation_786, Variation_786_Arg]) -> 'Variation_789':
        ...

    @overload
    def set_item(self, name : Literal['MC'], val : Union[Variation_787, Variation_787_Arg]) -> 'Variation_789':
        ...

    @overload
    def set_item(self, name : Literal['PO'], val : Union[Variation_788, Variation_788_Arg]) -> 'Variation_789':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['M5'], f : Any) -> 'Variation_789':
        ...

    @overload
    def modify_item(self, name : Literal['ID'], f : Any) -> 'Variation_789':
        ...

    @overload
    def modify_item(self, name : Literal['DA'], f : Any) -> 'Variation_789':
        ...

    @overload
    def modify_item(self, name : Literal['M1'], f : Any) -> 'Variation_789':
        ...

    @overload
    def modify_item(self, name : Literal['M2'], f : Any) -> 'Variation_789':
        ...

    @overload
    def modify_item(self, name : Literal['M3'], f : Any) -> 'Variation_789':
        ...

    @overload
    def modify_item(self, name : Literal['MC'], f : Any) -> 'Variation_789':
        ...

    @overload
    def modify_item(self, name : Literal['PO'], f : Any) -> 'Variation_789':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_790_Arg : TypeAlias = Raw
class Variation_790(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 14

    def __init__(self, arg : Variation_790_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_791_Arg : TypeAlias = Raw
class Variation_791(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 11

    def __init__(self, arg : Variation_791_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_792_Arg_Group = TypedDict('Variation_792_Arg_Group', {
    'PIN': Union[Variation_790, Variation_790_Arg],
    'NO': Union[Variation_791, Variation_791_Arg],
})
Variation_792_Arg : TypeAlias = Union[Raw, Variation_792_Arg_Group]
class Variation_792(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        Spare(0, 2),
        ('PIN', Variation_790),
        Spare(0, 5),
        ('NO', Variation_791),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PIN': ('PIN Code', Variation_790, 2, 14),
        'NO': ('National Origin Code', Variation_791, 21, 11),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PIN']) -> Type[Variation_790]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NO']) -> Type[Variation_791]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PIN'], Literal['NO']]) -> Union[Type['Variation_790'], Type['Variation_791']]:
        if key == 'PIN':
            return Variation_790
        if key == 'NO':
            return Variation_791
        assert_never(key)

    def __init__(self, arg : Variation_792_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PIN']) -> Variation_790:
        ...

    @overload
    def get_item(self, name : Literal['NO']) -> Variation_791:
        ...

    def get_item(self, name : Union[Literal['PIN'], Literal['NO']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PIN'], val : Union[Variation_790, Variation_790_Arg]) -> 'Variation_792':
        ...

    @overload
    def set_item(self, name : Literal['NO'], val : Union[Variation_791, Variation_791_Arg]) -> 'Variation_792':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PIN'], f : Any) -> 'Variation_792':
        ...

    @overload
    def modify_item(self, name : Literal['NO'], f : Any) -> 'Variation_792':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_793_Arg : TypeAlias = Raw
class Variation_793(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode 1 code as derived from the report of the transponder',
        1: 'Smoothed Mode 1 code as provided by a local tracker',
    }

    def __init__(self, arg : Variation_793_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_794_Arg_Group = TypedDict('Variation_794_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'L': Union[Variation_793, Variation_793_Arg],
    'EM1': Union[Variation_19, Variation_19_Arg],
})
Variation_794_Arg : TypeAlias = Union[Raw, Variation_794_Arg_Group]
class Variation_794(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        Spare(1, 1),
        ('L', Variation_793),
        Spare(3, 1),
        ('EM1', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'L': ('', Variation_793, 2, 1),
        'EM1': ('Extended Mode 1 Code in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_793]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EM1']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['L'], Literal['EM1']]) -> Union[Type['Variation_16'], Type['Variation_793'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'L':
            return Variation_793
        if key == 'EM1':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_794_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_793:
        ...

    @overload
    def get_item(self, name : Literal['EM1']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['L'], Literal['EM1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_794':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_793, Variation_793_Arg]) -> 'Variation_794':
        ...

    @overload
    def set_item(self, name : Literal['EM1'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_794':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_794':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_794':
        ...

    @overload
    def modify_item(self, name : Literal['EM1'], f : Any) -> 'Variation_794':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_795_Arg : TypeAlias = Raw
class Variation_795(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'X-Pulse not present',
        1: 'X-pulse present',
    }

    def __init__(self, arg : Variation_795_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_796_Arg : TypeAlias = Raw
class Variation_796(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'X-pulse set to zero or no authenticated Data reply or Report received',
        1: 'X-pulse set to one (present)',
    }

    def __init__(self, arg : Variation_796_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_797_Arg : TypeAlias = Raw
class Variation_797(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'X-pulse set to zero or no Mode C reply',
        1: 'X-pulse set to one (present)',
    }

    def __init__(self, arg : Variation_797_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_798_Arg : TypeAlias = Raw
class Variation_798(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'X-pulse set to zero or no Mode 3/A reply',
        1: 'X-pulse set to one (present)',
    }

    def __init__(self, arg : Variation_798_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_799_Arg : TypeAlias = Raw
class Variation_799(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: '0 X-pulse set to zero or no Mode 2 reply',
        1: 'X-pulse set to one (present)',
    }

    def __init__(self, arg : Variation_799_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_800_Arg : TypeAlias = Raw
class Variation_800(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'X-pulse set to zero or no Mode 1 reply',
        1: 'X-pulse set to one (present)',
    }

    def __init__(self, arg : Variation_800_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_801_Arg_Group = TypedDict('Variation_801_Arg_Group', {
    'XP': Union[Variation_795, Variation_795_Arg],
    'X5': Union[Variation_796, Variation_796_Arg],
    'XC': Union[Variation_797, Variation_797_Arg],
    'X3': Union[Variation_798, Variation_798_Arg],
    'X2': Union[Variation_799, Variation_799_Arg],
    'X1': Union[Variation_800, Variation_800_Arg],
})
Variation_801_Arg : TypeAlias = Union[Raw, Variation_801_Arg_Group]
class Variation_801(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 2),
        ('XP', Variation_795),
        ('X5', Variation_796),
        ('XC', Variation_797),
        ('X3', Variation_798),
        ('X2', Variation_799),
        ('X1', Variation_800),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'XP': ('X-pulse from Mode 5 PIN Reply/report', Variation_795, 2, 1),
        'X5': ('X-pulse from Mode 5 Data Reply or Report', Variation_796, 3, 1),
        'XC': ('X-pulse from Mode C Reply', Variation_797, 4, 1),
        'X3': ('X-pulse from Mode 3/A Reply', Variation_798, 5, 1),
        'X2': ('X-pulse from Mode 2 Reply', Variation_799, 6, 1),
        'X1': ('X-pulse from Mode 1 Reply', Variation_800, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['XP']) -> Type[Variation_795]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X5']) -> Type[Variation_796]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XC']) -> Type[Variation_797]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X3']) -> Type[Variation_798]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X2']) -> Type[Variation_799]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X1']) -> Type[Variation_800]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['XP'], Literal['X5'], Literal['XC'], Literal['X3'], Literal['X2'], Literal['X1']]) -> Union[Type['Variation_795'], Type['Variation_796'], Type['Variation_797'], Type['Variation_798'], Type['Variation_799'], Type['Variation_800']]:
        if key == 'XP':
            return Variation_795
        if key == 'X5':
            return Variation_796
        if key == 'XC':
            return Variation_797
        if key == 'X3':
            return Variation_798
        if key == 'X2':
            return Variation_799
        if key == 'X1':
            return Variation_800
        assert_never(key)

    def __init__(self, arg : Variation_801_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['XP']) -> Variation_795:
        ...

    @overload
    def get_item(self, name : Literal['X5']) -> Variation_796:
        ...

    @overload
    def get_item(self, name : Literal['XC']) -> Variation_797:
        ...

    @overload
    def get_item(self, name : Literal['X3']) -> Variation_798:
        ...

    @overload
    def get_item(self, name : Literal['X2']) -> Variation_799:
        ...

    @overload
    def get_item(self, name : Literal['X1']) -> Variation_800:
        ...

    def get_item(self, name : Union[Literal['XP'], Literal['X5'], Literal['XC'], Literal['X3'], Literal['X2'], Literal['X1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['XP'], val : Union[Variation_795, Variation_795_Arg]) -> 'Variation_801':
        ...

    @overload
    def set_item(self, name : Literal['X5'], val : Union[Variation_796, Variation_796_Arg]) -> 'Variation_801':
        ...

    @overload
    def set_item(self, name : Literal['XC'], val : Union[Variation_797, Variation_797_Arg]) -> 'Variation_801':
        ...

    @overload
    def set_item(self, name : Literal['X3'], val : Union[Variation_798, Variation_798_Arg]) -> 'Variation_801':
        ...

    @overload
    def set_item(self, name : Literal['X2'], val : Union[Variation_799, Variation_799_Arg]) -> 'Variation_801':
        ...

    @overload
    def set_item(self, name : Literal['X1'], val : Union[Variation_800, Variation_800_Arg]) -> 'Variation_801':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['XP'], f : Any) -> 'Variation_801':
        ...

    @overload
    def modify_item(self, name : Literal['X5'], f : Any) -> 'Variation_801':
        ...

    @overload
    def modify_item(self, name : Literal['XC'], f : Any) -> 'Variation_801':
        ...

    @overload
    def modify_item(self, name : Literal['X3'], f : Any) -> 'Variation_801':
        ...

    @overload
    def modify_item(self, name : Literal['X2'], f : Any) -> 'Variation_801':
        ...

    @overload
    def modify_item(self, name : Literal['X1'], f : Any) -> 'Variation_801':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_802_Arg_Group = TypedDict('Variation_802_Arg_Group', {
    'FOM': Union[Variation_375, Variation_375_Arg],
})
Variation_802_Arg : TypeAlias = Union[Raw, Variation_802_Arg_Group]
class Variation_802(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 3),
        ('FOM', Variation_375),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FOM': ('Figure of Merit', Variation_375, 3, 5),
    }


    @classmethod
    def spec(cls, key : Union[Literal['FOM']]) -> Union[Type['Variation_375']]:
        if key == 'FOM':
            return Variation_375
        assert_never(key)

    def __init__(self, arg : Variation_802_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['FOM']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['FOM'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_802':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['FOM'], f : Any) -> 'Variation_802':
        return self._modify_item(name, f) # type: ignore

Variation_803_Arg_Group = TypedDict('Variation_803_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'L': Union[Variation_26, Variation_26_Arg],
    'MODE2': Union[Variation_19, Variation_19_Arg],
})
Variation_803_Arg : TypeAlias = Union[Raw, Variation_803_Arg_Group]
class Variation_803(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        Spare(1, 1),
        ('L', Variation_26),
        Spare(3, 1),
        ('MODE2', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'L': ('', Variation_26, 2, 1),
        'MODE2': ('Mode 2 Code in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_26]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE2']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['L'], Literal['MODE2']]) -> Union[Type['Variation_16'], Type['Variation_26'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'L':
            return Variation_26
        if key == 'MODE2':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_803_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_26:
        ...

    @overload
    def get_item(self, name : Literal['MODE2']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['L'], Literal['MODE2']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_803':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_26, Variation_26_Arg]) -> 'Variation_803':
        ...

    @overload
    def set_item(self, name : Literal['MODE2'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_803':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_803':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_803':
        ...

    @overload
    def modify_item(self, name : Literal['MODE2'], f : Any) -> 'Variation_803':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_804_Arg = TypedDict('Variation_804_Arg', {
    'SUM': Union[Variation_789, Variation_789_Arg],
    'PNO': Union[Variation_792, Variation_792_Arg],
    'EM1': Union[Variation_794, Variation_794_Arg],
    'XP': Union[Variation_801, Variation_801_Arg],
    'FOM': Union[Variation_802, Variation_802_Arg],
    'M2': Union[Variation_803, Variation_803_Arg],
}, total=False)
class Variation_804(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('SUM', Variation_789),
        ('PNO', Variation_792),
        ('EM1', Variation_794),
        ('XP', Variation_801),
        ('FOM', Variation_802),
        ('M2', Variation_803),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'SUM': ('Mode 5 Summary', Variation_789, 0x80),
        'PNO': ('Mode 5 PIN / National Origin', Variation_792, 0x40),
        'EM1': ('Extended Mode 1 Code in Octal Representation', Variation_794, 0x20),
        'XP': ('X Pulse Presence', Variation_801, 0x10),
        'FOM': ('Figure of Merit', Variation_802, 0x08),
        'M2': ('Mode 2 Code in Octal Representation', Variation_803, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SUM']) -> Type[Variation_789]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PNO']) -> Type[Variation_792]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EM1']) -> Type[Variation_794]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XP']) -> Type[Variation_801]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FOM']) -> Type[Variation_802]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M2']) -> Type[Variation_803]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SUM'], Literal['PNO'], Literal['EM1'], Literal['XP'], Literal['FOM'], Literal['M2']]) -> Union[Type['Variation_789'], Type['Variation_792'], Type['Variation_794'], Type['Variation_801'], Type['Variation_802'], Type['Variation_803']]:
        if key == 'SUM':
            return Variation_789
        if key == 'PNO':
            return Variation_792
        if key == 'EM1':
            return Variation_794
        if key == 'XP':
            return Variation_801
        if key == 'FOM':
            return Variation_802
        if key == 'M2':
            return Variation_803
        assert_never(key)

    def __init__(self, arg : Optional[Variation_804_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['SUM'], val : Union[Variation_789, Variation_789_Arg]) -> 'Variation_804':
        ...

    @overload
    def set_item(self, name : Literal['PNO'], val : Union[Variation_792, Variation_792_Arg]) -> 'Variation_804':
        ...

    @overload
    def set_item(self, name : Literal['EM1'], val : Union[Variation_794, Variation_794_Arg]) -> 'Variation_804':
        ...

    @overload
    def set_item(self, name : Literal['XP'], val : Union[Variation_801, Variation_801_Arg]) -> 'Variation_804':
        ...

    @overload
    def set_item(self, name : Literal['FOM'], val : Union[Variation_802, Variation_802_Arg]) -> 'Variation_804':
        ...

    @overload
    def set_item(self, name : Literal['M2'], val : Union[Variation_803, Variation_803_Arg]) -> 'Variation_804':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['SUM']) -> 'Variation_804':
        ...

    @overload
    def del_item(self, name : Literal['PNO']) -> 'Variation_804':
        ...

    @overload
    def del_item(self, name : Literal['EM1']) -> 'Variation_804':
        ...

    @overload
    def del_item(self, name : Literal['XP']) -> 'Variation_804':
        ...

    @overload
    def del_item(self, name : Literal['FOM']) -> 'Variation_804':
        ...

    @overload
    def del_item(self, name : Literal['M2']) -> 'Variation_804':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['SUM']) -> Variation_789:
        ...

    @overload
    def get_item(self, name : Literal['PNO']) -> Variation_792:
        ...

    @overload
    def get_item(self, name : Literal['EM1']) -> Variation_794:
        ...

    @overload
    def get_item(self, name : Literal['XP']) -> Variation_801:
        ...

    @overload
    def get_item(self, name : Literal['FOM']) -> Variation_802:
        ...

    @overload
    def get_item(self, name : Literal['M2']) -> Variation_803:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['SUM'], f : Any) -> 'Variation_804':
        ...

    @overload
    def modify_item(self, name : Literal['PNO'], f : Any) -> 'Variation_804':
        ...

    @overload
    def modify_item(self, name : Literal['EM1'], f : Any) -> 'Variation_804':
        ...

    @overload
    def modify_item(self, name : Literal['XP'], f : Any) -> 'Variation_804':
        ...

    @overload
    def modify_item(self, name : Literal['FOM'], f : Any) -> 'Variation_804':
        ...

    @overload
    def modify_item(self, name : Literal['M2'], f : Any) -> 'Variation_804':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_805_Arg = TypedDict('Variation_805_Arg', {
    'BPS': Union[Variation_761, Variation_761_Arg],
    'SH': Union[Variation_765, Variation_765_Arg],
    'NAV': Union[Variation_770, Variation_770_Arg],
    'GAO': Union[Variation_0, Variation_0_Arg],
    'SGV': Union[Variation_777, Variation_777_Arg],
    'STA': Union[Variation_780, Variation_780_Arg],
    'TNH': Union[Variation_14, Variation_14_Arg],
    'MES': Union[Variation_804, Variation_804_Arg],
}, total=False)
class Variation_805(Compound):
    variation = 'Compound'

    fspec_fx = False
    fspec_max_bytes = 1

    subitems_list = [
        ('BPS', Variation_761),
        ('SH', Variation_765),
        ('NAV', Variation_770),
        ('GAO', Variation_0),
        ('SGV', Variation_777),
        ('STA', Variation_780),
        ('TNH', Variation_14),
        ('MES', Variation_804),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'BPS': ('Barometric Pressure Setting', Variation_761, 0x80),
        'SH': ('Selected Heading', Variation_765, 0x40),
        'NAV': ('Navigation Mode', Variation_770, 0x20),
        'GAO': ('GPS Antenna Offset', Variation_0, 0x10),
        'SGV': ('Surface Ground Vector', Variation_777, 0x08),
        'STA': ('Aircraft Status', Variation_780, 0x04),
        'TNH': ('True North Heading', Variation_14, 0x02),
        'MES': ('Military Extended Squitter', Variation_804, 0x01),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['BPS']) -> Type[Variation_761]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SH']) -> Type[Variation_765]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NAV']) -> Type[Variation_770]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GAO']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SGV']) -> Type[Variation_777]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STA']) -> Type[Variation_780]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TNH']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MES']) -> Type[Variation_804]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['BPS'], Literal['SH'], Literal['NAV'], Literal['GAO'], Literal['SGV'], Literal['STA'], Literal['TNH'], Literal['MES']]) -> Union[Type['Variation_761'], Type['Variation_765'], Type['Variation_770'], Type['Variation_0'], Type['Variation_777'], Type['Variation_780'], Type['Variation_14'], Type['Variation_804']]:
        if key == 'BPS':
            return Variation_761
        if key == 'SH':
            return Variation_765
        if key == 'NAV':
            return Variation_770
        if key == 'GAO':
            return Variation_0
        if key == 'SGV':
            return Variation_777
        if key == 'STA':
            return Variation_780
        if key == 'TNH':
            return Variation_14
        if key == 'MES':
            return Variation_804
        assert_never(key)

    def __init__(self, arg : Optional[Variation_805_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['BPS'], val : Union[Variation_761, Variation_761_Arg]) -> 'Variation_805':
        ...

    @overload
    def set_item(self, name : Literal['SH'], val : Union[Variation_765, Variation_765_Arg]) -> 'Variation_805':
        ...

    @overload
    def set_item(self, name : Literal['NAV'], val : Union[Variation_770, Variation_770_Arg]) -> 'Variation_805':
        ...

    @overload
    def set_item(self, name : Literal['GAO'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_805':
        ...

    @overload
    def set_item(self, name : Literal['SGV'], val : Union[Variation_777, Variation_777_Arg]) -> 'Variation_805':
        ...

    @overload
    def set_item(self, name : Literal['STA'], val : Union[Variation_780, Variation_780_Arg]) -> 'Variation_805':
        ...

    @overload
    def set_item(self, name : Literal['TNH'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_805':
        ...

    @overload
    def set_item(self, name : Literal['MES'], val : Union[Variation_804, Variation_804_Arg]) -> 'Variation_805':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['BPS']) -> 'Variation_805':
        ...

    @overload
    def del_item(self, name : Literal['SH']) -> 'Variation_805':
        ...

    @overload
    def del_item(self, name : Literal['NAV']) -> 'Variation_805':
        ...

    @overload
    def del_item(self, name : Literal['GAO']) -> 'Variation_805':
        ...

    @overload
    def del_item(self, name : Literal['SGV']) -> 'Variation_805':
        ...

    @overload
    def del_item(self, name : Literal['STA']) -> 'Variation_805':
        ...

    @overload
    def del_item(self, name : Literal['TNH']) -> 'Variation_805':
        ...

    @overload
    def del_item(self, name : Literal['MES']) -> 'Variation_805':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['BPS']) -> Variation_761:
        ...

    @overload
    def get_item(self, name : Literal['SH']) -> Variation_765:
        ...

    @overload
    def get_item(self, name : Literal['NAV']) -> Variation_770:
        ...

    @overload
    def get_item(self, name : Literal['GAO']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SGV']) -> Variation_777:
        ...

    @overload
    def get_item(self, name : Literal['STA']) -> Variation_780:
        ...

    @overload
    def get_item(self, name : Literal['TNH']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['MES']) -> Variation_804:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['BPS'], f : Any) -> 'Variation_805':
        ...

    @overload
    def modify_item(self, name : Literal['SH'], f : Any) -> 'Variation_805':
        ...

    @overload
    def modify_item(self, name : Literal['NAV'], f : Any) -> 'Variation_805':
        ...

    @overload
    def modify_item(self, name : Literal['GAO'], f : Any) -> 'Variation_805':
        ...

    @overload
    def modify_item(self, name : Literal['SGV'], f : Any) -> 'Variation_805':
        ...

    @overload
    def modify_item(self, name : Literal['STA'], f : Any) -> 'Variation_805':
        ...

    @overload
    def modify_item(self, name : Literal['TNH'], f : Any) -> 'Variation_805':
        ...

    @overload
    def modify_item(self, name : Literal['MES'], f : Any) -> 'Variation_805':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_806_Arg : TypeAlias = Raw
class Variation_806(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Element not populated',
        1: 'Element populated',
    }

    def __init__(self, arg : Variation_806_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_807_Arg : TypeAlias = Raw
class Variation_807(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'MCP/FCU Mode Bits not populated',
        1: 'MCP/FCU Mode Bits populated',
    }

    def __init__(self, arg : Variation_807_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_808_Arg_Group = TypedDict('Variation_808_Arg_Group', {
    'EP': Union[Variation_806, Variation_806_Arg],
    'VAL': Union[Variation_807, Variation_807_Arg],
})
Variation_808_Arg : TypeAlias = Union[Raw, Variation_808_Arg_Group]
class Variation_808(Group):
    variation = 'Group'

    bit_size = 2

    subitems_list = [
        ('EP', Variation_806),
        ('VAL', Variation_807),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_806, 0, 1),
        'VAL': ('Value', Variation_807, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_806]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_807]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_806'], Type['Variation_807']]:
        if key == 'EP':
            return Variation_806
        if key == 'VAL':
            return Variation_807
        assert_never(key)

    def __init__(self, arg : Variation_808_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_806:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_807:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_806, Variation_806_Arg]) -> 'Variation_808':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_807, Variation_807_Arg]) -> 'Variation_808':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_808':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_808':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_809_Arg_Group = TypedDict('Variation_809_Arg_Group', {
    'AP': Union[Variation_766, Variation_766_Arg],
    'VN': Union[Variation_767, Variation_767_Arg],
    'AH': Union[Variation_768, Variation_768_Arg],
    'AM': Union[Variation_769, Variation_769_Arg],
    'MFM': Union[Variation_808, Variation_808_Arg],
})
Variation_809_Arg : TypeAlias = Union[Raw, Variation_809_Arg_Group]
class Variation_809(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('AP', Variation_766),
        ('VN', Variation_767),
        ('AH', Variation_768),
        ('AM', Variation_769),
        ('MFM', Variation_808),
        Spare(6, 2),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'AP': ('Autopilot', Variation_766, 0, 1),
        'VN': ('Vertical Navigation', Variation_767, 1, 1),
        'AH': ('Altitude Hold', Variation_768, 2, 1),
        'AM': ('Approach Mode', Variation_769, 3, 1),
        'MFM': ('Status of MCP/FCU Mode Bits', Variation_808, 4, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AP']) -> Type[Variation_766]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VN']) -> Type[Variation_767]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AH']) -> Type[Variation_768]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AM']) -> Type[Variation_769]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MFM']) -> Type[Variation_808]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AP'], Literal['VN'], Literal['AH'], Literal['AM'], Literal['MFM']]) -> Union[Type['Variation_766'], Type['Variation_767'], Type['Variation_768'], Type['Variation_769'], Type['Variation_808']]:
        if key == 'AP':
            return Variation_766
        if key == 'VN':
            return Variation_767
        if key == 'AH':
            return Variation_768
        if key == 'AM':
            return Variation_769
        if key == 'MFM':
            return Variation_808
        assert_never(key)

    def __init__(self, arg : Variation_809_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['AP']) -> Variation_766:
        ...

    @overload
    def get_item(self, name : Literal['VN']) -> Variation_767:
        ...

    @overload
    def get_item(self, name : Literal['AH']) -> Variation_768:
        ...

    @overload
    def get_item(self, name : Literal['AM']) -> Variation_769:
        ...

    @overload
    def get_item(self, name : Literal['MFM']) -> Variation_808:
        ...

    def get_item(self, name : Union[Literal['AP'], Literal['VN'], Literal['AH'], Literal['AM'], Literal['MFM']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['AP'], val : Union[Variation_766, Variation_766_Arg]) -> 'Variation_809':
        ...

    @overload
    def set_item(self, name : Literal['VN'], val : Union[Variation_767, Variation_767_Arg]) -> 'Variation_809':
        ...

    @overload
    def set_item(self, name : Literal['AH'], val : Union[Variation_768, Variation_768_Arg]) -> 'Variation_809':
        ...

    @overload
    def set_item(self, name : Literal['AM'], val : Union[Variation_769, Variation_769_Arg]) -> 'Variation_809':
        ...

    @overload
    def set_item(self, name : Literal['MFM'], val : Union[Variation_808, Variation_808_Arg]) -> 'Variation_809':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['AP'], f : Any) -> 'Variation_809':
        ...

    @overload
    def modify_item(self, name : Literal['VN'], f : Any) -> 'Variation_809':
        ...

    @overload
    def modify_item(self, name : Literal['AH'], f : Any) -> 'Variation_809':
        ...

    @overload
    def modify_item(self, name : Literal['AM'], f : Any) -> 'Variation_809':
        ...

    @overload
    def modify_item(self, name : Literal['MFM'], f : Any) -> 'Variation_809':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_810_Arg : TypeAlias = Raw
class Variation_810(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Element not populated',
        1: 'Element populated',
    }

    def __init__(self, arg : Variation_810_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_811_Arg : TypeAlias = Raw
class Variation_811(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 2
    table = {
        0: 'Not RCE',
        1: 'TABS (see Note 2)',
        2: 'Reserved for future use',
        3: 'Other RCE',
    }

    def __init__(self, arg : Variation_811_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_812_Arg_Group = TypedDict('Variation_812_Arg_Group', {
    'EP': Union[Variation_810, Variation_810_Arg],
    'VAL': Union[Variation_811, Variation_811_Arg],
})
Variation_812_Arg : TypeAlias = Union[Raw, Variation_812_Arg_Group]
class Variation_812(Group):
    variation = 'Group'

    bit_size = 3

    subitems_list = [
        ('EP', Variation_810),
        ('VAL', Variation_811),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_810, 0, 1),
        'VAL': ('Value', Variation_811, 1, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_810]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_811]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_810'], Type['Variation_811']]:
        if key == 'EP':
            return Variation_810
        if key == 'VAL':
            return Variation_811
        assert_never(key)

    def __init__(self, arg : Variation_812_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_810:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_811:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_810, Variation_810_Arg]) -> 'Variation_812':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_811, Variation_811_Arg]) -> 'Variation_812':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_812':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_812':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_813_Arg : TypeAlias = Raw
class Variation_813(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Element not populated',
        1: 'Element populated',
    }

    def __init__(self, arg : Variation_813_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_814_Arg : TypeAlias = Raw
class Variation_814(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Reply Rate Limiting is not active',
        1: 'Reply Rate Limiting is active',
    }

    def __init__(self, arg : Variation_814_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_815_Arg_Group = TypedDict('Variation_815_Arg_Group', {
    'EP': Union[Variation_813, Variation_813_Arg],
    'VAL': Union[Variation_814, Variation_814_Arg],
})
Variation_815_Arg : TypeAlias = Union[Raw, Variation_815_Arg_Group]
class Variation_815(Group):
    variation = 'Group'

    bit_size = 2

    subitems_list = [
        ('EP', Variation_813),
        ('VAL', Variation_814),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_813, 0, 1),
        'VAL': ('Value', Variation_814, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_813]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_814]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_813'], Type['Variation_814']]:
        if key == 'EP':
            return Variation_813
        if key == 'VAL':
            return Variation_814
        assert_never(key)

    def __init__(self, arg : Variation_815_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_813:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_814:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_813, Variation_813_Arg]) -> 'Variation_815':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_814, Variation_814_Arg]) -> 'Variation_815':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_815':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_815':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_816_Arg : TypeAlias = Raw
class Variation_816(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Element not populated',
        1: 'Element populated',
    }

    def __init__(self, arg : Variation_816_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_817_Arg : TypeAlias = Raw
class Variation_817(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 3
    table = {
        0: 'No emergency / not reported',
        1: 'General emergency',
        2: 'UAS/RPAS - Lost link',
        3: 'Minimum fuel',
        4: 'No communications',
        5: 'Unlawful interference',
        6: 'Aircraft in Distress',
        7: 'Aircraft in Distress Manual Activation',
    }

    def __init__(self, arg : Variation_817_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_818_Arg_Group = TypedDict('Variation_818_Arg_Group', {
    'EP': Union[Variation_816, Variation_816_Arg],
    'VAL': Union[Variation_817, Variation_817_Arg],
})
Variation_818_Arg : TypeAlias = Union[Raw, Variation_818_Arg_Group]
class Variation_818(Group):
    variation = 'Group'

    bit_size = 4

    subitems_list = [
        ('EP', Variation_816),
        ('VAL', Variation_817),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_816, 0, 1),
        'VAL': ('Value', Variation_817, 1, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_816]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_817]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_816'], Type['Variation_817']]:
        if key == 'EP':
            return Variation_816
        if key == 'VAL':
            return Variation_817
        assert_never(key)

    def __init__(self, arg : Variation_818_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_816:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_817:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_816, Variation_816_Arg]) -> 'Variation_818':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_817, Variation_817_Arg]) -> 'Variation_818':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_818':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_818':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_819_Arg : TypeAlias = Raw
class Variation_819(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'Unavailable, Unknown, or less than 70 W',
        1: '70 W',
        2: '125 W',
        3: '200 W',
    }

    def __init__(self, arg : Variation_819_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_820_Arg_Group = TypedDict('Variation_820_Arg_Group', {
    'EP': Union[Variation_806, Variation_806_Arg],
    'VAL': Union[Variation_819, Variation_819_Arg],
})
Variation_820_Arg : TypeAlias = Union[Raw, Variation_820_Arg_Group]
class Variation_820(Group):
    variation = 'Group'

    bit_size = 3

    subitems_list = [
        ('EP', Variation_806),
        ('VAL', Variation_819),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_806, 0, 1),
        'VAL': ('Value', Variation_819, 1, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_806]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_819]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_806'], Type['Variation_819']]:
        if key == 'EP':
            return Variation_806
        if key == 'VAL':
            return Variation_819
        assert_never(key)

    def __init__(self, arg : Variation_820_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_806:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_819:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_806, Variation_806_Arg]) -> 'Variation_820':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_819, Variation_819_Arg]) -> 'Variation_820':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_820':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_820':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_821_Arg : TypeAlias = Raw
class Variation_821(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Transponder #1 (left/pilot side or single)',
        2: 'Transponder #2 (right/co-pilot side)',
        3: 'Transponder #3 (auxiliary or Backup)',
    }

    def __init__(self, arg : Variation_821_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_822_Arg_Group = TypedDict('Variation_822_Arg_Group', {
    'EP': Union[Variation_816, Variation_816_Arg],
    'VAL': Union[Variation_821, Variation_821_Arg],
})
Variation_822_Arg : TypeAlias = Union[Raw, Variation_822_Arg_Group]
class Variation_822(Group):
    variation = 'Group'

    bit_size = 3

    subitems_list = [
        ('EP', Variation_816),
        ('VAL', Variation_821),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_816, 0, 1),
        'VAL': ('Value', Variation_821, 1, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_816]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_821]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_816'], Type['Variation_821']]:
        if key == 'EP':
            return Variation_816
        if key == 'VAL':
            return Variation_821
        assert_never(key)

    def __init__(self, arg : Variation_822_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_816:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_821:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_816, Variation_816_Arg]) -> 'Variation_822':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_821, Variation_821_Arg]) -> 'Variation_822':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_822':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_822':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_823_Arg : TypeAlias = Raw
class Variation_823(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Element not populated',
        1: 'Element populated',
    }

    def __init__(self, arg : Variation_823_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_824_Arg : TypeAlias = Raw
class Variation_824(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Manned Operation',
        1: 'Unmanned Operation',
    }

    def __init__(self, arg : Variation_824_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_825_Arg_Group = TypedDict('Variation_825_Arg_Group', {
    'EP': Union[Variation_823, Variation_823_Arg],
    'VAL': Union[Variation_824, Variation_824_Arg],
})
Variation_825_Arg : TypeAlias = Union[Raw, Variation_825_Arg_Group]
class Variation_825(Group):
    variation = 'Group'

    bit_size = 2

    subitems_list = [
        ('EP', Variation_823),
        ('VAL', Variation_824),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_823, 0, 1),
        'VAL': ('Value', Variation_824, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_823]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_824]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_823'], Type['Variation_824']]:
        if key == 'EP':
            return Variation_823
        if key == 'VAL':
            return Variation_824
        assert_never(key)

    def __init__(self, arg : Variation_825_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_823:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_824:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_823, Variation_823_Arg]) -> 'Variation_825':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_824, Variation_824_Arg]) -> 'Variation_825':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_825':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_825':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_826_Arg : TypeAlias = Raw
class Variation_826(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'RWC Corrective Alert not active',
        1: 'RWC Corrective Alert active',
    }

    def __init__(self, arg : Variation_826_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_827_Arg_Group = TypedDict('Variation_827_Arg_Group', {
    'EP': Union[Variation_813, Variation_813_Arg],
    'VAL': Union[Variation_826, Variation_826_Arg],
})
Variation_827_Arg : TypeAlias = Union[Raw, Variation_827_Arg_Group]
class Variation_827(Group):
    variation = 'Group'

    bit_size = 2

    subitems_list = [
        ('EP', Variation_813),
        ('VAL', Variation_826),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_813, 0, 1),
        'VAL': ('Value', Variation_826, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_813]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_826]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_813'], Type['Variation_826']]:
        if key == 'EP':
            return Variation_813
        if key == 'VAL':
            return Variation_826
        assert_never(key)

    def __init__(self, arg : Variation_827_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_813:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_826:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_813, Variation_813_Arg]) -> 'Variation_827':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_826, Variation_826_Arg]) -> 'Variation_827':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_827':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_827':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_828_Arg : TypeAlias = Raw
class Variation_828(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'No RWC Capability',
        1: 'RWC/RA/OCM Capability',
        2: 'RWC/OCM Capability',
        3: 'Invalid ASTERIX Value',
    }

    def __init__(self, arg : Variation_828_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_829_Arg_Group = TypedDict('Variation_829_Arg_Group', {
    'EP': Union[Variation_816, Variation_816_Arg],
    'VAL': Union[Variation_828, Variation_828_Arg],
})
Variation_829_Arg : TypeAlias = Union[Raw, Variation_829_Arg_Group]
class Variation_829(Group):
    variation = 'Group'

    bit_size = 3

    subitems_list = [
        ('EP', Variation_816),
        ('VAL', Variation_828),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_816, 0, 1),
        'VAL': ('Value', Variation_828, 1, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_816]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_828]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_816'], Type['Variation_828']]:
        if key == 'EP':
            return Variation_816
        if key == 'VAL':
            return Variation_828
        assert_never(key)

    def __init__(self, arg : Variation_829_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_816:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_828:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_816, Variation_816_Arg]) -> 'Variation_829':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_828, Variation_828_Arg]) -> 'Variation_829':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_829':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_829':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_830_Arg_Group = TypedDict('Variation_830_Arg_Group', {
    'EP': Union[Variation_823, Variation_823_Arg],
    'VAL': Union[Variation_93, Variation_93_Arg],
})
Variation_830_Arg : TypeAlias = Union[Raw, Variation_830_Arg_Group]
class Variation_830(Group):
    variation = 'Group'

    bit_size = 4

    subitems_list = [
        ('EP', Variation_823),
        ('VAL', Variation_93),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_823, 0, 1),
        'VAL': ('Value', Variation_93, 1, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_823]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_93]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_823'], Type['Variation_93']]:
        if key == 'EP':
            return Variation_823
        if key == 'VAL':
            return Variation_93
        assert_never(key)

    def __init__(self, arg : Variation_830_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_823:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_93:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_823, Variation_823_Arg]) -> 'Variation_830':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_93, Variation_93_Arg]) -> 'Variation_830':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_830':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_830':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_831_Arg : TypeAlias = Raw
class Variation_831(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'Vertical Only',
        1: 'Horizontal Only',
        2: 'Blended',
        3: 'Vertical Only or Horizontal Only per intruder',
    }

    def __init__(self, arg : Variation_831_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_832_Arg_Group = TypedDict('Variation_832_Arg_Group', {
    'EP': Union[Variation_816, Variation_816_Arg],
    'VAL': Union[Variation_831, Variation_831_Arg],
})
Variation_832_Arg : TypeAlias = Union[Raw, Variation_832_Arg_Group]
class Variation_832(Group):
    variation = 'Group'

    bit_size = 3

    subitems_list = [
        ('EP', Variation_816),
        ('VAL', Variation_831),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_816, 0, 1),
        'VAL': ('Value', Variation_831, 1, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_816]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_831]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_816'], Type['Variation_831']]:
        if key == 'EP':
            return Variation_816
        if key == 'VAL':
            return Variation_831
        assert_never(key)

    def __init__(self, arg : Variation_832_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_816:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_831:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_816, Variation_816_Arg]) -> 'Variation_832':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_831, Variation_831_Arg]) -> 'Variation_832':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_832':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_832':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_833_Arg : TypeAlias = Raw
class Variation_833(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 3
    table = {
        0: 'Active CAS (TCAS II) or no CAS',
        1: 'Active CAS (not TCAS II)',
        2: 'Active CAS (not TCAS II) with OCM transmit capability',
        3: 'Active CAS of Junior Status',
        4: 'Passive CAS with 1030TCAS Resolution Message receive capability',
        5: 'Passive CAS with only OCM receive capability',
        6: 'Reserved for future use',
        7: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_833_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_834_Arg_Group = TypedDict('Variation_834_Arg_Group', {
    'EP': Union[Variation_823, Variation_823_Arg],
    'VAL': Union[Variation_833, Variation_833_Arg],
})
Variation_834_Arg : TypeAlias = Union[Raw, Variation_834_Arg_Group]
class Variation_834(Group):
    variation = 'Group'

    bit_size = 4

    subitems_list = [
        ('EP', Variation_823),
        ('VAL', Variation_833),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Population Bit', Variation_823, 0, 1),
        'VAL': ('Value', Variation_833, 1, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_823]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_833]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_823'], Type['Variation_833']]:
        if key == 'EP':
            return Variation_823
        if key == 'VAL':
            return Variation_833
        assert_never(key)

    def __init__(self, arg : Variation_834_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_823:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_833:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_823, Variation_823_Arg]) -> 'Variation_834':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_833, Variation_833_Arg]) -> 'Variation_834':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_834':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_834':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_835_Arg : TypeAlias = Raw
class Variation_835(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Element Not Populated',
        1: 'Element Populated',
    }

    def __init__(self, arg : Variation_835_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_836_Arg : TypeAlias = Raw
class Variation_836(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 5
    table = {
        0: 'No data',
        1: '0 ≤ TAO ≤ 1',
        2: '1 < TAO ≤ 2',
        3: '2 < TAO ≤ 4',
        4: '4 < TAO ≤ 6',
        5: '6 < TAO ≤ 8',
        6: '8 < TAO ≤ 10',
        7: '10 < TAO ≤ 12',
        8: '12 < TAO ≤ 14',
        9: '14 < TAO ≤ 16',
        10: '16 < TAO ≤ 18',
        11: '18 < TAO ≤ 20',
        12: '20 < TAO ≤ 22',
        13: '22 < TAO ≤ 24',
        14: '24 < TAO ≤ 26',
        15: '26 < TAO ≤ 28',
        16: '28 < TAO ≤ 30',
        17: '30 < TAO ≤ 32',
        18: '32 < TAO ≤ 34',
        19: '34 < TAO ≤ 36',
        20: '36 < TAO ≤ 38',
        21: '38 < TAO ≤ 40',
        22: '40 < TAO ≤ 42',
        23: '42 < TAO ≤ 44',
        24: '44 < TAO ≤ 46',
        25: '46 < TAO ≤ 48',
        26: '48 < TAO ≤ 50',
        27: '50 < TAO ≤ 52',
        28: '52 < TAO ≤ 54',
        29: '54 < TAO ≤ 56',
        30: '56 < TAO ≤ 58',
        31: 'TAO > 58',
    }

    def __init__(self, arg : Variation_836_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_837_Arg_Group = TypedDict('Variation_837_Arg_Group', {
    'EP': Union[Variation_835, Variation_835_Arg],
    'VAL': Union[Variation_836, Variation_836_Arg],
})
Variation_837_Arg : TypeAlias = Union[Raw, Variation_837_Arg_Group]
class Variation_837(Group):
    variation = 'Group'

    bit_size = 7

    subitems_list = [
        ('EP', Variation_835),
        ('VAL', Variation_836),
        Spare(6, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_835, 0, 1),
        'VAL': ('Value', Variation_836, 1, 5),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_835]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_836]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_835'], Type['Variation_836']]:
        if key == 'EP':
            return Variation_835
        if key == 'VAL':
            return Variation_836
        assert_never(key)

    def __init__(self, arg : Variation_837_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_835:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_836:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_835, Variation_835_Arg]) -> 'Variation_837':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_836, Variation_836_Arg]) -> 'Variation_837':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_837':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_837':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_838_Arg_Group_1 = TypedDict('Variation_838_Arg_Group_1', {
    'ES': Union[Variation_778, Variation_778_Arg],
    'UAT': Union[Variation_779, Variation_779_Arg],
    'RCE': Union[Variation_812, Variation_812_Arg],
    'RRL': Union[Variation_815, Variation_815_Arg],
})
Variation_838_Arg_Group_2 = TypedDict('Variation_838_Arg_Group_2', {
    'ES': Union[Variation_778, Variation_778_Arg],
    'UAT': Union[Variation_779, Variation_779_Arg],
    'RCE': Union[Variation_812, Variation_812_Arg],
    'RRL': Union[Variation_815, Variation_815_Arg],
    'PS3': Union[Variation_818, Variation_818_Arg],
    'TPW': Union[Variation_820, Variation_820_Arg],
})
Variation_838_Arg_Group_3 = TypedDict('Variation_838_Arg_Group_3', {
    'ES': Union[Variation_778, Variation_778_Arg],
    'UAT': Union[Variation_779, Variation_779_Arg],
    'RCE': Union[Variation_812, Variation_812_Arg],
    'RRL': Union[Variation_815, Variation_815_Arg],
    'PS3': Union[Variation_818, Variation_818_Arg],
    'TPW': Union[Variation_820, Variation_820_Arg],
    'TSI': Union[Variation_822, Variation_822_Arg],
    'MUO': Union[Variation_825, Variation_825_Arg],
    'RWC': Union[Variation_827, Variation_827_Arg],
})
Variation_838_Arg_Group_4 = TypedDict('Variation_838_Arg_Group_4', {
    'ES': Union[Variation_778, Variation_778_Arg],
    'UAT': Union[Variation_779, Variation_779_Arg],
    'RCE': Union[Variation_812, Variation_812_Arg],
    'RRL': Union[Variation_815, Variation_815_Arg],
    'PS3': Union[Variation_818, Variation_818_Arg],
    'TPW': Union[Variation_820, Variation_820_Arg],
    'TSI': Union[Variation_822, Variation_822_Arg],
    'MUO': Union[Variation_825, Variation_825_Arg],
    'RWC': Union[Variation_827, Variation_827_Arg],
    'DAA': Union[Variation_829, Variation_829_Arg],
    'DF17CA': Union[Variation_830, Variation_830_Arg],
})
Variation_838_Arg_Group_5 = TypedDict('Variation_838_Arg_Group_5', {
    'ES': Union[Variation_778, Variation_778_Arg],
    'UAT': Union[Variation_779, Variation_779_Arg],
    'RCE': Union[Variation_812, Variation_812_Arg],
    'RRL': Union[Variation_815, Variation_815_Arg],
    'PS3': Union[Variation_818, Variation_818_Arg],
    'TPW': Union[Variation_820, Variation_820_Arg],
    'TSI': Union[Variation_822, Variation_822_Arg],
    'MUO': Union[Variation_825, Variation_825_Arg],
    'RWC': Union[Variation_827, Variation_827_Arg],
    'DAA': Union[Variation_829, Variation_829_Arg],
    'DF17CA': Union[Variation_830, Variation_830_Arg],
    'SVH': Union[Variation_832, Variation_832_Arg],
    'CATC': Union[Variation_834, Variation_834_Arg],
})
Variation_838_Arg_Group_6 = TypedDict('Variation_838_Arg_Group_6', {
    'ES': Union[Variation_778, Variation_778_Arg],
    'UAT': Union[Variation_779, Variation_779_Arg],
    'RCE': Union[Variation_812, Variation_812_Arg],
    'RRL': Union[Variation_815, Variation_815_Arg],
    'PS3': Union[Variation_818, Variation_818_Arg],
    'TPW': Union[Variation_820, Variation_820_Arg],
    'TSI': Union[Variation_822, Variation_822_Arg],
    'MUO': Union[Variation_825, Variation_825_Arg],
    'RWC': Union[Variation_827, Variation_827_Arg],
    'DAA': Union[Variation_829, Variation_829_Arg],
    'DF17CA': Union[Variation_830, Variation_830_Arg],
    'SVH': Union[Variation_832, Variation_832_Arg],
    'CATC': Union[Variation_834, Variation_834_Arg],
    'TAO': Union[Variation_837, Variation_837_Arg],
})
Variation_838_Arg : TypeAlias = Union[
    int,
    Variation_838_Arg_Group_1,
    Tuple[int],
    Variation_838_Arg_Group_2,
    Tuple[int,int],
    Variation_838_Arg_Group_3,
    Tuple[int,int,int],
    Variation_838_Arg_Group_4,
    Tuple[int,int,int,int],
    Variation_838_Arg_Group_5,
    Tuple[int,int,int,int,int],
    Variation_838_Arg_Group_6,
    Tuple[int,int,int,int,int,int],
]
class Variation_838(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('ES', Variation_778),
            ('UAT', Variation_779),
            ('RCE', Variation_812),
            ('RRL', Variation_815),
        ],
        [
            ('PS3', Variation_818),
            ('TPW', Variation_820),
        ],
        [
            ('TSI', Variation_822),
            ('MUO', Variation_825),
            ('RWC', Variation_827),
        ],
        [
            ('DAA', Variation_829),
            ('DF17CA', Variation_830),
        ],
        [
            ('SVH', Variation_832),
            ('CATC', Variation_834),
        ],
        [
            ('TAO', Variation_837),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ES': ('ES IN Capability', Variation_778, 0, 1),
        'UAT': ('UAT IN Capability', Variation_779, 1, 1),
        'RCE': ('Reduced Capability Equipment', Variation_812, 2, 3),
        'RRL': ('Reply Rate Limiting', Variation_815, 5, 2),
        'PS3': ('Priority Status for Version 3 ADS-B Systems', Variation_818, 0, 4),
        'TPW': ('Transmit Power', Variation_820, 4, 3),
        'TSI': ('Transponder Side Indication', Variation_822, 0, 3),
        'MUO': ('Manned / Unmanned Operation', Variation_825, 3, 2),
        'RWC': ('Remain Well Clear Corrective Alert', Variation_827, 5, 2),
        'DAA': ('Detectand Avoid Capabilities', Variation_829, 0, 3),
        'DF17CA': ('Transponder Capability', Variation_830, 3, 4),
        'SVH': ('Sense Vertical & Horizontal', Variation_832, 0, 3),
        'CATC': ('CAS Type & Capability', Variation_834, 3, 4),
        'TAO': ('Transponder Antenna Offset', Variation_837, 0, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ES']) -> Type[Variation_778]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['UAT']) -> Type[Variation_779]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RCE']) -> Type[Variation_812]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RRL']) -> Type[Variation_815]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PS3']) -> Type[Variation_818]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TPW']) -> Type[Variation_820]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSI']) -> Type[Variation_822]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MUO']) -> Type[Variation_825]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RWC']) -> Type[Variation_827]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DAA']) -> Type[Variation_829]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DF17CA']) -> Type[Variation_830]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SVH']) -> Type[Variation_832]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CATC']) -> Type[Variation_834]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAO']) -> Type[Variation_837]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ES'], Literal['UAT'], Literal['RCE'], Literal['RRL'], Literal['PS3'], Literal['TPW'], Literal['TSI'], Literal['MUO'], Literal['RWC'], Literal['DAA'], Literal['DF17CA'], Literal['SVH'], Literal['CATC'], Literal['TAO']]) -> Union[Type['Variation_778'], Type['Variation_779'], Type['Variation_812'], Type['Variation_815'], Type['Variation_818'], Type['Variation_820'], Type['Variation_822'], Type['Variation_825'], Type['Variation_827'], Type['Variation_829'], Type['Variation_830'], Type['Variation_832'], Type['Variation_834'], Type['Variation_837']]:
        if key == 'ES':
            return Variation_778
        if key == 'UAT':
            return Variation_779
        if key == 'RCE':
            return Variation_812
        if key == 'RRL':
            return Variation_815
        if key == 'PS3':
            return Variation_818
        if key == 'TPW':
            return Variation_820
        if key == 'TSI':
            return Variation_822
        if key == 'MUO':
            return Variation_825
        if key == 'RWC':
            return Variation_827
        if key == 'DAA':
            return Variation_829
        if key == 'DF17CA':
            return Variation_830
        if key == 'SVH':
            return Variation_832
        if key == 'CATC':
            return Variation_834
        if key == 'TAO':
            return Variation_837
        assert_never(key)

    def __init__(self, arg : Variation_838_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_838_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_838_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_838_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            if Variation_838_Arg_Group_4.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(4, arg)); return
            if Variation_838_Arg_Group_5.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(5, arg)); return
            if Variation_838_Arg_Group_6.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(6, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ES']) -> Variation_778:
        ...

    @overload
    def get_item(self, name : Literal['UAT']) -> Variation_779:
        ...

    @overload
    def get_item(self, name : Literal['RCE']) -> Variation_812:
        ...

    @overload
    def get_item(self, name : Literal['RRL']) -> Variation_815:
        ...

    @overload
    def get_item(self, name : Literal['PS3']) -> Variation_818:
        ...

    @overload
    def get_item(self, name : Literal['TPW']) -> Variation_820:
        ...

    @overload
    def get_item(self, name : Literal['TSI']) -> Variation_822:
        ...

    @overload
    def get_item(self, name : Literal['MUO']) -> Variation_825:
        ...

    @overload
    def get_item(self, name : Literal['RWC']) -> Variation_827:
        ...

    @overload
    def get_item(self, name : Literal['DAA']) -> Variation_829:
        ...

    @overload
    def get_item(self, name : Literal['DF17CA']) -> Variation_830:
        ...

    @overload
    def get_item(self, name : Literal['SVH']) -> Variation_832:
        ...

    @overload
    def get_item(self, name : Literal['CATC']) -> Variation_834:
        ...

    @overload
    def get_item(self, name : Literal['TAO']) -> Variation_837:
        ...

    def get_item(self, name : Union[Literal['ES'], Literal['UAT'], Literal['RCE'], Literal['RRL'], Literal['PS3'], Literal['TPW'], Literal['TSI'], Literal['MUO'], Literal['RWC'], Literal['DAA'], Literal['DF17CA'], Literal['SVH'], Literal['CATC'], Literal['TAO']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ES'], val : Union[Variation_778, Variation_778_Arg]) -> 'Variation_838':
        ...

    @overload
    def set_item(self, name : Literal['UAT'], val : Union[Variation_779, Variation_779_Arg]) -> 'Variation_838':
        ...

    @overload
    def set_item(self, name : Literal['RCE'], val : Union[Variation_812, Variation_812_Arg]) -> 'Variation_838':
        ...

    @overload
    def set_item(self, name : Literal['RRL'], val : Union[Variation_815, Variation_815_Arg]) -> 'Variation_838':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ES'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['UAT'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['RCE'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['RRL'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['PS3'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['TPW'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['TSI'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['MUO'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['RWC'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['DAA'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['DF17CA'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['SVH'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['CATC'], f : Any) -> 'Variation_838':
        ...

    @overload
    def modify_item(self, name : Literal['TAO'], f : Any) -> 'Variation_838':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_839_Arg = TypedDict('Variation_839_Arg', {
    'BPS': Union[Variation_761, Variation_761_Arg],
    'SH': Union[Variation_765, Variation_765_Arg],
    'NAV': Union[Variation_809, Variation_809_Arg],
    'GAO': Union[Variation_0, Variation_0_Arg],
    'SGV': Union[Variation_777, Variation_777_Arg],
    'STA': Union[Variation_838, Variation_838_Arg],
    'TNH': Union[Variation_14, Variation_14_Arg],
    'MES': Union[Variation_804, Variation_804_Arg],
}, total=False)
class Variation_839(Compound):
    variation = 'Compound'

    fspec_fx = False
    fspec_max_bytes = 1

    subitems_list = [
        ('BPS', Variation_761),
        ('SH', Variation_765),
        ('NAV', Variation_809),
        ('GAO', Variation_0),
        ('SGV', Variation_777),
        ('STA', Variation_838),
        ('TNH', Variation_14),
        ('MES', Variation_804),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'BPS': ('Barometric Pressure Setting', Variation_761, 0x80),
        'SH': ('Selected Heading', Variation_765, 0x40),
        'NAV': ('Navigation Mode', Variation_809, 0x20),
        'GAO': ('GPS Antenna Offset', Variation_0, 0x10),
        'SGV': ('Surface Ground Vector', Variation_777, 0x08),
        'STA': ('Aircraft Status', Variation_838, 0x04),
        'TNH': ('True North Heading', Variation_14, 0x02),
        'MES': ('Military Extended Squitter', Variation_804, 0x01),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['BPS']) -> Type[Variation_761]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SH']) -> Type[Variation_765]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NAV']) -> Type[Variation_809]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GAO']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SGV']) -> Type[Variation_777]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STA']) -> Type[Variation_838]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TNH']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MES']) -> Type[Variation_804]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['BPS'], Literal['SH'], Literal['NAV'], Literal['GAO'], Literal['SGV'], Literal['STA'], Literal['TNH'], Literal['MES']]) -> Union[Type['Variation_761'], Type['Variation_765'], Type['Variation_809'], Type['Variation_0'], Type['Variation_777'], Type['Variation_838'], Type['Variation_14'], Type['Variation_804']]:
        if key == 'BPS':
            return Variation_761
        if key == 'SH':
            return Variation_765
        if key == 'NAV':
            return Variation_809
        if key == 'GAO':
            return Variation_0
        if key == 'SGV':
            return Variation_777
        if key == 'STA':
            return Variation_838
        if key == 'TNH':
            return Variation_14
        if key == 'MES':
            return Variation_804
        assert_never(key)

    def __init__(self, arg : Optional[Variation_839_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['BPS'], val : Union[Variation_761, Variation_761_Arg]) -> 'Variation_839':
        ...

    @overload
    def set_item(self, name : Literal['SH'], val : Union[Variation_765, Variation_765_Arg]) -> 'Variation_839':
        ...

    @overload
    def set_item(self, name : Literal['NAV'], val : Union[Variation_809, Variation_809_Arg]) -> 'Variation_839':
        ...

    @overload
    def set_item(self, name : Literal['GAO'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_839':
        ...

    @overload
    def set_item(self, name : Literal['SGV'], val : Union[Variation_777, Variation_777_Arg]) -> 'Variation_839':
        ...

    @overload
    def set_item(self, name : Literal['STA'], val : Union[Variation_838, Variation_838_Arg]) -> 'Variation_839':
        ...

    @overload
    def set_item(self, name : Literal['TNH'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_839':
        ...

    @overload
    def set_item(self, name : Literal['MES'], val : Union[Variation_804, Variation_804_Arg]) -> 'Variation_839':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['BPS']) -> 'Variation_839':
        ...

    @overload
    def del_item(self, name : Literal['SH']) -> 'Variation_839':
        ...

    @overload
    def del_item(self, name : Literal['NAV']) -> 'Variation_839':
        ...

    @overload
    def del_item(self, name : Literal['GAO']) -> 'Variation_839':
        ...

    @overload
    def del_item(self, name : Literal['SGV']) -> 'Variation_839':
        ...

    @overload
    def del_item(self, name : Literal['STA']) -> 'Variation_839':
        ...

    @overload
    def del_item(self, name : Literal['TNH']) -> 'Variation_839':
        ...

    @overload
    def del_item(self, name : Literal['MES']) -> 'Variation_839':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['BPS']) -> Variation_761:
        ...

    @overload
    def get_item(self, name : Literal['SH']) -> Variation_765:
        ...

    @overload
    def get_item(self, name : Literal['NAV']) -> Variation_809:
        ...

    @overload
    def get_item(self, name : Literal['GAO']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SGV']) -> Variation_777:
        ...

    @overload
    def get_item(self, name : Literal['STA']) -> Variation_838:
        ...

    @overload
    def get_item(self, name : Literal['TNH']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['MES']) -> Variation_804:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['BPS'], f : Any) -> 'Variation_839':
        ...

    @overload
    def modify_item(self, name : Literal['SH'], f : Any) -> 'Variation_839':
        ...

    @overload
    def modify_item(self, name : Literal['NAV'], f : Any) -> 'Variation_839':
        ...

    @overload
    def modify_item(self, name : Literal['GAO'], f : Any) -> 'Variation_839':
        ...

    @overload
    def modify_item(self, name : Literal['SGV'], f : Any) -> 'Variation_839':
        ...

    @overload
    def modify_item(self, name : Literal['STA'], f : Any) -> 'Variation_839':
        ...

    @overload
    def modify_item(self, name : Literal['TNH'], f : Any) -> 'Variation_839':
        ...

    @overload
    def modify_item(self, name : Literal['MES'], f : Any) -> 'Variation_839':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_840_Arg : TypeAlias = Raw
class Variation_840(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: '24-Bit ICAO address',
        1: 'Duplicate address',
        2: 'Surface vehicle address',
        3: 'Anonymous address',
        4: 'Reserved for future use',
        5: 'Reserved for future use',
        6: 'Reserved for future use',
        7: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_840_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_841_Arg : TypeAlias = Raw
class Variation_841(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 2
    table = {
        0: '25 ft',
        1: '100 ft',
        2: 'Unknown',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_841_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_842_Arg : TypeAlias = Raw
class Variation_842(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Range Check passed, CPR Validation pending',
    }

    def __init__(self, arg : Variation_842_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_843_Arg : TypeAlias = Raw
class Variation_843(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Report from target transponder',
        1: 'Report from field monitor (fixed transponder)',
    }

    def __init__(self, arg : Variation_843_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_844_Arg : TypeAlias = Raw
class Variation_844(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Equipment capable to provide Selected Altitude',
        1: 'Equipment not capable to provide Selected Altitude',
    }

    def __init__(self, arg : Variation_844_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_845_Arg : TypeAlias = Raw
class Variation_845(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'Report valid',
        1: 'Report suspect',
        2: 'No information',
        3: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_845_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_846_Arg : TypeAlias = Raw
class Variation_846(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default (see note)',
        1: 'Independent Position Check failed',
    }

    def __init__(self, arg : Variation_846_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_847_Arg : TypeAlias = Raw
class Variation_847(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'NOGO-bit not set',
        1: 'NOGO-bit set',
    }

    def __init__(self, arg : Variation_847_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_848_Arg : TypeAlias = Raw
class Variation_848(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'CPR Validation correct',
        1: 'CPR Validation failed',
    }

    def __init__(self, arg : Variation_848_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_849_Arg : TypeAlias = Raw
class Variation_849(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'LDPJ not detected',
        1: 'LDPJ detected',
    }

    def __init__(self, arg : Variation_849_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_850_Arg : TypeAlias = Raw
class Variation_850(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Range Check failed',
    }

    def __init__(self, arg : Variation_850_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_851_Arg_Group_1 = TypedDict('Variation_851_Arg_Group_1', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
})
Variation_851_Arg_Group_2 = TypedDict('Variation_851_Arg_Group_2', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
    'DCR': Union[Variation_694, Variation_694_Arg],
    'GBS': Union[Variation_695, Variation_695_Arg],
    'SIM': Union[Variation_696, Variation_696_Arg],
    'TST': Union[Variation_697, Variation_697_Arg],
    'SAA': Union[Variation_844, Variation_844_Arg],
    'CL': Union[Variation_845, Variation_845_Arg],
})
Variation_851_Arg_Group_3 = TypedDict('Variation_851_Arg_Group_3', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
    'DCR': Union[Variation_694, Variation_694_Arg],
    'GBS': Union[Variation_695, Variation_695_Arg],
    'SIM': Union[Variation_696, Variation_696_Arg],
    'TST': Union[Variation_697, Variation_697_Arg],
    'SAA': Union[Variation_844, Variation_844_Arg],
    'CL': Union[Variation_845, Variation_845_Arg],
    'IPC': Union[Variation_846, Variation_846_Arg],
    'NOGO': Union[Variation_847, Variation_847_Arg],
    'CPR': Union[Variation_848, Variation_848_Arg],
    'LDPJ': Union[Variation_849, Variation_849_Arg],
    'RCF': Union[Variation_850, Variation_850_Arg],
})
Variation_851_Arg : TypeAlias = Union[
    int,
    Variation_851_Arg_Group_1,
    Tuple[int],
    Variation_851_Arg_Group_2,
    Tuple[int,int],
    Variation_851_Arg_Group_3,
    Tuple[int,int,int],
]
class Variation_851(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('ATP', Variation_840),
            ('ARC', Variation_841),
            ('RC', Variation_842),
            ('RAB', Variation_843),
        ],
        [
            ('DCR', Variation_694),
            ('GBS', Variation_695),
            ('SIM', Variation_696),
            ('TST', Variation_697),
            ('SAA', Variation_844),
            ('CL', Variation_845),
        ],
        [
            Spare(0, 2),
            ('IPC', Variation_846),
            ('NOGO', Variation_847),
            ('CPR', Variation_848),
            ('LDPJ', Variation_849),
            ('RCF', Variation_850),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ATP': ('Address Type', Variation_840, 0, 3),
        'ARC': ('Altitude Reporting Capability', Variation_841, 3, 2),
        'RC': ('Range Check', Variation_842, 5, 1),
        'RAB': ('Report Type', Variation_843, 6, 1),
        'DCR': ('Differential Correction', Variation_694, 0, 1),
        'GBS': ('Ground Bit Setting', Variation_695, 1, 1),
        'SIM': ('Simulated Target', Variation_696, 2, 1),
        'TST': ('Test Target', Variation_697, 3, 1),
        'SAA': ('Selected Altitude Available', Variation_844, 4, 1),
        'CL': ('Confidence Level', Variation_845, 5, 2),
        'IPC': ('Independent Position Check', Variation_846, 2, 1),
        'NOGO': ('No-go Bit Status', Variation_847, 3, 1),
        'CPR': ('Compact Position Reporting', Variation_848, 4, 1),
        'LDPJ': ('Local Decoding Position Jump', Variation_849, 5, 1),
        'RCF': ('Range Check', Variation_850, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ATP']) -> Type[Variation_840]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_841]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RC']) -> Type[Variation_842]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_843]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DCR']) -> Type[Variation_694]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GBS']) -> Type[Variation_695]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_696]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_697]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAA']) -> Type[Variation_844]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CL']) -> Type[Variation_845]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IPC']) -> Type[Variation_846]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOGO']) -> Type[Variation_847]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CPR']) -> Type[Variation_848]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LDPJ']) -> Type[Variation_849]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RCF']) -> Type[Variation_850]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ATP'], Literal['ARC'], Literal['RC'], Literal['RAB'], Literal['DCR'], Literal['GBS'], Literal['SIM'], Literal['TST'], Literal['SAA'], Literal['CL'], Literal['IPC'], Literal['NOGO'], Literal['CPR'], Literal['LDPJ'], Literal['RCF']]) -> Union[Type['Variation_840'], Type['Variation_841'], Type['Variation_842'], Type['Variation_843'], Type['Variation_694'], Type['Variation_695'], Type['Variation_696'], Type['Variation_697'], Type['Variation_844'], Type['Variation_845'], Type['Variation_846'], Type['Variation_847'], Type['Variation_848'], Type['Variation_849'], Type['Variation_850']]:
        if key == 'ATP':
            return Variation_840
        if key == 'ARC':
            return Variation_841
        if key == 'RC':
            return Variation_842
        if key == 'RAB':
            return Variation_843
        if key == 'DCR':
            return Variation_694
        if key == 'GBS':
            return Variation_695
        if key == 'SIM':
            return Variation_696
        if key == 'TST':
            return Variation_697
        if key == 'SAA':
            return Variation_844
        if key == 'CL':
            return Variation_845
        if key == 'IPC':
            return Variation_846
        if key == 'NOGO':
            return Variation_847
        if key == 'CPR':
            return Variation_848
        if key == 'LDPJ':
            return Variation_849
        if key == 'RCF':
            return Variation_850
        assert_never(key)

    def __init__(self, arg : Variation_851_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_851_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_851_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_851_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ATP']) -> Variation_840:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_841:
        ...

    @overload
    def get_item(self, name : Literal['RC']) -> Variation_842:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_843:
        ...

    @overload
    def get_item(self, name : Literal['DCR']) -> Variation_694:
        ...

    @overload
    def get_item(self, name : Literal['GBS']) -> Variation_695:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_696:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_697:
        ...

    @overload
    def get_item(self, name : Literal['SAA']) -> Variation_844:
        ...

    @overload
    def get_item(self, name : Literal['CL']) -> Variation_845:
        ...

    @overload
    def get_item(self, name : Literal['IPC']) -> Variation_846:
        ...

    @overload
    def get_item(self, name : Literal['NOGO']) -> Variation_847:
        ...

    @overload
    def get_item(self, name : Literal['CPR']) -> Variation_848:
        ...

    @overload
    def get_item(self, name : Literal['LDPJ']) -> Variation_849:
        ...

    @overload
    def get_item(self, name : Literal['RCF']) -> Variation_850:
        ...

    def get_item(self, name : Union[Literal['ATP'], Literal['ARC'], Literal['RC'], Literal['RAB'], Literal['DCR'], Literal['GBS'], Literal['SIM'], Literal['TST'], Literal['SAA'], Literal['CL'], Literal['IPC'], Literal['NOGO'], Literal['CPR'], Literal['LDPJ'], Literal['RCF']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ATP'], val : Union[Variation_840, Variation_840_Arg]) -> 'Variation_851':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_841, Variation_841_Arg]) -> 'Variation_851':
        ...

    @overload
    def set_item(self, name : Literal['RC'], val : Union[Variation_842, Variation_842_Arg]) -> 'Variation_851':
        ...

    @overload
    def set_item(self, name : Literal['RAB'], val : Union[Variation_843, Variation_843_Arg]) -> 'Variation_851':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ATP'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['RC'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['DCR'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['GBS'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['SAA'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['CL'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['IPC'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['NOGO'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['CPR'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['LDPJ'], f : Any) -> 'Variation_851':
        ...

    @overload
    def modify_item(self, name : Literal['RCF'], f : Any) -> 'Variation_851':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_852_Arg_Group = TypedDict('Variation_852_Arg_Group', {
    'TRNUM': Union[Variation_43, Variation_43_Arg],
})
Variation_852_Arg : TypeAlias = Union[Raw, Variation_852_Arg_Group]
class Variation_852(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('TRNUM', Variation_43),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TRNUM': ('Track Number', Variation_43, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['TRNUM']]) -> Union[Type['Variation_43']]:
        if key == 'TRNUM':
            return Variation_43
        assert_never(key)

    def __init__(self, arg : Variation_852_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['TRNUM']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['TRNUM'], val : Union[Variation_43, Variation_43_Arg]) -> 'Variation_852':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['TRNUM'], f : Any) -> 'Variation_852':
        return self._modify_item(name, f) # type: ignore

Variation_853_Arg : TypeAlias = Raw
class Variation_853(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Value in defined range',
        1: 'Value exceeds defined range',
    }

    def __init__(self, arg : Variation_853_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_854_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['kt']]]
class Variation_854(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 15
    quantity = Quantity('Unsigned', 1.0, 'kt')

    def __init__(self, arg : Variation_854_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_855_Arg_Group = TypedDict('Variation_855_Arg_Group', {
    'RE': Union[Variation_853, Variation_853_Arg],
    'TAS': Union[Variation_854, Variation_854_Arg],
})
Variation_855_Arg : TypeAlias = Union[Raw, Variation_855_Arg_Group]
class Variation_855(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('RE', Variation_853),
        ('TAS', Variation_854),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RE': ('Range Exceeded Indicator', Variation_853, 0, 1),
        'TAS': ('True Air Speed', Variation_854, 1, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_853]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAS']) -> Type[Variation_854]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RE'], Literal['TAS']]) -> Union[Type['Variation_853'], Type['Variation_854']]:
        if key == 'RE':
            return Variation_853
        if key == 'TAS':
            return Variation_854
        assert_never(key)

    def __init__(self, arg : Variation_855_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_853:
        ...

    @overload
    def get_item(self, name : Literal['TAS']) -> Variation_854:
        ...

    def get_item(self, name : Union[Literal['RE'], Literal['TAS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_853, Variation_853_Arg]) -> 'Variation_855':
        ...

    @overload
    def set_item(self, name : Literal['TAS'], val : Union[Variation_854, Variation_854_Arg]) -> 'Variation_855':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_855':
        ...

    @overload
    def modify_item(self, name : Literal['TAS'], f : Any) -> 'Variation_855':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_856_Arg : TypeAlias = Raw
class Variation_856(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        3: 'Reserved',
        2: 'TOMRp whole seconds = (I021/073) Whole seconds - 1',
        1: 'TOMRp whole seconds = (I021/073) Whole seconds + 1',
        0: 'TOMRp whole seconds = (I021/073) Whole seconds',
    }

    def __init__(self, arg : Variation_856_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_857_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_857(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 30
    quantity = Quantity('Unsigned', 9.313225746154785e-10, 's')

    def __init__(self, arg : Variation_857_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_858_Arg_Group = TypedDict('Variation_858_Arg_Group', {
    'FSI': Union[Variation_856, Variation_856_Arg],
    'TOMRP': Union[Variation_857, Variation_857_Arg],
})
Variation_858_Arg : TypeAlias = Union[Raw, Variation_858_Arg_Group]
class Variation_858(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('FSI', Variation_856),
        ('TOMRP', Variation_857),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FSI': ('Full Second Indication', Variation_856, 0, 2),
        'TOMRP': ('Fractional Part of the Time of Message Reception for Position in the Ground Station', Variation_857, 2, 30),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['FSI']) -> Type[Variation_856]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOMRP']) -> Type[Variation_857]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['FSI'], Literal['TOMRP']]) -> Union[Type['Variation_856'], Type['Variation_857']]:
        if key == 'FSI':
            return Variation_856
        if key == 'TOMRP':
            return Variation_857
        assert_never(key)

    def __init__(self, arg : Variation_858_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['FSI']) -> Variation_856:
        ...

    @overload
    def get_item(self, name : Literal['TOMRP']) -> Variation_857:
        ...

    def get_item(self, name : Union[Literal['FSI'], Literal['TOMRP']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['FSI'], val : Union[Variation_856, Variation_856_Arg]) -> 'Variation_858':
        ...

    @overload
    def set_item(self, name : Literal['TOMRP'], val : Union[Variation_857, Variation_857_Arg]) -> 'Variation_858':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['FSI'], f : Any) -> 'Variation_858':
        ...

    @overload
    def modify_item(self, name : Literal['TOMRP'], f : Any) -> 'Variation_858':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_859_Arg : TypeAlias = Raw
class Variation_859(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        3: 'Reserved',
        2: 'TOMRp whole seconds = (I021/075) Whole seconds - 1',
        1: 'TOMRp whole seconds = (I021/075) Whole seconds + 1',
        0: 'TOMRp whole seconds = (I021/075) Whole seconds',
    }

    def __init__(self, arg : Variation_859_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_860_Arg_Group = TypedDict('Variation_860_Arg_Group', {
    'FSI': Union[Variation_859, Variation_859_Arg],
    'TOMRP': Union[Variation_857, Variation_857_Arg],
})
Variation_860_Arg : TypeAlias = Union[Raw, Variation_860_Arg_Group]
class Variation_860(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('FSI', Variation_859),
        ('TOMRP', Variation_857),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FSI': ('Full Second Indication', Variation_859, 0, 2),
        'TOMRP': ('Fractional Part of the Time of Message Reception for Position in the Ground Station', Variation_857, 2, 30),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['FSI']) -> Type[Variation_859]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOMRP']) -> Type[Variation_857]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['FSI'], Literal['TOMRP']]) -> Union[Type['Variation_859'], Type['Variation_857']]:
        if key == 'FSI':
            return Variation_859
        if key == 'TOMRP':
            return Variation_857
        assert_never(key)

    def __init__(self, arg : Variation_860_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['FSI']) -> Variation_859:
        ...

    @overload
    def get_item(self, name : Literal['TOMRP']) -> Variation_857:
        ...

    def get_item(self, name : Union[Literal['FSI'], Literal['TOMRP']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['FSI'], val : Union[Variation_859, Variation_859_Arg]) -> 'Variation_860':
        ...

    @overload
    def set_item(self, name : Literal['TOMRP'], val : Union[Variation_857, Variation_857_Arg]) -> 'Variation_860':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['FSI'], f : Any) -> 'Variation_860':
        ...

    @overload
    def modify_item(self, name : Literal['TOMRP'], f : Any) -> 'Variation_860':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_861_Arg : TypeAlias = Raw
class Variation_861(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3

    def __init__(self, arg : Variation_861_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_862_Arg : TypeAlias = Raw
class Variation_862(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 4

    def __init__(self, arg : Variation_862_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_863_Arg : TypeAlias = Raw
class Variation_863(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1

    def __init__(self, arg : Variation_863_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_864_Arg : TypeAlias = Raw
class Variation_864(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2

    def __init__(self, arg : Variation_864_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_865_Arg : TypeAlias = Raw
class Variation_865(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Measured per flight-hour',
        1: 'Measured per sample',
    }

    def __init__(self, arg : Variation_865_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_866_Arg : TypeAlias = Raw
class Variation_866(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 2

    def __init__(self, arg : Variation_866_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_867_Arg : TypeAlias = Raw
class Variation_867(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2

    def __init__(self, arg : Variation_867_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_868_Arg_Group_1 = TypedDict('Variation_868_Arg_Group_1', {
    'NUCRNACV': Union[Variation_861, Variation_861_Arg],
    'NUCPNIC': Union[Variation_862, Variation_862_Arg],
})
Variation_868_Arg_Group_2 = TypedDict('Variation_868_Arg_Group_2', {
    'NUCRNACV': Union[Variation_861, Variation_861_Arg],
    'NUCPNIC': Union[Variation_862, Variation_862_Arg],
    'NICBARO': Union[Variation_863, Variation_863_Arg],
    'SIL': Union[Variation_864, Variation_864_Arg],
    'NACP': Union[Variation_862, Variation_862_Arg],
})
Variation_868_Arg_Group_3 = TypedDict('Variation_868_Arg_Group_3', {
    'NUCRNACV': Union[Variation_861, Variation_861_Arg],
    'NUCPNIC': Union[Variation_862, Variation_862_Arg],
    'NICBARO': Union[Variation_863, Variation_863_Arg],
    'SIL': Union[Variation_864, Variation_864_Arg],
    'NACP': Union[Variation_862, Variation_862_Arg],
    'SILS': Union[Variation_865, Variation_865_Arg],
    'SDA': Union[Variation_866, Variation_866_Arg],
    'GVA': Union[Variation_867, Variation_867_Arg],
})
Variation_868_Arg_Group_4 = TypedDict('Variation_868_Arg_Group_4', {
    'NUCRNACV': Union[Variation_861, Variation_861_Arg],
    'NUCPNIC': Union[Variation_862, Variation_862_Arg],
    'NICBARO': Union[Variation_863, Variation_863_Arg],
    'SIL': Union[Variation_864, Variation_864_Arg],
    'NACP': Union[Variation_862, Variation_862_Arg],
    'SILS': Union[Variation_865, Variation_865_Arg],
    'SDA': Union[Variation_866, Variation_866_Arg],
    'GVA': Union[Variation_867, Variation_867_Arg],
    'PIC': Union[Variation_187, Variation_187_Arg],
})
Variation_868_Arg : TypeAlias = Union[
    int,
    Variation_868_Arg_Group_1,
    Tuple[int],
    Variation_868_Arg_Group_2,
    Tuple[int,int],
    Variation_868_Arg_Group_3,
    Tuple[int,int,int],
    Variation_868_Arg_Group_4,
    Tuple[int,int,int,int],
]
class Variation_868(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('NUCRNACV', Variation_861),
            ('NUCPNIC', Variation_862),
        ],
        [
            ('NICBARO', Variation_863),
            ('SIL', Variation_864),
            ('NACP', Variation_862),
        ],
        [
            Spare(0, 2),
            ('SILS', Variation_865),
            ('SDA', Variation_866),
            ('GVA', Variation_867),
        ],
        [
            ('PIC', Variation_187),
            Spare(4, 3),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NUCRNACV': ('Navigation Uncertainty Category for Velocity NUCr or the Navigation Accuracy Category for Velocity NACv', Variation_861, 0, 3),
        'NUCPNIC': ('Navigation Uncertainty Category for Position NUCp or Navigation Integrity Category NIC', Variation_862, 3, 4),
        'NICBARO': ('Navigation Integrity Category for Barometric Altitude', Variation_863, 0, 1),
        'SIL': ('Surveillance (version 1) or Source (version 2) Integrity Level', Variation_864, 1, 2),
        'NACP': ('Navigation Accuracy Category for Position', Variation_862, 3, 4),
        'SILS': ('SIL-Supplement', Variation_865, 2, 1),
        'SDA': ('Horizontal Position System Design Assurance Level (as Defined in Version 2)', Variation_866, 3, 2),
        'GVA': ('Geometric Altitude Accuracy', Variation_867, 5, 2),
        'PIC': ('Position Integrity Category', Variation_187, 0, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NUCRNACV']) -> Type[Variation_861]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NUCPNIC']) -> Type[Variation_862]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NICBARO']) -> Type[Variation_863]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIL']) -> Type[Variation_864]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NACP']) -> Type[Variation_862]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SILS']) -> Type[Variation_865]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDA']) -> Type[Variation_866]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GVA']) -> Type[Variation_867]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PIC']) -> Type[Variation_187]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NUCRNACV'], Literal['NUCPNIC'], Literal['NICBARO'], Literal['SIL'], Literal['NACP'], Literal['SILS'], Literal['SDA'], Literal['GVA'], Literal['PIC']]) -> Union[Type['Variation_861'], Type['Variation_862'], Type['Variation_863'], Type['Variation_864'], Type['Variation_862'], Type['Variation_865'], Type['Variation_866'], Type['Variation_867'], Type['Variation_187']]:
        if key == 'NUCRNACV':
            return Variation_861
        if key == 'NUCPNIC':
            return Variation_862
        if key == 'NICBARO':
            return Variation_863
        if key == 'SIL':
            return Variation_864
        if key == 'NACP':
            return Variation_862
        if key == 'SILS':
            return Variation_865
        if key == 'SDA':
            return Variation_866
        if key == 'GVA':
            return Variation_867
        if key == 'PIC':
            return Variation_187
        assert_never(key)

    def __init__(self, arg : Variation_868_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_868_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_868_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_868_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            if Variation_868_Arg_Group_4.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(4, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NUCRNACV']) -> Variation_861:
        ...

    @overload
    def get_item(self, name : Literal['NUCPNIC']) -> Variation_862:
        ...

    @overload
    def get_item(self, name : Literal['NICBARO']) -> Variation_863:
        ...

    @overload
    def get_item(self, name : Literal['SIL']) -> Variation_864:
        ...

    @overload
    def get_item(self, name : Literal['NACP']) -> Variation_862:
        ...

    @overload
    def get_item(self, name : Literal['SILS']) -> Variation_865:
        ...

    @overload
    def get_item(self, name : Literal['SDA']) -> Variation_866:
        ...

    @overload
    def get_item(self, name : Literal['GVA']) -> Variation_867:
        ...

    @overload
    def get_item(self, name : Literal['PIC']) -> Variation_187:
        ...

    def get_item(self, name : Union[Literal['NUCRNACV'], Literal['NUCPNIC'], Literal['NICBARO'], Literal['SIL'], Literal['NACP'], Literal['SILS'], Literal['SDA'], Literal['GVA'], Literal['PIC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NUCRNACV'], val : Union[Variation_861, Variation_861_Arg]) -> 'Variation_868':
        ...

    @overload
    def set_item(self, name : Literal['NUCPNIC'], val : Union[Variation_862, Variation_862_Arg]) -> 'Variation_868':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NUCRNACV'], f : Any) -> 'Variation_868':
        ...

    @overload
    def modify_item(self, name : Literal['NUCPNIC'], f : Any) -> 'Variation_868':
        ...

    @overload
    def modify_item(self, name : Literal['NICBARO'], f : Any) -> 'Variation_868':
        ...

    @overload
    def modify_item(self, name : Literal['SIL'], f : Any) -> 'Variation_868':
        ...

    @overload
    def modify_item(self, name : Literal['NACP'], f : Any) -> 'Variation_868':
        ...

    @overload
    def modify_item(self, name : Literal['SILS'], f : Any) -> 'Variation_868':
        ...

    @overload
    def modify_item(self, name : Literal['SDA'], f : Any) -> 'Variation_868':
        ...

    @overload
    def modify_item(self, name : Literal['GVA'], f : Any) -> 'Variation_868':
        ...

    @overload
    def modify_item(self, name : Literal['PIC'], f : Any) -> 'Variation_868':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_869_Arg : TypeAlias = Raw
class Variation_869(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'The MOPS Version is supported by the GS',
        1: 'The MOPS Version is not supported by the GS',
    }

    def __init__(self, arg : Variation_869_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_870_Arg : TypeAlias = Raw
class Variation_870(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 3
    table = {
        0: 'ED102/DO-260 [Ref. 8]',
        1: 'DO-260A [Ref. 9]',
        2: 'ED102A/DO-260B [Ref. 11]',
    }

    def __init__(self, arg : Variation_870_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_871_Arg : TypeAlias = Raw
class Variation_871(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 3
    table = {
        0: 'Other',
        1: 'UAT',
        2: '1090 ES',
        3: 'VDL 4',
        4: 'Not assigned',
        5: 'Not assigned',
        6: 'Not assigned',
        7: 'Not assigned',
    }

    def __init__(self, arg : Variation_871_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_872_Arg_Group = TypedDict('Variation_872_Arg_Group', {
    'VNS': Union[Variation_869, Variation_869_Arg],
    'VN': Union[Variation_870, Variation_870_Arg],
    'LTT': Union[Variation_871, Variation_871_Arg],
})
Variation_872_Arg : TypeAlias = Union[Raw, Variation_872_Arg_Group]
class Variation_872(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 1),
        ('VNS', Variation_869),
        ('VN', Variation_870),
        ('LTT', Variation_871),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'VNS': ('Version Not Supported', Variation_869, 1, 1),
        'VN': ('Version Number', Variation_870, 2, 3),
        'LTT': ('Link Technology Type', Variation_871, 5, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VNS']) -> Type[Variation_869]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VN']) -> Type[Variation_870]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LTT']) -> Type[Variation_871]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VNS'], Literal['VN'], Literal['LTT']]) -> Union[Type['Variation_869'], Type['Variation_870'], Type['Variation_871']]:
        if key == 'VNS':
            return Variation_869
        if key == 'VN':
            return Variation_870
        if key == 'LTT':
            return Variation_871
        assert_never(key)

    def __init__(self, arg : Variation_872_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['VNS']) -> Variation_869:
        ...

    @overload
    def get_item(self, name : Literal['VN']) -> Variation_870:
        ...

    @overload
    def get_item(self, name : Literal['LTT']) -> Variation_871:
        ...

    def get_item(self, name : Union[Literal['VNS'], Literal['VN'], Literal['LTT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['VNS'], val : Union[Variation_869, Variation_869_Arg]) -> 'Variation_872':
        ...

    @overload
    def set_item(self, name : Literal['VN'], val : Union[Variation_870, Variation_870_Arg]) -> 'Variation_872':
        ...

    @overload
    def set_item(self, name : Literal['LTT'], val : Union[Variation_871, Variation_871_Arg]) -> 'Variation_872':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['VNS'], f : Any) -> 'Variation_872':
        ...

    @overload
    def modify_item(self, name : Literal['VN'], f : Any) -> 'Variation_872':
        ...

    @overload
    def modify_item(self, name : Literal['LTT'], f : Any) -> 'Variation_872':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_873_Arg_Group = TypedDict('Variation_873_Arg_Group', {
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_873_Arg : TypeAlias = Union[Raw, Variation_873_Arg_Group]
class Variation_873(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MODE3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['MODE3A']]) -> Union[Type['Variation_19']]:
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_873_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['MODE3A']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_873':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_873':
        return self._modify_item(name, f) # type: ignore

Variation_874_Arg : TypeAlias = Raw
class Variation_874(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No intent change active',
        1: 'Intent change flag raised',
    }

    def __init__(self, arg : Variation_874_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_875_Arg : TypeAlias = Raw
class Variation_875(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'LNAV Mode engaged',
        1: 'LNAV Mode not engaged',
    }

    def __init__(self, arg : Variation_875_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_876_Arg : TypeAlias = Raw
class Variation_876(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 3
    table = {
        0: 'No emergency / not reported',
        1: 'General emergency',
        2: 'Lifeguard / medical emergency',
        3: 'Minimum fuel',
        4: 'No communications',
        5: 'Unlawful interference',
        6: 'DOWNED Aircraft',
    }

    def __init__(self, arg : Variation_876_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_877_Arg : TypeAlias = Raw
class Variation_877(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 2
    table = {
        0: 'No condition reported',
        1: 'Permanent Alert (Emergency condition)',
        2: 'Temporary Alert (change in Mode 3/A Code other than emergency)',
        3: 'SPI set',
    }

    def __init__(self, arg : Variation_877_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_878_Arg_Group = TypedDict('Variation_878_Arg_Group', {
    'ICF': Union[Variation_874, Variation_874_Arg],
    'LNAV': Union[Variation_875, Variation_875_Arg],
    'PS': Union[Variation_876, Variation_876_Arg],
    'SS': Union[Variation_877, Variation_877_Arg],
})
Variation_878_Arg : TypeAlias = Union[Raw, Variation_878_Arg_Group]
class Variation_878(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('ICF', Variation_874),
        ('LNAV', Variation_875),
        Spare(2, 1),
        ('PS', Variation_876),
        ('SS', Variation_877),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ICF': ('Intent Change Flag (see Note)', Variation_874, 0, 1),
        'LNAV': ('LNAV Mode', Variation_875, 1, 1),
        'PS': ('Priority Status', Variation_876, 3, 3),
        'SS': ('Surveillance Status', Variation_877, 6, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ICF']) -> Type[Variation_874]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LNAV']) -> Type[Variation_875]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PS']) -> Type[Variation_876]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SS']) -> Type[Variation_877]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ICF'], Literal['LNAV'], Literal['PS'], Literal['SS']]) -> Union[Type['Variation_874'], Type['Variation_875'], Type['Variation_876'], Type['Variation_877']]:
        if key == 'ICF':
            return Variation_874
        if key == 'LNAV':
            return Variation_875
        if key == 'PS':
            return Variation_876
        if key == 'SS':
            return Variation_877
        assert_never(key)

    def __init__(self, arg : Variation_878_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ICF']) -> Variation_874:
        ...

    @overload
    def get_item(self, name : Literal['LNAV']) -> Variation_875:
        ...

    @overload
    def get_item(self, name : Literal['PS']) -> Variation_876:
        ...

    @overload
    def get_item(self, name : Literal['SS']) -> Variation_877:
        ...

    def get_item(self, name : Union[Literal['ICF'], Literal['LNAV'], Literal['PS'], Literal['SS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ICF'], val : Union[Variation_874, Variation_874_Arg]) -> 'Variation_878':
        ...

    @overload
    def set_item(self, name : Literal['LNAV'], val : Union[Variation_875, Variation_875_Arg]) -> 'Variation_878':
        ...

    @overload
    def set_item(self, name : Literal['PS'], val : Union[Variation_876, Variation_876_Arg]) -> 'Variation_878':
        ...

    @overload
    def set_item(self, name : Literal['SS'], val : Union[Variation_877, Variation_877_Arg]) -> 'Variation_878':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ICF'], f : Any) -> 'Variation_878':
        ...

    @overload
    def modify_item(self, name : Literal['LNAV'], f : Any) -> 'Variation_878':
        ...

    @overload
    def modify_item(self, name : Literal['PS'], f : Any) -> 'Variation_878':
        ...

    @overload
    def modify_item(self, name : Literal['SS'], f : Any) -> 'Variation_878':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_879_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft/min']]]
class Variation_879(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 15
    quantity = Quantity('Signed', 6.25, 'ft/min')

    def __init__(self, arg : Variation_879_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_880_Arg_Group = TypedDict('Variation_880_Arg_Group', {
    'RE': Union[Variation_853, Variation_853_Arg],
    'BVR': Union[Variation_879, Variation_879_Arg],
})
Variation_880_Arg : TypeAlias = Union[Raw, Variation_880_Arg_Group]
class Variation_880(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('RE', Variation_853),
        ('BVR', Variation_879),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RE': ('Range Exceeded Indicator', Variation_853, 0, 1),
        'BVR': ('Barometric Vertical Rate', Variation_879, 1, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_853]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BVR']) -> Type[Variation_879]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RE'], Literal['BVR']]) -> Union[Type['Variation_853'], Type['Variation_879']]:
        if key == 'RE':
            return Variation_853
        if key == 'BVR':
            return Variation_879
        assert_never(key)

    def __init__(self, arg : Variation_880_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_853:
        ...

    @overload
    def get_item(self, name : Literal['BVR']) -> Variation_879:
        ...

    def get_item(self, name : Union[Literal['RE'], Literal['BVR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_853, Variation_853_Arg]) -> 'Variation_880':
        ...

    @overload
    def set_item(self, name : Literal['BVR'], val : Union[Variation_879, Variation_879_Arg]) -> 'Variation_880':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_880':
        ...

    @overload
    def modify_item(self, name : Literal['BVR'], f : Any) -> 'Variation_880':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_881_Arg_Group = TypedDict('Variation_881_Arg_Group', {
    'RE': Union[Variation_853, Variation_853_Arg],
    'GVR': Union[Variation_879, Variation_879_Arg],
})
Variation_881_Arg : TypeAlias = Union[Raw, Variation_881_Arg_Group]
class Variation_881(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('RE', Variation_853),
        ('GVR', Variation_879),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RE': ('Range Exceeded Indicator', Variation_853, 0, 1),
        'GVR': ('Geometric Vertical Rate', Variation_879, 1, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_853]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GVR']) -> Type[Variation_879]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RE'], Literal['GVR']]) -> Union[Type['Variation_853'], Type['Variation_879']]:
        if key == 'RE':
            return Variation_853
        if key == 'GVR':
            return Variation_879
        assert_never(key)

    def __init__(self, arg : Variation_881_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_853:
        ...

    @overload
    def get_item(self, name : Literal['GVR']) -> Variation_879:
        ...

    def get_item(self, name : Union[Literal['RE'], Literal['GVR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_853, Variation_853_Arg]) -> 'Variation_881':
        ...

    @overload
    def set_item(self, name : Literal['GVR'], val : Union[Variation_879, Variation_879_Arg]) -> 'Variation_881':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_881':
        ...

    @overload
    def modify_item(self, name : Literal['GVR'], f : Any) -> 'Variation_881':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_882_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM/s']]]
class Variation_882(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 15
    quantity = Quantity('Unsigned', 6.103515625e-5, 'NM/s')

    def __init__(self, arg : Variation_882_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_883_Arg_Group = TypedDict('Variation_883_Arg_Group', {
    'RE': Union[Variation_853, Variation_853_Arg],
    'GS': Union[Variation_882, Variation_882_Arg],
    'TA': Union[Variation_14, Variation_14_Arg],
})
Variation_883_Arg : TypeAlias = Union[Raw, Variation_883_Arg_Group]
class Variation_883(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('RE', Variation_853),
        ('GS', Variation_882),
        ('TA', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RE': ('Range Exceeded Indicator', Variation_853, 0, 1),
        'GS': ('Ground Speed Referenced to WGS-84', Variation_882, 1, 15),
        'TA': ('Track Angle Clockwise Reference to True North', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_853]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GS']) -> Type[Variation_882]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TA']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RE'], Literal['GS'], Literal['TA']]) -> Union[Type['Variation_853'], Type['Variation_882'], Type['Variation_14']]:
        if key == 'RE':
            return Variation_853
        if key == 'GS':
            return Variation_882
        if key == 'TA':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_883_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_853:
        ...

    @overload
    def get_item(self, name : Literal['GS']) -> Variation_882:
        ...

    @overload
    def get_item(self, name : Literal['TA']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['RE'], Literal['GS'], Literal['TA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_853, Variation_853_Arg]) -> 'Variation_883':
        ...

    @overload
    def set_item(self, name : Literal['GS'], val : Union[Variation_882, Variation_882_Arg]) -> 'Variation_883':
        ...

    @overload
    def set_item(self, name : Literal['TA'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_883':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_883':
        ...

    @overload
    def modify_item(self, name : Literal['GS'], f : Any) -> 'Variation_883':
        ...

    @overload
    def modify_item(self, name : Literal['TA'], f : Any) -> 'Variation_883':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_884_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°/s']]]
class Variation_884(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 10
    quantity = Quantity('Signed', 3.125e-2, '°/s')

    def __init__(self, arg : Variation_884_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_885_Arg_Group = TypedDict('Variation_885_Arg_Group', {
    'TAR': Union[Variation_884, Variation_884_Arg],
})
Variation_885_Arg : TypeAlias = Union[Raw, Variation_885_Arg_Group]
class Variation_885(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 6),
        ('TAR', Variation_884),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TAR': ('Track Angle Rate', Variation_884, 6, 10),
    }


    @classmethod
    def spec(cls, key : Union[Literal['TAR']]) -> Union[Type['Variation_884']]:
        if key == 'TAR':
            return Variation_884
        assert_never(key)

    def __init__(self, arg : Variation_885_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['TAR']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['TAR'], val : Union[Variation_884, Variation_884_Arg]) -> 'Variation_885':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['TAR'], f : Any) -> 'Variation_885':
        return self._modify_item(name, f) # type: ignore

Variation_886_Arg : TypeAlias = Raw
class Variation_886(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'No ADS-B Emitter Category Information',
        1: 'Light aircraft <= 15500 lbs',
        2: '15500 lbs < small aircraft <75000 lbs',
        3: '75000 lbs < medium a/c < 300000 lbs',
        4: 'High Vortex Large',
        5: '300000 lbs <= heavy aircraft',
        6: 'Highly manoeuvrable (5g acceleration capability) and high speed (>400 knots cruise)',
        7: 'Reserved',
        8: 'Reserved',
        9: 'Reserved',
        10: 'Rotocraft',
        11: 'Glider / sailplane',
        12: 'Lighter-than-air',
        13: 'Unmanned aerial vehicle',
        14: 'Space / transatmospheric vehicle',
        15: 'Ultralight / handglider / paraglider',
        16: 'Parachutist / skydiver',
        17: 'Reserved',
        18: 'Reserved',
        19: 'Reserved',
        20: 'Surface emergency vehicle',
        21: 'Surface service vehicle',
        22: 'Fixed ground or tethered obstruction',
        23: 'Cluster obstacle',
        24: 'Line obstacle',
    }

    def __init__(self, arg : Variation_886_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_887_Arg_Group = TypedDict('Variation_887_Arg_Group', {
    'SAS': Union[Variation_732, Variation_732_Arg],
    'S': Union[Variation_733, Variation_733_Arg],
    'ALT': Union[Variation_734, Variation_734_Arg],
})
Variation_887_Arg : TypeAlias = Union[Raw, Variation_887_Arg_Group]
class Variation_887(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('SAS', Variation_732),
        ('S', Variation_733),
        ('ALT', Variation_734),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SAS': ('Source Availability', Variation_732, 0, 1),
        'S': ('Source', Variation_733, 1, 2),
        'ALT': ('Altitude', Variation_734, 3, 13),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SAS']) -> Type[Variation_732]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['S']) -> Type[Variation_733]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_734]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SAS'], Literal['S'], Literal['ALT']]) -> Union[Type['Variation_732'], Type['Variation_733'], Type['Variation_734']]:
        if key == 'SAS':
            return Variation_732
        if key == 'S':
            return Variation_733
        if key == 'ALT':
            return Variation_734
        assert_never(key)

    def __init__(self, arg : Variation_887_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SAS']) -> Variation_732:
        ...

    @overload
    def get_item(self, name : Literal['S']) -> Variation_733:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_734:
        ...

    def get_item(self, name : Union[Literal['SAS'], Literal['S'], Literal['ALT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SAS'], val : Union[Variation_732, Variation_732_Arg]) -> 'Variation_887':
        ...

    @overload
    def set_item(self, name : Literal['S'], val : Union[Variation_733, Variation_733_Arg]) -> 'Variation_887':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_734, Variation_734_Arg]) -> 'Variation_887':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SAS'], f : Any) -> 'Variation_887':
        ...

    @overload
    def modify_item(self, name : Literal['S'], f : Any) -> 'Variation_887':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_887':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_888_Arg : TypeAlias = Raw
class Variation_888(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Not active or unknown',
        1: 'Active',
    }

    def __init__(self, arg : Variation_888_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_889_Arg : TypeAlias = Raw
class Variation_889(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Not active or unknown',
        1: 'Active',
    }

    def __init__(self, arg : Variation_889_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_890_Arg : TypeAlias = Raw
class Variation_890(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Not active or unknown',
        1: 'Active',
    }

    def __init__(self, arg : Variation_890_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_891_Arg_Group = TypedDict('Variation_891_Arg_Group', {
    'MV': Union[Variation_888, Variation_888_Arg],
    'AH': Union[Variation_889, Variation_889_Arg],
    'AM': Union[Variation_890, Variation_890_Arg],
    'ALT': Union[Variation_734, Variation_734_Arg],
})
Variation_891_Arg : TypeAlias = Union[Raw, Variation_891_Arg_Group]
class Variation_891(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('MV', Variation_888),
        ('AH', Variation_889),
        ('AM', Variation_890),
        ('ALT', Variation_734),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MV': ('Manage Vertical Mode', Variation_888, 0, 1),
        'AH': ('Altitude Hold Mode', Variation_889, 1, 1),
        'AM': ('Approach Mode', Variation_890, 2, 1),
        'ALT': ('Altitude', Variation_734, 3, 13),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MV']) -> Type[Variation_888]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AH']) -> Type[Variation_889]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AM']) -> Type[Variation_890]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_734]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MV'], Literal['AH'], Literal['AM'], Literal['ALT']]) -> Union[Type['Variation_888'], Type['Variation_889'], Type['Variation_890'], Type['Variation_734']]:
        if key == 'MV':
            return Variation_888
        if key == 'AH':
            return Variation_889
        if key == 'AM':
            return Variation_890
        if key == 'ALT':
            return Variation_734
        assert_never(key)

    def __init__(self, arg : Variation_891_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MV']) -> Variation_888:
        ...

    @overload
    def get_item(self, name : Literal['AH']) -> Variation_889:
        ...

    @overload
    def get_item(self, name : Literal['AM']) -> Variation_890:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_734:
        ...

    def get_item(self, name : Union[Literal['MV'], Literal['AH'], Literal['AM'], Literal['ALT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MV'], val : Union[Variation_888, Variation_888_Arg]) -> 'Variation_891':
        ...

    @overload
    def set_item(self, name : Literal['AH'], val : Union[Variation_889, Variation_889_Arg]) -> 'Variation_891':
        ...

    @overload
    def set_item(self, name : Literal['AM'], val : Union[Variation_890, Variation_890_Arg]) -> 'Variation_891':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_734, Variation_734_Arg]) -> 'Variation_891':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MV'], f : Any) -> 'Variation_891':
        ...

    @overload
    def modify_item(self, name : Literal['AH'], f : Any) -> 'Variation_891':
        ...

    @overload
    def modify_item(self, name : Literal['AM'], f : Any) -> 'Variation_891':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_891':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_892_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_892(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 0.5, 's')

    def __init__(self, arg : Variation_892_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_893_Arg : TypeAlias = Raw
class Variation_893(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'TCAS II or ACAS RA not active',
        1: 'TCAS RA active',
    }

    def __init__(self, arg : Variation_893_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_894_Arg : TypeAlias = Raw
class Variation_894(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'No capability for Trajectory Change Reports',
        1: 'Support for TC+0 reports only',
        2: 'Support for multiple TC reports',
        3: 'Reserved',
    }

    def __init__(self, arg : Variation_894_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_895_Arg : TypeAlias = Raw
class Variation_895(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'No capability to support Target State Reports',
        1: 'Capable of supporting target State Reports',
    }

    def __init__(self, arg : Variation_895_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_896_Arg : TypeAlias = Raw
class Variation_896(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'No capability to generate ARV-reports',
        1: 'Capable of generate ARV-reports',
    }

    def __init__(self, arg : Variation_896_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_897_Arg : TypeAlias = Raw
class Variation_897(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'CDTI not operational',
        1: 'CDTI operational',
    }

    def __init__(self, arg : Variation_897_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_898_Arg : TypeAlias = Raw
class Variation_898(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'TCAS operational',
        1: 'TCAS not operational',
    }

    def __init__(self, arg : Variation_898_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_899_Arg : TypeAlias = Raw
class Variation_899(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'Antenna Diversity',
        1: 'Single Antenna only',
    }

    def __init__(self, arg : Variation_899_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_900_Arg_Group = TypedDict('Variation_900_Arg_Group', {
    'RA': Union[Variation_893, Variation_893_Arg],
    'TC': Union[Variation_894, Variation_894_Arg],
    'TS': Union[Variation_895, Variation_895_Arg],
    'ARV': Union[Variation_896, Variation_896_Arg],
    'CDTIA': Union[Variation_897, Variation_897_Arg],
    'NOTTCAS': Union[Variation_898, Variation_898_Arg],
    'SA': Union[Variation_899, Variation_899_Arg],
})
Variation_900_Arg : TypeAlias = Union[Raw, Variation_900_Arg_Group]
class Variation_900(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('RA', Variation_893),
        ('TC', Variation_894),
        ('TS', Variation_895),
        ('ARV', Variation_896),
        ('CDTIA', Variation_897),
        ('NOTTCAS', Variation_898),
        ('SA', Variation_899),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RA': ('TCAS Resolution Advisory Active', Variation_893, 0, 1),
        'TC': ('Target Trajectory Change Report Capability', Variation_894, 1, 2),
        'TS': ('Target State Report Capability', Variation_895, 3, 1),
        'ARV': ('Air-Referenced Velocity Report Capability', Variation_896, 4, 1),
        'CDTIA': ('Cockpit Display of Traffic Information Airborne', Variation_897, 5, 1),
        'NOTTCAS': ('TCAS System Status', Variation_898, 6, 1),
        'SA': ('Single Antenna', Variation_899, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RA']) -> Type[Variation_893]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TC']) -> Type[Variation_894]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TS']) -> Type[Variation_895]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARV']) -> Type[Variation_896]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CDTIA']) -> Type[Variation_897]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOTTCAS']) -> Type[Variation_898]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SA']) -> Type[Variation_899]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RA'], Literal['TC'], Literal['TS'], Literal['ARV'], Literal['CDTIA'], Literal['NOTTCAS'], Literal['SA']]) -> Union[Type['Variation_893'], Type['Variation_894'], Type['Variation_895'], Type['Variation_896'], Type['Variation_897'], Type['Variation_898'], Type['Variation_899']]:
        if key == 'RA':
            return Variation_893
        if key == 'TC':
            return Variation_894
        if key == 'TS':
            return Variation_895
        if key == 'ARV':
            return Variation_896
        if key == 'CDTIA':
            return Variation_897
        if key == 'NOTTCAS':
            return Variation_898
        if key == 'SA':
            return Variation_899
        assert_never(key)

    def __init__(self, arg : Variation_900_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RA']) -> Variation_893:
        ...

    @overload
    def get_item(self, name : Literal['TC']) -> Variation_894:
        ...

    @overload
    def get_item(self, name : Literal['TS']) -> Variation_895:
        ...

    @overload
    def get_item(self, name : Literal['ARV']) -> Variation_896:
        ...

    @overload
    def get_item(self, name : Literal['CDTIA']) -> Variation_897:
        ...

    @overload
    def get_item(self, name : Literal['NOTTCAS']) -> Variation_898:
        ...

    @overload
    def get_item(self, name : Literal['SA']) -> Variation_899:
        ...

    def get_item(self, name : Union[Literal['RA'], Literal['TC'], Literal['TS'], Literal['ARV'], Literal['CDTIA'], Literal['NOTTCAS'], Literal['SA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RA'], val : Union[Variation_893, Variation_893_Arg]) -> 'Variation_900':
        ...

    @overload
    def set_item(self, name : Literal['TC'], val : Union[Variation_894, Variation_894_Arg]) -> 'Variation_900':
        ...

    @overload
    def set_item(self, name : Literal['TS'], val : Union[Variation_895, Variation_895_Arg]) -> 'Variation_900':
        ...

    @overload
    def set_item(self, name : Literal['ARV'], val : Union[Variation_896, Variation_896_Arg]) -> 'Variation_900':
        ...

    @overload
    def set_item(self, name : Literal['CDTIA'], val : Union[Variation_897, Variation_897_Arg]) -> 'Variation_900':
        ...

    @overload
    def set_item(self, name : Literal['NOTTCAS'], val : Union[Variation_898, Variation_898_Arg]) -> 'Variation_900':
        ...

    @overload
    def set_item(self, name : Literal['SA'], val : Union[Variation_899, Variation_899_Arg]) -> 'Variation_900':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RA'], f : Any) -> 'Variation_900':
        ...

    @overload
    def modify_item(self, name : Literal['TC'], f : Any) -> 'Variation_900':
        ...

    @overload
    def modify_item(self, name : Literal['TS'], f : Any) -> 'Variation_900':
        ...

    @overload
    def modify_item(self, name : Literal['ARV'], f : Any) -> 'Variation_900':
        ...

    @overload
    def modify_item(self, name : Literal['CDTIA'], f : Any) -> 'Variation_900':
        ...

    @overload
    def modify_item(self, name : Literal['NOTTCAS'], f : Any) -> 'Variation_900':
        ...

    @overload
    def modify_item(self, name : Literal['SA'], f : Any) -> 'Variation_900':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_901_Arg : TypeAlias = Raw
class Variation_901(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Position transmitted is not ADS-B position reference point',
        1: 'Position transmitted is the ADS-B position reference point',
    }

    def __init__(self, arg : Variation_901_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_902_Arg : TypeAlias = Raw
class Variation_902(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'CDTI not operational',
        1: 'CDTI operational',
    }

    def __init__(self, arg : Variation_902_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_903_Arg : TypeAlias = Raw
class Variation_903(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: '>= 70 Watts',
        1: '< 70 Watts',
    }

    def __init__(self, arg : Variation_903_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_904_Arg : TypeAlias = Raw
class Variation_904(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Aircraft not receiving ATC-services',
        1: 'Aircraft receiving ATC services',
    }

    def __init__(self, arg : Variation_904_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_905_Arg : TypeAlias = Raw
class Variation_905(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'IDENT switch not active',
        1: 'IDENT switch active',
    }

    def __init__(self, arg : Variation_905_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_906_Arg_Group_1 = TypedDict('Variation_906_Arg_Group_1', {
    'POA': Union[Variation_901, Variation_901_Arg],
    'CDTIS': Union[Variation_902, Variation_902_Arg],
    'B2LOW': Union[Variation_903, Variation_903_Arg],
    'RAS': Union[Variation_904, Variation_904_Arg],
    'IDENT': Union[Variation_905, Variation_905_Arg],
})
Variation_906_Arg_Group_2 = TypedDict('Variation_906_Arg_Group_2', {
    'POA': Union[Variation_901, Variation_901_Arg],
    'CDTIS': Union[Variation_902, Variation_902_Arg],
    'B2LOW': Union[Variation_903, Variation_903_Arg],
    'RAS': Union[Variation_904, Variation_904_Arg],
    'IDENT': Union[Variation_905, Variation_905_Arg],
    'LW': Union[Variation_282, Variation_282_Arg],
})
Variation_906_Arg : TypeAlias = Union[
    int,
    Variation_906_Arg_Group_1,
    Tuple[int],
    Variation_906_Arg_Group_2,
    Tuple[int,int],
]
class Variation_906(Extended):
    variation = 'Extended'

    no_trailing_fx = True
    groups_bit_sizes = [
        7,
        8,
    ]

    subitems_list = [
        [
            Spare(0, 2),
            ('POA', Variation_901),
            ('CDTIS', Variation_902),
            ('B2LOW', Variation_903),
            ('RAS', Variation_904),
            ('IDENT', Variation_905),
        ],
        [
            Spare(0, 4),
            ('LW', Variation_282),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'POA': ('Position Offset Applied', Variation_901, 2, 1),
        'CDTIS': ('Cockpit Display of Traffic Information Surface', Variation_902, 3, 1),
        'B2LOW': ('Class B2 Transmit Power Less Than 70 Watts', Variation_903, 4, 1),
        'RAS': ('Receiving ATC Services', Variation_904, 5, 1),
        'IDENT': ('Setting of IDENT Switch', Variation_905, 6, 1),
        'LW': ('Length and Width of the Aircraft', Variation_282, 4, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['POA']) -> Type[Variation_901]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CDTIS']) -> Type[Variation_902]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B2LOW']) -> Type[Variation_903]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAS']) -> Type[Variation_904]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IDENT']) -> Type[Variation_905]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LW']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['POA'], Literal['CDTIS'], Literal['B2LOW'], Literal['RAS'], Literal['IDENT'], Literal['LW']]) -> Union[Type['Variation_901'], Type['Variation_902'], Type['Variation_903'], Type['Variation_904'], Type['Variation_905'], Type['Variation_282']]:
        if key == 'POA':
            return Variation_901
        if key == 'CDTIS':
            return Variation_902
        if key == 'B2LOW':
            return Variation_903
        if key == 'RAS':
            return Variation_904
        if key == 'IDENT':
            return Variation_905
        if key == 'LW':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_906_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_906_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_906_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['POA']) -> Variation_901:
        ...

    @overload
    def get_item(self, name : Literal['CDTIS']) -> Variation_902:
        ...

    @overload
    def get_item(self, name : Literal['B2LOW']) -> Variation_903:
        ...

    @overload
    def get_item(self, name : Literal['RAS']) -> Variation_904:
        ...

    @overload
    def get_item(self, name : Literal['IDENT']) -> Variation_905:
        ...

    @overload
    def get_item(self, name : Literal['LW']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['POA'], Literal['CDTIS'], Literal['B2LOW'], Literal['RAS'], Literal['IDENT'], Literal['LW']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['POA'], val : Union[Variation_901, Variation_901_Arg]) -> 'Variation_906':
        ...

    @overload
    def set_item(self, name : Literal['CDTIS'], val : Union[Variation_902, Variation_902_Arg]) -> 'Variation_906':
        ...

    @overload
    def set_item(self, name : Literal['B2LOW'], val : Union[Variation_903, Variation_903_Arg]) -> 'Variation_906':
        ...

    @overload
    def set_item(self, name : Literal['RAS'], val : Union[Variation_904, Variation_904_Arg]) -> 'Variation_906':
        ...

    @overload
    def set_item(self, name : Literal['IDENT'], val : Union[Variation_905, Variation_905_Arg]) -> 'Variation_906':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['POA'], f : Any) -> 'Variation_906':
        ...

    @overload
    def modify_item(self, name : Literal['CDTIS'], f : Any) -> 'Variation_906':
        ...

    @overload
    def modify_item(self, name : Literal['B2LOW'], f : Any) -> 'Variation_906':
        ...

    @overload
    def modify_item(self, name : Literal['RAS'], f : Any) -> 'Variation_906':
        ...

    @overload
    def modify_item(self, name : Literal['IDENT'], f : Any) -> 'Variation_906':
        ...

    @overload
    def modify_item(self, name : Literal['LW'], f : Any) -> 'Variation_906':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_907_Arg : TypeAlias = Raw
class Variation_907(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 14

    def __init__(self, arg : Variation_907_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_908_Arg : TypeAlias = Raw
class Variation_908(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 4

    def __init__(self, arg : Variation_908_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_909_Arg : TypeAlias = Raw
class Variation_909(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1

    def __init__(self, arg : Variation_909_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_910_Arg : TypeAlias = Raw
class Variation_910(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2

    def __init__(self, arg : Variation_910_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_911_Arg : TypeAlias = Raw
class Variation_911(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 26

    def __init__(self, arg : Variation_911_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_912_Arg_Group = TypedDict('Variation_912_Arg_Group', {
    'TYP': Union[Variation_222, Variation_222_Arg],
    'STYP': Union[Variation_223, Variation_223_Arg],
    'ARA': Union[Variation_907, Variation_907_Arg],
    'RAC': Union[Variation_908, Variation_908_Arg],
    'RAT': Union[Variation_909, Variation_909_Arg],
    'MTE': Union[Variation_237, Variation_237_Arg],
    'TTI': Union[Variation_910, Variation_910_Arg],
    'TID': Union[Variation_911, Variation_911_Arg],
})
Variation_912_Arg : TypeAlias = Union[Raw, Variation_912_Arg_Group]
class Variation_912(Group):
    variation = 'Group'

    bit_size = 56

    subitems_list = [
        ('TYP', Variation_222),
        ('STYP', Variation_223),
        ('ARA', Variation_907),
        ('RAC', Variation_908),
        ('RAT', Variation_909),
        ('MTE', Variation_237),
        ('TTI', Variation_910),
        ('TID', Variation_911),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('Message Type (= 28 for 1090 ES, Version 2)', Variation_222, 0, 5),
        'STYP': ('Message Sub-type (= 2 for 1090 ES, Version 2)', Variation_223, 5, 3),
        'ARA': ('Active Resolution Advisories', Variation_907, 8, 14),
        'RAC': ('RAC (RA Complement) Record', Variation_908, 22, 4),
        'RAT': ('RA Terminated', Variation_909, 26, 1),
        'MTE': ('Multiple Threat Encounter', Variation_237, 27, 1),
        'TTI': ('Threat Type Indicator', Variation_910, 28, 2),
        'TID': ('Threat Identity Data', Variation_911, 30, 26),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_222]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STYP']) -> Type[Variation_223]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARA']) -> Type[Variation_907]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAC']) -> Type[Variation_908]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAT']) -> Type[Variation_909]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MTE']) -> Type[Variation_237]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TTI']) -> Type[Variation_910]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_911]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['STYP'], Literal['ARA'], Literal['RAC'], Literal['RAT'], Literal['MTE'], Literal['TTI'], Literal['TID']]) -> Union[Type['Variation_222'], Type['Variation_223'], Type['Variation_907'], Type['Variation_908'], Type['Variation_909'], Type['Variation_237'], Type['Variation_910'], Type['Variation_911']]:
        if key == 'TYP':
            return Variation_222
        if key == 'STYP':
            return Variation_223
        if key == 'ARA':
            return Variation_907
        if key == 'RAC':
            return Variation_908
        if key == 'RAT':
            return Variation_909
        if key == 'MTE':
            return Variation_237
        if key == 'TTI':
            return Variation_910
        if key == 'TID':
            return Variation_911
        assert_never(key)

    def __init__(self, arg : Variation_912_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_222:
        ...

    @overload
    def get_item(self, name : Literal['STYP']) -> Variation_223:
        ...

    @overload
    def get_item(self, name : Literal['ARA']) -> Variation_907:
        ...

    @overload
    def get_item(self, name : Literal['RAC']) -> Variation_908:
        ...

    @overload
    def get_item(self, name : Literal['RAT']) -> Variation_909:
        ...

    @overload
    def get_item(self, name : Literal['MTE']) -> Variation_237:
        ...

    @overload
    def get_item(self, name : Literal['TTI']) -> Variation_910:
        ...

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_911:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['STYP'], Literal['ARA'], Literal['RAC'], Literal['RAT'], Literal['MTE'], Literal['TTI'], Literal['TID']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_222, Variation_222_Arg]) -> 'Variation_912':
        ...

    @overload
    def set_item(self, name : Literal['STYP'], val : Union[Variation_223, Variation_223_Arg]) -> 'Variation_912':
        ...

    @overload
    def set_item(self, name : Literal['ARA'], val : Union[Variation_907, Variation_907_Arg]) -> 'Variation_912':
        ...

    @overload
    def set_item(self, name : Literal['RAC'], val : Union[Variation_908, Variation_908_Arg]) -> 'Variation_912':
        ...

    @overload
    def set_item(self, name : Literal['RAT'], val : Union[Variation_909, Variation_909_Arg]) -> 'Variation_912':
        ...

    @overload
    def set_item(self, name : Literal['MTE'], val : Union[Variation_237, Variation_237_Arg]) -> 'Variation_912':
        ...

    @overload
    def set_item(self, name : Literal['TTI'], val : Union[Variation_910, Variation_910_Arg]) -> 'Variation_912':
        ...

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_911, Variation_911_Arg]) -> 'Variation_912':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_912':
        ...

    @overload
    def modify_item(self, name : Literal['STYP'], f : Any) -> 'Variation_912':
        ...

    @overload
    def modify_item(self, name : Literal['ARA'], f : Any) -> 'Variation_912':
        ...

    @overload
    def modify_item(self, name : Literal['RAC'], f : Any) -> 'Variation_912':
        ...

    @overload
    def modify_item(self, name : Literal['RAT'], f : Any) -> 'Variation_912':
        ...

    @overload
    def modify_item(self, name : Literal['MTE'], f : Any) -> 'Variation_912':
        ...

    @overload
    def modify_item(self, name : Literal['TTI'], f : Any) -> 'Variation_912':
        ...

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_912':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_913_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_913(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 0.1, 's')

    def __init__(self, arg : Variation_913_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_914_Arg = TypedDict('Variation_914_Arg', {
    'AOS': Union[Variation_913, Variation_913_Arg],
    'TRD': Union[Variation_913, Variation_913_Arg],
    'M3A': Union[Variation_913, Variation_913_Arg],
    'QI': Union[Variation_913, Variation_913_Arg],
    'TI1': Union[Variation_913, Variation_913_Arg],
    'MAM': Union[Variation_913, Variation_913_Arg],
    'GH': Union[Variation_913, Variation_913_Arg],
    'FL': Union[Variation_913, Variation_913_Arg],
    'ISA': Union[Variation_913, Variation_913_Arg],
    'FSA': Union[Variation_913, Variation_913_Arg],
    'AS': Union[Variation_913, Variation_913_Arg],
    'TAS': Union[Variation_913, Variation_913_Arg],
    'MH': Union[Variation_913, Variation_913_Arg],
    'BVR': Union[Variation_913, Variation_913_Arg],
    'GVR': Union[Variation_913, Variation_913_Arg],
    'GV': Union[Variation_913, Variation_913_Arg],
    'TAR': Union[Variation_913, Variation_913_Arg],
    'TI2': Union[Variation_913, Variation_913_Arg],
    'TS': Union[Variation_913, Variation_913_Arg],
    'MET': Union[Variation_913, Variation_913_Arg],
    'ROA': Union[Variation_913, Variation_913_Arg],
    'ARA': Union[Variation_913, Variation_913_Arg],
    'SCC': Union[Variation_913, Variation_913_Arg],
}, total=False)
class Variation_914(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('AOS', Variation_913),
        ('TRD', Variation_913),
        ('M3A', Variation_913),
        ('QI', Variation_913),
        ('TI1', Variation_913),
        ('MAM', Variation_913),
        ('GH', Variation_913),
        ('FL', Variation_913),
        ('ISA', Variation_913),
        ('FSA', Variation_913),
        ('AS', Variation_913),
        ('TAS', Variation_913),
        ('MH', Variation_913),
        ('BVR', Variation_913),
        ('GVR', Variation_913),
        ('GV', Variation_913),
        ('TAR', Variation_913),
        ('TI2', Variation_913),
        ('TS', Variation_913),
        ('MET', Variation_913),
        ('ROA', Variation_913),
        ('ARA', Variation_913),
        ('SCC', Variation_913),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'AOS': ('Aircraft Operational Status Age', Variation_913, 0x80000000),
        'TRD': ('Target Report Descriptor Age', Variation_913, 0x40000000),
        'M3A': ('Mode 3/A Age', Variation_913, 0x20000000),
        'QI': ('Quality Indicators Age', Variation_913, 0x10000000),
        'TI1': ('Trajectory Intent Age', Variation_913, 0x08000000),
        'MAM': ('Message Amplitude Age', Variation_913, 0x04000000),
        'GH': ('Geometric Height Age', Variation_913, 0x02000000),
        'FL': ('Flight Level Age', Variation_913, 0x01800000),
        'ISA': ('Intermediate State Selected Altitude Age', Variation_913, 0x01400000),
        'FSA': ('Final State Selected Altitude Age', Variation_913, 0x01200000),
        'AS': ('Air Speed Age', Variation_913, 0x01100000),
        'TAS': ('True Air Speed Age', Variation_913, 0x01080000),
        'MH': ('Magnetic Heading Age', Variation_913, 0x01040000),
        'BVR': ('Barometric Vertical Rate Age', Variation_913, 0x01020000),
        'GVR': ('Geometric Vertical Rate Age', Variation_913, 0x01018000),
        'GV': ('Ground Vector Age', Variation_913, 0x01014000),
        'TAR': ('Track Angle Rate Age', Variation_913, 0x01012000),
        'TI2': ('Target Identification Age', Variation_913, 0x01011000),
        'TS': ('Target Status Age', Variation_913, 0x01010800),
        'MET': ('Met Information Age', Variation_913, 0x01010400),
        'ROA': ('Roll Angle Age', Variation_913, 0x01010200),
        'ARA': ('ACAS Resolution Advisory Age', Variation_913, 0x01010180),
        'SCC': ('Surface Capabilities and Characteristics Age', Variation_913, 0x01010140),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AOS']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRD']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M3A']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QI']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TI1']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAM']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GH']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FL']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ISA']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FSA']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AS']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAS']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MH']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BVR']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GVR']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GV']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAR']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TI2']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TS']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MET']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ROA']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARA']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SCC']) -> Type[Variation_913]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AOS'], Literal['TRD'], Literal['M3A'], Literal['QI'], Literal['TI1'], Literal['MAM'], Literal['GH'], Literal['FL'], Literal['ISA'], Literal['FSA'], Literal['AS'], Literal['TAS'], Literal['MH'], Literal['BVR'], Literal['GVR'], Literal['GV'], Literal['TAR'], Literal['TI2'], Literal['TS'], Literal['MET'], Literal['ROA'], Literal['ARA'], Literal['SCC']]) -> Union[Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913']]:
        if key == 'AOS':
            return Variation_913
        if key == 'TRD':
            return Variation_913
        if key == 'M3A':
            return Variation_913
        if key == 'QI':
            return Variation_913
        if key == 'TI1':
            return Variation_913
        if key == 'MAM':
            return Variation_913
        if key == 'GH':
            return Variation_913
        if key == 'FL':
            return Variation_913
        if key == 'ISA':
            return Variation_913
        if key == 'FSA':
            return Variation_913
        if key == 'AS':
            return Variation_913
        if key == 'TAS':
            return Variation_913
        if key == 'MH':
            return Variation_913
        if key == 'BVR':
            return Variation_913
        if key == 'GVR':
            return Variation_913
        if key == 'GV':
            return Variation_913
        if key == 'TAR':
            return Variation_913
        if key == 'TI2':
            return Variation_913
        if key == 'TS':
            return Variation_913
        if key == 'MET':
            return Variation_913
        if key == 'ROA':
            return Variation_913
        if key == 'ARA':
            return Variation_913
        if key == 'SCC':
            return Variation_913
        assert_never(key)

    def __init__(self, arg : Optional[Variation_914_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['AOS'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['TRD'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['M3A'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['QI'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['TI1'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['MAM'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['GH'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['FL'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['ISA'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['FSA'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['AS'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['TAS'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['MH'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['BVR'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['GVR'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['GV'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['TAR'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['TI2'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['TS'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['MET'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['ROA'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['ARA'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    @overload
    def set_item(self, name : Literal['SCC'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_914':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['AOS']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['TRD']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['M3A']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['QI']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['TI1']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['MAM']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['GH']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['FL']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['ISA']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['FSA']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['AS']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['TAS']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['MH']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['BVR']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['GVR']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['GV']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['TAR']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['TI2']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['TS']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['MET']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['ROA']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['ARA']) -> 'Variation_914':
        ...

    @overload
    def del_item(self, name : Literal['SCC']) -> 'Variation_914':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['AOS']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TRD']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['M3A']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['QI']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TI1']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['MAM']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['GH']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['FL']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['ISA']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['FSA']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['AS']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TAS']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['MH']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['BVR']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['GVR']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['GV']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TAR']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TI2']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TS']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['MET']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['ROA']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['ARA']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['SCC']) -> Variation_913:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['AOS'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['TRD'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['M3A'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['QI'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['TI1'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['MAM'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['GH'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['FL'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['ISA'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['FSA'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['AS'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['TAS'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['MH'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['BVR'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['GVR'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['GV'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['TAR'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['TI2'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['TS'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['MET'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['ROA'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['ARA'], f : Any) -> 'Variation_914':
        ...

    @overload
    def modify_item(self, name : Literal['SCC'], f : Any) -> 'Variation_914':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_915_Arg = TypedDict('Variation_915_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '040': Union[Variation_851, Variation_851_Arg],
    '161': Union[Variation_852, Variation_852_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '071': Union[Variation_80, Variation_80_Arg],
    '130': Union[Variation_705, Variation_705_Arg],
    '131': Union[Variation_632, Variation_632_Arg],
    '072': Union[Variation_80, Variation_80_Arg],
    '150': Union[Variation_719, Variation_719_Arg],
    '151': Union[Variation_855, Variation_855_Arg],
    '080': Union[Variation_278, Variation_278_Arg],
    '073': Union[Variation_80, Variation_80_Arg],
    '074': Union[Variation_858, Variation_858_Arg],
    '075': Union[Variation_80, Variation_80_Arg],
    '076': Union[Variation_860, Variation_860_Arg],
    '140': Union[Variation_287, Variation_287_Arg],
    '090': Union[Variation_868, Variation_868_Arg],
    '210': Union[Variation_872, Variation_872_Arg],
    '070': Union[Variation_873, Variation_873_Arg],
    '230': Union[Variation_717, Variation_717_Arg],
    '145': Union[Variation_360, Variation_360_Arg],
    '152': Union[Variation_14, Variation_14_Arg],
    '200': Union[Variation_878, Variation_878_Arg],
    '155': Union[Variation_880, Variation_880_Arg],
    '157': Union[Variation_881, Variation_881_Arg],
    '160': Union[Variation_883, Variation_883_Arg],
    '165': Union[Variation_885, Variation_885_Arg],
    '077': Union[Variation_80, Variation_80_Arg],
    '170': Union[Variation_196, Variation_196_Arg],
    '020': Union[Variation_886, Variation_886_Arg],
    '220': Union[Variation_731, Variation_731_Arg],
    '146': Union[Variation_887, Variation_887_Arg],
    '148': Union[Variation_891, Variation_891_Arg],
    '110': Union[Variation_754, Variation_754_Arg],
    '016': Union[Variation_892, Variation_892_Arg],
    '008': Union[Variation_900, Variation_900_Arg],
    '271': Union[Variation_906, Variation_906_Arg],
    '132': Union[Variation_29, Variation_29_Arg],
    '250': Union[Variation_321, Variation_321_Arg],
    '260': Union[Variation_912, Variation_912_Arg],
    '400': Union[Variation_0, Variation_0_Arg],
    '295': Union[Variation_914, Variation_914_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_915(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 7

    subitems_list = [
        ('010', Variation_1),
        ('040', Variation_851),
        ('161', Variation_852),
        ('015', Variation_0),
        ('071', Variation_80),
        ('130', Variation_705),
        ('131', Variation_632),
        ('072', Variation_80),
        ('150', Variation_719),
        ('151', Variation_855),
        ('080', Variation_278),
        ('073', Variation_80),
        ('074', Variation_858),
        ('075', Variation_80),
        ('076', Variation_860),
        ('140', Variation_287),
        ('090', Variation_868),
        ('210', Variation_872),
        ('070', Variation_873),
        ('230', Variation_717),
        ('145', Variation_360),
        ('152', Variation_14),
        ('200', Variation_878),
        ('155', Variation_880),
        ('157', Variation_881),
        ('160', Variation_883),
        ('165', Variation_885),
        ('077', Variation_80),
        ('170', Variation_196),
        ('020', Variation_886),
        ('220', Variation_731),
        ('146', Variation_887),
        ('148', Variation_891),
        ('110', Variation_754),
        ('016', Variation_892),
        ('008', Variation_900),
        ('271', Variation_906),
        ('132', Variation_29),
        ('250', Variation_321),
        ('260', Variation_912),
        ('400', Variation_0),
        ('295', Variation_914),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identification', Variation_1, 0x80000000000000),
        '040': ('Target Report Descriptor', Variation_851, 0x40000000000000),
        '161': ('Track Number', Variation_852, 0x20000000000000),
        '015': ('Service Identification', Variation_0, 0x10000000000000),
        '071': ('Time of Applicability for Position', Variation_80, 0x08000000000000),
        '130': ('Position in WGS-84 Co-ordinates', Variation_705, 0x04000000000000),
        '131': ('High-Resolution Position in WGS-84 Co-ordinates', Variation_632, 0x02000000000000),
        '072': ('Time of Applicability for Velocity', Variation_80, 0x01800000000000),
        '150': ('Air Speed', Variation_719, 0x01400000000000),
        '151': ('True Airspeed', Variation_855, 0x01200000000000),
        '080': ('Target Address', Variation_278, 0x01100000000000),
        '073': ('Time of Message Reception for Position', Variation_80, 0x01080000000000),
        '074': ('Time of Message Reception of Position-High Precision', Variation_858, 0x01040000000000),
        '075': ('Time of Message Reception for Velocity', Variation_80, 0x01020000000000),
        '076': ('Time of Message Reception of Velocity-High Precision', Variation_860, 0x01018000000000),
        '140': ('Geometric Height', Variation_287, 0x01014000000000),
        '090': ('Quality Indicators', Variation_868, 0x01012000000000),
        '210': ('MOPS Version', Variation_872, 0x01011000000000),
        '070': ('Mode 3/A Code in Octal Representation', Variation_873, 0x01010800000000),
        '230': ('Roll Angle', Variation_717, 0x01010400000000),
        '145': ('Flight Level', Variation_360, 0x01010200000000),
        '152': ('Magnetic Heading', Variation_14, 0x01010180000000),
        '200': ('Target Status', Variation_878, 0x01010140000000),
        '155': ('Barometric Vertical Rate', Variation_880, 0x01010120000000),
        '157': ('Geometric Vertical Rate', Variation_881, 0x01010110000000),
        '160': ('Airborne Ground Vector', Variation_883, 0x01010108000000),
        '165': ('Track Angle Rate', Variation_885, 0x01010104000000),
        '077': ('Time of ASTERIX Report Transmission', Variation_80, 0x01010102000000),
        '170': ('Target Identification', Variation_196, 0x01010101800000),
        '020': ('Emitter Category', Variation_886, 0x01010101400000),
        '220': ('Met Information', Variation_731, 0x01010101200000),
        '146': ('Selected Altitude', Variation_887, 0x01010101100000),
        '148': ('Final State Selected Altitude', Variation_891, 0x01010101080000),
        '110': ('Trajectory Intent', Variation_754, 0x01010101040000),
        '016': ('Service Management', Variation_892, 0x01010101020000),
        '008': ('Aircraft Operational Status', Variation_900, 0x01010101018000),
        '271': ('Surface Capabilities and Characteristics', Variation_906, 0x01010101014000),
        '132': ('Message Amplitude', Variation_29, 0x01010101012000),
        '250': ('Mode S MB Data', Variation_321, 0x01010101011000),
        '260': ('ACAS Resolution Advisory Report', Variation_912, 0x01010101010800),
        '400': ('Receiver ID', Variation_0, 0x01010101010400),
        '295': ('Data Ages', Variation_914, 0x01010101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x01010101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_851]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_852]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['071']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_705]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['131']) -> Type[Variation_632]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['072']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_719]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['151']) -> Type[Variation_855]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['073']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['074']) -> Type[Variation_858]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['075']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['076']) -> Type[Variation_860]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_868]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_872]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_873]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['145']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['152']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_878]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['155']) -> Type[Variation_880]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['157']) -> Type[Variation_881]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['160']) -> Type[Variation_883]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['165']) -> Type[Variation_885]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['077']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_886]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_731]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['146']) -> Type[Variation_887]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['148']) -> Type[Variation_891]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_754]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['016']) -> Type[Variation_892]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['008']) -> Type[Variation_900]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['271']) -> Type[Variation_906]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['132']) -> Type[Variation_29]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_912]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['295']) -> Type[Variation_914]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['040'], Literal['161'], Literal['015'], Literal['071'], Literal['130'], Literal['131'], Literal['072'], Literal['150'], Literal['151'], Literal['080'], Literal['073'], Literal['074'], Literal['075'], Literal['076'], Literal['140'], Literal['090'], Literal['210'], Literal['070'], Literal['230'], Literal['145'], Literal['152'], Literal['200'], Literal['155'], Literal['157'], Literal['160'], Literal['165'], Literal['077'], Literal['170'], Literal['020'], Literal['220'], Literal['146'], Literal['148'], Literal['110'], Literal['016'], Literal['008'], Literal['271'], Literal['132'], Literal['250'], Literal['260'], Literal['400'], Literal['295'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_851'], Type['Variation_852'], Type['Variation_0'], Type['Variation_80'], Type['Variation_705'], Type['Variation_632'], Type['Variation_80'], Type['Variation_719'], Type['Variation_855'], Type['Variation_278'], Type['Variation_80'], Type['Variation_858'], Type['Variation_80'], Type['Variation_860'], Type['Variation_287'], Type['Variation_868'], Type['Variation_872'], Type['Variation_873'], Type['Variation_717'], Type['Variation_360'], Type['Variation_14'], Type['Variation_878'], Type['Variation_880'], Type['Variation_881'], Type['Variation_883'], Type['Variation_885'], Type['Variation_80'], Type['Variation_196'], Type['Variation_886'], Type['Variation_731'], Type['Variation_887'], Type['Variation_891'], Type['Variation_754'], Type['Variation_892'], Type['Variation_900'], Type['Variation_906'], Type['Variation_29'], Type['Variation_321'], Type['Variation_912'], Type['Variation_0'], Type['Variation_914'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '040':
            return Variation_851
        if key == '161':
            return Variation_852
        if key == '015':
            return Variation_0
        if key == '071':
            return Variation_80
        if key == '130':
            return Variation_705
        if key == '131':
            return Variation_632
        if key == '072':
            return Variation_80
        if key == '150':
            return Variation_719
        if key == '151':
            return Variation_855
        if key == '080':
            return Variation_278
        if key == '073':
            return Variation_80
        if key == '074':
            return Variation_858
        if key == '075':
            return Variation_80
        if key == '076':
            return Variation_860
        if key == '140':
            return Variation_287
        if key == '090':
            return Variation_868
        if key == '210':
            return Variation_872
        if key == '070':
            return Variation_873
        if key == '230':
            return Variation_717
        if key == '145':
            return Variation_360
        if key == '152':
            return Variation_14
        if key == '200':
            return Variation_878
        if key == '155':
            return Variation_880
        if key == '157':
            return Variation_881
        if key == '160':
            return Variation_883
        if key == '165':
            return Variation_885
        if key == '077':
            return Variation_80
        if key == '170':
            return Variation_196
        if key == '020':
            return Variation_886
        if key == '220':
            return Variation_731
        if key == '146':
            return Variation_887
        if key == '148':
            return Variation_891
        if key == '110':
            return Variation_754
        if key == '016':
            return Variation_892
        if key == '008':
            return Variation_900
        if key == '271':
            return Variation_906
        if key == '132':
            return Variation_29
        if key == '250':
            return Variation_321
        if key == '260':
            return Variation_912
        if key == '400':
            return Variation_0
        if key == '295':
            return Variation_914
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_915_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_851, Variation_851_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_852, Variation_852_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['071'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_705, Variation_705_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['131'], val : Union[Variation_632, Variation_632_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['072'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_719, Variation_719_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['151'], val : Union[Variation_855, Variation_855_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['073'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['074'], val : Union[Variation_858, Variation_858_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['075'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['076'], val : Union[Variation_860, Variation_860_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_868, Variation_868_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_872, Variation_872_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_873, Variation_873_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['145'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['152'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_878, Variation_878_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['155'], val : Union[Variation_880, Variation_880_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['157'], val : Union[Variation_881, Variation_881_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['160'], val : Union[Variation_883, Variation_883_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['165'], val : Union[Variation_885, Variation_885_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['077'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_886, Variation_886_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_731, Variation_731_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['146'], val : Union[Variation_887, Variation_887_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['148'], val : Union[Variation_891, Variation_891_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_754, Variation_754_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['016'], val : Union[Variation_892, Variation_892_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['008'], val : Union[Variation_900, Variation_900_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['271'], val : Union[Variation_906, Variation_906_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['132'], val : Union[Variation_29, Variation_29_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_912, Variation_912_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['295'], val : Union[Variation_914, Variation_914_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_915':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_915':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['071']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['131']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['072']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['151']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['073']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['074']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['075']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['076']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['145']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['152']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['155']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['157']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['160']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['165']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['077']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['146']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['148']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['016']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['008']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['271']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['132']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['295']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_915':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_915':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_851:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_852:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['071']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_705:
        ...

    @overload
    def get_item(self, name : Literal['131']) -> Variation_632:
        ...

    @overload
    def get_item(self, name : Literal['072']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_719:
        ...

    @overload
    def get_item(self, name : Literal['151']) -> Variation_855:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['073']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['074']) -> Variation_858:
        ...

    @overload
    def get_item(self, name : Literal['075']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['076']) -> Variation_860:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_868:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_872:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_873:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['145']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['152']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_878:
        ...

    @overload
    def get_item(self, name : Literal['155']) -> Variation_880:
        ...

    @overload
    def get_item(self, name : Literal['157']) -> Variation_881:
        ...

    @overload
    def get_item(self, name : Literal['160']) -> Variation_883:
        ...

    @overload
    def get_item(self, name : Literal['165']) -> Variation_885:
        ...

    @overload
    def get_item(self, name : Literal['077']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_886:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_731:
        ...

    @overload
    def get_item(self, name : Literal['146']) -> Variation_887:
        ...

    @overload
    def get_item(self, name : Literal['148']) -> Variation_891:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_754:
        ...

    @overload
    def get_item(self, name : Literal['016']) -> Variation_892:
        ...

    @overload
    def get_item(self, name : Literal['008']) -> Variation_900:
        ...

    @overload
    def get_item(self, name : Literal['271']) -> Variation_906:
        ...

    @overload
    def get_item(self, name : Literal['132']) -> Variation_29:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_912:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['295']) -> Variation_914:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['071'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['131'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['072'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['151'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['073'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['074'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['075'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['076'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['145'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['152'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['155'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['157'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['160'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['165'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['077'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['146'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['148'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['016'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['008'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['271'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['132'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['295'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_915':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_915':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_916_Arg : TypeAlias = Raw
class Variation_916(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'No military emergency',
        1: 'Military emergency',
    }

    def __init__(self, arg : Variation_916_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_917_Arg_Group = TypedDict('Variation_917_Arg_Group', {
    'ICF': Union[Variation_874, Variation_874_Arg],
    'LNAV': Union[Variation_875, Variation_875_Arg],
    'ME': Union[Variation_916, Variation_916_Arg],
    'PS': Union[Variation_876, Variation_876_Arg],
    'SS': Union[Variation_877, Variation_877_Arg],
})
Variation_917_Arg : TypeAlias = Union[Raw, Variation_917_Arg_Group]
class Variation_917(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('ICF', Variation_874),
        ('LNAV', Variation_875),
        ('ME', Variation_916),
        ('PS', Variation_876),
        ('SS', Variation_877),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ICF': ('Intent Change Flag (see Note)', Variation_874, 0, 1),
        'LNAV': ('LNAV Mode', Variation_875, 1, 1),
        'ME': ('Military Emergency', Variation_916, 2, 1),
        'PS': ('Priority Status', Variation_876, 3, 3),
        'SS': ('Surveillance Status', Variation_877, 6, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ICF']) -> Type[Variation_874]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LNAV']) -> Type[Variation_875]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ME']) -> Type[Variation_916]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PS']) -> Type[Variation_876]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SS']) -> Type[Variation_877]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ICF'], Literal['LNAV'], Literal['ME'], Literal['PS'], Literal['SS']]) -> Union[Type['Variation_874'], Type['Variation_875'], Type['Variation_916'], Type['Variation_876'], Type['Variation_877']]:
        if key == 'ICF':
            return Variation_874
        if key == 'LNAV':
            return Variation_875
        if key == 'ME':
            return Variation_916
        if key == 'PS':
            return Variation_876
        if key == 'SS':
            return Variation_877
        assert_never(key)

    def __init__(self, arg : Variation_917_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ICF']) -> Variation_874:
        ...

    @overload
    def get_item(self, name : Literal['LNAV']) -> Variation_875:
        ...

    @overload
    def get_item(self, name : Literal['ME']) -> Variation_916:
        ...

    @overload
    def get_item(self, name : Literal['PS']) -> Variation_876:
        ...

    @overload
    def get_item(self, name : Literal['SS']) -> Variation_877:
        ...

    def get_item(self, name : Union[Literal['ICF'], Literal['LNAV'], Literal['ME'], Literal['PS'], Literal['SS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ICF'], val : Union[Variation_874, Variation_874_Arg]) -> 'Variation_917':
        ...

    @overload
    def set_item(self, name : Literal['LNAV'], val : Union[Variation_875, Variation_875_Arg]) -> 'Variation_917':
        ...

    @overload
    def set_item(self, name : Literal['ME'], val : Union[Variation_916, Variation_916_Arg]) -> 'Variation_917':
        ...

    @overload
    def set_item(self, name : Literal['PS'], val : Union[Variation_876, Variation_876_Arg]) -> 'Variation_917':
        ...

    @overload
    def set_item(self, name : Literal['SS'], val : Union[Variation_877, Variation_877_Arg]) -> 'Variation_917':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ICF'], f : Any) -> 'Variation_917':
        ...

    @overload
    def modify_item(self, name : Literal['LNAV'], f : Any) -> 'Variation_917':
        ...

    @overload
    def modify_item(self, name : Literal['ME'], f : Any) -> 'Variation_917':
        ...

    @overload
    def modify_item(self, name : Literal['PS'], f : Any) -> 'Variation_917':
        ...

    @overload
    def modify_item(self, name : Literal['SS'], f : Any) -> 'Variation_917':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_918_Arg_Group_1 = TypedDict('Variation_918_Arg_Group_1', {
    'POA': Union[Variation_901, Variation_901_Arg],
    'CDTIS': Union[Variation_902, Variation_902_Arg],
    'B2LOW': Union[Variation_903, Variation_903_Arg],
    'RAS': Union[Variation_904, Variation_904_Arg],
    'IDENT': Union[Variation_905, Variation_905_Arg],
})
Variation_918_Arg_Group_2 = TypedDict('Variation_918_Arg_Group_2', {
    'POA': Union[Variation_901, Variation_901_Arg],
    'CDTIS': Union[Variation_902, Variation_902_Arg],
    'B2LOW': Union[Variation_903, Variation_903_Arg],
    'RAS': Union[Variation_904, Variation_904_Arg],
    'IDENT': Union[Variation_905, Variation_905_Arg],
    'LW': Union[Variation_187, Variation_187_Arg],
})
Variation_918_Arg : TypeAlias = Union[
    int,
    Variation_918_Arg_Group_1,
    Tuple[int],
    Variation_918_Arg_Group_2,
    Tuple[int,int],
]
class Variation_918(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            Spare(0, 2),
            ('POA', Variation_901),
            ('CDTIS', Variation_902),
            ('B2LOW', Variation_903),
            ('RAS', Variation_904),
            ('IDENT', Variation_905),
        ],
        [
            ('LW', Variation_187),
            Spare(4, 3),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'POA': ('Position Offset Applied', Variation_901, 2, 1),
        'CDTIS': ('Cockpit Display of Traffic Information Surface', Variation_902, 3, 1),
        'B2LOW': ('Class B2 Transmit Power Less Than 70 Watts', Variation_903, 4, 1),
        'RAS': ('Receiving ATC Services', Variation_904, 5, 1),
        'IDENT': ('Setting of IDENT Switch', Variation_905, 6, 1),
        'LW': ('Length and Width of the Aircraft', Variation_187, 0, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['POA']) -> Type[Variation_901]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CDTIS']) -> Type[Variation_902]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B2LOW']) -> Type[Variation_903]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAS']) -> Type[Variation_904]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IDENT']) -> Type[Variation_905]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LW']) -> Type[Variation_187]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['POA'], Literal['CDTIS'], Literal['B2LOW'], Literal['RAS'], Literal['IDENT'], Literal['LW']]) -> Union[Type['Variation_901'], Type['Variation_902'], Type['Variation_903'], Type['Variation_904'], Type['Variation_905'], Type['Variation_187']]:
        if key == 'POA':
            return Variation_901
        if key == 'CDTIS':
            return Variation_902
        if key == 'B2LOW':
            return Variation_903
        if key == 'RAS':
            return Variation_904
        if key == 'IDENT':
            return Variation_905
        if key == 'LW':
            return Variation_187
        assert_never(key)

    def __init__(self, arg : Variation_918_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_918_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_918_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['POA']) -> Variation_901:
        ...

    @overload
    def get_item(self, name : Literal['CDTIS']) -> Variation_902:
        ...

    @overload
    def get_item(self, name : Literal['B2LOW']) -> Variation_903:
        ...

    @overload
    def get_item(self, name : Literal['RAS']) -> Variation_904:
        ...

    @overload
    def get_item(self, name : Literal['IDENT']) -> Variation_905:
        ...

    @overload
    def get_item(self, name : Literal['LW']) -> Variation_187:
        ...

    def get_item(self, name : Union[Literal['POA'], Literal['CDTIS'], Literal['B2LOW'], Literal['RAS'], Literal['IDENT'], Literal['LW']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['POA'], val : Union[Variation_901, Variation_901_Arg]) -> 'Variation_918':
        ...

    @overload
    def set_item(self, name : Literal['CDTIS'], val : Union[Variation_902, Variation_902_Arg]) -> 'Variation_918':
        ...

    @overload
    def set_item(self, name : Literal['B2LOW'], val : Union[Variation_903, Variation_903_Arg]) -> 'Variation_918':
        ...

    @overload
    def set_item(self, name : Literal['RAS'], val : Union[Variation_904, Variation_904_Arg]) -> 'Variation_918':
        ...

    @overload
    def set_item(self, name : Literal['IDENT'], val : Union[Variation_905, Variation_905_Arg]) -> 'Variation_918':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['POA'], f : Any) -> 'Variation_918':
        ...

    @overload
    def modify_item(self, name : Literal['CDTIS'], f : Any) -> 'Variation_918':
        ...

    @overload
    def modify_item(self, name : Literal['B2LOW'], f : Any) -> 'Variation_918':
        ...

    @overload
    def modify_item(self, name : Literal['RAS'], f : Any) -> 'Variation_918':
        ...

    @overload
    def modify_item(self, name : Literal['IDENT'], f : Any) -> 'Variation_918':
        ...

    @overload
    def modify_item(self, name : Literal['LW'], f : Any) -> 'Variation_918':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_919_Arg = TypedDict('Variation_919_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '040': Union[Variation_851, Variation_851_Arg],
    '161': Union[Variation_852, Variation_852_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '071': Union[Variation_80, Variation_80_Arg],
    '130': Union[Variation_705, Variation_705_Arg],
    '131': Union[Variation_632, Variation_632_Arg],
    '072': Union[Variation_80, Variation_80_Arg],
    '150': Union[Variation_719, Variation_719_Arg],
    '151': Union[Variation_855, Variation_855_Arg],
    '080': Union[Variation_278, Variation_278_Arg],
    '073': Union[Variation_80, Variation_80_Arg],
    '074': Union[Variation_858, Variation_858_Arg],
    '075': Union[Variation_80, Variation_80_Arg],
    '076': Union[Variation_860, Variation_860_Arg],
    '140': Union[Variation_287, Variation_287_Arg],
    '090': Union[Variation_868, Variation_868_Arg],
    '210': Union[Variation_872, Variation_872_Arg],
    '070': Union[Variation_873, Variation_873_Arg],
    '230': Union[Variation_717, Variation_717_Arg],
    '145': Union[Variation_360, Variation_360_Arg],
    '152': Union[Variation_14, Variation_14_Arg],
    '200': Union[Variation_917, Variation_917_Arg],
    '155': Union[Variation_880, Variation_880_Arg],
    '157': Union[Variation_881, Variation_881_Arg],
    '160': Union[Variation_883, Variation_883_Arg],
    '165': Union[Variation_885, Variation_885_Arg],
    '077': Union[Variation_80, Variation_80_Arg],
    '170': Union[Variation_196, Variation_196_Arg],
    '020': Union[Variation_886, Variation_886_Arg],
    '220': Union[Variation_731, Variation_731_Arg],
    '146': Union[Variation_887, Variation_887_Arg],
    '148': Union[Variation_891, Variation_891_Arg],
    '110': Union[Variation_754, Variation_754_Arg],
    '016': Union[Variation_892, Variation_892_Arg],
    '008': Union[Variation_900, Variation_900_Arg],
    '271': Union[Variation_918, Variation_918_Arg],
    '132': Union[Variation_29, Variation_29_Arg],
    '250': Union[Variation_321, Variation_321_Arg],
    '260': Union[Variation_912, Variation_912_Arg],
    '400': Union[Variation_0, Variation_0_Arg],
    '295': Union[Variation_914, Variation_914_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_919(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 7

    subitems_list = [
        ('010', Variation_1),
        ('040', Variation_851),
        ('161', Variation_852),
        ('015', Variation_0),
        ('071', Variation_80),
        ('130', Variation_705),
        ('131', Variation_632),
        ('072', Variation_80),
        ('150', Variation_719),
        ('151', Variation_855),
        ('080', Variation_278),
        ('073', Variation_80),
        ('074', Variation_858),
        ('075', Variation_80),
        ('076', Variation_860),
        ('140', Variation_287),
        ('090', Variation_868),
        ('210', Variation_872),
        ('070', Variation_873),
        ('230', Variation_717),
        ('145', Variation_360),
        ('152', Variation_14),
        ('200', Variation_917),
        ('155', Variation_880),
        ('157', Variation_881),
        ('160', Variation_883),
        ('165', Variation_885),
        ('077', Variation_80),
        ('170', Variation_196),
        ('020', Variation_886),
        ('220', Variation_731),
        ('146', Variation_887),
        ('148', Variation_891),
        ('110', Variation_754),
        ('016', Variation_892),
        ('008', Variation_900),
        ('271', Variation_918),
        ('132', Variation_29),
        ('250', Variation_321),
        ('260', Variation_912),
        ('400', Variation_0),
        ('295', Variation_914),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identification', Variation_1, 0x80000000000000),
        '040': ('Target Report Descriptor', Variation_851, 0x40000000000000),
        '161': ('Track Number', Variation_852, 0x20000000000000),
        '015': ('Service Identification', Variation_0, 0x10000000000000),
        '071': ('Time of Applicability for Position', Variation_80, 0x08000000000000),
        '130': ('Position in WGS-84 Co-ordinates', Variation_705, 0x04000000000000),
        '131': ('High-Resolution Position in WGS-84 Co-ordinates', Variation_632, 0x02000000000000),
        '072': ('Time of Applicability for Velocity', Variation_80, 0x01800000000000),
        '150': ('Air Speed', Variation_719, 0x01400000000000),
        '151': ('True Airspeed', Variation_855, 0x01200000000000),
        '080': ('Target Address', Variation_278, 0x01100000000000),
        '073': ('Time of Message Reception for Position', Variation_80, 0x01080000000000),
        '074': ('Time of Message Reception of Position-High Precision', Variation_858, 0x01040000000000),
        '075': ('Time of Message Reception for Velocity', Variation_80, 0x01020000000000),
        '076': ('Time of Message Reception of Velocity-High Precision', Variation_860, 0x01018000000000),
        '140': ('Geometric Height', Variation_287, 0x01014000000000),
        '090': ('Quality Indicators', Variation_868, 0x01012000000000),
        '210': ('MOPS Version', Variation_872, 0x01011000000000),
        '070': ('Mode 3/A Code in Octal Representation', Variation_873, 0x01010800000000),
        '230': ('Roll Angle', Variation_717, 0x01010400000000),
        '145': ('Flight Level', Variation_360, 0x01010200000000),
        '152': ('Magnetic Heading', Variation_14, 0x01010180000000),
        '200': ('Target Status', Variation_917, 0x01010140000000),
        '155': ('Barometric Vertical Rate', Variation_880, 0x01010120000000),
        '157': ('Geometric Vertical Rate', Variation_881, 0x01010110000000),
        '160': ('Airborne Ground Vector', Variation_883, 0x01010108000000),
        '165': ('Track Angle Rate', Variation_885, 0x01010104000000),
        '077': ('Time of ASTERIX Report Transmission', Variation_80, 0x01010102000000),
        '170': ('Target Identification', Variation_196, 0x01010101800000),
        '020': ('Emitter Category', Variation_886, 0x01010101400000),
        '220': ('Met Information', Variation_731, 0x01010101200000),
        '146': ('Selected Altitude', Variation_887, 0x01010101100000),
        '148': ('Final State Selected Altitude', Variation_891, 0x01010101080000),
        '110': ('Trajectory Intent', Variation_754, 0x01010101040000),
        '016': ('Service Management', Variation_892, 0x01010101020000),
        '008': ('Aircraft Operational Status', Variation_900, 0x01010101018000),
        '271': ('Surface Capabilities and Characteristics', Variation_918, 0x01010101014000),
        '132': ('Message Amplitude', Variation_29, 0x01010101012000),
        '250': ('Mode S MB Data', Variation_321, 0x01010101011000),
        '260': ('ACAS Resolution Advisory Report', Variation_912, 0x01010101010800),
        '400': ('Receiver ID', Variation_0, 0x01010101010400),
        '295': ('Data Ages', Variation_914, 0x01010101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x01010101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_851]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_852]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['071']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_705]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['131']) -> Type[Variation_632]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['072']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_719]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['151']) -> Type[Variation_855]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['073']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['074']) -> Type[Variation_858]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['075']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['076']) -> Type[Variation_860]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_868]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_872]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_873]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['145']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['152']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_917]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['155']) -> Type[Variation_880]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['157']) -> Type[Variation_881]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['160']) -> Type[Variation_883]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['165']) -> Type[Variation_885]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['077']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_886]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_731]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['146']) -> Type[Variation_887]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['148']) -> Type[Variation_891]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_754]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['016']) -> Type[Variation_892]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['008']) -> Type[Variation_900]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['271']) -> Type[Variation_918]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['132']) -> Type[Variation_29]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_912]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['295']) -> Type[Variation_914]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['040'], Literal['161'], Literal['015'], Literal['071'], Literal['130'], Literal['131'], Literal['072'], Literal['150'], Literal['151'], Literal['080'], Literal['073'], Literal['074'], Literal['075'], Literal['076'], Literal['140'], Literal['090'], Literal['210'], Literal['070'], Literal['230'], Literal['145'], Literal['152'], Literal['200'], Literal['155'], Literal['157'], Literal['160'], Literal['165'], Literal['077'], Literal['170'], Literal['020'], Literal['220'], Literal['146'], Literal['148'], Literal['110'], Literal['016'], Literal['008'], Literal['271'], Literal['132'], Literal['250'], Literal['260'], Literal['400'], Literal['295'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_851'], Type['Variation_852'], Type['Variation_0'], Type['Variation_80'], Type['Variation_705'], Type['Variation_632'], Type['Variation_80'], Type['Variation_719'], Type['Variation_855'], Type['Variation_278'], Type['Variation_80'], Type['Variation_858'], Type['Variation_80'], Type['Variation_860'], Type['Variation_287'], Type['Variation_868'], Type['Variation_872'], Type['Variation_873'], Type['Variation_717'], Type['Variation_360'], Type['Variation_14'], Type['Variation_917'], Type['Variation_880'], Type['Variation_881'], Type['Variation_883'], Type['Variation_885'], Type['Variation_80'], Type['Variation_196'], Type['Variation_886'], Type['Variation_731'], Type['Variation_887'], Type['Variation_891'], Type['Variation_754'], Type['Variation_892'], Type['Variation_900'], Type['Variation_918'], Type['Variation_29'], Type['Variation_321'], Type['Variation_912'], Type['Variation_0'], Type['Variation_914'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '040':
            return Variation_851
        if key == '161':
            return Variation_852
        if key == '015':
            return Variation_0
        if key == '071':
            return Variation_80
        if key == '130':
            return Variation_705
        if key == '131':
            return Variation_632
        if key == '072':
            return Variation_80
        if key == '150':
            return Variation_719
        if key == '151':
            return Variation_855
        if key == '080':
            return Variation_278
        if key == '073':
            return Variation_80
        if key == '074':
            return Variation_858
        if key == '075':
            return Variation_80
        if key == '076':
            return Variation_860
        if key == '140':
            return Variation_287
        if key == '090':
            return Variation_868
        if key == '210':
            return Variation_872
        if key == '070':
            return Variation_873
        if key == '230':
            return Variation_717
        if key == '145':
            return Variation_360
        if key == '152':
            return Variation_14
        if key == '200':
            return Variation_917
        if key == '155':
            return Variation_880
        if key == '157':
            return Variation_881
        if key == '160':
            return Variation_883
        if key == '165':
            return Variation_885
        if key == '077':
            return Variation_80
        if key == '170':
            return Variation_196
        if key == '020':
            return Variation_886
        if key == '220':
            return Variation_731
        if key == '146':
            return Variation_887
        if key == '148':
            return Variation_891
        if key == '110':
            return Variation_754
        if key == '016':
            return Variation_892
        if key == '008':
            return Variation_900
        if key == '271':
            return Variation_918
        if key == '132':
            return Variation_29
        if key == '250':
            return Variation_321
        if key == '260':
            return Variation_912
        if key == '400':
            return Variation_0
        if key == '295':
            return Variation_914
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_919_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_851, Variation_851_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_852, Variation_852_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['071'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_705, Variation_705_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['131'], val : Union[Variation_632, Variation_632_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['072'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_719, Variation_719_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['151'], val : Union[Variation_855, Variation_855_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['073'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['074'], val : Union[Variation_858, Variation_858_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['075'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['076'], val : Union[Variation_860, Variation_860_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_868, Variation_868_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_872, Variation_872_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_873, Variation_873_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['145'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['152'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_917, Variation_917_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['155'], val : Union[Variation_880, Variation_880_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['157'], val : Union[Variation_881, Variation_881_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['160'], val : Union[Variation_883, Variation_883_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['165'], val : Union[Variation_885, Variation_885_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['077'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_886, Variation_886_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_731, Variation_731_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['146'], val : Union[Variation_887, Variation_887_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['148'], val : Union[Variation_891, Variation_891_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_754, Variation_754_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['016'], val : Union[Variation_892, Variation_892_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['008'], val : Union[Variation_900, Variation_900_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['271'], val : Union[Variation_918, Variation_918_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['132'], val : Union[Variation_29, Variation_29_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_912, Variation_912_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['295'], val : Union[Variation_914, Variation_914_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_919':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_919':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['071']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['131']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['072']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['151']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['073']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['074']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['075']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['076']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['145']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['152']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['155']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['157']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['160']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['165']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['077']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['146']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['148']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['016']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['008']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['271']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['132']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['295']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_919':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_919':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_851:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_852:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['071']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_705:
        ...

    @overload
    def get_item(self, name : Literal['131']) -> Variation_632:
        ...

    @overload
    def get_item(self, name : Literal['072']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_719:
        ...

    @overload
    def get_item(self, name : Literal['151']) -> Variation_855:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['073']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['074']) -> Variation_858:
        ...

    @overload
    def get_item(self, name : Literal['075']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['076']) -> Variation_860:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_868:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_872:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_873:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['145']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['152']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_917:
        ...

    @overload
    def get_item(self, name : Literal['155']) -> Variation_880:
        ...

    @overload
    def get_item(self, name : Literal['157']) -> Variation_881:
        ...

    @overload
    def get_item(self, name : Literal['160']) -> Variation_883:
        ...

    @overload
    def get_item(self, name : Literal['165']) -> Variation_885:
        ...

    @overload
    def get_item(self, name : Literal['077']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_886:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_731:
        ...

    @overload
    def get_item(self, name : Literal['146']) -> Variation_887:
        ...

    @overload
    def get_item(self, name : Literal['148']) -> Variation_891:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_754:
        ...

    @overload
    def get_item(self, name : Literal['016']) -> Variation_892:
        ...

    @overload
    def get_item(self, name : Literal['008']) -> Variation_900:
        ...

    @overload
    def get_item(self, name : Literal['271']) -> Variation_918:
        ...

    @overload
    def get_item(self, name : Literal['132']) -> Variation_29:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_912:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['295']) -> Variation_914:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['071'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['131'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['072'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['151'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['073'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['074'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['075'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['076'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['145'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['152'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['155'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['157'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['160'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['165'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['077'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['146'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['148'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['016'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['008'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['271'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['132'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['295'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_919':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_919':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_920_Arg : TypeAlias = Raw
class Variation_920(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default',
        1: 'List Lookup failed (see note)',
    }

    def __init__(self, arg : Variation_920_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_921_Arg_Group_1 = TypedDict('Variation_921_Arg_Group_1', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
})
Variation_921_Arg_Group_2 = TypedDict('Variation_921_Arg_Group_2', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
    'DCR': Union[Variation_694, Variation_694_Arg],
    'GBS': Union[Variation_695, Variation_695_Arg],
    'SIM': Union[Variation_696, Variation_696_Arg],
    'TST': Union[Variation_697, Variation_697_Arg],
    'SAA': Union[Variation_844, Variation_844_Arg],
    'CL': Union[Variation_845, Variation_845_Arg],
})
Variation_921_Arg_Group_3 = TypedDict('Variation_921_Arg_Group_3', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
    'DCR': Union[Variation_694, Variation_694_Arg],
    'GBS': Union[Variation_695, Variation_695_Arg],
    'SIM': Union[Variation_696, Variation_696_Arg],
    'TST': Union[Variation_697, Variation_697_Arg],
    'SAA': Union[Variation_844, Variation_844_Arg],
    'CL': Union[Variation_845, Variation_845_Arg],
    'LLC': Union[Variation_920, Variation_920_Arg],
    'IPC': Union[Variation_846, Variation_846_Arg],
    'NOGO': Union[Variation_847, Variation_847_Arg],
    'CPR': Union[Variation_848, Variation_848_Arg],
    'LDPJ': Union[Variation_849, Variation_849_Arg],
    'RCF': Union[Variation_850, Variation_850_Arg],
})
Variation_921_Arg : TypeAlias = Union[
    int,
    Variation_921_Arg_Group_1,
    Tuple[int],
    Variation_921_Arg_Group_2,
    Tuple[int,int],
    Variation_921_Arg_Group_3,
    Tuple[int,int,int],
]
class Variation_921(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('ATP', Variation_840),
            ('ARC', Variation_841),
            ('RC', Variation_842),
            ('RAB', Variation_843),
        ],
        [
            ('DCR', Variation_694),
            ('GBS', Variation_695),
            ('SIM', Variation_696),
            ('TST', Variation_697),
            ('SAA', Variation_844),
            ('CL', Variation_845),
        ],
        [
            Spare(0, 1),
            ('LLC', Variation_920),
            ('IPC', Variation_846),
            ('NOGO', Variation_847),
            ('CPR', Variation_848),
            ('LDPJ', Variation_849),
            ('RCF', Variation_850),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ATP': ('Address Type', Variation_840, 0, 3),
        'ARC': ('Altitude Reporting Capability', Variation_841, 3, 2),
        'RC': ('Range Check', Variation_842, 5, 1),
        'RAB': ('Report Type', Variation_843, 6, 1),
        'DCR': ('Differential Correction', Variation_694, 0, 1),
        'GBS': ('Ground Bit Setting', Variation_695, 1, 1),
        'SIM': ('Simulated Target', Variation_696, 2, 1),
        'TST': ('Test Target', Variation_697, 3, 1),
        'SAA': ('Selected Altitude Available', Variation_844, 4, 1),
        'CL': ('Confidence Level', Variation_845, 5, 2),
        'LLC': ('List Lookup Check', Variation_920, 1, 1),
        'IPC': ('Independent Position Check', Variation_846, 2, 1),
        'NOGO': ('No-go Bit Status', Variation_847, 3, 1),
        'CPR': ('Compact Position Reporting', Variation_848, 4, 1),
        'LDPJ': ('Local Decoding Position Jump', Variation_849, 5, 1),
        'RCF': ('Range Check', Variation_850, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ATP']) -> Type[Variation_840]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_841]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RC']) -> Type[Variation_842]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_843]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DCR']) -> Type[Variation_694]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GBS']) -> Type[Variation_695]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_696]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_697]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAA']) -> Type[Variation_844]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CL']) -> Type[Variation_845]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LLC']) -> Type[Variation_920]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IPC']) -> Type[Variation_846]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOGO']) -> Type[Variation_847]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CPR']) -> Type[Variation_848]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LDPJ']) -> Type[Variation_849]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RCF']) -> Type[Variation_850]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ATP'], Literal['ARC'], Literal['RC'], Literal['RAB'], Literal['DCR'], Literal['GBS'], Literal['SIM'], Literal['TST'], Literal['SAA'], Literal['CL'], Literal['LLC'], Literal['IPC'], Literal['NOGO'], Literal['CPR'], Literal['LDPJ'], Literal['RCF']]) -> Union[Type['Variation_840'], Type['Variation_841'], Type['Variation_842'], Type['Variation_843'], Type['Variation_694'], Type['Variation_695'], Type['Variation_696'], Type['Variation_697'], Type['Variation_844'], Type['Variation_845'], Type['Variation_920'], Type['Variation_846'], Type['Variation_847'], Type['Variation_848'], Type['Variation_849'], Type['Variation_850']]:
        if key == 'ATP':
            return Variation_840
        if key == 'ARC':
            return Variation_841
        if key == 'RC':
            return Variation_842
        if key == 'RAB':
            return Variation_843
        if key == 'DCR':
            return Variation_694
        if key == 'GBS':
            return Variation_695
        if key == 'SIM':
            return Variation_696
        if key == 'TST':
            return Variation_697
        if key == 'SAA':
            return Variation_844
        if key == 'CL':
            return Variation_845
        if key == 'LLC':
            return Variation_920
        if key == 'IPC':
            return Variation_846
        if key == 'NOGO':
            return Variation_847
        if key == 'CPR':
            return Variation_848
        if key == 'LDPJ':
            return Variation_849
        if key == 'RCF':
            return Variation_850
        assert_never(key)

    def __init__(self, arg : Variation_921_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_921_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_921_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_921_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ATP']) -> Variation_840:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_841:
        ...

    @overload
    def get_item(self, name : Literal['RC']) -> Variation_842:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_843:
        ...

    @overload
    def get_item(self, name : Literal['DCR']) -> Variation_694:
        ...

    @overload
    def get_item(self, name : Literal['GBS']) -> Variation_695:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_696:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_697:
        ...

    @overload
    def get_item(self, name : Literal['SAA']) -> Variation_844:
        ...

    @overload
    def get_item(self, name : Literal['CL']) -> Variation_845:
        ...

    @overload
    def get_item(self, name : Literal['LLC']) -> Variation_920:
        ...

    @overload
    def get_item(self, name : Literal['IPC']) -> Variation_846:
        ...

    @overload
    def get_item(self, name : Literal['NOGO']) -> Variation_847:
        ...

    @overload
    def get_item(self, name : Literal['CPR']) -> Variation_848:
        ...

    @overload
    def get_item(self, name : Literal['LDPJ']) -> Variation_849:
        ...

    @overload
    def get_item(self, name : Literal['RCF']) -> Variation_850:
        ...

    def get_item(self, name : Union[Literal['ATP'], Literal['ARC'], Literal['RC'], Literal['RAB'], Literal['DCR'], Literal['GBS'], Literal['SIM'], Literal['TST'], Literal['SAA'], Literal['CL'], Literal['LLC'], Literal['IPC'], Literal['NOGO'], Literal['CPR'], Literal['LDPJ'], Literal['RCF']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ATP'], val : Union[Variation_840, Variation_840_Arg]) -> 'Variation_921':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_841, Variation_841_Arg]) -> 'Variation_921':
        ...

    @overload
    def set_item(self, name : Literal['RC'], val : Union[Variation_842, Variation_842_Arg]) -> 'Variation_921':
        ...

    @overload
    def set_item(self, name : Literal['RAB'], val : Union[Variation_843, Variation_843_Arg]) -> 'Variation_921':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ATP'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['RC'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['DCR'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['GBS'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['SAA'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['CL'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['LLC'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['IPC'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['NOGO'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['CPR'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['LDPJ'], f : Any) -> 'Variation_921':
        ...

    @overload
    def modify_item(self, name : Literal['RCF'], f : Any) -> 'Variation_921':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_922_Arg = TypedDict('Variation_922_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '040': Union[Variation_921, Variation_921_Arg],
    '161': Union[Variation_852, Variation_852_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '071': Union[Variation_80, Variation_80_Arg],
    '130': Union[Variation_705, Variation_705_Arg],
    '131': Union[Variation_632, Variation_632_Arg],
    '072': Union[Variation_80, Variation_80_Arg],
    '150': Union[Variation_719, Variation_719_Arg],
    '151': Union[Variation_855, Variation_855_Arg],
    '080': Union[Variation_278, Variation_278_Arg],
    '073': Union[Variation_80, Variation_80_Arg],
    '074': Union[Variation_858, Variation_858_Arg],
    '075': Union[Variation_80, Variation_80_Arg],
    '076': Union[Variation_860, Variation_860_Arg],
    '140': Union[Variation_287, Variation_287_Arg],
    '090': Union[Variation_868, Variation_868_Arg],
    '210': Union[Variation_872, Variation_872_Arg],
    '070': Union[Variation_873, Variation_873_Arg],
    '230': Union[Variation_717, Variation_717_Arg],
    '145': Union[Variation_360, Variation_360_Arg],
    '152': Union[Variation_14, Variation_14_Arg],
    '200': Union[Variation_917, Variation_917_Arg],
    '155': Union[Variation_880, Variation_880_Arg],
    '157': Union[Variation_881, Variation_881_Arg],
    '160': Union[Variation_883, Variation_883_Arg],
    '165': Union[Variation_885, Variation_885_Arg],
    '077': Union[Variation_80, Variation_80_Arg],
    '170': Union[Variation_196, Variation_196_Arg],
    '020': Union[Variation_886, Variation_886_Arg],
    '220': Union[Variation_731, Variation_731_Arg],
    '146': Union[Variation_887, Variation_887_Arg],
    '148': Union[Variation_891, Variation_891_Arg],
    '110': Union[Variation_754, Variation_754_Arg],
    '016': Union[Variation_892, Variation_892_Arg],
    '008': Union[Variation_900, Variation_900_Arg],
    '271': Union[Variation_918, Variation_918_Arg],
    '132': Union[Variation_29, Variation_29_Arg],
    '250': Union[Variation_321, Variation_321_Arg],
    '260': Union[Variation_912, Variation_912_Arg],
    '400': Union[Variation_0, Variation_0_Arg],
    '295': Union[Variation_914, Variation_914_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_922(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 7

    subitems_list = [
        ('010', Variation_1),
        ('040', Variation_921),
        ('161', Variation_852),
        ('015', Variation_0),
        ('071', Variation_80),
        ('130', Variation_705),
        ('131', Variation_632),
        ('072', Variation_80),
        ('150', Variation_719),
        ('151', Variation_855),
        ('080', Variation_278),
        ('073', Variation_80),
        ('074', Variation_858),
        ('075', Variation_80),
        ('076', Variation_860),
        ('140', Variation_287),
        ('090', Variation_868),
        ('210', Variation_872),
        ('070', Variation_873),
        ('230', Variation_717),
        ('145', Variation_360),
        ('152', Variation_14),
        ('200', Variation_917),
        ('155', Variation_880),
        ('157', Variation_881),
        ('160', Variation_883),
        ('165', Variation_885),
        ('077', Variation_80),
        ('170', Variation_196),
        ('020', Variation_886),
        ('220', Variation_731),
        ('146', Variation_887),
        ('148', Variation_891),
        ('110', Variation_754),
        ('016', Variation_892),
        ('008', Variation_900),
        ('271', Variation_918),
        ('132', Variation_29),
        ('250', Variation_321),
        ('260', Variation_912),
        ('400', Variation_0),
        ('295', Variation_914),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identification', Variation_1, 0x80000000000000),
        '040': ('Target Report Descriptor', Variation_921, 0x40000000000000),
        '161': ('Track Number', Variation_852, 0x20000000000000),
        '015': ('Service Identification', Variation_0, 0x10000000000000),
        '071': ('Time of Applicability for Position', Variation_80, 0x08000000000000),
        '130': ('Position in WGS-84 Co-ordinates', Variation_705, 0x04000000000000),
        '131': ('High-Resolution Position in WGS-84 Co-ordinates', Variation_632, 0x02000000000000),
        '072': ('Time of Applicability for Velocity', Variation_80, 0x01800000000000),
        '150': ('Air Speed', Variation_719, 0x01400000000000),
        '151': ('True Airspeed', Variation_855, 0x01200000000000),
        '080': ('Target Address', Variation_278, 0x01100000000000),
        '073': ('Time of Message Reception for Position', Variation_80, 0x01080000000000),
        '074': ('Time of Message Reception of Position-High Precision', Variation_858, 0x01040000000000),
        '075': ('Time of Message Reception for Velocity', Variation_80, 0x01020000000000),
        '076': ('Time of Message Reception of Velocity-High Precision', Variation_860, 0x01018000000000),
        '140': ('Geometric Height', Variation_287, 0x01014000000000),
        '090': ('Quality Indicators', Variation_868, 0x01012000000000),
        '210': ('MOPS Version', Variation_872, 0x01011000000000),
        '070': ('Mode 3/A Code in Octal Representation', Variation_873, 0x01010800000000),
        '230': ('Roll Angle', Variation_717, 0x01010400000000),
        '145': ('Flight Level', Variation_360, 0x01010200000000),
        '152': ('Magnetic Heading', Variation_14, 0x01010180000000),
        '200': ('Target Status', Variation_917, 0x01010140000000),
        '155': ('Barometric Vertical Rate', Variation_880, 0x01010120000000),
        '157': ('Geometric Vertical Rate', Variation_881, 0x01010110000000),
        '160': ('Airborne Ground Vector', Variation_883, 0x01010108000000),
        '165': ('Track Angle Rate', Variation_885, 0x01010104000000),
        '077': ('Time of ASTERIX Report Transmission', Variation_80, 0x01010102000000),
        '170': ('Target Identification', Variation_196, 0x01010101800000),
        '020': ('Emitter Category', Variation_886, 0x01010101400000),
        '220': ('Met Information', Variation_731, 0x01010101200000),
        '146': ('Selected Altitude', Variation_887, 0x01010101100000),
        '148': ('Final State Selected Altitude', Variation_891, 0x01010101080000),
        '110': ('Trajectory Intent', Variation_754, 0x01010101040000),
        '016': ('Service Management', Variation_892, 0x01010101020000),
        '008': ('Aircraft Operational Status', Variation_900, 0x01010101018000),
        '271': ('Surface Capabilities and Characteristics', Variation_918, 0x01010101014000),
        '132': ('Message Amplitude', Variation_29, 0x01010101012000),
        '250': ('Mode S MB Data', Variation_321, 0x01010101011000),
        '260': ('ACAS Resolution Advisory Report', Variation_912, 0x01010101010800),
        '400': ('Receiver ID', Variation_0, 0x01010101010400),
        '295': ('Data Ages', Variation_914, 0x01010101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x01010101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_921]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_852]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['071']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_705]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['131']) -> Type[Variation_632]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['072']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_719]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['151']) -> Type[Variation_855]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['073']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['074']) -> Type[Variation_858]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['075']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['076']) -> Type[Variation_860]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_868]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_872]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_873]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['145']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['152']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_917]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['155']) -> Type[Variation_880]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['157']) -> Type[Variation_881]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['160']) -> Type[Variation_883]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['165']) -> Type[Variation_885]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['077']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_886]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_731]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['146']) -> Type[Variation_887]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['148']) -> Type[Variation_891]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_754]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['016']) -> Type[Variation_892]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['008']) -> Type[Variation_900]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['271']) -> Type[Variation_918]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['132']) -> Type[Variation_29]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_912]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['295']) -> Type[Variation_914]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['040'], Literal['161'], Literal['015'], Literal['071'], Literal['130'], Literal['131'], Literal['072'], Literal['150'], Literal['151'], Literal['080'], Literal['073'], Literal['074'], Literal['075'], Literal['076'], Literal['140'], Literal['090'], Literal['210'], Literal['070'], Literal['230'], Literal['145'], Literal['152'], Literal['200'], Literal['155'], Literal['157'], Literal['160'], Literal['165'], Literal['077'], Literal['170'], Literal['020'], Literal['220'], Literal['146'], Literal['148'], Literal['110'], Literal['016'], Literal['008'], Literal['271'], Literal['132'], Literal['250'], Literal['260'], Literal['400'], Literal['295'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_921'], Type['Variation_852'], Type['Variation_0'], Type['Variation_80'], Type['Variation_705'], Type['Variation_632'], Type['Variation_80'], Type['Variation_719'], Type['Variation_855'], Type['Variation_278'], Type['Variation_80'], Type['Variation_858'], Type['Variation_80'], Type['Variation_860'], Type['Variation_287'], Type['Variation_868'], Type['Variation_872'], Type['Variation_873'], Type['Variation_717'], Type['Variation_360'], Type['Variation_14'], Type['Variation_917'], Type['Variation_880'], Type['Variation_881'], Type['Variation_883'], Type['Variation_885'], Type['Variation_80'], Type['Variation_196'], Type['Variation_886'], Type['Variation_731'], Type['Variation_887'], Type['Variation_891'], Type['Variation_754'], Type['Variation_892'], Type['Variation_900'], Type['Variation_918'], Type['Variation_29'], Type['Variation_321'], Type['Variation_912'], Type['Variation_0'], Type['Variation_914'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '040':
            return Variation_921
        if key == '161':
            return Variation_852
        if key == '015':
            return Variation_0
        if key == '071':
            return Variation_80
        if key == '130':
            return Variation_705
        if key == '131':
            return Variation_632
        if key == '072':
            return Variation_80
        if key == '150':
            return Variation_719
        if key == '151':
            return Variation_855
        if key == '080':
            return Variation_278
        if key == '073':
            return Variation_80
        if key == '074':
            return Variation_858
        if key == '075':
            return Variation_80
        if key == '076':
            return Variation_860
        if key == '140':
            return Variation_287
        if key == '090':
            return Variation_868
        if key == '210':
            return Variation_872
        if key == '070':
            return Variation_873
        if key == '230':
            return Variation_717
        if key == '145':
            return Variation_360
        if key == '152':
            return Variation_14
        if key == '200':
            return Variation_917
        if key == '155':
            return Variation_880
        if key == '157':
            return Variation_881
        if key == '160':
            return Variation_883
        if key == '165':
            return Variation_885
        if key == '077':
            return Variation_80
        if key == '170':
            return Variation_196
        if key == '020':
            return Variation_886
        if key == '220':
            return Variation_731
        if key == '146':
            return Variation_887
        if key == '148':
            return Variation_891
        if key == '110':
            return Variation_754
        if key == '016':
            return Variation_892
        if key == '008':
            return Variation_900
        if key == '271':
            return Variation_918
        if key == '132':
            return Variation_29
        if key == '250':
            return Variation_321
        if key == '260':
            return Variation_912
        if key == '400':
            return Variation_0
        if key == '295':
            return Variation_914
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_922_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_921, Variation_921_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_852, Variation_852_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['071'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_705, Variation_705_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['131'], val : Union[Variation_632, Variation_632_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['072'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_719, Variation_719_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['151'], val : Union[Variation_855, Variation_855_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['073'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['074'], val : Union[Variation_858, Variation_858_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['075'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['076'], val : Union[Variation_860, Variation_860_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_868, Variation_868_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_872, Variation_872_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_873, Variation_873_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['145'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['152'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_917, Variation_917_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['155'], val : Union[Variation_880, Variation_880_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['157'], val : Union[Variation_881, Variation_881_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['160'], val : Union[Variation_883, Variation_883_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['165'], val : Union[Variation_885, Variation_885_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['077'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_886, Variation_886_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_731, Variation_731_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['146'], val : Union[Variation_887, Variation_887_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['148'], val : Union[Variation_891, Variation_891_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_754, Variation_754_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['016'], val : Union[Variation_892, Variation_892_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['008'], val : Union[Variation_900, Variation_900_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['271'], val : Union[Variation_918, Variation_918_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['132'], val : Union[Variation_29, Variation_29_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_912, Variation_912_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['295'], val : Union[Variation_914, Variation_914_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_922':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_922':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['071']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['131']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['072']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['151']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['073']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['074']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['075']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['076']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['145']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['152']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['155']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['157']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['160']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['165']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['077']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['146']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['148']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['016']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['008']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['271']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['132']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['295']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_922':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_922':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_921:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_852:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['071']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_705:
        ...

    @overload
    def get_item(self, name : Literal['131']) -> Variation_632:
        ...

    @overload
    def get_item(self, name : Literal['072']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_719:
        ...

    @overload
    def get_item(self, name : Literal['151']) -> Variation_855:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['073']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['074']) -> Variation_858:
        ...

    @overload
    def get_item(self, name : Literal['075']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['076']) -> Variation_860:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_868:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_872:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_873:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['145']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['152']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_917:
        ...

    @overload
    def get_item(self, name : Literal['155']) -> Variation_880:
        ...

    @overload
    def get_item(self, name : Literal['157']) -> Variation_881:
        ...

    @overload
    def get_item(self, name : Literal['160']) -> Variation_883:
        ...

    @overload
    def get_item(self, name : Literal['165']) -> Variation_885:
        ...

    @overload
    def get_item(self, name : Literal['077']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_886:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_731:
        ...

    @overload
    def get_item(self, name : Literal['146']) -> Variation_887:
        ...

    @overload
    def get_item(self, name : Literal['148']) -> Variation_891:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_754:
        ...

    @overload
    def get_item(self, name : Literal['016']) -> Variation_892:
        ...

    @overload
    def get_item(self, name : Literal['008']) -> Variation_900:
        ...

    @overload
    def get_item(self, name : Literal['271']) -> Variation_918:
        ...

    @overload
    def get_item(self, name : Literal['132']) -> Variation_29:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_912:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['295']) -> Variation_914:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['071'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['131'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['072'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['151'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['073'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['074'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['075'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['076'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['145'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['152'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['155'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['157'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['160'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['165'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['077'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['146'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['148'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['016'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['008'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['271'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['132'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['295'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_922':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_922':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_923_Arg : TypeAlias = Raw
class Variation_923(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 3
    table = {
        0: 'ED102/DO-260 [Ref. 7]',
        1: 'DO-260A [Ref. 8]',
        2: 'ED102A/DO-260B [Ref. 10]',
        3: 'ED-102B/DO-260C [Ref. 11]',
    }

    def __init__(self, arg : Variation_923_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_924_Arg_Group = TypedDict('Variation_924_Arg_Group', {
    'VNS': Union[Variation_869, Variation_869_Arg],
    'VN': Union[Variation_923, Variation_923_Arg],
    'LTT': Union[Variation_871, Variation_871_Arg],
})
Variation_924_Arg : TypeAlias = Union[Raw, Variation_924_Arg_Group]
class Variation_924(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 1),
        ('VNS', Variation_869),
        ('VN', Variation_923),
        ('LTT', Variation_871),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'VNS': ('Version Not Supported', Variation_869, 1, 1),
        'VN': ('Version Number', Variation_923, 2, 3),
        'LTT': ('Link Technology Type', Variation_871, 5, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VNS']) -> Type[Variation_869]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VN']) -> Type[Variation_923]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LTT']) -> Type[Variation_871]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VNS'], Literal['VN'], Literal['LTT']]) -> Union[Type['Variation_869'], Type['Variation_923'], Type['Variation_871']]:
        if key == 'VNS':
            return Variation_869
        if key == 'VN':
            return Variation_923
        if key == 'LTT':
            return Variation_871
        assert_never(key)

    def __init__(self, arg : Variation_924_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['VNS']) -> Variation_869:
        ...

    @overload
    def get_item(self, name : Literal['VN']) -> Variation_923:
        ...

    @overload
    def get_item(self, name : Literal['LTT']) -> Variation_871:
        ...

    def get_item(self, name : Union[Literal['VNS'], Literal['VN'], Literal['LTT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['VNS'], val : Union[Variation_869, Variation_869_Arg]) -> 'Variation_924':
        ...

    @overload
    def set_item(self, name : Literal['VN'], val : Union[Variation_923, Variation_923_Arg]) -> 'Variation_924':
        ...

    @overload
    def set_item(self, name : Literal['LTT'], val : Union[Variation_871, Variation_871_Arg]) -> 'Variation_924':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['VNS'], f : Any) -> 'Variation_924':
        ...

    @overload
    def modify_item(self, name : Literal['VN'], f : Any) -> 'Variation_924':
        ...

    @overload
    def modify_item(self, name : Literal['LTT'], f : Any) -> 'Variation_924':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_925_Arg = TypedDict('Variation_925_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '040': Union[Variation_921, Variation_921_Arg],
    '161': Union[Variation_852, Variation_852_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '071': Union[Variation_80, Variation_80_Arg],
    '130': Union[Variation_705, Variation_705_Arg],
    '131': Union[Variation_632, Variation_632_Arg],
    '072': Union[Variation_80, Variation_80_Arg],
    '150': Union[Variation_719, Variation_719_Arg],
    '151': Union[Variation_855, Variation_855_Arg],
    '080': Union[Variation_278, Variation_278_Arg],
    '073': Union[Variation_80, Variation_80_Arg],
    '074': Union[Variation_858, Variation_858_Arg],
    '075': Union[Variation_80, Variation_80_Arg],
    '076': Union[Variation_860, Variation_860_Arg],
    '140': Union[Variation_287, Variation_287_Arg],
    '090': Union[Variation_868, Variation_868_Arg],
    '210': Union[Variation_924, Variation_924_Arg],
    '070': Union[Variation_873, Variation_873_Arg],
    '230': Union[Variation_717, Variation_717_Arg],
    '145': Union[Variation_360, Variation_360_Arg],
    '152': Union[Variation_14, Variation_14_Arg],
    '200': Union[Variation_917, Variation_917_Arg],
    '155': Union[Variation_880, Variation_880_Arg],
    '157': Union[Variation_881, Variation_881_Arg],
    '160': Union[Variation_883, Variation_883_Arg],
    '165': Union[Variation_885, Variation_885_Arg],
    '077': Union[Variation_80, Variation_80_Arg],
    '170': Union[Variation_196, Variation_196_Arg],
    '020': Union[Variation_886, Variation_886_Arg],
    '220': Union[Variation_731, Variation_731_Arg],
    '146': Union[Variation_887, Variation_887_Arg],
    '148': Union[Variation_891, Variation_891_Arg],
    '110': Union[Variation_754, Variation_754_Arg],
    '016': Union[Variation_892, Variation_892_Arg],
    '008': Union[Variation_900, Variation_900_Arg],
    '271': Union[Variation_918, Variation_918_Arg],
    '132': Union[Variation_29, Variation_29_Arg],
    '250': Union[Variation_321, Variation_321_Arg],
    '260': Union[Variation_912, Variation_912_Arg],
    '400': Union[Variation_0, Variation_0_Arg],
    '295': Union[Variation_914, Variation_914_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_925(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 7

    subitems_list = [
        ('010', Variation_1),
        ('040', Variation_921),
        ('161', Variation_852),
        ('015', Variation_0),
        ('071', Variation_80),
        ('130', Variation_705),
        ('131', Variation_632),
        ('072', Variation_80),
        ('150', Variation_719),
        ('151', Variation_855),
        ('080', Variation_278),
        ('073', Variation_80),
        ('074', Variation_858),
        ('075', Variation_80),
        ('076', Variation_860),
        ('140', Variation_287),
        ('090', Variation_868),
        ('210', Variation_924),
        ('070', Variation_873),
        ('230', Variation_717),
        ('145', Variation_360),
        ('152', Variation_14),
        ('200', Variation_917),
        ('155', Variation_880),
        ('157', Variation_881),
        ('160', Variation_883),
        ('165', Variation_885),
        ('077', Variation_80),
        ('170', Variation_196),
        ('020', Variation_886),
        ('220', Variation_731),
        ('146', Variation_887),
        ('148', Variation_891),
        ('110', Variation_754),
        ('016', Variation_892),
        ('008', Variation_900),
        ('271', Variation_918),
        ('132', Variation_29),
        ('250', Variation_321),
        ('260', Variation_912),
        ('400', Variation_0),
        ('295', Variation_914),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identification', Variation_1, 0x80000000000000),
        '040': ('Target Report Descriptor', Variation_921, 0x40000000000000),
        '161': ('Track Number', Variation_852, 0x20000000000000),
        '015': ('Service Identification', Variation_0, 0x10000000000000),
        '071': ('Time of Applicability for Position', Variation_80, 0x08000000000000),
        '130': ('Position in WGS-84 Co-ordinates', Variation_705, 0x04000000000000),
        '131': ('High-Resolution Position in WGS-84 Co-ordinates', Variation_632, 0x02000000000000),
        '072': ('Time of Applicability for Velocity', Variation_80, 0x01800000000000),
        '150': ('Air Speed', Variation_719, 0x01400000000000),
        '151': ('True Airspeed', Variation_855, 0x01200000000000),
        '080': ('Target Address', Variation_278, 0x01100000000000),
        '073': ('Time of Message Reception for Position', Variation_80, 0x01080000000000),
        '074': ('Time of Message Reception of Position-High Precision', Variation_858, 0x01040000000000),
        '075': ('Time of Message Reception for Velocity', Variation_80, 0x01020000000000),
        '076': ('Time of Message Reception of Velocity-High Precision', Variation_860, 0x01018000000000),
        '140': ('Geometric Height', Variation_287, 0x01014000000000),
        '090': ('Quality Indicators', Variation_868, 0x01012000000000),
        '210': ('MOPS Version', Variation_924, 0x01011000000000),
        '070': ('Mode 3/A Code in Octal Representation', Variation_873, 0x01010800000000),
        '230': ('Roll Angle', Variation_717, 0x01010400000000),
        '145': ('Flight Level', Variation_360, 0x01010200000000),
        '152': ('Magnetic Heading', Variation_14, 0x01010180000000),
        '200': ('Target Status', Variation_917, 0x01010140000000),
        '155': ('Barometric Vertical Rate', Variation_880, 0x01010120000000),
        '157': ('Geometric Vertical Rate', Variation_881, 0x01010110000000),
        '160': ('Airborne Ground Vector', Variation_883, 0x01010108000000),
        '165': ('Track Angle Rate', Variation_885, 0x01010104000000),
        '077': ('Time of ASTERIX Report Transmission', Variation_80, 0x01010102000000),
        '170': ('Target Identification', Variation_196, 0x01010101800000),
        '020': ('Emitter Category', Variation_886, 0x01010101400000),
        '220': ('Met Information', Variation_731, 0x01010101200000),
        '146': ('Selected Altitude', Variation_887, 0x01010101100000),
        '148': ('Final State Selected Altitude', Variation_891, 0x01010101080000),
        '110': ('Trajectory Intent', Variation_754, 0x01010101040000),
        '016': ('Service Management', Variation_892, 0x01010101020000),
        '008': ('Aircraft Operational Status', Variation_900, 0x01010101018000),
        '271': ('Surface Capabilities and Characteristics', Variation_918, 0x01010101014000),
        '132': ('Message Amplitude', Variation_29, 0x01010101012000),
        '250': ('Mode S MB Data', Variation_321, 0x01010101011000),
        '260': ('ACAS Resolution Advisory Report', Variation_912, 0x01010101010800),
        '400': ('Receiver ID', Variation_0, 0x01010101010400),
        '295': ('Data Ages', Variation_914, 0x01010101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x01010101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_921]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_852]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['071']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_705]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['131']) -> Type[Variation_632]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['072']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_719]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['151']) -> Type[Variation_855]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['073']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['074']) -> Type[Variation_858]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['075']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['076']) -> Type[Variation_860]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_868]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_924]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_873]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['145']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['152']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_917]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['155']) -> Type[Variation_880]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['157']) -> Type[Variation_881]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['160']) -> Type[Variation_883]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['165']) -> Type[Variation_885]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['077']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_886]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_731]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['146']) -> Type[Variation_887]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['148']) -> Type[Variation_891]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_754]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['016']) -> Type[Variation_892]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['008']) -> Type[Variation_900]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['271']) -> Type[Variation_918]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['132']) -> Type[Variation_29]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_912]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['295']) -> Type[Variation_914]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['040'], Literal['161'], Literal['015'], Literal['071'], Literal['130'], Literal['131'], Literal['072'], Literal['150'], Literal['151'], Literal['080'], Literal['073'], Literal['074'], Literal['075'], Literal['076'], Literal['140'], Literal['090'], Literal['210'], Literal['070'], Literal['230'], Literal['145'], Literal['152'], Literal['200'], Literal['155'], Literal['157'], Literal['160'], Literal['165'], Literal['077'], Literal['170'], Literal['020'], Literal['220'], Literal['146'], Literal['148'], Literal['110'], Literal['016'], Literal['008'], Literal['271'], Literal['132'], Literal['250'], Literal['260'], Literal['400'], Literal['295'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_921'], Type['Variation_852'], Type['Variation_0'], Type['Variation_80'], Type['Variation_705'], Type['Variation_632'], Type['Variation_80'], Type['Variation_719'], Type['Variation_855'], Type['Variation_278'], Type['Variation_80'], Type['Variation_858'], Type['Variation_80'], Type['Variation_860'], Type['Variation_287'], Type['Variation_868'], Type['Variation_924'], Type['Variation_873'], Type['Variation_717'], Type['Variation_360'], Type['Variation_14'], Type['Variation_917'], Type['Variation_880'], Type['Variation_881'], Type['Variation_883'], Type['Variation_885'], Type['Variation_80'], Type['Variation_196'], Type['Variation_886'], Type['Variation_731'], Type['Variation_887'], Type['Variation_891'], Type['Variation_754'], Type['Variation_892'], Type['Variation_900'], Type['Variation_918'], Type['Variation_29'], Type['Variation_321'], Type['Variation_912'], Type['Variation_0'], Type['Variation_914'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '040':
            return Variation_921
        if key == '161':
            return Variation_852
        if key == '015':
            return Variation_0
        if key == '071':
            return Variation_80
        if key == '130':
            return Variation_705
        if key == '131':
            return Variation_632
        if key == '072':
            return Variation_80
        if key == '150':
            return Variation_719
        if key == '151':
            return Variation_855
        if key == '080':
            return Variation_278
        if key == '073':
            return Variation_80
        if key == '074':
            return Variation_858
        if key == '075':
            return Variation_80
        if key == '076':
            return Variation_860
        if key == '140':
            return Variation_287
        if key == '090':
            return Variation_868
        if key == '210':
            return Variation_924
        if key == '070':
            return Variation_873
        if key == '230':
            return Variation_717
        if key == '145':
            return Variation_360
        if key == '152':
            return Variation_14
        if key == '200':
            return Variation_917
        if key == '155':
            return Variation_880
        if key == '157':
            return Variation_881
        if key == '160':
            return Variation_883
        if key == '165':
            return Variation_885
        if key == '077':
            return Variation_80
        if key == '170':
            return Variation_196
        if key == '020':
            return Variation_886
        if key == '220':
            return Variation_731
        if key == '146':
            return Variation_887
        if key == '148':
            return Variation_891
        if key == '110':
            return Variation_754
        if key == '016':
            return Variation_892
        if key == '008':
            return Variation_900
        if key == '271':
            return Variation_918
        if key == '132':
            return Variation_29
        if key == '250':
            return Variation_321
        if key == '260':
            return Variation_912
        if key == '400':
            return Variation_0
        if key == '295':
            return Variation_914
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_925_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_921, Variation_921_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_852, Variation_852_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['071'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_705, Variation_705_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['131'], val : Union[Variation_632, Variation_632_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['072'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_719, Variation_719_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['151'], val : Union[Variation_855, Variation_855_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['073'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['074'], val : Union[Variation_858, Variation_858_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['075'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['076'], val : Union[Variation_860, Variation_860_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_868, Variation_868_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_924, Variation_924_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_873, Variation_873_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['145'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['152'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_917, Variation_917_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['155'], val : Union[Variation_880, Variation_880_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['157'], val : Union[Variation_881, Variation_881_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['160'], val : Union[Variation_883, Variation_883_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['165'], val : Union[Variation_885, Variation_885_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['077'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_886, Variation_886_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_731, Variation_731_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['146'], val : Union[Variation_887, Variation_887_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['148'], val : Union[Variation_891, Variation_891_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_754, Variation_754_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['016'], val : Union[Variation_892, Variation_892_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['008'], val : Union[Variation_900, Variation_900_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['271'], val : Union[Variation_918, Variation_918_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['132'], val : Union[Variation_29, Variation_29_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_912, Variation_912_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['295'], val : Union[Variation_914, Variation_914_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_925':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_925':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['071']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['131']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['072']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['151']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['073']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['074']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['075']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['076']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['145']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['152']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['155']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['157']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['160']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['165']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['077']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['146']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['148']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['016']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['008']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['271']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['132']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['295']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_925':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_925':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_921:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_852:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['071']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_705:
        ...

    @overload
    def get_item(self, name : Literal['131']) -> Variation_632:
        ...

    @overload
    def get_item(self, name : Literal['072']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_719:
        ...

    @overload
    def get_item(self, name : Literal['151']) -> Variation_855:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['073']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['074']) -> Variation_858:
        ...

    @overload
    def get_item(self, name : Literal['075']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['076']) -> Variation_860:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_868:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_924:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_873:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['145']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['152']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_917:
        ...

    @overload
    def get_item(self, name : Literal['155']) -> Variation_880:
        ...

    @overload
    def get_item(self, name : Literal['157']) -> Variation_881:
        ...

    @overload
    def get_item(self, name : Literal['160']) -> Variation_883:
        ...

    @overload
    def get_item(self, name : Literal['165']) -> Variation_885:
        ...

    @overload
    def get_item(self, name : Literal['077']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_886:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_731:
        ...

    @overload
    def get_item(self, name : Literal['146']) -> Variation_887:
        ...

    @overload
    def get_item(self, name : Literal['148']) -> Variation_891:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_754:
        ...

    @overload
    def get_item(self, name : Literal['016']) -> Variation_892:
        ...

    @overload
    def get_item(self, name : Literal['008']) -> Variation_900:
        ...

    @overload
    def get_item(self, name : Literal['271']) -> Variation_918:
        ...

    @overload
    def get_item(self, name : Literal['132']) -> Variation_29:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_912:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['295']) -> Variation_914:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['071'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['131'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['072'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['151'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['073'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['074'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['075'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['076'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['145'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['152'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['155'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['157'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['160'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['165'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['077'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['146'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['148'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['016'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['008'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['271'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['132'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['295'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_925':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_925':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_926_Arg : TypeAlias = Raw
class Variation_926(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 6

    def __init__(self, arg : Variation_926_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_927_Arg_Group = TypedDict('Variation_927_Arg_Group', {
    'EP': Union[Variation_816, Variation_816_Arg],
    'VAL': Union[Variation_926, Variation_926_Arg],
})
Variation_927_Arg : TypeAlias = Union[Raw, Variation_927_Arg_Group]
class Variation_927(Group):
    variation = 'Group'

    bit_size = 7

    subitems_list = [
        ('EP', Variation_816),
        ('VAL', Variation_926),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_816, 0, 1),
        'VAL': ('Value', Variation_926, 1, 6),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_816]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_926]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_816'], Type['Variation_926']]:
        if key == 'EP':
            return Variation_816
        if key == 'VAL':
            return Variation_926
        assert_never(key)

    def __init__(self, arg : Variation_927_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_816:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_926:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_816, Variation_816_Arg]) -> 'Variation_927':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_926, Variation_926_Arg]) -> 'Variation_927':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_927':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_927':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_928_Arg_Group_1 = TypedDict('Variation_928_Arg_Group_1', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
})
Variation_928_Arg_Group_2 = TypedDict('Variation_928_Arg_Group_2', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
    'DCR': Union[Variation_694, Variation_694_Arg],
    'GBS': Union[Variation_695, Variation_695_Arg],
    'SIM': Union[Variation_696, Variation_696_Arg],
    'TST': Union[Variation_697, Variation_697_Arg],
    'SAA': Union[Variation_844, Variation_844_Arg],
    'CL': Union[Variation_845, Variation_845_Arg],
})
Variation_928_Arg_Group_3 = TypedDict('Variation_928_Arg_Group_3', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
    'DCR': Union[Variation_694, Variation_694_Arg],
    'GBS': Union[Variation_695, Variation_695_Arg],
    'SIM': Union[Variation_696, Variation_696_Arg],
    'TST': Union[Variation_697, Variation_697_Arg],
    'SAA': Union[Variation_844, Variation_844_Arg],
    'CL': Union[Variation_845, Variation_845_Arg],
    'LLC': Union[Variation_920, Variation_920_Arg],
    'IPC': Union[Variation_846, Variation_846_Arg],
    'NOGO': Union[Variation_847, Variation_847_Arg],
    'CPR': Union[Variation_848, Variation_848_Arg],
    'LDPJ': Union[Variation_849, Variation_849_Arg],
    'RCF': Union[Variation_850, Variation_850_Arg],
})
Variation_928_Arg_Group_4 = TypedDict('Variation_928_Arg_Group_4', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
    'DCR': Union[Variation_694, Variation_694_Arg],
    'GBS': Union[Variation_695, Variation_695_Arg],
    'SIM': Union[Variation_696, Variation_696_Arg],
    'TST': Union[Variation_697, Variation_697_Arg],
    'SAA': Union[Variation_844, Variation_844_Arg],
    'CL': Union[Variation_845, Variation_845_Arg],
    'LLC': Union[Variation_920, Variation_920_Arg],
    'IPC': Union[Variation_846, Variation_846_Arg],
    'NOGO': Union[Variation_847, Variation_847_Arg],
    'CPR': Union[Variation_848, Variation_848_Arg],
    'LDPJ': Union[Variation_849, Variation_849_Arg],
    'RCF': Union[Variation_850, Variation_850_Arg],
    'TBC': Union[Variation_927, Variation_927_Arg],
})
Variation_928_Arg_Group_5 = TypedDict('Variation_928_Arg_Group_5', {
    'ATP': Union[Variation_840, Variation_840_Arg],
    'ARC': Union[Variation_841, Variation_841_Arg],
    'RC': Union[Variation_842, Variation_842_Arg],
    'RAB': Union[Variation_843, Variation_843_Arg],
    'DCR': Union[Variation_694, Variation_694_Arg],
    'GBS': Union[Variation_695, Variation_695_Arg],
    'SIM': Union[Variation_696, Variation_696_Arg],
    'TST': Union[Variation_697, Variation_697_Arg],
    'SAA': Union[Variation_844, Variation_844_Arg],
    'CL': Union[Variation_845, Variation_845_Arg],
    'LLC': Union[Variation_920, Variation_920_Arg],
    'IPC': Union[Variation_846, Variation_846_Arg],
    'NOGO': Union[Variation_847, Variation_847_Arg],
    'CPR': Union[Variation_848, Variation_848_Arg],
    'LDPJ': Union[Variation_849, Variation_849_Arg],
    'RCF': Union[Variation_850, Variation_850_Arg],
    'TBC': Union[Variation_927, Variation_927_Arg],
    'MBC': Union[Variation_927, Variation_927_Arg],
})
Variation_928_Arg : TypeAlias = Union[
    int,
    Variation_928_Arg_Group_1,
    Tuple[int],
    Variation_928_Arg_Group_2,
    Tuple[int,int],
    Variation_928_Arg_Group_3,
    Tuple[int,int,int],
    Variation_928_Arg_Group_4,
    Tuple[int,int,int,int],
    Variation_928_Arg_Group_5,
    Tuple[int,int,int,int,int],
]
class Variation_928(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('ATP', Variation_840),
            ('ARC', Variation_841),
            ('RC', Variation_842),
            ('RAB', Variation_843),
        ],
        [
            ('DCR', Variation_694),
            ('GBS', Variation_695),
            ('SIM', Variation_696),
            ('TST', Variation_697),
            ('SAA', Variation_844),
            ('CL', Variation_845),
        ],
        [
            Spare(0, 1),
            ('LLC', Variation_920),
            ('IPC', Variation_846),
            ('NOGO', Variation_847),
            ('CPR', Variation_848),
            ('LDPJ', Variation_849),
            ('RCF', Variation_850),
        ],
        [
            ('TBC', Variation_927),
        ],
        [
            ('MBC', Variation_927),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ATP': ('Address Type', Variation_840, 0, 3),
        'ARC': ('Altitude Reporting Capability', Variation_841, 3, 2),
        'RC': ('Range Check', Variation_842, 5, 1),
        'RAB': ('Report Type', Variation_843, 6, 1),
        'DCR': ('Differential Correction', Variation_694, 0, 1),
        'GBS': ('Ground Bit Setting', Variation_695, 1, 1),
        'SIM': ('Simulated Target', Variation_696, 2, 1),
        'TST': ('Test Target', Variation_697, 3, 1),
        'SAA': ('Selected Altitude Available', Variation_844, 4, 1),
        'CL': ('Confidence Level', Variation_845, 5, 2),
        'LLC': ('List Lookup Check', Variation_920, 1, 1),
        'IPC': ('Independent Position Check', Variation_846, 2, 1),
        'NOGO': ('No-go Bit Status', Variation_847, 3, 1),
        'CPR': ('Compact Position Reporting', Variation_848, 4, 1),
        'LDPJ': ('Local Decoding Position Jump', Variation_849, 5, 1),
        'RCF': ('Range Check', Variation_850, 6, 1),
        'TBC': ('Total Bits Corrected', Variation_927, 0, 7),
        'MBC': ('Maximum Bits Corrected', Variation_927, 0, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ATP']) -> Type[Variation_840]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_841]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RC']) -> Type[Variation_842]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_843]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DCR']) -> Type[Variation_694]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GBS']) -> Type[Variation_695]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_696]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_697]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAA']) -> Type[Variation_844]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CL']) -> Type[Variation_845]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LLC']) -> Type[Variation_920]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IPC']) -> Type[Variation_846]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOGO']) -> Type[Variation_847]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CPR']) -> Type[Variation_848]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LDPJ']) -> Type[Variation_849]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RCF']) -> Type[Variation_850]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TBC']) -> Type[Variation_927]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MBC']) -> Type[Variation_927]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ATP'], Literal['ARC'], Literal['RC'], Literal['RAB'], Literal['DCR'], Literal['GBS'], Literal['SIM'], Literal['TST'], Literal['SAA'], Literal['CL'], Literal['LLC'], Literal['IPC'], Literal['NOGO'], Literal['CPR'], Literal['LDPJ'], Literal['RCF'], Literal['TBC'], Literal['MBC']]) -> Union[Type['Variation_840'], Type['Variation_841'], Type['Variation_842'], Type['Variation_843'], Type['Variation_694'], Type['Variation_695'], Type['Variation_696'], Type['Variation_697'], Type['Variation_844'], Type['Variation_845'], Type['Variation_920'], Type['Variation_846'], Type['Variation_847'], Type['Variation_848'], Type['Variation_849'], Type['Variation_850'], Type['Variation_927'], Type['Variation_927']]:
        if key == 'ATP':
            return Variation_840
        if key == 'ARC':
            return Variation_841
        if key == 'RC':
            return Variation_842
        if key == 'RAB':
            return Variation_843
        if key == 'DCR':
            return Variation_694
        if key == 'GBS':
            return Variation_695
        if key == 'SIM':
            return Variation_696
        if key == 'TST':
            return Variation_697
        if key == 'SAA':
            return Variation_844
        if key == 'CL':
            return Variation_845
        if key == 'LLC':
            return Variation_920
        if key == 'IPC':
            return Variation_846
        if key == 'NOGO':
            return Variation_847
        if key == 'CPR':
            return Variation_848
        if key == 'LDPJ':
            return Variation_849
        if key == 'RCF':
            return Variation_850
        if key == 'TBC':
            return Variation_927
        if key == 'MBC':
            return Variation_927
        assert_never(key)

    def __init__(self, arg : Variation_928_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_928_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_928_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_928_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            if Variation_928_Arg_Group_4.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(4, arg)); return
            if Variation_928_Arg_Group_5.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(5, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ATP']) -> Variation_840:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_841:
        ...

    @overload
    def get_item(self, name : Literal['RC']) -> Variation_842:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_843:
        ...

    @overload
    def get_item(self, name : Literal['DCR']) -> Variation_694:
        ...

    @overload
    def get_item(self, name : Literal['GBS']) -> Variation_695:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_696:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_697:
        ...

    @overload
    def get_item(self, name : Literal['SAA']) -> Variation_844:
        ...

    @overload
    def get_item(self, name : Literal['CL']) -> Variation_845:
        ...

    @overload
    def get_item(self, name : Literal['LLC']) -> Variation_920:
        ...

    @overload
    def get_item(self, name : Literal['IPC']) -> Variation_846:
        ...

    @overload
    def get_item(self, name : Literal['NOGO']) -> Variation_847:
        ...

    @overload
    def get_item(self, name : Literal['CPR']) -> Variation_848:
        ...

    @overload
    def get_item(self, name : Literal['LDPJ']) -> Variation_849:
        ...

    @overload
    def get_item(self, name : Literal['RCF']) -> Variation_850:
        ...

    @overload
    def get_item(self, name : Literal['TBC']) -> Variation_927:
        ...

    @overload
    def get_item(self, name : Literal['MBC']) -> Variation_927:
        ...

    def get_item(self, name : Union[Literal['ATP'], Literal['ARC'], Literal['RC'], Literal['RAB'], Literal['DCR'], Literal['GBS'], Literal['SIM'], Literal['TST'], Literal['SAA'], Literal['CL'], Literal['LLC'], Literal['IPC'], Literal['NOGO'], Literal['CPR'], Literal['LDPJ'], Literal['RCF'], Literal['TBC'], Literal['MBC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ATP'], val : Union[Variation_840, Variation_840_Arg]) -> 'Variation_928':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_841, Variation_841_Arg]) -> 'Variation_928':
        ...

    @overload
    def set_item(self, name : Literal['RC'], val : Union[Variation_842, Variation_842_Arg]) -> 'Variation_928':
        ...

    @overload
    def set_item(self, name : Literal['RAB'], val : Union[Variation_843, Variation_843_Arg]) -> 'Variation_928':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ATP'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['RC'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['DCR'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['GBS'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['SAA'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['CL'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['LLC'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['IPC'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['NOGO'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['CPR'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['LDPJ'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['RCF'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['TBC'], f : Any) -> 'Variation_928':
        ...

    @overload
    def modify_item(self, name : Literal['MBC'], f : Any) -> 'Variation_928':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_929_Arg = TypedDict('Variation_929_Arg', {
    'AOS': Union[Variation_913, Variation_913_Arg],
    'TRD': Union[Variation_913, Variation_913_Arg],
    'M3A': Union[Variation_913, Variation_913_Arg],
    'QI': Union[Variation_913, Variation_913_Arg],
    'TI1': Union[Variation_913, Variation_913_Arg],
    'MAM': Union[Variation_913, Variation_913_Arg],
    'GH': Union[Variation_913, Variation_913_Arg],
    'FL': Union[Variation_913, Variation_913_Arg],
    'SAL': Union[Variation_913, Variation_913_Arg],
    'FSA': Union[Variation_913, Variation_913_Arg],
    'AS': Union[Variation_913, Variation_913_Arg],
    'TAS': Union[Variation_913, Variation_913_Arg],
    'MH': Union[Variation_913, Variation_913_Arg],
    'BVR': Union[Variation_913, Variation_913_Arg],
    'GVR': Union[Variation_913, Variation_913_Arg],
    'GV': Union[Variation_913, Variation_913_Arg],
    'TAR': Union[Variation_913, Variation_913_Arg],
    'TI2': Union[Variation_913, Variation_913_Arg],
    'TS': Union[Variation_913, Variation_913_Arg],
    'MET': Union[Variation_913, Variation_913_Arg],
    'ROA': Union[Variation_913, Variation_913_Arg],
    'ARA': Union[Variation_913, Variation_913_Arg],
    'SCC': Union[Variation_913, Variation_913_Arg],
}, total=False)
class Variation_929(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('AOS', Variation_913),
        ('TRD', Variation_913),
        ('M3A', Variation_913),
        ('QI', Variation_913),
        ('TI1', Variation_913),
        ('MAM', Variation_913),
        ('GH', Variation_913),
        ('FL', Variation_913),
        ('SAL', Variation_913),
        ('FSA', Variation_913),
        ('AS', Variation_913),
        ('TAS', Variation_913),
        ('MH', Variation_913),
        ('BVR', Variation_913),
        ('GVR', Variation_913),
        ('GV', Variation_913),
        ('TAR', Variation_913),
        ('TI2', Variation_913),
        ('TS', Variation_913),
        ('MET', Variation_913),
        ('ROA', Variation_913),
        ('ARA', Variation_913),
        ('SCC', Variation_913),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'AOS': ('Aircraft Operational Status Age', Variation_913, 0x80000000),
        'TRD': ('Target Report Descriptor Age', Variation_913, 0x40000000),
        'M3A': ('Mode 3/A Age', Variation_913, 0x20000000),
        'QI': ('Quality Indicators Age', Variation_913, 0x10000000),
        'TI1': ('Trajectory Intent Age', Variation_913, 0x08000000),
        'MAM': ('Message Amplitude Age', Variation_913, 0x04000000),
        'GH': ('Geometric Height Age', Variation_913, 0x02000000),
        'FL': ('Flight Level Age', Variation_913, 0x01800000),
        'SAL': ('Selected Altitude Age', Variation_913, 0x01400000),
        'FSA': ('Final State Selected Altitude Age', Variation_913, 0x01200000),
        'AS': ('Air Speed Age', Variation_913, 0x01100000),
        'TAS': ('True Air Speed Age', Variation_913, 0x01080000),
        'MH': ('Magnetic Heading Age', Variation_913, 0x01040000),
        'BVR': ('Barometric Vertical Rate Age', Variation_913, 0x01020000),
        'GVR': ('Geometric Vertical Rate Age', Variation_913, 0x01018000),
        'GV': ('Ground Vector Age', Variation_913, 0x01014000),
        'TAR': ('Track Angle Rate Age', Variation_913, 0x01012000),
        'TI2': ('Target Identification Age', Variation_913, 0x01011000),
        'TS': ('Target Status Age', Variation_913, 0x01010800),
        'MET': ('Met Information Age', Variation_913, 0x01010400),
        'ROA': ('Roll Angle Age', Variation_913, 0x01010200),
        'ARA': ('ACAS Resolution Advisory Age', Variation_913, 0x01010180),
        'SCC': ('Surface Capabilities and Characteristics Age', Variation_913, 0x01010140),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AOS']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRD']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M3A']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QI']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TI1']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAM']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GH']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FL']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAL']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FSA']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AS']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAS']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MH']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BVR']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GVR']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GV']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAR']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TI2']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TS']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MET']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ROA']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARA']) -> Type[Variation_913]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SCC']) -> Type[Variation_913]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AOS'], Literal['TRD'], Literal['M3A'], Literal['QI'], Literal['TI1'], Literal['MAM'], Literal['GH'], Literal['FL'], Literal['SAL'], Literal['FSA'], Literal['AS'], Literal['TAS'], Literal['MH'], Literal['BVR'], Literal['GVR'], Literal['GV'], Literal['TAR'], Literal['TI2'], Literal['TS'], Literal['MET'], Literal['ROA'], Literal['ARA'], Literal['SCC']]) -> Union[Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913'], Type['Variation_913']]:
        if key == 'AOS':
            return Variation_913
        if key == 'TRD':
            return Variation_913
        if key == 'M3A':
            return Variation_913
        if key == 'QI':
            return Variation_913
        if key == 'TI1':
            return Variation_913
        if key == 'MAM':
            return Variation_913
        if key == 'GH':
            return Variation_913
        if key == 'FL':
            return Variation_913
        if key == 'SAL':
            return Variation_913
        if key == 'FSA':
            return Variation_913
        if key == 'AS':
            return Variation_913
        if key == 'TAS':
            return Variation_913
        if key == 'MH':
            return Variation_913
        if key == 'BVR':
            return Variation_913
        if key == 'GVR':
            return Variation_913
        if key == 'GV':
            return Variation_913
        if key == 'TAR':
            return Variation_913
        if key == 'TI2':
            return Variation_913
        if key == 'TS':
            return Variation_913
        if key == 'MET':
            return Variation_913
        if key == 'ROA':
            return Variation_913
        if key == 'ARA':
            return Variation_913
        if key == 'SCC':
            return Variation_913
        assert_never(key)

    def __init__(self, arg : Optional[Variation_929_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['AOS'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['TRD'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['M3A'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['QI'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['TI1'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['MAM'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['GH'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['FL'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['SAL'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['FSA'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['AS'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['TAS'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['MH'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['BVR'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['GVR'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['GV'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['TAR'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['TI2'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['TS'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['MET'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['ROA'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['ARA'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    @overload
    def set_item(self, name : Literal['SCC'], val : Union[Variation_913, Variation_913_Arg]) -> 'Variation_929':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['AOS']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['TRD']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['M3A']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['QI']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['TI1']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['MAM']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['GH']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['FL']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['SAL']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['FSA']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['AS']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['TAS']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['MH']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['BVR']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['GVR']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['GV']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['TAR']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['TI2']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['TS']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['MET']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['ROA']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['ARA']) -> 'Variation_929':
        ...

    @overload
    def del_item(self, name : Literal['SCC']) -> 'Variation_929':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['AOS']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TRD']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['M3A']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['QI']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TI1']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['MAM']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['GH']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['FL']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['SAL']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['FSA']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['AS']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TAS']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['MH']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['BVR']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['GVR']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['GV']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TAR']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TI2']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['TS']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['MET']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['ROA']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['ARA']) -> Variation_913:
        ...

    @overload
    def get_item(self, name : Literal['SCC']) -> Variation_913:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['AOS'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['TRD'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['M3A'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['QI'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['TI1'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['MAM'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['GH'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['FL'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['SAL'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['FSA'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['AS'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['TAS'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['MH'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['BVR'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['GVR'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['GV'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['TAR'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['TI2'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['TS'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['MET'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['ROA'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['ARA'], f : Any) -> 'Variation_929':
        ...

    @overload
    def modify_item(self, name : Literal['SCC'], f : Any) -> 'Variation_929':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_930_Arg = TypedDict('Variation_930_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '040': Union[Variation_928, Variation_928_Arg],
    '161': Union[Variation_852, Variation_852_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '071': Union[Variation_80, Variation_80_Arg],
    '130': Union[Variation_705, Variation_705_Arg],
    '131': Union[Variation_632, Variation_632_Arg],
    '072': Union[Variation_80, Variation_80_Arg],
    '150': Union[Variation_719, Variation_719_Arg],
    '151': Union[Variation_855, Variation_855_Arg],
    '080': Union[Variation_278, Variation_278_Arg],
    '073': Union[Variation_80, Variation_80_Arg],
    '074': Union[Variation_858, Variation_858_Arg],
    '075': Union[Variation_80, Variation_80_Arg],
    '076': Union[Variation_860, Variation_860_Arg],
    '140': Union[Variation_287, Variation_287_Arg],
    '090': Union[Variation_868, Variation_868_Arg],
    '210': Union[Variation_924, Variation_924_Arg],
    '070': Union[Variation_873, Variation_873_Arg],
    '230': Union[Variation_717, Variation_717_Arg],
    '145': Union[Variation_360, Variation_360_Arg],
    '152': Union[Variation_14, Variation_14_Arg],
    '200': Union[Variation_917, Variation_917_Arg],
    '155': Union[Variation_880, Variation_880_Arg],
    '157': Union[Variation_881, Variation_881_Arg],
    '160': Union[Variation_883, Variation_883_Arg],
    '165': Union[Variation_885, Variation_885_Arg],
    '077': Union[Variation_80, Variation_80_Arg],
    '170': Union[Variation_196, Variation_196_Arg],
    '020': Union[Variation_886, Variation_886_Arg],
    '220': Union[Variation_731, Variation_731_Arg],
    '146': Union[Variation_887, Variation_887_Arg],
    '148': Union[Variation_891, Variation_891_Arg],
    '110': Union[Variation_754, Variation_754_Arg],
    '016': Union[Variation_892, Variation_892_Arg],
    '008': Union[Variation_900, Variation_900_Arg],
    '271': Union[Variation_918, Variation_918_Arg],
    '132': Union[Variation_29, Variation_29_Arg],
    '250': Union[Variation_321, Variation_321_Arg],
    '260': Union[Variation_912, Variation_912_Arg],
    '400': Union[Variation_0, Variation_0_Arg],
    '295': Union[Variation_929, Variation_929_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_930(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 7

    subitems_list = [
        ('010', Variation_1),
        ('040', Variation_928),
        ('161', Variation_852),
        ('015', Variation_0),
        ('071', Variation_80),
        ('130', Variation_705),
        ('131', Variation_632),
        ('072', Variation_80),
        ('150', Variation_719),
        ('151', Variation_855),
        ('080', Variation_278),
        ('073', Variation_80),
        ('074', Variation_858),
        ('075', Variation_80),
        ('076', Variation_860),
        ('140', Variation_287),
        ('090', Variation_868),
        ('210', Variation_924),
        ('070', Variation_873),
        ('230', Variation_717),
        ('145', Variation_360),
        ('152', Variation_14),
        ('200', Variation_917),
        ('155', Variation_880),
        ('157', Variation_881),
        ('160', Variation_883),
        ('165', Variation_885),
        ('077', Variation_80),
        ('170', Variation_196),
        ('020', Variation_886),
        ('220', Variation_731),
        ('146', Variation_887),
        ('148', Variation_891),
        ('110', Variation_754),
        ('016', Variation_892),
        ('008', Variation_900),
        ('271', Variation_918),
        ('132', Variation_29),
        ('250', Variation_321),
        ('260', Variation_912),
        ('400', Variation_0),
        ('295', Variation_929),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identification', Variation_1, 0x80000000000000),
        '040': ('Target Report Descriptor', Variation_928, 0x40000000000000),
        '161': ('Track Number', Variation_852, 0x20000000000000),
        '015': ('Service Identification', Variation_0, 0x10000000000000),
        '071': ('Time of Applicability for Position', Variation_80, 0x08000000000000),
        '130': ('Position in WGS-84 Co-ordinates', Variation_705, 0x04000000000000),
        '131': ('High-Resolution Position in WGS-84 Co-ordinates', Variation_632, 0x02000000000000),
        '072': ('Time of Applicability for Velocity', Variation_80, 0x01800000000000),
        '150': ('Air Speed', Variation_719, 0x01400000000000),
        '151': ('True Airspeed', Variation_855, 0x01200000000000),
        '080': ('Target Address', Variation_278, 0x01100000000000),
        '073': ('Time of Message Reception for Position', Variation_80, 0x01080000000000),
        '074': ('Time of Message Reception of Position-High Precision', Variation_858, 0x01040000000000),
        '075': ('Time of Message Reception for Velocity', Variation_80, 0x01020000000000),
        '076': ('Time of Message Reception of Velocity-High Precision', Variation_860, 0x01018000000000),
        '140': ('Geometric Height', Variation_287, 0x01014000000000),
        '090': ('Quality Indicators', Variation_868, 0x01012000000000),
        '210': ('MOPS Version', Variation_924, 0x01011000000000),
        '070': ('Mode 3/A Code in Octal Representation', Variation_873, 0x01010800000000),
        '230': ('Roll Angle', Variation_717, 0x01010400000000),
        '145': ('Flight Level', Variation_360, 0x01010200000000),
        '152': ('Magnetic Heading', Variation_14, 0x01010180000000),
        '200': ('Target Status', Variation_917, 0x01010140000000),
        '155': ('Barometric Vertical Rate', Variation_880, 0x01010120000000),
        '157': ('Geometric Vertical Rate', Variation_881, 0x01010110000000),
        '160': ('Airborne Ground Vector', Variation_883, 0x01010108000000),
        '165': ('Track Angle Rate', Variation_885, 0x01010104000000),
        '077': ('Time of ASTERIX Report Transmission', Variation_80, 0x01010102000000),
        '170': ('Target Identification', Variation_196, 0x01010101800000),
        '020': ('Emitter Category', Variation_886, 0x01010101400000),
        '220': ('Met Information', Variation_731, 0x01010101200000),
        '146': ('Selected Altitude', Variation_887, 0x01010101100000),
        '148': ('Final State Selected Altitude', Variation_891, 0x01010101080000),
        '110': ('Trajectory Intent', Variation_754, 0x01010101040000),
        '016': ('Service Management', Variation_892, 0x01010101020000),
        '008': ('Aircraft Operational Status', Variation_900, 0x01010101018000),
        '271': ('Surface Capabilities and Characteristics', Variation_918, 0x01010101014000),
        '132': ('Message Amplitude', Variation_29, 0x01010101012000),
        '250': ('Mode S MB Data', Variation_321, 0x01010101011000),
        '260': ('ACAS Resolution Advisory Report', Variation_912, 0x01010101010800),
        '400': ('Receiver ID', Variation_0, 0x01010101010400),
        '295': ('Data Ages', Variation_929, 0x01010101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x01010101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_928]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_852]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['071']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_705]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['131']) -> Type[Variation_632]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['072']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_719]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['151']) -> Type[Variation_855]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['073']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['074']) -> Type[Variation_858]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['075']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['076']) -> Type[Variation_860]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_868]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_924]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_873]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['145']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['152']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_917]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['155']) -> Type[Variation_880]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['157']) -> Type[Variation_881]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['160']) -> Type[Variation_883]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['165']) -> Type[Variation_885]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['077']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_886]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_731]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['146']) -> Type[Variation_887]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['148']) -> Type[Variation_891]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_754]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['016']) -> Type[Variation_892]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['008']) -> Type[Variation_900]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['271']) -> Type[Variation_918]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['132']) -> Type[Variation_29]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_912]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['295']) -> Type[Variation_929]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['040'], Literal['161'], Literal['015'], Literal['071'], Literal['130'], Literal['131'], Literal['072'], Literal['150'], Literal['151'], Literal['080'], Literal['073'], Literal['074'], Literal['075'], Literal['076'], Literal['140'], Literal['090'], Literal['210'], Literal['070'], Literal['230'], Literal['145'], Literal['152'], Literal['200'], Literal['155'], Literal['157'], Literal['160'], Literal['165'], Literal['077'], Literal['170'], Literal['020'], Literal['220'], Literal['146'], Literal['148'], Literal['110'], Literal['016'], Literal['008'], Literal['271'], Literal['132'], Literal['250'], Literal['260'], Literal['400'], Literal['295'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_928'], Type['Variation_852'], Type['Variation_0'], Type['Variation_80'], Type['Variation_705'], Type['Variation_632'], Type['Variation_80'], Type['Variation_719'], Type['Variation_855'], Type['Variation_278'], Type['Variation_80'], Type['Variation_858'], Type['Variation_80'], Type['Variation_860'], Type['Variation_287'], Type['Variation_868'], Type['Variation_924'], Type['Variation_873'], Type['Variation_717'], Type['Variation_360'], Type['Variation_14'], Type['Variation_917'], Type['Variation_880'], Type['Variation_881'], Type['Variation_883'], Type['Variation_885'], Type['Variation_80'], Type['Variation_196'], Type['Variation_886'], Type['Variation_731'], Type['Variation_887'], Type['Variation_891'], Type['Variation_754'], Type['Variation_892'], Type['Variation_900'], Type['Variation_918'], Type['Variation_29'], Type['Variation_321'], Type['Variation_912'], Type['Variation_0'], Type['Variation_929'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '040':
            return Variation_928
        if key == '161':
            return Variation_852
        if key == '015':
            return Variation_0
        if key == '071':
            return Variation_80
        if key == '130':
            return Variation_705
        if key == '131':
            return Variation_632
        if key == '072':
            return Variation_80
        if key == '150':
            return Variation_719
        if key == '151':
            return Variation_855
        if key == '080':
            return Variation_278
        if key == '073':
            return Variation_80
        if key == '074':
            return Variation_858
        if key == '075':
            return Variation_80
        if key == '076':
            return Variation_860
        if key == '140':
            return Variation_287
        if key == '090':
            return Variation_868
        if key == '210':
            return Variation_924
        if key == '070':
            return Variation_873
        if key == '230':
            return Variation_717
        if key == '145':
            return Variation_360
        if key == '152':
            return Variation_14
        if key == '200':
            return Variation_917
        if key == '155':
            return Variation_880
        if key == '157':
            return Variation_881
        if key == '160':
            return Variation_883
        if key == '165':
            return Variation_885
        if key == '077':
            return Variation_80
        if key == '170':
            return Variation_196
        if key == '020':
            return Variation_886
        if key == '220':
            return Variation_731
        if key == '146':
            return Variation_887
        if key == '148':
            return Variation_891
        if key == '110':
            return Variation_754
        if key == '016':
            return Variation_892
        if key == '008':
            return Variation_900
        if key == '271':
            return Variation_918
        if key == '132':
            return Variation_29
        if key == '250':
            return Variation_321
        if key == '260':
            return Variation_912
        if key == '400':
            return Variation_0
        if key == '295':
            return Variation_929
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_930_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_928, Variation_928_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_852, Variation_852_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['071'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_705, Variation_705_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['131'], val : Union[Variation_632, Variation_632_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['072'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_719, Variation_719_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['151'], val : Union[Variation_855, Variation_855_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['073'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['074'], val : Union[Variation_858, Variation_858_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['075'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['076'], val : Union[Variation_860, Variation_860_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_868, Variation_868_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_924, Variation_924_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_873, Variation_873_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['145'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['152'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_917, Variation_917_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['155'], val : Union[Variation_880, Variation_880_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['157'], val : Union[Variation_881, Variation_881_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['160'], val : Union[Variation_883, Variation_883_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['165'], val : Union[Variation_885, Variation_885_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['077'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_886, Variation_886_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_731, Variation_731_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['146'], val : Union[Variation_887, Variation_887_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['148'], val : Union[Variation_891, Variation_891_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_754, Variation_754_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['016'], val : Union[Variation_892, Variation_892_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['008'], val : Union[Variation_900, Variation_900_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['271'], val : Union[Variation_918, Variation_918_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['132'], val : Union[Variation_29, Variation_29_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_912, Variation_912_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['295'], val : Union[Variation_929, Variation_929_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_930':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_930':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['071']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['131']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['072']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['151']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['073']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['074']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['075']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['076']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['145']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['152']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['155']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['157']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['160']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['165']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['077']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['146']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['148']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['016']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['008']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['271']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['132']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['295']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_930':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_930':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_928:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_852:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['071']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_705:
        ...

    @overload
    def get_item(self, name : Literal['131']) -> Variation_632:
        ...

    @overload
    def get_item(self, name : Literal['072']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_719:
        ...

    @overload
    def get_item(self, name : Literal['151']) -> Variation_855:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['073']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['074']) -> Variation_858:
        ...

    @overload
    def get_item(self, name : Literal['075']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['076']) -> Variation_860:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_868:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_924:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_873:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['145']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['152']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_917:
        ...

    @overload
    def get_item(self, name : Literal['155']) -> Variation_880:
        ...

    @overload
    def get_item(self, name : Literal['157']) -> Variation_881:
        ...

    @overload
    def get_item(self, name : Literal['160']) -> Variation_883:
        ...

    @overload
    def get_item(self, name : Literal['165']) -> Variation_885:
        ...

    @overload
    def get_item(self, name : Literal['077']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_886:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_731:
        ...

    @overload
    def get_item(self, name : Literal['146']) -> Variation_887:
        ...

    @overload
    def get_item(self, name : Literal['148']) -> Variation_891:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_754:
        ...

    @overload
    def get_item(self, name : Literal['016']) -> Variation_892:
        ...

    @overload
    def get_item(self, name : Literal['008']) -> Variation_900:
        ...

    @overload
    def get_item(self, name : Literal['271']) -> Variation_918:
        ...

    @overload
    def get_item(self, name : Literal['132']) -> Variation_29:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_912:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['295']) -> Variation_929:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['071'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['131'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['072'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['151'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['073'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['074'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['075'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['076'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['145'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['152'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['155'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['157'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['160'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['165'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['077'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['146'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['148'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['016'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['008'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['271'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['132'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['295'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_930':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_930':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_931_Arg : TypeAlias = Raw
class Variation_931(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Ground station status report',
        2: 'Service status report',
        3: 'Service statistics report',
    }

    def __init__(self, arg : Variation_931_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_932_Arg : TypeAlias = Raw
class Variation_932(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 4
    table = {
        1: 'ADS-B VDL4',
        2: 'ADS-B Ext Squitter',
        3: 'ADS-B UAT',
        4: 'TIS-B VDL4',
        5: 'TIS-B Ext Squitter',
        6: 'TIS-B UAT',
        7: 'FIS-B VDL4',
        8: 'GRAS VDL4',
        9: 'MLT',
    }

    def __init__(self, arg : Variation_932_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_933_Arg_Group = TypedDict('Variation_933_Arg_Group', {
    'SID': Union[Variation_187, Variation_187_Arg],
    'STYP': Union[Variation_932, Variation_932_Arg],
})
Variation_933_Arg : TypeAlias = Union[Raw, Variation_933_Arg_Group]
class Variation_933(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('SID', Variation_187),
        ('STYP', Variation_932),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SID': ('Service Identification', Variation_187, 0, 4),
        'STYP': ('Type of Service', Variation_932, 4, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SID']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STYP']) -> Type[Variation_932]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SID'], Literal['STYP']]) -> Union[Type['Variation_187'], Type['Variation_932']]:
        if key == 'SID':
            return Variation_187
        if key == 'STYP':
            return Variation_932
        assert_never(key)

    def __init__(self, arg : Variation_933_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SID']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['STYP']) -> Variation_932:
        ...

    def get_item(self, name : Union[Literal['SID'], Literal['STYP']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SID'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_933':
        ...

    @overload
    def set_item(self, name : Literal['STYP'], val : Union[Variation_932, Variation_932_Arg]) -> 'Variation_933':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SID'], f : Any) -> 'Variation_933':
        ...

    @overload
    def modify_item(self, name : Literal['STYP'], f : Any) -> 'Variation_933':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_934_Arg : TypeAlias = Raw
class Variation_934(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Data is released for operational use',
        1: 'Data must not be used operationally',
    }

    def __init__(self, arg : Variation_934_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_935_Arg : TypeAlias = Raw
class Variation_935(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default, no overload',
        1: 'Overload in DP',
    }

    def __init__(self, arg : Variation_935_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_936_Arg : TypeAlias = Raw
class Variation_936(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default, no overload',
        1: 'Overload in transmission subsystem',
    }

    def __init__(self, arg : Variation_936_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_937_Arg : TypeAlias = Raw
class Variation_937(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Monitoring system not connected or unknown',
        1: 'Monitoring system connected',
    }

    def __init__(self, arg : Variation_937_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_938_Arg : TypeAlias = Raw
class Variation_938(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Valid',
        1: 'Invalid',
    }

    def __init__(self, arg : Variation_938_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_939_Arg : TypeAlias = Raw
class Variation_939(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'No spoofing detected',
        1: 'Potential spoofing attack',
    }

    def __init__(self, arg : Variation_939_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_940_Arg : TypeAlias = Raw
class Variation_940(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Track numbering has restarted',
    }

    def __init__(self, arg : Variation_940_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_941_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_941(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    quantity = Quantity('Unsigned', 1.0, 's')

    def __init__(self, arg : Variation_941_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_942_Arg_Group_1 = TypedDict('Variation_942_Arg_Group_1', {
    'NOGO': Union[Variation_934, Variation_934_Arg],
    'ODP': Union[Variation_935, Variation_935_Arg],
    'OXT': Union[Variation_936, Variation_936_Arg],
    'MSC': Union[Variation_937, Variation_937_Arg],
    'TSV': Union[Variation_938, Variation_938_Arg],
    'SPO': Union[Variation_939, Variation_939_Arg],
    'RN': Union[Variation_940, Variation_940_Arg],
})
Variation_942_Arg_Group_2 = TypedDict('Variation_942_Arg_Group_2', {
    'NOGO': Union[Variation_934, Variation_934_Arg],
    'ODP': Union[Variation_935, Variation_935_Arg],
    'OXT': Union[Variation_936, Variation_936_Arg],
    'MSC': Union[Variation_937, Variation_937_Arg],
    'TSV': Union[Variation_938, Variation_938_Arg],
    'SPO': Union[Variation_939, Variation_939_Arg],
    'RN': Union[Variation_940, Variation_940_Arg],
    'GSSP': Union[Variation_941, Variation_941_Arg],
})
Variation_942_Arg : TypeAlias = Union[
    int,
    Variation_942_Arg_Group_1,
    Tuple[int],
    Variation_942_Arg_Group_2,
    Tuple[int,int],
]
class Variation_942(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('NOGO', Variation_934),
            ('ODP', Variation_935),
            ('OXT', Variation_936),
            ('MSC', Variation_937),
            ('TSV', Variation_938),
            ('SPO', Variation_939),
            ('RN', Variation_940),
        ],
        [
            ('GSSP', Variation_941),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NOGO': ('Operational Release Status of the Data', Variation_934, 0, 1),
        'ODP': ('Data Processor Overload Indicator', Variation_935, 1, 1),
        'OXT': ('Ground Interface Data Communications Overload', Variation_936, 2, 1),
        'MSC': ('Monitoring System Connected Status', Variation_937, 3, 1),
        'TSV': ('Time Source Validity', Variation_938, 4, 1),
        'SPO': ('Indication of Spoofing Attack', Variation_939, 5, 1),
        'RN': ('Renumbering Indication for Track ID', Variation_940, 6, 1),
        'GSSP': ('Ground Station Status Reporting Period', Variation_941, 0, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NOGO']) -> Type[Variation_934]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ODP']) -> Type[Variation_935]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OXT']) -> Type[Variation_936]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSC']) -> Type[Variation_937]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSV']) -> Type[Variation_938]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPO']) -> Type[Variation_939]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RN']) -> Type[Variation_940]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GSSP']) -> Type[Variation_941]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NOGO'], Literal['ODP'], Literal['OXT'], Literal['MSC'], Literal['TSV'], Literal['SPO'], Literal['RN'], Literal['GSSP']]) -> Union[Type['Variation_934'], Type['Variation_935'], Type['Variation_936'], Type['Variation_937'], Type['Variation_938'], Type['Variation_939'], Type['Variation_940'], Type['Variation_941']]:
        if key == 'NOGO':
            return Variation_934
        if key == 'ODP':
            return Variation_935
        if key == 'OXT':
            return Variation_936
        if key == 'MSC':
            return Variation_937
        if key == 'TSV':
            return Variation_938
        if key == 'SPO':
            return Variation_939
        if key == 'RN':
            return Variation_940
        if key == 'GSSP':
            return Variation_941
        assert_never(key)

    def __init__(self, arg : Variation_942_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_942_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_942_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NOGO']) -> Variation_934:
        ...

    @overload
    def get_item(self, name : Literal['ODP']) -> Variation_935:
        ...

    @overload
    def get_item(self, name : Literal['OXT']) -> Variation_936:
        ...

    @overload
    def get_item(self, name : Literal['MSC']) -> Variation_937:
        ...

    @overload
    def get_item(self, name : Literal['TSV']) -> Variation_938:
        ...

    @overload
    def get_item(self, name : Literal['SPO']) -> Variation_939:
        ...

    @overload
    def get_item(self, name : Literal['RN']) -> Variation_940:
        ...

    @overload
    def get_item(self, name : Literal['GSSP']) -> Variation_941:
        ...

    def get_item(self, name : Union[Literal['NOGO'], Literal['ODP'], Literal['OXT'], Literal['MSC'], Literal['TSV'], Literal['SPO'], Literal['RN'], Literal['GSSP']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NOGO'], val : Union[Variation_934, Variation_934_Arg]) -> 'Variation_942':
        ...

    @overload
    def set_item(self, name : Literal['ODP'], val : Union[Variation_935, Variation_935_Arg]) -> 'Variation_942':
        ...

    @overload
    def set_item(self, name : Literal['OXT'], val : Union[Variation_936, Variation_936_Arg]) -> 'Variation_942':
        ...

    @overload
    def set_item(self, name : Literal['MSC'], val : Union[Variation_937, Variation_937_Arg]) -> 'Variation_942':
        ...

    @overload
    def set_item(self, name : Literal['TSV'], val : Union[Variation_938, Variation_938_Arg]) -> 'Variation_942':
        ...

    @overload
    def set_item(self, name : Literal['SPO'], val : Union[Variation_939, Variation_939_Arg]) -> 'Variation_942':
        ...

    @overload
    def set_item(self, name : Literal['RN'], val : Union[Variation_940, Variation_940_Arg]) -> 'Variation_942':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NOGO'], f : Any) -> 'Variation_942':
        ...

    @overload
    def modify_item(self, name : Literal['ODP'], f : Any) -> 'Variation_942':
        ...

    @overload
    def modify_item(self, name : Literal['OXT'], f : Any) -> 'Variation_942':
        ...

    @overload
    def modify_item(self, name : Literal['MSC'], f : Any) -> 'Variation_942':
        ...

    @overload
    def modify_item(self, name : Literal['TSV'], f : Any) -> 'Variation_942':
        ...

    @overload
    def modify_item(self, name : Literal['SPO'], f : Any) -> 'Variation_942':
        ...

    @overload
    def modify_item(self, name : Literal['RN'], f : Any) -> 'Variation_942':
        ...

    @overload
    def modify_item(self, name : Literal['GSSP'], f : Any) -> 'Variation_942':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_943_Arg : TypeAlias = Raw
class Variation_943(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: 'No information',
        1: 'NRA class',
        2: 'Reserved for future use',
        3: 'Reserved for future use',
        4: 'Reserved for future use',
        5: 'Reserved for future use',
        6: 'Reserved for future use',
        7: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_943_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_944_Arg_Group_1 = TypedDict('Variation_944_Arg_Group_1', {
    'RP': Union[Variation_892, Variation_892_Arg],
    'SC': Union[Variation_943, Variation_943_Arg],
})
Variation_944_Arg_Group_2 = TypedDict('Variation_944_Arg_Group_2', {
    'RP': Union[Variation_892, Variation_892_Arg],
    'SC': Union[Variation_943, Variation_943_Arg],
    'SSRP': Union[Variation_941, Variation_941_Arg],
})
Variation_944_Arg : TypeAlias = Union[
    int,
    Variation_944_Arg_Group_1,
    Tuple[int],
    Variation_944_Arg_Group_2,
    Tuple[int,int],
]
class Variation_944(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        15,
        7,
    ]

    subitems_list = [
        [
            ('RP', Variation_892),
            ('SC', Variation_943),
            Spare(3, 4),
        ],
        [
            ('SSRP', Variation_941),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RP': ('Report Period for Category 021 Reports', Variation_892, 0, 8),
        'SC': ('Service Class', Variation_943, 8, 3),
        'SSRP': ('Service Status Reporting Period', Variation_941, 0, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RP']) -> Type[Variation_892]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SC']) -> Type[Variation_943]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSRP']) -> Type[Variation_941]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RP'], Literal['SC'], Literal['SSRP']]) -> Union[Type['Variation_892'], Type['Variation_943'], Type['Variation_941']]:
        if key == 'RP':
            return Variation_892
        if key == 'SC':
            return Variation_943
        if key == 'SSRP':
            return Variation_941
        assert_never(key)

    def __init__(self, arg : Variation_944_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_944_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_944_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RP']) -> Variation_892:
        ...

    @overload
    def get_item(self, name : Literal['SC']) -> Variation_943:
        ...

    @overload
    def get_item(self, name : Literal['SSRP']) -> Variation_941:
        ...

    def get_item(self, name : Union[Literal['RP'], Literal['SC'], Literal['SSRP']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RP'], val : Union[Variation_892, Variation_892_Arg]) -> 'Variation_944':
        ...

    @overload
    def set_item(self, name : Literal['SC'], val : Union[Variation_943, Variation_943_Arg]) -> 'Variation_944':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RP'], f : Any) -> 'Variation_944':
        ...

    @overload
    def modify_item(self, name : Literal['SC'], f : Any) -> 'Variation_944':
        ...

    @overload
    def modify_item(self, name : Literal['SSRP'], f : Any) -> 'Variation_944':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_945_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_945(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 1.0, 'NM')

    def __init__(self, arg : Variation_945_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_946_Arg : TypeAlias = Raw
class Variation_946(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 3
    table = {
        0: 'Unknown',
        1: 'Failed',
        2: 'Disabled',
        3: 'Degraded',
        4: 'Normal',
        5: 'Initialisation',
    }

    def __init__(self, arg : Variation_946_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_947_Arg_Group_1 = TypedDict('Variation_947_Arg_Group_1', {
    'STAT': Union[Variation_946, Variation_946_Arg],
})
Variation_947_Arg : TypeAlias = Union[
    int,
    Variation_947_Arg_Group_1,
    Tuple[int],
]
class Variation_947(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            Spare(0, 4),
            ('STAT', Variation_946),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STAT': ('Status of the Service', Variation_946, 4, 3),
    }


    @classmethod
    def spec(cls, key : Union[Literal['STAT']]) -> Union[Type['Variation_946']]:
        if key == 'STAT':
            return Variation_946
        assert_never(key)

    def __init__(self, arg : Variation_947_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_947_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    def get_item(self, name : Literal['STAT']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['STAT'], val : Union[Variation_946, Variation_946_Arg]) -> 'Variation_947':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_947':
        return self._modify_item(name, f) # type: ignore

Variation_948_Arg : TypeAlias = Raw
class Variation_948(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'Number of unknown messages received',
        1: 'Number of too old messages received',
        2: 'Number of failed message conversions',
        3: 'Total Number of messages received',
        4: 'Total Number of messages transmitted',
        20: 'Number of TIS-B management messages received',
        21: 'Number of Basic messages received',
        22: 'Number of High Dynamic messages received',
        23: 'Number of Full Position messages received',
        24: 'Number of Basic Ground  messages received',
        25: 'Number of TCP messages received',
        26: 'Number of UTC time  messages received',
        27: 'Number of Data messages received',
        28: 'Number of High Resolution messages received',
        29: 'Number of Aircraft Target Airborne messages received',
        30: 'Number of Aircraft Target Ground messages received',
        31: 'Number of Ground Vehicle Target messages received',
        32: 'Number of 2 slots TCP messages received',
    }

    def __init__(self, arg : Variation_948_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_949_Arg : TypeAlias = Raw
class Variation_949(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'From midnight',
        1: 'From the last report',
    }

    def __init__(self, arg : Variation_949_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_950_Arg_Group = TypedDict('Variation_950_Arg_Group', {
    'TYPE': Union[Variation_948, Variation_948_Arg],
    'REF': Union[Variation_949, Variation_949_Arg],
    'CV': Union[Variation_555, Variation_555_Arg],
})
Variation_950_Arg : TypeAlias = Union[Raw, Variation_950_Arg_Group]
class Variation_950(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('TYPE', Variation_948),
        ('REF', Variation_949),
        Spare(1, 7),
        ('CV', Variation_555),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYPE': ('Type of Report Counter', Variation_948, 0, 8),
        'REF': ('Reference from which the Messages Are Countered', Variation_949, 8, 1),
        'CV': ('32-bit Counter Value', Variation_555, 16, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYPE']) -> Type[Variation_948]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['REF']) -> Type[Variation_949]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CV']) -> Type[Variation_555]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYPE'], Literal['REF'], Literal['CV']]) -> Union[Type['Variation_948'], Type['Variation_949'], Type['Variation_555']]:
        if key == 'TYPE':
            return Variation_948
        if key == 'REF':
            return Variation_949
        if key == 'CV':
            return Variation_555
        assert_never(key)

    def __init__(self, arg : Variation_950_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYPE']) -> Variation_948:
        ...

    @overload
    def get_item(self, name : Literal['REF']) -> Variation_949:
        ...

    @overload
    def get_item(self, name : Literal['CV']) -> Variation_555:
        ...

    def get_item(self, name : Union[Literal['TYPE'], Literal['REF'], Literal['CV']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYPE'], val : Union[Variation_948, Variation_948_Arg]) -> 'Variation_950':
        ...

    @overload
    def set_item(self, name : Literal['REF'], val : Union[Variation_949, Variation_949_Arg]) -> 'Variation_950':
        ...

    @overload
    def set_item(self, name : Literal['CV'], val : Union[Variation_555, Variation_555_Arg]) -> 'Variation_950':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYPE'], f : Any) -> 'Variation_950':
        ...

    @overload
    def modify_item(self, name : Literal['REF'], f : Any) -> 'Variation_950':
        ...

    @overload
    def modify_item(self, name : Literal['CV'], f : Any) -> 'Variation_950':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_951_Arg : TypeAlias = Union[Variation_950, Variation_950_Arg]
class Variation_951(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 48
    variation_type = Variation_950

    @classmethod
    def spec(cls) -> Type[Variation_950]:
        return Variation_950

    def __init__(self, arg : List[Union[Variation_950, Variation_950_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_950, Variation_950_Arg]) -> 'Variation_951':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_950, Variation_950_Arg]) -> 'Variation_951':
        return self._prepend_item(arg) # type: ignore

Variation_952_Arg = TypedDict('Variation_952_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_931, Variation_931_Arg],
    '015': Union[Variation_933, Variation_933_Arg],
    '070': Union[Variation_80, Variation_80_Arg],
    '100': Union[Variation_942, Variation_942_Arg],
    '101': Union[Variation_944, Variation_944_Arg],
    '200': Union[Variation_945, Variation_945_Arg],
    '110': Union[Variation_947, Variation_947_Arg],
    '120': Union[Variation_951, Variation_951_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_952(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_931),
        ('015', Variation_933),
        ('070', Variation_80),
        ('100', Variation_942),
        ('101', Variation_944),
        ('200', Variation_945),
        ('110', Variation_947),
        ('120', Variation_951),
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Report Type', Variation_931, 0x4000),
        '015': ('Service Type and Identification', Variation_933, 0x2000),
        '070': ('Time of Day', Variation_80, 0x1000),
        '100': ('Ground Station Status', Variation_942, 0x0800),
        '101': ('Service Configuration', Variation_944, 0x0400),
        '200': ('Operational Range', Variation_945, 0x0200),
        '110': ('Service Status', Variation_947, 0x0180),
        '120': ('Service Statistics', Variation_951, 0x0140),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0104),
        'SP': ('Special Purpose Field', Variation_62, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_931]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_933]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_942]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['101']) -> Type[Variation_944]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_945]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_947]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_951]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['015'], Literal['070'], Literal['100'], Literal['101'], Literal['200'], Literal['110'], Literal['120'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_931'], Type['Variation_933'], Type['Variation_80'], Type['Variation_942'], Type['Variation_944'], Type['Variation_945'], Type['Variation_947'], Type['Variation_951'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_931
        if key == '015':
            return Variation_933
        if key == '070':
            return Variation_80
        if key == '100':
            return Variation_942
        if key == '101':
            return Variation_944
        if key == '200':
            return Variation_945
        if key == '110':
            return Variation_947
        if key == '120':
            return Variation_951
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_952_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_931, Variation_931_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_933, Variation_933_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_942, Variation_942_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['101'], val : Union[Variation_944, Variation_944_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_945, Variation_945_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_947, Variation_947_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_951, Variation_951_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_952':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_952':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['101']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_952':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_952':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_931:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_933:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_942:
        ...

    @overload
    def get_item(self, name : Literal['101']) -> Variation_944:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_945:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_947:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_951:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['101'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_952':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_952':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_953_Arg_Group = TypedDict('Variation_953_Arg_Group', {
    'RTYP': Union[Variation_23, Variation_23_Arg],
    'RG': Union[Variation_431, Variation_431_Arg],
})
Variation_953_Arg : TypeAlias = Union[Raw, Variation_953_Arg_Group]
class Variation_953(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('RTYP', Variation_23),
        ('RG', Variation_431),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RTYP': ('Report Type', Variation_23, 0, 7),
        'RG': ('Report Generation', Variation_431, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RTYP']) -> Type[Variation_23]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RG']) -> Type[Variation_431]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RTYP'], Literal['RG']]) -> Union[Type['Variation_23'], Type['Variation_431']]:
        if key == 'RTYP':
            return Variation_23
        if key == 'RG':
            return Variation_431
        assert_never(key)

    def __init__(self, arg : Variation_953_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RTYP']) -> Variation_23:
        ...

    @overload
    def get_item(self, name : Literal['RG']) -> Variation_431:
        ...

    def get_item(self, name : Union[Literal['RTYP'], Literal['RG']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RTYP'], val : Union[Variation_23, Variation_23_Arg]) -> 'Variation_953':
        ...

    @overload
    def set_item(self, name : Literal['RG'], val : Union[Variation_431, Variation_431_Arg]) -> 'Variation_953':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RTYP'], f : Any) -> 'Variation_953':
        ...

    @overload
    def modify_item(self, name : Literal['RG'], f : Any) -> 'Variation_953':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_954_Arg : TypeAlias = Raw
class Variation_954(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'Operational',
        1: 'Operational but in Standby',
        2: 'Maintenance',
        3: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_954_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_955_Arg : TypeAlias = Raw
class Variation_955(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 4
    table = {
        0: 'Running',
        1: 'Failed',
        2: 'Degraded',
        3: 'Undefined',
        4: 'Reserved for future use',
        5: 'Reserved for future use',
        6: 'Reserved for future use',
        7: 'Reserved for future use',
        8: 'Reserved for future use',
        9: 'Reserved for future use',
        10: 'Reserved for future use',
        11: 'Reserved for future use',
        12: 'Reserved for future use',
        13: 'Reserved for future use',
        14: 'Reserved for future use',
        15: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_955_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_956_Arg : TypeAlias = Raw
class Variation_956(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 3
    table = {
        0: 'Running / OK',
        1: 'Failed',
        2: 'Degraded',
        3: 'Undefined',
        4: 'Reserved for future use',
        5: 'Reserved for future use',
        6: 'Reserved for future use',
        7: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_956_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_957_Arg : TypeAlias = Raw
class Variation_957(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 3
    table = {
        0: 'OK',
        1: 'Failed',
        2: 'Degraded',
        3: 'Undefined',
        4: 'Reserved for future use',
        5: 'Reserved for future use',
        6: 'Reserved for future use',
        7: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_957_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_958_Arg_Group_1 = TypedDict('Variation_958_Arg_Group_1', {
    'NOGO': Union[Variation_934, Variation_934_Arg],
    'OPS': Union[Variation_954, Variation_954_Arg],
    'SSTAT': Union[Variation_955, Variation_955_Arg],
})
Variation_958_Arg_Group_2 = TypedDict('Variation_958_Arg_Group_2', {
    'NOGO': Union[Variation_934, Variation_934_Arg],
    'OPS': Union[Variation_954, Variation_954_Arg],
    'SSTAT': Union[Variation_955, Variation_955_Arg],
    'SYSTAT': Union[Variation_956, Variation_956_Arg],
    'SESTAT': Union[Variation_957, Variation_957_Arg],
})
Variation_958_Arg : TypeAlias = Union[
    int,
    Variation_958_Arg_Group_1,
    Tuple[int],
    Variation_958_Arg_Group_2,
    Tuple[int,int],
]
class Variation_958(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('NOGO', Variation_934),
            ('OPS', Variation_954),
            ('SSTAT', Variation_955),
        ],
        [
            Spare(0, 1),
            ('SYSTAT', Variation_956),
            ('SESTAT', Variation_957),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NOGO': ('', Variation_934, 0, 1),
        'OPS': ('', Variation_954, 1, 2),
        'SSTAT': ('', Variation_955, 3, 4),
        'SYSTAT': ('', Variation_956, 1, 3),
        'SESTAT': ('', Variation_957, 4, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NOGO']) -> Type[Variation_934]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OPS']) -> Type[Variation_954]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSTAT']) -> Type[Variation_955]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SYSTAT']) -> Type[Variation_956]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SESTAT']) -> Type[Variation_957]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NOGO'], Literal['OPS'], Literal['SSTAT'], Literal['SYSTAT'], Literal['SESTAT']]) -> Union[Type['Variation_934'], Type['Variation_954'], Type['Variation_955'], Type['Variation_956'], Type['Variation_957']]:
        if key == 'NOGO':
            return Variation_934
        if key == 'OPS':
            return Variation_954
        if key == 'SSTAT':
            return Variation_955
        if key == 'SYSTAT':
            return Variation_956
        if key == 'SESTAT':
            return Variation_957
        assert_never(key)

    def __init__(self, arg : Variation_958_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_958_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_958_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NOGO']) -> Variation_934:
        ...

    @overload
    def get_item(self, name : Literal['OPS']) -> Variation_954:
        ...

    @overload
    def get_item(self, name : Literal['SSTAT']) -> Variation_955:
        ...

    @overload
    def get_item(self, name : Literal['SYSTAT']) -> Variation_956:
        ...

    @overload
    def get_item(self, name : Literal['SESTAT']) -> Variation_957:
        ...

    def get_item(self, name : Union[Literal['NOGO'], Literal['OPS'], Literal['SSTAT'], Literal['SYSTAT'], Literal['SESTAT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NOGO'], val : Union[Variation_934, Variation_934_Arg]) -> 'Variation_958':
        ...

    @overload
    def set_item(self, name : Literal['OPS'], val : Union[Variation_954, Variation_954_Arg]) -> 'Variation_958':
        ...

    @overload
    def set_item(self, name : Literal['SSTAT'], val : Union[Variation_955, Variation_955_Arg]) -> 'Variation_958':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NOGO'], f : Any) -> 'Variation_958':
        ...

    @overload
    def modify_item(self, name : Literal['OPS'], f : Any) -> 'Variation_958':
        ...

    @overload
    def modify_item(self, name : Literal['SSTAT'], f : Any) -> 'Variation_958':
        ...

    @overload
    def modify_item(self, name : Literal['SYSTAT'], f : Any) -> 'Variation_958':
        ...

    @overload
    def modify_item(self, name : Literal['SESTAT'], f : Any) -> 'Variation_958':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_959_Arg : TypeAlias = Raw
class Variation_959(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'No error detected (shall not be sent)',
        1: 'Error Code Undefined',
        2: 'Time Source Invalid',
        3: 'Time Source Coasting',
        4: 'Track ID numbering has restarted',
        5: 'Data Processor Overload',
        6: 'Ground Interface Data Communications Overload',
        7: 'System stopped by operator',
        8: 'CBIT failed',
        9: 'Test Target Failure',
        10: 'Reserved for allocation by the AMG',
        11: 'Reserved for allocation by the AMG',
        12: 'Reserved for allocation by the AMG',
        13: 'Reserved for allocation by the AMG',
        14: 'Reserved for allocation by the AMG',
        15: 'Reserved for allocation by the AMG',
        16: 'Reserved for allocation by the AMG',
        17: 'Reserved for allocation by the AMG',
        18: 'Reserved for allocation by the AMG',
        19: 'Reserved for allocation by the AMG',
        20: 'Reserved for allocation by the AMG',
        21: 'Reserved for allocation by the AMG',
        22: 'Reserved for allocation by the AMG',
        23: 'Reserved for allocation by the AMG',
        24: 'Reserved for allocation by the AMG',
        25: 'Reserved for allocation by the AMG',
        26: 'Reserved for allocation by the AMG',
        27: 'Reserved for allocation by the AMG',
        28: 'Reserved for allocation by the AMG',
        29: 'Reserved for allocation by the AMG',
        30: 'Reserved for allocation by the AMG',
        31: 'Reserved for allocation by the AMG',
        32: 'Reserved for allocation by system manufacturers',
        33: 'Reserved for allocation by system manufacturers',
        34: 'Reserved for allocation by system manufacturers',
        35: 'Reserved for allocation by system manufacturers',
        36: 'Reserved for allocation by system manufacturers',
        37: 'Reserved for allocation by system manufacturers',
        38: 'Reserved for allocation by system manufacturers',
        39: 'Reserved for allocation by system manufacturers',
        40: 'Reserved for allocation by system manufacturers',
        41: 'Reserved for allocation by system manufacturers',
        42: 'Reserved for allocation by system manufacturers',
        43: 'Reserved for allocation by system manufacturers',
        44: 'Reserved for allocation by system manufacturers',
        45: 'Reserved for allocation by system manufacturers',
        46: 'Reserved for allocation by system manufacturers',
        47: 'Reserved for allocation by system manufacturers',
        48: 'Reserved for allocation by system manufacturers',
        49: 'Reserved for allocation by system manufacturers',
        50: 'Reserved for allocation by system manufacturers',
        51: 'Reserved for allocation by system manufacturers',
        52: 'Reserved for allocation by system manufacturers',
        53: 'Reserved for allocation by system manufacturers',
        54: 'Reserved for allocation by system manufacturers',
        55: 'Reserved for allocation by system manufacturers',
        56: 'Reserved for allocation by system manufacturers',
        57: 'Reserved for allocation by system manufacturers',
        58: 'Reserved for allocation by system manufacturers',
        59: 'Reserved for allocation by system manufacturers',
        60: 'Reserved for allocation by system manufacturers',
        61: 'Reserved for allocation by system manufacturers',
        62: 'Reserved for allocation by system manufacturers',
        63: 'Reserved for allocation by system manufacturers',
        64: 'Reserved for allocation by system manufacturers',
        65: 'Reserved for allocation by system manufacturers',
        66: 'Reserved for allocation by system manufacturers',
        67: 'Reserved for allocation by system manufacturers',
        68: 'Reserved for allocation by system manufacturers',
        69: 'Reserved for allocation by system manufacturers',
        70: 'Reserved for allocation by system manufacturers',
        71: 'Reserved for allocation by system manufacturers',
        72: 'Reserved for allocation by system manufacturers',
        73: 'Reserved for allocation by system manufacturers',
        74: 'Reserved for allocation by system manufacturers',
        75: 'Reserved for allocation by system manufacturers',
        76: 'Reserved for allocation by system manufacturers',
        77: 'Reserved for allocation by system manufacturers',
        78: 'Reserved for allocation by system manufacturers',
        79: 'Reserved for allocation by system manufacturers',
        80: 'Reserved for allocation by system manufacturers',
        81: 'Reserved for allocation by system manufacturers',
        82: 'Reserved for allocation by system manufacturers',
        83: 'Reserved for allocation by system manufacturers',
        84: 'Reserved for allocation by system manufacturers',
        85: 'Reserved for allocation by system manufacturers',
        86: 'Reserved for allocation by system manufacturers',
        87: 'Reserved for allocation by system manufacturers',
        88: 'Reserved for allocation by system manufacturers',
        89: 'Reserved for allocation by system manufacturers',
        90: 'Reserved for allocation by system manufacturers',
        91: 'Reserved for allocation by system manufacturers',
        92: 'Reserved for allocation by system manufacturers',
        93: 'Reserved for allocation by system manufacturers',
        94: 'Reserved for allocation by system manufacturers',
        95: 'Reserved for allocation by system manufacturers',
        96: 'Reserved for allocation by system manufacturers',
        97: 'Reserved for allocation by system manufacturers',
        98: 'Reserved for allocation by system manufacturers',
        99: 'Reserved for allocation by system manufacturers',
        100: 'Reserved for allocation by system manufacturers',
        101: 'Reserved for allocation by system manufacturers',
        102: 'Reserved for allocation by system manufacturers',
        103: 'Reserved for allocation by system manufacturers',
        104: 'Reserved for allocation by system manufacturers',
        105: 'Reserved for allocation by system manufacturers',
        106: 'Reserved for allocation by system manufacturers',
        107: 'Reserved for allocation by system manufacturers',
        108: 'Reserved for allocation by system manufacturers',
        109: 'Reserved for allocation by system manufacturers',
        110: 'Reserved for allocation by system manufacturers',
        111: 'Reserved for allocation by system manufacturers',
        112: 'Reserved for allocation by system manufacturers',
        113: 'Reserved for allocation by system manufacturers',
        114: 'Reserved for allocation by system manufacturers',
        115: 'Reserved for allocation by system manufacturers',
        116: 'Reserved for allocation by system manufacturers',
        117: 'Reserved for allocation by system manufacturers',
        118: 'Reserved for allocation by system manufacturers',
        119: 'Reserved for allocation by system manufacturers',
        120: 'Reserved for allocation by system manufacturers',
        121: 'Reserved for allocation by system manufacturers',
        122: 'Reserved for allocation by system manufacturers',
        123: 'Reserved for allocation by system manufacturers',
        124: 'Reserved for allocation by system manufacturers',
        125: 'Reserved for allocation by system manufacturers',
        126: 'Reserved for allocation by system manufacturers',
        127: 'Reserved for allocation by system manufacturers',
        128: 'Reserved for allocation by system manufacturers',
        129: 'Reserved for allocation by system manufacturers',
        130: 'Reserved for allocation by system manufacturers',
        131: 'Reserved for allocation by system manufacturers',
        132: 'Reserved for allocation by system manufacturers',
        133: 'Reserved for allocation by system manufacturers',
        134: 'Reserved for allocation by system manufacturers',
        135: 'Reserved for allocation by system manufacturers',
        136: 'Reserved for allocation by system manufacturers',
        137: 'Reserved for allocation by system manufacturers',
        138: 'Reserved for allocation by system manufacturers',
        139: 'Reserved for allocation by system manufacturers',
        140: 'Reserved for allocation by system manufacturers',
        141: 'Reserved for allocation by system manufacturers',
        142: 'Reserved for allocation by system manufacturers',
        143: 'Reserved for allocation by system manufacturers',
        144: 'Reserved for allocation by system manufacturers',
        145: 'Reserved for allocation by system manufacturers',
        146: 'Reserved for allocation by system manufacturers',
        147: 'Reserved for allocation by system manufacturers',
        148: 'Reserved for allocation by system manufacturers',
        149: 'Reserved for allocation by system manufacturers',
        150: 'Reserved for allocation by system manufacturers',
        151: 'Reserved for allocation by system manufacturers',
        152: 'Reserved for allocation by system manufacturers',
        153: 'Reserved for allocation by system manufacturers',
        154: 'Reserved for allocation by system manufacturers',
        155: 'Reserved for allocation by system manufacturers',
        156: 'Reserved for allocation by system manufacturers',
        157: 'Reserved for allocation by system manufacturers',
        158: 'Reserved for allocation by system manufacturers',
        159: 'Reserved for allocation by system manufacturers',
        160: 'Reserved for allocation by system manufacturers',
        161: 'Reserved for allocation by system manufacturers',
        162: 'Reserved for allocation by system manufacturers',
        163: 'Reserved for allocation by system manufacturers',
        164: 'Reserved for allocation by system manufacturers',
        165: 'Reserved for allocation by system manufacturers',
        166: 'Reserved for allocation by system manufacturers',
        167: 'Reserved for allocation by system manufacturers',
        168: 'Reserved for allocation by system manufacturers',
        169: 'Reserved for allocation by system manufacturers',
        170: 'Reserved for allocation by system manufacturers',
        171: 'Reserved for allocation by system manufacturers',
        172: 'Reserved for allocation by system manufacturers',
        173: 'Reserved for allocation by system manufacturers',
        174: 'Reserved for allocation by system manufacturers',
        175: 'Reserved for allocation by system manufacturers',
        176: 'Reserved for allocation by system manufacturers',
        177: 'Reserved for allocation by system manufacturers',
        178: 'Reserved for allocation by system manufacturers',
        179: 'Reserved for allocation by system manufacturers',
        180: 'Reserved for allocation by system manufacturers',
        181: 'Reserved for allocation by system manufacturers',
        182: 'Reserved for allocation by system manufacturers',
        183: 'Reserved for allocation by system manufacturers',
        184: 'Reserved for allocation by system manufacturers',
        185: 'Reserved for allocation by system manufacturers',
        186: 'Reserved for allocation by system manufacturers',
        187: 'Reserved for allocation by system manufacturers',
        188: 'Reserved for allocation by system manufacturers',
        189: 'Reserved for allocation by system manufacturers',
        190: 'Reserved for allocation by system manufacturers',
        191: 'Reserved for allocation by system manufacturers',
        192: 'Reserved for allocation by system manufacturers',
        193: 'Reserved for allocation by system manufacturers',
        194: 'Reserved for allocation by system manufacturers',
        195: 'Reserved for allocation by system manufacturers',
        196: 'Reserved for allocation by system manufacturers',
        197: 'Reserved for allocation by system manufacturers',
        198: 'Reserved for allocation by system manufacturers',
        199: 'Reserved for allocation by system manufacturers',
        200: 'Reserved for allocation by system manufacturers',
        201: 'Reserved for allocation by system manufacturers',
        202: 'Reserved for allocation by system manufacturers',
        203: 'Reserved for allocation by system manufacturers',
        204: 'Reserved for allocation by system manufacturers',
        205: 'Reserved for allocation by system manufacturers',
        206: 'Reserved for allocation by system manufacturers',
        207: 'Reserved for allocation by system manufacturers',
        208: 'Reserved for allocation by system manufacturers',
        209: 'Reserved for allocation by system manufacturers',
        210: 'Reserved for allocation by system manufacturers',
        211: 'Reserved for allocation by system manufacturers',
        212: 'Reserved for allocation by system manufacturers',
        213: 'Reserved for allocation by system manufacturers',
        214: 'Reserved for allocation by system manufacturers',
        215: 'Reserved for allocation by system manufacturers',
        216: 'Reserved for allocation by system manufacturers',
        217: 'Reserved for allocation by system manufacturers',
        218: 'Reserved for allocation by system manufacturers',
        219: 'Reserved for allocation by system manufacturers',
        220: 'Reserved for allocation by system manufacturers',
        221: 'Reserved for allocation by system manufacturers',
        222: 'Reserved for allocation by system manufacturers',
        223: 'Reserved for allocation by system manufacturers',
        224: 'Reserved for allocation by system manufacturers',
        225: 'Reserved for allocation by system manufacturers',
        226: 'Reserved for allocation by system manufacturers',
        227: 'Reserved for allocation by system manufacturers',
        228: 'Reserved for allocation by system manufacturers',
        229: 'Reserved for allocation by system manufacturers',
        230: 'Reserved for allocation by system manufacturers',
        231: 'Reserved for allocation by system manufacturers',
        232: 'Reserved for allocation by system manufacturers',
        233: 'Reserved for allocation by system manufacturers',
        234: 'Reserved for allocation by system manufacturers',
        235: 'Reserved for allocation by system manufacturers',
        236: 'Reserved for allocation by system manufacturers',
        237: 'Reserved for allocation by system manufacturers',
        238: 'Reserved for allocation by system manufacturers',
        239: 'Reserved for allocation by system manufacturers',
        240: 'Reserved for allocation by system manufacturers',
        241: 'Reserved for allocation by system manufacturers',
        242: 'Reserved for allocation by system manufacturers',
        243: 'Reserved for allocation by system manufacturers',
        244: 'Reserved for allocation by system manufacturers',
        245: 'Reserved for allocation by system manufacturers',
        246: 'Reserved for allocation by system manufacturers',
        247: 'Reserved for allocation by system manufacturers',
        248: 'Reserved for allocation by system manufacturers',
        249: 'Reserved for allocation by system manufacturers',
        250: 'Reserved for allocation by system manufacturers',
        251: 'Reserved for allocation by system manufacturers',
        252: 'Reserved for allocation by system manufacturers',
        253: 'Reserved for allocation by system manufacturers',
        254: 'Reserved for allocation by system manufacturers',
        255: 'Reserved for allocation by system manufacturers',
    }

    def __init__(self, arg : Variation_959_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_960_Arg : TypeAlias = Union[Variation_959, Variation_959_Arg]
class Variation_960(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 8
    variation_type = Variation_959

    @classmethod
    def spec(cls) -> Type[Variation_959]:
        return Variation_959

    def __init__(self, arg : List[Union[Variation_959, Variation_959_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_959, Variation_959_Arg]) -> 'Variation_960':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_959, Variation_959_Arg]) -> 'Variation_960':
        return self._prepend_item(arg) # type: ignore

Variation_961_Arg : TypeAlias = Raw
class Variation_961(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 6
    table = {
        0: 'No Error Detected',
        1: 'Error Code Undefined',
        2: 'Reserved for allocation by the AMG',
        3: 'Reserved for allocation by the AMG',
        4: 'Reserved for allocation by the AMG',
        5: 'Reserved for allocation by the AMG',
        6: 'Reserved for allocation by the AMG',
        7: 'Reserved for allocation by the AMG',
        8: 'Reserved for allocation by the AMG',
        9: 'Reserved for allocation by the AMG',
        10: 'Reserved for allocation by the AMG',
        11: 'Reserved for allocation by the AMG',
        12: 'Reserved for allocation by the AMG',
        13: 'Reserved for allocation by the AMG',
        14: 'Reserved for allocation by the AMG',
        15: 'Reserved for allocation by the AMG',
        16: 'Reserved for allocation by system manufacturers',
        17: 'Reserved for allocation by system manufacturers',
        18: 'Reserved for allocation by system manufacturers',
        19: 'Reserved for allocation by system manufacturers',
        20: 'Reserved for allocation by system manufacturers',
        21: 'Reserved for allocation by system manufacturers',
        22: 'Reserved for allocation by system manufacturers',
        23: 'Reserved for allocation by system manufacturers',
        24: 'Reserved for allocation by system manufacturers',
        25: 'Reserved for allocation by system manufacturers',
        26: 'Reserved for allocation by system manufacturers',
        27: 'Reserved for allocation by system manufacturers',
        28: 'Reserved for allocation by system manufacturers',
        29: 'Reserved for allocation by system manufacturers',
        30: 'Reserved for allocation by system manufacturers',
        31: 'Reserved for allocation by system manufacturers',
        32: 'Reserved for allocation by system manufacturers',
        33: 'Reserved for allocation by system manufacturers',
        34: 'Reserved for allocation by system manufacturers',
        35: 'Reserved for allocation by system manufacturers',
        36: 'Reserved for allocation by system manufacturers',
        37: 'Reserved for allocation by system manufacturers',
        38: 'Reserved for allocation by system manufacturers',
        39: 'Reserved for allocation by system manufacturers',
        40: 'Reserved for allocation by system manufacturers',
        41: 'Reserved for allocation by system manufacturers',
        42: 'Reserved for allocation by system manufacturers',
        43: 'Reserved for allocation by system manufacturers',
        44: 'Reserved for allocation by system manufacturers',
        45: 'Reserved for allocation by system manufacturers',
        46: 'Reserved for allocation by system manufacturers',
        47: 'Reserved for allocation by system manufacturers',
        48: 'Reserved for allocation by system manufacturers',
        49: 'Reserved for allocation by system manufacturers',
        50: 'Reserved for allocation by system manufacturers',
        51: 'Reserved for allocation by system manufacturers',
        52: 'Reserved for allocation by system manufacturers',
        53: 'Reserved for allocation by system manufacturers',
        54: 'Reserved for allocation by system manufacturers',
        55: 'Reserved for allocation by system manufacturers',
        56: 'Reserved for allocation by system manufacturers',
        57: 'Reserved for allocation by system manufacturers',
        58: 'Reserved for allocation by system manufacturers',
        59: 'Reserved for allocation by system manufacturers',
        60: 'Reserved for allocation by system manufacturers',
        61: 'Reserved for allocation by system manufacturers',
        62: 'Reserved for allocation by system manufacturers',
        63: 'Reserved for allocation by system manufacturers',
    }

    def __init__(self, arg : Variation_961_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_962_Arg : TypeAlias = Raw
class Variation_962(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 2
    table = {
        0: 'Running',
        1: 'Failed',
        2: 'Maintenance',
        3: 'Reserved',
    }

    def __init__(self, arg : Variation_962_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_963_Arg_Group = TypedDict('Variation_963_Arg_Group', {
    'CID': Union[Variation_64, Variation_64_Arg],
    'ERRC': Union[Variation_961, Variation_961_Arg],
    'CS': Union[Variation_962, Variation_962_Arg],
})
Variation_963_Arg : TypeAlias = Union[Raw, Variation_963_Arg_Group]
class Variation_963(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('CID', Variation_64),
        ('ERRC', Variation_961),
        ('CS', Variation_962),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CID': ('Component ID', Variation_64, 0, 16),
        'ERRC': ('Error Code', Variation_961, 16, 6),
        'CS': ('Component State/Mode', Variation_962, 22, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CID']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ERRC']) -> Type[Variation_961]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CS']) -> Type[Variation_962]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CID'], Literal['ERRC'], Literal['CS']]) -> Union[Type['Variation_64'], Type['Variation_961'], Type['Variation_962']]:
        if key == 'CID':
            return Variation_64
        if key == 'ERRC':
            return Variation_961
        if key == 'CS':
            return Variation_962
        assert_never(key)

    def __init__(self, arg : Variation_963_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CID']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['ERRC']) -> Variation_961:
        ...

    @overload
    def get_item(self, name : Literal['CS']) -> Variation_962:
        ...

    def get_item(self, name : Union[Literal['CID'], Literal['ERRC'], Literal['CS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CID'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_963':
        ...

    @overload
    def set_item(self, name : Literal['ERRC'], val : Union[Variation_961, Variation_961_Arg]) -> 'Variation_963':
        ...

    @overload
    def set_item(self, name : Literal['CS'], val : Union[Variation_962, Variation_962_Arg]) -> 'Variation_963':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CID'], f : Any) -> 'Variation_963':
        ...

    @overload
    def modify_item(self, name : Literal['ERRC'], f : Any) -> 'Variation_963':
        ...

    @overload
    def modify_item(self, name : Literal['CS'], f : Any) -> 'Variation_963':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_964_Arg : TypeAlias = Union[Variation_963, Variation_963_Arg]
class Variation_964(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 24
    variation_type = Variation_963

    @classmethod
    def spec(cls) -> Type[Variation_963]:
        return Variation_963

    def __init__(self, arg : List[Union[Variation_963, Variation_963_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_963, Variation_963_Arg]) -> 'Variation_964':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_963, Variation_963_Arg]) -> 'Variation_964':
        return self._prepend_item(arg) # type: ignore

Variation_965_Arg : TypeAlias = Raw
class Variation_965(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'Number of unknown messages received',
        1: 'Number of too old messages received',
        2: 'Number of failed message conversions',
        3: 'Total Number of messages received',
        4: 'Total number of messages transmitted',
        5: 'Reserved for AMG',
        6: 'Reserved for AMG',
        7: 'Reserved for AMG',
        8: 'Reserved for AMG',
        9: 'Reserved for AMG',
        10: 'Reserved for AMG',
        11: 'Reserved for AMG',
        12: 'Reserved for AMG',
        13: 'Reserved for AMG',
        14: 'Reserved for AMG',
        15: 'Reserved for AMG',
        16: 'Reserved for AMG',
        17: 'Reserved for AMG',
        18: 'Reserved for AMG',
        19: 'Reserved for AMG',
        20: 'Implementation specific',
        21: 'Implementation specific',
        22: 'Implementation specific',
        23: 'Implementation specific',
        24: 'Implementation specific',
        25: 'Implementation specific',
        26: 'Implementation specific',
        27: 'Implementation specific',
        28: 'Implementation specific',
        29: 'Implementation specific',
        30: 'Implementation specific',
        31: 'Implementation specific',
        32: 'Implementation specific',
        33: 'Implementation specific',
        34: 'Implementation specific',
        35: 'Implementation specific',
        36: 'Implementation specific',
        37: 'Implementation specific',
        38: 'Implementation specific',
        39: 'Implementation specific',
        40: 'Implementation specific',
        41: 'Implementation specific',
        42: 'Implementation specific',
        43: 'Implementation specific',
        44: 'Implementation specific',
        45: 'Implementation specific',
        46: 'Implementation specific',
        47: 'Implementation specific',
        48: 'Implementation specific',
        49: 'Implementation specific',
        50: 'Implementation specific',
        51: 'Implementation specific',
        52: 'Implementation specific',
        53: 'Implementation specific',
        54: 'Implementation specific',
        55: 'Implementation specific',
        56: 'Implementation specific',
        57: 'Implementation specific',
        58: 'Implementation specific',
        59: 'Implementation specific',
        60: 'Implementation specific',
        61: 'Implementation specific',
        62: 'Implementation specific',
        63: 'Implementation specific',
        64: 'Implementation specific',
        65: 'Implementation specific',
        66: 'Implementation specific',
        67: 'Implementation specific',
        68: 'Implementation specific',
        69: 'Implementation specific',
        70: 'Implementation specific',
        71: 'Implementation specific',
        72: 'Implementation specific',
        73: 'Implementation specific',
        74: 'Implementation specific',
        75: 'Implementation specific',
        76: 'Implementation specific',
        77: 'Implementation specific',
        78: 'Implementation specific',
        79: 'Implementation specific',
        80: 'Implementation specific',
        81: 'Implementation specific',
        82: 'Implementation specific',
        83: 'Implementation specific',
        84: 'Implementation specific',
        85: 'Implementation specific',
        86: 'Implementation specific',
        87: 'Implementation specific',
        88: 'Implementation specific',
        89: 'Implementation specific',
        90: 'Implementation specific',
        91: 'Implementation specific',
        92: 'Implementation specific',
        93: 'Implementation specific',
        94: 'Implementation specific',
        95: 'Implementation specific',
        96: 'Implementation specific',
        97: 'Implementation specific',
        98: 'Implementation specific',
        99: 'Implementation specific',
        100: 'Implementation specific',
        101: 'Implementation specific',
        102: 'Implementation specific',
        103: 'Implementation specific',
        104: 'Implementation specific',
        105: 'Implementation specific',
        106: 'Implementation specific',
        107: 'Implementation specific',
        108: 'Implementation specific',
        109: 'Implementation specific',
        110: 'Implementation specific',
        111: 'Implementation specific',
        112: 'Implementation specific',
        113: 'Implementation specific',
        114: 'Implementation specific',
        115: 'Implementation specific',
        116: 'Implementation specific',
        117: 'Implementation specific',
        118: 'Implementation specific',
        119: 'Implementation specific',
        120: 'Implementation specific',
        121: 'Implementation specific',
        122: 'Implementation specific',
        123: 'Implementation specific',
        124: 'Implementation specific',
        125: 'Implementation specific',
        126: 'Implementation specific',
        127: 'Implementation specific',
        128: 'Implementation specific',
        129: 'Implementation specific',
        130: 'Implementation specific',
        131: 'Implementation specific',
        132: 'Implementation specific',
        133: 'Implementation specific',
        134: 'Implementation specific',
        135: 'Implementation specific',
        136: 'Implementation specific',
        137: 'Implementation specific',
        138: 'Implementation specific',
        139: 'Implementation specific',
        140: 'Implementation specific',
        141: 'Implementation specific',
        142: 'Implementation specific',
        143: 'Implementation specific',
        144: 'Implementation specific',
        145: 'Implementation specific',
        146: 'Implementation specific',
        147: 'Implementation specific',
        148: 'Implementation specific',
        149: 'Implementation specific',
        150: 'Implementation specific',
        151: 'Implementation specific',
        152: 'Implementation specific',
        153: 'Implementation specific',
        154: 'Implementation specific',
        155: 'Implementation specific',
        156: 'Implementation specific',
        157: 'Implementation specific',
        158: 'Implementation specific',
        159: 'Implementation specific',
        160: 'Implementation specific',
        161: 'Implementation specific',
        162: 'Implementation specific',
        163: 'Implementation specific',
        164: 'Implementation specific',
        165: 'Implementation specific',
        166: 'Implementation specific',
        167: 'Implementation specific',
        168: 'Implementation specific',
        169: 'Implementation specific',
        170: 'Implementation specific',
        171: 'Implementation specific',
        172: 'Implementation specific',
        173: 'Implementation specific',
        174: 'Implementation specific',
        175: 'Implementation specific',
        176: 'Implementation specific',
        177: 'Implementation specific',
        178: 'Implementation specific',
        179: 'Implementation specific',
        180: 'Implementation specific',
        181: 'Implementation specific',
        182: 'Implementation specific',
        183: 'Implementation specific',
        184: 'Implementation specific',
        185: 'Implementation specific',
        186: 'Implementation specific',
        187: 'Implementation specific',
        188: 'Implementation specific',
        189: 'Implementation specific',
        190: 'Implementation specific',
        191: 'Implementation specific',
        192: 'Implementation specific',
        193: 'Implementation specific',
        194: 'Implementation specific',
        195: 'Implementation specific',
        196: 'Implementation specific',
        197: 'Implementation specific',
        198: 'Implementation specific',
        199: 'Implementation specific',
        200: 'Implementation specific',
        201: 'Implementation specific',
        202: 'Implementation specific',
        203: 'Implementation specific',
        204: 'Implementation specific',
        205: 'Implementation specific',
        206: 'Implementation specific',
        207: 'Implementation specific',
        208: 'Implementation specific',
        209: 'Implementation specific',
        210: 'Implementation specific',
        211: 'Implementation specific',
        212: 'Implementation specific',
        213: 'Implementation specific',
        214: 'Implementation specific',
        215: 'Implementation specific',
        216: 'Implementation specific',
        217: 'Implementation specific',
        218: 'Implementation specific',
        219: 'Implementation specific',
        220: 'Implementation specific',
        221: 'Implementation specific',
        222: 'Implementation specific',
        223: 'Implementation specific',
        224: 'Implementation specific',
        225: 'Implementation specific',
        226: 'Implementation specific',
        227: 'Implementation specific',
        228: 'Implementation specific',
        229: 'Implementation specific',
        230: 'Implementation specific',
        231: 'Implementation specific',
        232: 'Implementation specific',
        233: 'Implementation specific',
        234: 'Implementation specific',
        235: 'Implementation specific',
        236: 'Implementation specific',
        237: 'Implementation specific',
        238: 'Implementation specific',
        239: 'Implementation specific',
        240: 'Implementation specific',
        241: 'Implementation specific',
        242: 'Implementation specific',
        243: 'Implementation specific',
        244: 'Implementation specific',
        245: 'Implementation specific',
        246: 'Implementation specific',
        247: 'Implementation specific',
        248: 'Implementation specific',
        249: 'Implementation specific',
        250: 'Implementation specific',
        251: 'Implementation specific',
        252: 'Implementation specific',
        253: 'Implementation specific',
        254: 'Implementation specific',
        255: 'Implementation specific',
    }

    def __init__(self, arg : Variation_965_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_966_Arg : TypeAlias = Raw
class Variation_966(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'From UTC midnight',
        1: 'From the previous report',
    }

    def __init__(self, arg : Variation_966_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_967_Arg_Group = TypedDict('Variation_967_Arg_Group', {
    'TYPE': Union[Variation_965, Variation_965_Arg],
    'REF': Union[Variation_966, Variation_966_Arg],
    'COUNT': Union[Variation_555, Variation_555_Arg],
})
Variation_967_Arg : TypeAlias = Union[Raw, Variation_967_Arg_Group]
class Variation_967(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('TYPE', Variation_965),
        ('REF', Variation_966),
        Spare(1, 7),
        ('COUNT', Variation_555),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYPE': ('Type of Report Counter', Variation_965, 0, 8),
        'REF': ('Reference from which the Messages Are Counted', Variation_966, 8, 1),
        'COUNT': ('Counter Value', Variation_555, 16, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYPE']) -> Type[Variation_965]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['REF']) -> Type[Variation_966]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COUNT']) -> Type[Variation_555]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYPE'], Literal['REF'], Literal['COUNT']]) -> Union[Type['Variation_965'], Type['Variation_966'], Type['Variation_555']]:
        if key == 'TYPE':
            return Variation_965
        if key == 'REF':
            return Variation_966
        if key == 'COUNT':
            return Variation_555
        assert_never(key)

    def __init__(self, arg : Variation_967_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYPE']) -> Variation_965:
        ...

    @overload
    def get_item(self, name : Literal['REF']) -> Variation_966:
        ...

    @overload
    def get_item(self, name : Literal['COUNT']) -> Variation_555:
        ...

    def get_item(self, name : Union[Literal['TYPE'], Literal['REF'], Literal['COUNT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYPE'], val : Union[Variation_965, Variation_965_Arg]) -> 'Variation_967':
        ...

    @overload
    def set_item(self, name : Literal['REF'], val : Union[Variation_966, Variation_966_Arg]) -> 'Variation_967':
        ...

    @overload
    def set_item(self, name : Literal['COUNT'], val : Union[Variation_555, Variation_555_Arg]) -> 'Variation_967':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYPE'], f : Any) -> 'Variation_967':
        ...

    @overload
    def modify_item(self, name : Literal['REF'], f : Any) -> 'Variation_967':
        ...

    @overload
    def modify_item(self, name : Literal['COUNT'], f : Any) -> 'Variation_967':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_968_Arg : TypeAlias = Union[Variation_967, Variation_967_Arg]
class Variation_968(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 48
    variation_type = Variation_967

    @classmethod
    def spec(cls) -> Type[Variation_967]:
        return Variation_967

    def __init__(self, arg : List[Union[Variation_967, Variation_967_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_967, Variation_967_Arg]) -> 'Variation_968':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_967, Variation_967_Arg]) -> 'Variation_968':
        return self._prepend_item(arg) # type: ignore

Variation_969_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_969(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 32
    quantity = Quantity('Signed', 4.190951585769653e-8, '°')

    def __init__(self, arg : Variation_969_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_970_Arg_Group = TypedDict('Variation_970_Arg_Group', {
    'LAT': Union[Variation_969, Variation_969_Arg],
    'LON': Union[Variation_969, Variation_969_Arg],
})
Variation_970_Arg : TypeAlias = Union[Raw, Variation_970_Arg_Group]
class Variation_970(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('LAT', Variation_969),
        ('LON', Variation_969),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude', Variation_969, 0, 32),
        'LON': ('Longitude', Variation_969, 32, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_969]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_969]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_969'], Type['Variation_969']]:
        if key == 'LAT':
            return Variation_969
        if key == 'LON':
            return Variation_969
        assert_never(key)

    def __init__(self, arg : Variation_970_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_969:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_969:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_969, Variation_969_Arg]) -> 'Variation_970':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_969, Variation_969_Arg]) -> 'Variation_970':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_970':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_970':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_971_Arg = TypedDict('Variation_971_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_953, Variation_953_Arg],
    '200': Union[Variation_278, Variation_278_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '020': Union[Variation_196, Variation_196_Arg],
    '070': Union[Variation_80, Variation_80_Arg],
    '100': Union[Variation_958, Variation_958_Arg],
    '105': Union[Variation_960, Variation_960_Arg],
    '120': Union[Variation_964, Variation_964_Arg],
    '140': Union[Variation_968, Variation_968_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    '600': Union[Variation_970, Variation_970_Arg],
    '610': Union[Variation_301, Variation_301_Arg],
}, total=False)
class Variation_971(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_953),
        ('200', Variation_278),
        ('015', Variation_0),
        ('020', Variation_196),
        ('070', Variation_80),
        ('100', Variation_958),
        ('105', Variation_960),
        ('120', Variation_964),
        ('140', Variation_968),
        ('SP', Variation_62),
        ('600', Variation_970),
        ('610', Variation_301),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Report Type', Variation_953, 0x4000),
        '200': ('Message Identification', Variation_278, 0x2000),
        '015': ('Service Identification', Variation_0, 0x1000),
        '020': ('Service Designator', Variation_196, 0x0800),
        '070': ('Time of Day', Variation_80, 0x0400),
        '100': ('System and Service Status', Variation_958, 0x0200),
        '105': ('System and Service Error Codes', Variation_960, 0x0180),
        '120': ('Component Status', Variation_964, 0x0140),
        '140': ('Service Statistics', Variation_968, 0x0120),
        'SP': ('Special Purpose Field', Variation_62, 0x0110),
        '600': ('Position of the System Reference Point', Variation_970, 0x0108),
        '610': ('Height of the System Reference Point', Variation_301, 0x0104),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_953]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_958]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['105']) -> Type[Variation_960]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_964]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_968]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['600']) -> Type[Variation_970]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['610']) -> Type[Variation_301]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['200'], Literal['015'], Literal['020'], Literal['070'], Literal['100'], Literal['105'], Literal['120'], Literal['140'], Literal['SP'], Literal['600'], Literal['610']]) -> Union[Type['Variation_1'], Type['Variation_953'], Type['Variation_278'], Type['Variation_0'], Type['Variation_196'], Type['Variation_80'], Type['Variation_958'], Type['Variation_960'], Type['Variation_964'], Type['Variation_968'], Type['Variation_62'], Type['Variation_970'], Type['Variation_301']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_953
        if key == '200':
            return Variation_278
        if key == '015':
            return Variation_0
        if key == '020':
            return Variation_196
        if key == '070':
            return Variation_80
        if key == '100':
            return Variation_958
        if key == '105':
            return Variation_960
        if key == '120':
            return Variation_964
        if key == '140':
            return Variation_968
        if key == 'SP':
            return Variation_62
        if key == '600':
            return Variation_970
        if key == '610':
            return Variation_301
        assert_never(key)

    def __init__(self, arg : Optional[Variation_971_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_953, Variation_953_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_958, Variation_958_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['105'], val : Union[Variation_960, Variation_960_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_964, Variation_964_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_968, Variation_968_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['600'], val : Union[Variation_970, Variation_970_Arg]) -> 'Variation_971':
        ...

    @overload
    def set_item(self, name : Literal['610'], val : Union[Variation_301, Variation_301_Arg]) -> 'Variation_971':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['105']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['600']) -> 'Variation_971':
        ...

    @overload
    def del_item(self, name : Literal['610']) -> 'Variation_971':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_953:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_958:
        ...

    @overload
    def get_item(self, name : Literal['105']) -> Variation_960:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_964:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_968:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['600']) -> Variation_970:
        ...

    @overload
    def get_item(self, name : Literal['610']) -> Variation_301:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['105'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['600'], f : Any) -> 'Variation_971':
        ...

    @overload
    def modify_item(self, name : Literal['610'], f : Any) -> 'Variation_971':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_972_Arg : TypeAlias = Raw
class Variation_972(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 4
    table = {
        1: 'Information sent by an FPPS',
    }

    def __init__(self, arg : Variation_972_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_973_Arg : TypeAlias = Raw
class Variation_973(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 4
    table = {
        1: 'Flight Plan to track initial correlation',
        2: 'Miniplan update',
        3: 'End of correlation',
        4: 'Miniplan Cancellation',
        5: 'Retained Miniplan',
    }

    def __init__(self, arg : Variation_973_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_974_Arg_Group = TypedDict('Variation_974_Arg_Group', {
    'FAMILY': Union[Variation_972, Variation_972_Arg],
    'NATURE': Union[Variation_973, Variation_973_Arg],
})
Variation_974_Arg : TypeAlias = Union[Raw, Variation_974_Arg_Group]
class Variation_974(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('FAMILY', Variation_972),
        ('NATURE', Variation_973),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FAMILY': ('', Variation_972, 0, 4),
        'NATURE': ('', Variation_973, 4, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['FAMILY']) -> Type[Variation_972]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NATURE']) -> Type[Variation_973]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['FAMILY'], Literal['NATURE']]) -> Union[Type['Variation_972'], Type['Variation_973']]:
        if key == 'FAMILY':
            return Variation_972
        if key == 'NATURE':
            return Variation_973
        assert_never(key)

    def __init__(self, arg : Variation_974_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['FAMILY']) -> Variation_972:
        ...

    @overload
    def get_item(self, name : Literal['NATURE']) -> Variation_973:
        ...

    def get_item(self, name : Union[Literal['FAMILY'], Literal['NATURE']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['FAMILY'], val : Union[Variation_972, Variation_972_Arg]) -> 'Variation_974':
        ...

    @overload
    def set_item(self, name : Literal['NATURE'], val : Union[Variation_973, Variation_973_Arg]) -> 'Variation_974':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['FAMILY'], f : Any) -> 'Variation_974':
        ...

    @overload
    def modify_item(self, name : Literal['NATURE'], f : Any) -> 'Variation_974':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_975_Arg_Group_1 = TypedDict('Variation_975_Arg_Group_1', {
    'SUI': Union[Variation_0, Variation_0_Arg],
    'STN': Union[Variation_224, Variation_224_Arg],
})
Variation_975_Arg : TypeAlias = Union[
    int,
    Variation_975_Arg_Group_1,
    Tuple[int],
]
class Variation_975(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        23,
    ]

    subitems_list = [
        [
            ('SUI', Variation_0),
            ('STN', Variation_224),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SUI': ('System Unit Identification', Variation_0, 0, 8),
        'STN': ('System Track Number', Variation_224, 8, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SUI']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STN']) -> Type[Variation_224]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SUI'], Literal['STN']]) -> Union[Type['Variation_0'], Type['Variation_224']]:
        if key == 'SUI':
            return Variation_0
        if key == 'STN':
            return Variation_224
        assert_never(key)

    def __init__(self, arg : Variation_975_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_975_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SUI']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['STN']) -> Variation_224:
        ...

    def get_item(self, name : Union[Literal['SUI'], Literal['STN']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SUI'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_975':
        ...

    @overload
    def set_item(self, name : Literal['STN'], val : Union[Variation_224, Variation_224_Arg]) -> 'Variation_975':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SUI'], f : Any) -> 'Variation_975':
        ...

    @overload
    def modify_item(self, name : Literal['STN'], f : Any) -> 'Variation_975':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_976_Arg_Group = TypedDict('Variation_976_Arg_Group', {
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_976_Arg : TypeAlias = Union[Raw, Variation_976_Arg_Group]
class Variation_976(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MODE3A': ('(Mode 3/A Code) 4 Digits, Octal Representation', Variation_19, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['MODE3A']]) -> Union[Type['Variation_19']]:
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_976_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['MODE3A']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_976':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_976':
        return self._modify_item(name, f) # type: ignore

Variation_977_Arg : TypeAlias = Raw
class Variation_977(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1

    def __init__(self, arg : Variation_977_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_978_Arg : TypeAlias = Raw
class Variation_978(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1

    def __init__(self, arg : Variation_978_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_979_Arg_Group = TypedDict('Variation_979_Arg_Group', {
    'GATOAT': Union[Variation_153, Variation_153_Arg],
    'FR1FR2': Union[Variation_154, Variation_154_Arg],
    'SP3': Union[Variation_238, Variation_238_Arg],
    'SP2': Union[Variation_977, Variation_977_Arg],
    'SP1': Union[Variation_978, Variation_978_Arg],
})
Variation_979_Arg : TypeAlias = Union[Raw, Variation_979_Arg_Group]
class Variation_979(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('GATOAT', Variation_153),
        ('FR1FR2', Variation_154),
        ('SP3', Variation_238),
        ('SP2', Variation_977),
        ('SP1', Variation_978),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'GATOAT': ('', Variation_153, 0, 2),
        'FR1FR2': ('', Variation_154, 2, 2),
        'SP3': ('', Variation_238, 4, 1),
        'SP2': ('', Variation_977, 5, 1),
        'SP1': ('', Variation_978, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['GATOAT']) -> Type[Variation_153]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FR1FR2']) -> Type[Variation_154]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP3']) -> Type[Variation_238]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP2']) -> Type[Variation_977]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP1']) -> Type[Variation_978]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['SP3'], Literal['SP2'], Literal['SP1']]) -> Union[Type['Variation_153'], Type['Variation_154'], Type['Variation_238'], Type['Variation_977'], Type['Variation_978']]:
        if key == 'GATOAT':
            return Variation_153
        if key == 'FR1FR2':
            return Variation_154
        if key == 'SP3':
            return Variation_238
        if key == 'SP2':
            return Variation_977
        if key == 'SP1':
            return Variation_978
        assert_never(key)

    def __init__(self, arg : Variation_979_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['GATOAT']) -> Variation_153:
        ...

    @overload
    def get_item(self, name : Literal['FR1FR2']) -> Variation_154:
        ...

    @overload
    def get_item(self, name : Literal['SP3']) -> Variation_238:
        ...

    @overload
    def get_item(self, name : Literal['SP2']) -> Variation_977:
        ...

    @overload
    def get_item(self, name : Literal['SP1']) -> Variation_978:
        ...

    def get_item(self, name : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['SP3'], Literal['SP2'], Literal['SP1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['GATOAT'], val : Union[Variation_153, Variation_153_Arg]) -> 'Variation_979':
        ...

    @overload
    def set_item(self, name : Literal['FR1FR2'], val : Union[Variation_154, Variation_154_Arg]) -> 'Variation_979':
        ...

    @overload
    def set_item(self, name : Literal['SP3'], val : Union[Variation_238, Variation_238_Arg]) -> 'Variation_979':
        ...

    @overload
    def set_item(self, name : Literal['SP2'], val : Union[Variation_977, Variation_977_Arg]) -> 'Variation_979':
        ...

    @overload
    def set_item(self, name : Literal['SP1'], val : Union[Variation_978, Variation_978_Arg]) -> 'Variation_979':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['GATOAT'], f : Any) -> 'Variation_979':
        ...

    @overload
    def modify_item(self, name : Literal['FR1FR2'], f : Any) -> 'Variation_979':
        ...

    @overload
    def modify_item(self, name : Literal['SP3'], f : Any) -> 'Variation_979':
        ...

    @overload
    def modify_item(self, name : Literal['SP2'], f : Any) -> 'Variation_979':
        ...

    @overload
    def modify_item(self, name : Literal['SP1'], f : Any) -> 'Variation_979':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_980_Arg_Group = TypedDict('Variation_980_Arg_Group', {
    'CEN': Union[Variation_0, Variation_0_Arg],
    'POS': Union[Variation_0, Variation_0_Arg],
})
Variation_980_Arg : TypeAlias = Union[Raw, Variation_980_Arg_Group]
class Variation_980(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('CEN', Variation_0),
        ('POS', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CEN': ('Centre', Variation_0, 0, 8),
        'POS': ('Position', Variation_0, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CEN']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CEN'], Literal['POS']]) -> Union[Type['Variation_0'], Type['Variation_0']]:
        if key == 'CEN':
            return Variation_0
        if key == 'POS':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_980_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CEN']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['CEN'], Literal['POS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CEN'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_980':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_980':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CEN'], f : Any) -> 'Variation_980':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_980':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_981_Arg : TypeAlias = Raw
class Variation_981(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 3

    def __init__(self, arg : Variation_981_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_982_Arg : TypeAlias = Raw
class Variation_982(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 3

    def __init__(self, arg : Variation_982_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_983_Arg_Group = TypedDict('Variation_983_Arg_Group', {
    'OCT1': Union[Variation_93, Variation_93_Arg],
    'OCT2': Union[Variation_981, Variation_981_Arg],
    'OCT3': Union[Variation_982, Variation_982_Arg],
    'OCT4': Union[Variation_223, Variation_223_Arg],
})
Variation_983_Arg : TypeAlias = Union[Raw, Variation_983_Arg_Group]
class Variation_983(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('OCT1', Variation_93),
        ('OCT2', Variation_981),
        ('OCT3', Variation_982),
        ('OCT4', Variation_223),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'OCT1': ('1st Octal Digit', Variation_93, 4, 3),
        'OCT2': ('2nd Octal Digit', Variation_981, 7, 3),
        'OCT3': ('3rd Octal Digit', Variation_982, 10, 3),
        'OCT4': ('4th Octal Digit', Variation_223, 13, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['OCT1']) -> Type[Variation_93]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OCT2']) -> Type[Variation_981]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OCT3']) -> Type[Variation_982]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OCT4']) -> Type[Variation_223]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['OCT1'], Literal['OCT2'], Literal['OCT3'], Literal['OCT4']]) -> Union[Type['Variation_93'], Type['Variation_981'], Type['Variation_982'], Type['Variation_223']]:
        if key == 'OCT1':
            return Variation_93
        if key == 'OCT2':
            return Variation_981
        if key == 'OCT3':
            return Variation_982
        if key == 'OCT4':
            return Variation_223
        assert_never(key)

    def __init__(self, arg : Variation_983_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['OCT1']) -> Variation_93:
        ...

    @overload
    def get_item(self, name : Literal['OCT2']) -> Variation_981:
        ...

    @overload
    def get_item(self, name : Literal['OCT3']) -> Variation_982:
        ...

    @overload
    def get_item(self, name : Literal['OCT4']) -> Variation_223:
        ...

    def get_item(self, name : Union[Literal['OCT1'], Literal['OCT2'], Literal['OCT3'], Literal['OCT4']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['OCT1'], val : Union[Variation_93, Variation_93_Arg]) -> 'Variation_983':
        ...

    @overload
    def set_item(self, name : Literal['OCT2'], val : Union[Variation_981, Variation_981_Arg]) -> 'Variation_983':
        ...

    @overload
    def set_item(self, name : Literal['OCT3'], val : Union[Variation_982, Variation_982_Arg]) -> 'Variation_983':
        ...

    @overload
    def set_item(self, name : Literal['OCT4'], val : Union[Variation_223, Variation_223_Arg]) -> 'Variation_983':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['OCT1'], f : Any) -> 'Variation_983':
        ...

    @overload
    def modify_item(self, name : Literal['OCT2'], f : Any) -> 'Variation_983':
        ...

    @overload
    def modify_item(self, name : Literal['OCT3'], f : Any) -> 'Variation_983':
        ...

    @overload
    def modify_item(self, name : Literal['OCT4'], f : Any) -> 'Variation_983':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_984_Arg : TypeAlias = Union[Variation_983, Variation_983_Arg]
class Variation_984(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_983

    @classmethod
    def spec(cls) -> Type[Variation_983]:
        return Variation_983

    def __init__(self, arg : List[Union[Variation_983, Variation_983_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_983, Variation_983_Arg]) -> 'Variation_984':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_983, Variation_983_Arg]) -> 'Variation_984':
        return self._prepend_item(arg) # type: ignore

Variation_985_Arg : TypeAlias = Raw
class Variation_985(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Plan Number',
        1: 'Unit 1 internal flight number',
        2: 'Unit 2 internal flight number',
        3: 'Unit 3 internal flight number',
    }

    def __init__(self, arg : Variation_985_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_986_Arg_Group = TypedDict('Variation_986_Arg_Group', {
    'TYP': Union[Variation_985, Variation_985_Arg],
    'NBR': Union[Variation_367, Variation_367_Arg],
})
Variation_986_Arg : TypeAlias = Union[Raw, Variation_986_Arg_Group]
class Variation_986(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('TYP', Variation_985),
        Spare(2, 3),
        ('NBR', Variation_367),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('', Variation_985, 0, 2),
        'NBR': ('', Variation_367, 5, 27),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_985]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NBR']) -> Type[Variation_367]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['NBR']]) -> Union[Type['Variation_985'], Type['Variation_367']]:
        if key == 'TYP':
            return Variation_985
        if key == 'NBR':
            return Variation_367
        assert_never(key)

    def __init__(self, arg : Variation_986_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_985:
        ...

    @overload
    def get_item(self, name : Literal['NBR']) -> Variation_367:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['NBR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_985, Variation_985_Arg]) -> 'Variation_986':
        ...

    @overload
    def set_item(self, name : Literal['NBR'], val : Union[Variation_367, Variation_367_Arg]) -> 'Variation_986':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_986':
        ...

    @overload
    def modify_item(self, name : Literal['NBR'], f : Any) -> 'Variation_986':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_987_Arg : TypeAlias = Raw
class Variation_987(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Approved',
        2: 'Exempt',
        3: 'Not approved',
    }

    def __init__(self, arg : Variation_987_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_988_Arg : TypeAlias = Raw
class Variation_988(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'Normal Priority Flight',
        1: 'High Priority Flight',
    }

    def __init__(self, arg : Variation_988_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_989_Arg_Group = TypedDict('Variation_989_Arg_Group', {
    'RVSM': Union[Variation_987, Variation_987_Arg],
    'HPR': Union[Variation_988, Variation_988_Arg],
})
Variation_989_Arg : TypeAlias = Union[Raw, Variation_989_Arg_Group]
class Variation_989(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 5),
        ('RVSM', Variation_987),
        ('HPR', Variation_988),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RVSM': ('', Variation_987, 5, 2),
        'HPR': ('', Variation_988, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RVSM']) -> Type[Variation_987]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HPR']) -> Type[Variation_988]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RVSM'], Literal['HPR']]) -> Union[Type['Variation_987'], Type['Variation_988']]:
        if key == 'RVSM':
            return Variation_987
        if key == 'HPR':
            return Variation_988
        assert_never(key)

    def __init__(self, arg : Variation_989_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RVSM']) -> Variation_987:
        ...

    @overload
    def get_item(self, name : Literal['HPR']) -> Variation_988:
        ...

    def get_item(self, name : Union[Literal['RVSM'], Literal['HPR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RVSM'], val : Union[Variation_987, Variation_987_Arg]) -> 'Variation_989':
        ...

    @overload
    def set_item(self, name : Literal['HPR'], val : Union[Variation_988, Variation_988_Arg]) -> 'Variation_989':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RVSM'], f : Any) -> 'Variation_989':
        ...

    @overload
    def modify_item(self, name : Literal['HPR'], f : Any) -> 'Variation_989':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_990_Arg : TypeAlias = Union[Raw,str]
class Variation_990(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    string_type = StringAscii()

    def __init__(self, arg : Variation_990_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, str):
            super().__init__(self._from_string(arg)); return
        assert_never(arg)


    def to_string(self) -> str:
        return self._to_string()


Variation_991_Arg_Group = TypedDict('Variation_991_Arg_Group', {
    'NU1': Union[Variation_990, Variation_990_Arg],
    'NU2': Union[Variation_990, Variation_990_Arg],
    'LTR': Union[Variation_990, Variation_990_Arg],
})
Variation_991_Arg : TypeAlias = Union[Raw, Variation_991_Arg_Group]
class Variation_991(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('NU1', Variation_990),
        ('NU2', Variation_990),
        ('LTR', Variation_990),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NU1': ('First Number', Variation_990, 0, 8),
        'NU2': ('Second Number', Variation_990, 8, 8),
        'LTR': ('Letter', Variation_990, 16, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NU1']) -> Type[Variation_990]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NU2']) -> Type[Variation_990]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LTR']) -> Type[Variation_990]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NU1'], Literal['NU2'], Literal['LTR']]) -> Union[Type['Variation_990'], Type['Variation_990'], Type['Variation_990']]:
        if key == 'NU1':
            return Variation_990
        if key == 'NU2':
            return Variation_990
        if key == 'LTR':
            return Variation_990
        assert_never(key)

    def __init__(self, arg : Variation_991_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NU1']) -> Variation_990:
        ...

    @overload
    def get_item(self, name : Literal['NU2']) -> Variation_990:
        ...

    @overload
    def get_item(self, name : Literal['LTR']) -> Variation_990:
        ...

    def get_item(self, name : Union[Literal['NU1'], Literal['NU2'], Literal['LTR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NU1'], val : Union[Variation_990, Variation_990_Arg]) -> 'Variation_991':
        ...

    @overload
    def set_item(self, name : Literal['NU2'], val : Union[Variation_990, Variation_990_Arg]) -> 'Variation_991':
        ...

    @overload
    def set_item(self, name : Literal['LTR'], val : Union[Variation_990, Variation_990_Arg]) -> 'Variation_991':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NU1'], f : Any) -> 'Variation_991':
        ...

    @overload
    def modify_item(self, name : Literal['NU2'], f : Any) -> 'Variation_991':
        ...

    @overload
    def modify_item(self, name : Literal['LTR'], f : Any) -> 'Variation_991':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_992_Arg : TypeAlias = Raw
class Variation_992(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 5
    table = {
        0: 'Scheduled Off-Block Time',
        1: 'Estimated Off-Block Time',
        2: 'Estimated Take-Off Time',
        3: 'Actual Off-Block Time',
        4: 'Predicted Time at Runway Hold',
        5: 'Actual Time at Runway Hold',
        6: 'Actual Line-Up Time',
        7: 'Actual Take-Off Time',
        8: 'Estimated Time of Arrival',
        9: 'Predicted Landing Time',
        10: 'Actual Landing Time',
        11: 'Actual Time off Runway',
        12: 'Predicted Time to Gate',
        13: 'Actual On-Block Time',
    }

    def __init__(self, arg : Variation_992_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_993_Arg : TypeAlias = Raw
class Variation_993(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'Today',
        1: 'Yesterday',
        2: 'Tomorrow',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_993_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_994_Arg_Group = TypedDict('Variation_994_Arg_Group', {
    'TYP': Union[Variation_992, Variation_992_Arg],
    'DAY': Union[Variation_993, Variation_993_Arg],
    'HOR': Union[Variation_375, Variation_375_Arg],
    'MIN': Union[Variation_376, Variation_376_Arg],
    'AVS': Union[Variation_377, Variation_377_Arg],
    'SEC': Union[Variation_376, Variation_376_Arg],
})
Variation_994_Arg : TypeAlias = Union[Raw, Variation_994_Arg_Group]
class Variation_994(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('TYP', Variation_992),
        ('DAY', Variation_993),
        Spare(7, 4),
        ('HOR', Variation_375),
        Spare(0, 2),
        ('MIN', Variation_376),
        ('AVS', Variation_377),
        Spare(1, 1),
        ('SEC', Variation_376),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('', Variation_992, 0, 5),
        'DAY': ('', Variation_993, 5, 2),
        'HOR': ('', Variation_375, 11, 5),
        'MIN': ('', Variation_376, 18, 6),
        'AVS': ('', Variation_377, 24, 1),
        'SEC': ('', Variation_376, 26, 6),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_992]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DAY']) -> Type[Variation_993]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HOR']) -> Type[Variation_375]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MIN']) -> Type[Variation_376]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AVS']) -> Type[Variation_377]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SEC']) -> Type[Variation_376]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['DAY'], Literal['HOR'], Literal['MIN'], Literal['AVS'], Literal['SEC']]) -> Union[Type['Variation_992'], Type['Variation_993'], Type['Variation_375'], Type['Variation_376'], Type['Variation_377'], Type['Variation_376']]:
        if key == 'TYP':
            return Variation_992
        if key == 'DAY':
            return Variation_993
        if key == 'HOR':
            return Variation_375
        if key == 'MIN':
            return Variation_376
        if key == 'AVS':
            return Variation_377
        if key == 'SEC':
            return Variation_376
        assert_never(key)

    def __init__(self, arg : Variation_994_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_992:
        ...

    @overload
    def get_item(self, name : Literal['DAY']) -> Variation_993:
        ...

    @overload
    def get_item(self, name : Literal['HOR']) -> Variation_375:
        ...

    @overload
    def get_item(self, name : Literal['MIN']) -> Variation_376:
        ...

    @overload
    def get_item(self, name : Literal['AVS']) -> Variation_377:
        ...

    @overload
    def get_item(self, name : Literal['SEC']) -> Variation_376:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['DAY'], Literal['HOR'], Literal['MIN'], Literal['AVS'], Literal['SEC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_992, Variation_992_Arg]) -> 'Variation_994':
        ...

    @overload
    def set_item(self, name : Literal['DAY'], val : Union[Variation_993, Variation_993_Arg]) -> 'Variation_994':
        ...

    @overload
    def set_item(self, name : Literal['HOR'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_994':
        ...

    @overload
    def set_item(self, name : Literal['MIN'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_994':
        ...

    @overload
    def set_item(self, name : Literal['AVS'], val : Union[Variation_377, Variation_377_Arg]) -> 'Variation_994':
        ...

    @overload
    def set_item(self, name : Literal['SEC'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_994':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_994':
        ...

    @overload
    def modify_item(self, name : Literal['DAY'], f : Any) -> 'Variation_994':
        ...

    @overload
    def modify_item(self, name : Literal['HOR'], f : Any) -> 'Variation_994':
        ...

    @overload
    def modify_item(self, name : Literal['MIN'], f : Any) -> 'Variation_994':
        ...

    @overload
    def modify_item(self, name : Literal['AVS'], f : Any) -> 'Variation_994':
        ...

    @overload
    def modify_item(self, name : Literal['SEC'], f : Any) -> 'Variation_994':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_995_Arg : TypeAlias = Union[Variation_994, Variation_994_Arg]
class Variation_995(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 32
    variation_type = Variation_994

    @classmethod
    def spec(cls) -> Type[Variation_994]:
        return Variation_994

    def __init__(self, arg : List[Union[Variation_994, Variation_994_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_994, Variation_994_Arg]) -> 'Variation_995':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_994, Variation_994_Arg]) -> 'Variation_995':
        return self._prepend_item(arg) # type: ignore

Variation_996_Arg : TypeAlias = Raw
class Variation_996(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Empty',
        1: 'Occupied',
        2: 'Unknown',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_996_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_997_Arg : TypeAlias = Raw
class Variation_997(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'Available',
        1: 'Not available',
        2: 'Unknown',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_997_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_998_Arg_Group = TypedDict('Variation_998_Arg_Group', {
    'EMP': Union[Variation_996, Variation_996_Arg],
    'AVL': Union[Variation_997, Variation_997_Arg],
})
Variation_998_Arg : TypeAlias = Union[Raw, Variation_998_Arg_Group]
class Variation_998(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('EMP', Variation_996),
        ('AVL', Variation_997),
        Spare(4, 4),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EMP': ('', Variation_996, 0, 2),
        'AVL': ('', Variation_997, 2, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EMP']) -> Type[Variation_996]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AVL']) -> Type[Variation_997]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EMP'], Literal['AVL']]) -> Union[Type['Variation_996'], Type['Variation_997']]:
        if key == 'EMP':
            return Variation_996
        if key == 'AVL':
            return Variation_997
        assert_never(key)

    def __init__(self, arg : Variation_998_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EMP']) -> Variation_996:
        ...

    @overload
    def get_item(self, name : Literal['AVL']) -> Variation_997:
        ...

    def get_item(self, name : Union[Literal['EMP'], Literal['AVL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EMP'], val : Union[Variation_996, Variation_996_Arg]) -> 'Variation_998':
        ...

    @overload
    def set_item(self, name : Literal['AVL'], val : Union[Variation_997, Variation_997_Arg]) -> 'Variation_998':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EMP'], f : Any) -> 'Variation_998':
        ...

    @overload
    def modify_item(self, name : Literal['AVL'], f : Any) -> 'Variation_998':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_999_Arg = TypedDict('Variation_999_Arg', {
    'IFI': Union[Variation_986, Variation_986_Arg],
    'RVP': Union[Variation_989, Variation_989_Arg],
    'RDS': Union[Variation_991, Variation_991_Arg],
    'TOD': Union[Variation_995, Variation_995_Arg],
    'AST': Union[Variation_161, Variation_161_Arg],
    'STS': Union[Variation_998, Variation_998_Arg],
    'SID': Union[Variation_145, Variation_145_Arg],
    'STAR': Union[Variation_145, Variation_145_Arg],
}, total=False)
class Variation_999(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('IFI', Variation_986),
        ('RVP', Variation_989),
        ('RDS', Variation_991),
        ('TOD', Variation_995),
        ('AST', Variation_161),
        ('STS', Variation_998),
        ('SID', Variation_145),
        ('STAR', Variation_145),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'IFI': ('IFPS FLIGHT ID', Variation_986, 0x8000),
        'RVP': ('RVSM & Flight Priority', Variation_989, 0x4000),
        'RDS': ('Runway Designation', Variation_991, 0x2000),
        'TOD': ('Time of Departure / Arrival', Variation_995, 0x1000),
        'AST': ('Aircraft Stand', Variation_161, 0x0800),
        'STS': ('Stand Status', Variation_998, 0x0400),
        'SID': ('Standard Instrument Departure', Variation_145, 0x0200),
        'STAR': ('Standard Instrument Arrival', Variation_145, 0x0180),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['IFI']) -> Type[Variation_986]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RVP']) -> Type[Variation_989]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RDS']) -> Type[Variation_991]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOD']) -> Type[Variation_995]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AST']) -> Type[Variation_161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STS']) -> Type[Variation_998]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SID']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STAR']) -> Type[Variation_145]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['IFI'], Literal['RVP'], Literal['RDS'], Literal['TOD'], Literal['AST'], Literal['STS'], Literal['SID'], Literal['STAR']]) -> Union[Type['Variation_986'], Type['Variation_989'], Type['Variation_991'], Type['Variation_995'], Type['Variation_161'], Type['Variation_998'], Type['Variation_145'], Type['Variation_145']]:
        if key == 'IFI':
            return Variation_986
        if key == 'RVP':
            return Variation_989
        if key == 'RDS':
            return Variation_991
        if key == 'TOD':
            return Variation_995
        if key == 'AST':
            return Variation_161
        if key == 'STS':
            return Variation_998
        if key == 'SID':
            return Variation_145
        if key == 'STAR':
            return Variation_145
        assert_never(key)

    def __init__(self, arg : Optional[Variation_999_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['IFI'], val : Union[Variation_986, Variation_986_Arg]) -> 'Variation_999':
        ...

    @overload
    def set_item(self, name : Literal['RVP'], val : Union[Variation_989, Variation_989_Arg]) -> 'Variation_999':
        ...

    @overload
    def set_item(self, name : Literal['RDS'], val : Union[Variation_991, Variation_991_Arg]) -> 'Variation_999':
        ...

    @overload
    def set_item(self, name : Literal['TOD'], val : Union[Variation_995, Variation_995_Arg]) -> 'Variation_999':
        ...

    @overload
    def set_item(self, name : Literal['AST'], val : Union[Variation_161, Variation_161_Arg]) -> 'Variation_999':
        ...

    @overload
    def set_item(self, name : Literal['STS'], val : Union[Variation_998, Variation_998_Arg]) -> 'Variation_999':
        ...

    @overload
    def set_item(self, name : Literal['SID'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_999':
        ...

    @overload
    def set_item(self, name : Literal['STAR'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_999':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['IFI']) -> 'Variation_999':
        ...

    @overload
    def del_item(self, name : Literal['RVP']) -> 'Variation_999':
        ...

    @overload
    def del_item(self, name : Literal['RDS']) -> 'Variation_999':
        ...

    @overload
    def del_item(self, name : Literal['TOD']) -> 'Variation_999':
        ...

    @overload
    def del_item(self, name : Literal['AST']) -> 'Variation_999':
        ...

    @overload
    def del_item(self, name : Literal['STS']) -> 'Variation_999':
        ...

    @overload
    def del_item(self, name : Literal['SID']) -> 'Variation_999':
        ...

    @overload
    def del_item(self, name : Literal['STAR']) -> 'Variation_999':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['IFI']) -> Variation_986:
        ...

    @overload
    def get_item(self, name : Literal['RVP']) -> Variation_989:
        ...

    @overload
    def get_item(self, name : Literal['RDS']) -> Variation_991:
        ...

    @overload
    def get_item(self, name : Literal['TOD']) -> Variation_995:
        ...

    @overload
    def get_item(self, name : Literal['AST']) -> Variation_161:
        ...

    @overload
    def get_item(self, name : Literal['STS']) -> Variation_998:
        ...

    @overload
    def get_item(self, name : Literal['SID']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['STAR']) -> Variation_145:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['IFI'], f : Any) -> 'Variation_999':
        ...

    @overload
    def modify_item(self, name : Literal['RVP'], f : Any) -> 'Variation_999':
        ...

    @overload
    def modify_item(self, name : Literal['RDS'], f : Any) -> 'Variation_999':
        ...

    @overload
    def modify_item(self, name : Literal['TOD'], f : Any) -> 'Variation_999':
        ...

    @overload
    def modify_item(self, name : Literal['AST'], f : Any) -> 'Variation_999':
        ...

    @overload
    def modify_item(self, name : Literal['STS'], f : Any) -> 'Variation_999':
        ...

    @overload
    def modify_item(self, name : Literal['SID'], f : Any) -> 'Variation_999':
        ...

    @overload
    def modify_item(self, name : Literal['STAR'], f : Any) -> 'Variation_999':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1000_Arg = TypedDict('Variation_1000_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '015': Union[Variation_64, Variation_64_Arg],
    '018': Union[Variation_1, Variation_1_Arg],
    '035': Union[Variation_974, Variation_974_Arg],
    '020': Union[Variation_80, Variation_80_Arg],
    '040': Union[Variation_64, Variation_64_Arg],
    '050': Union[Variation_975, Variation_975_Arg],
    '060': Union[Variation_976, Variation_976_Arg],
    '400': Union[Variation_145, Variation_145_Arg],
    '410': Union[Variation_64, Variation_64_Arg],
    '420': Union[Variation_979, Variation_979_Arg],
    '440': Union[Variation_330, Variation_330_Arg],
    '450': Union[Variation_330, Variation_330_Arg],
    '480': Union[Variation_164, Variation_164_Arg],
    '490': Union[Variation_980, Variation_980_Arg],
    '430': Union[Variation_330, Variation_330_Arg],
    '435': Union[Variation_370, Variation_370_Arg],
    '460': Union[Variation_984, Variation_984_Arg],
    '500': Union[Variation_999, Variation_999_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
}, total=False)
class Variation_1000(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 3

    subitems_list = [
        ('010', Variation_1),
        ('015', Variation_64),
        ('018', Variation_1),
        ('035', Variation_974),
        ('020', Variation_80),
        ('040', Variation_64),
        ('050', Variation_975),
        ('060', Variation_976),
        ('400', Variation_145),
        ('410', Variation_64),
        ('420', Variation_979),
        ('440', Variation_330),
        ('450', Variation_330),
        ('480', Variation_164),
        ('490', Variation_980),
        ('430', Variation_330),
        ('435', Variation_370),
        ('460', Variation_984),
        ('500', Variation_999),
        None,
        ('RE', Variation_202),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Server Identification Tag', Variation_1, 0x800000),
        '015': ('User Number', Variation_64, 0x400000),
        '018': ('Data Source Identification Tag', Variation_1, 0x200000),
        '035': ('Type of Message', Variation_974, 0x100000),
        '020': ('Time of ASTERIX Report Generation', Variation_80, 0x080000),
        '040': ('Track Number', Variation_64, 0x040000),
        '050': ('Composed Track Number', Variation_975, 0x020000),
        '060': ('Track Mode 3/A', Variation_976, 0x018000),
        '400': ('Callsign', Variation_145, 0x014000),
        '410': ('Plan Number', Variation_64, 0x012000),
        '420': ('Flight Category', Variation_979, 0x011000),
        '440': ('Departure Aerodrome', Variation_330, 0x010800),
        '450': ('Destination Aerodrome', Variation_330, 0x010400),
        '480': ('Current Cleared Flight Level', Variation_164, 0x010200),
        '490': ('Current Control Position', Variation_980, 0x010180),
        '430': ('Type of Aircraft', Variation_330, 0x010140),
        '435': ('Wake Turbulence Category', Variation_370, 0x010120),
        '460': ('Allocated SSR Codes', Variation_984, 0x010110),
        '500': ('Supplementary Flight Data', Variation_999, 0x010108),
        'RE': ('Reserved Expansion Field', Variation_202, 0x010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['018']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['035']) -> Type[Variation_974]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_975]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_976]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['400']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['410']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['420']) -> Type[Variation_979]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['440']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['450']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['480']) -> Type[Variation_164]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['490']) -> Type[Variation_980]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['430']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['435']) -> Type[Variation_370]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['460']) -> Type[Variation_984]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_999]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['015'], Literal['018'], Literal['035'], Literal['020'], Literal['040'], Literal['050'], Literal['060'], Literal['400'], Literal['410'], Literal['420'], Literal['440'], Literal['450'], Literal['480'], Literal['490'], Literal['430'], Literal['435'], Literal['460'], Literal['500'], Literal['RE']]) -> Union[Type['Variation_1'], Type['Variation_64'], Type['Variation_1'], Type['Variation_974'], Type['Variation_80'], Type['Variation_64'], Type['Variation_975'], Type['Variation_976'], Type['Variation_145'], Type['Variation_64'], Type['Variation_979'], Type['Variation_330'], Type['Variation_330'], Type['Variation_164'], Type['Variation_980'], Type['Variation_330'], Type['Variation_370'], Type['Variation_984'], Type['Variation_999'], Type['Variation_202']]:
        if key == '010':
            return Variation_1
        if key == '015':
            return Variation_64
        if key == '018':
            return Variation_1
        if key == '035':
            return Variation_974
        if key == '020':
            return Variation_80
        if key == '040':
            return Variation_64
        if key == '050':
            return Variation_975
        if key == '060':
            return Variation_976
        if key == '400':
            return Variation_145
        if key == '410':
            return Variation_64
        if key == '420':
            return Variation_979
        if key == '440':
            return Variation_330
        if key == '450':
            return Variation_330
        if key == '480':
            return Variation_164
        if key == '490':
            return Variation_980
        if key == '430':
            return Variation_330
        if key == '435':
            return Variation_370
        if key == '460':
            return Variation_984
        if key == '500':
            return Variation_999
        if key == 'RE':
            return Variation_202
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1000_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['018'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['035'], val : Union[Variation_974, Variation_974_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_975, Variation_975_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_976, Variation_976_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['400'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['410'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['420'], val : Union[Variation_979, Variation_979_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['440'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['450'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['480'], val : Union[Variation_164, Variation_164_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['490'], val : Union[Variation_980, Variation_980_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['430'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['435'], val : Union[Variation_370, Variation_370_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['460'], val : Union[Variation_984, Variation_984_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_999, Variation_999_Arg]) -> 'Variation_1000':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1000':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['018']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['035']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['400']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['410']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['420']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['440']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['450']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['480']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['490']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['430']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['435']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['460']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_1000':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1000':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['018']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['035']) -> Variation_974:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_975:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_976:
        ...

    @overload
    def get_item(self, name : Literal['400']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['410']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['420']) -> Variation_979:
        ...

    @overload
    def get_item(self, name : Literal['440']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['450']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['480']) -> Variation_164:
        ...

    @overload
    def get_item(self, name : Literal['490']) -> Variation_980:
        ...

    @overload
    def get_item(self, name : Literal['430']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['435']) -> Variation_370:
        ...

    @overload
    def get_item(self, name : Literal['460']) -> Variation_984:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_999:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['018'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['035'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['400'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['410'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['420'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['440'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['450'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['480'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['490'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['430'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['435'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['460'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_1000':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1000':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1001_Arg : TypeAlias = Raw
class Variation_1001(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'North marker message',
        2: 'Sector crossing message',
        3: 'Geographical filtering message',
        4: 'Jamming strobe message',
    }

    def __init__(self, arg : Variation_1001_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1002_Arg : TypeAlias = Raw
class Variation_1002(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'System is released for operational use',
        1: 'Operational use of System is inhibited, i.e. the data shall be discarded by an operational SDPS',
    }

    def __init__(self, arg : Variation_1002_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1003_Arg : TypeAlias = Raw
class Variation_1003(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'RDPC-1 selected',
        1: 'RDPC-2 selected',
    }

    def __init__(self, arg : Variation_1003_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1004_Arg : TypeAlias = Raw
class Variation_1004(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default situation',
        1: 'Reset of RDPC',
    }

    def __init__(self, arg : Variation_1004_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1005_Arg : TypeAlias = Raw
class Variation_1005(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default, no overload',
        1: 'Overload in RDP',
    }

    def __init__(self, arg : Variation_1005_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1006_Arg : TypeAlias = Raw
class Variation_1006(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default, no overload',
        1: 'Overload in transmission subsystem',
    }

    def __init__(self, arg : Variation_1006_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1007_Arg : TypeAlias = Raw
class Variation_1007(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Monitoring system connected',
        1: 'Monitoring system disconnected',
    }

    def __init__(self, arg : Variation_1007_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1008_Arg : TypeAlias = Raw
class Variation_1008(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Valid',
        1: 'Invalid',
    }

    def __init__(self, arg : Variation_1008_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1009_Arg_Group = TypedDict('Variation_1009_Arg_Group', {
    'NOGO': Union[Variation_1002, Variation_1002_Arg],
    'RDPC': Union[Variation_1003, Variation_1003_Arg],
    'RDPR': Union[Variation_1004, Variation_1004_Arg],
    'OVLRDP': Union[Variation_1005, Variation_1005_Arg],
    'OVLXMT': Union[Variation_1006, Variation_1006_Arg],
    'MSC': Union[Variation_1007, Variation_1007_Arg],
    'TSV': Union[Variation_1008, Variation_1008_Arg],
})
Variation_1009_Arg : TypeAlias = Union[Raw, Variation_1009_Arg_Group]
class Variation_1009(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('NOGO', Variation_1002),
        ('RDPC', Variation_1003),
        ('RDPR', Variation_1004),
        ('OVLRDP', Variation_1005),
        ('OVLXMT', Variation_1006),
        ('MSC', Variation_1007),
        ('TSV', Variation_1008),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NOGO': ('Operational Release Status of the System', Variation_1002, 0, 1),
        'RDPC': ('Radar Data Processor Chain Selection Status', Variation_1003, 1, 1),
        'RDPR': ('Event to Signal a Reset/restart of the Selected Radar Data Processor Chain, I.e. Expect a New Assignment of Track Numbers', Variation_1004, 2, 1),
        'OVLRDP': ('Radar Data Processor Overload Indicator', Variation_1005, 3, 1),
        'OVLXMT': ('Transmission Subsystem Overload Status', Variation_1006, 4, 1),
        'MSC': ('Monitoring System Connected Status', Variation_1007, 5, 1),
        'TSV': ('Time Source Validity', Variation_1008, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NOGO']) -> Type[Variation_1002]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RDPC']) -> Type[Variation_1003]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RDPR']) -> Type[Variation_1004]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVLRDP']) -> Type[Variation_1005]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVLXMT']) -> Type[Variation_1006]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSC']) -> Type[Variation_1007]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSV']) -> Type[Variation_1008]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NOGO'], Literal['RDPC'], Literal['RDPR'], Literal['OVLRDP'], Literal['OVLXMT'], Literal['MSC'], Literal['TSV']]) -> Union[Type['Variation_1002'], Type['Variation_1003'], Type['Variation_1004'], Type['Variation_1005'], Type['Variation_1006'], Type['Variation_1007'], Type['Variation_1008']]:
        if key == 'NOGO':
            return Variation_1002
        if key == 'RDPC':
            return Variation_1003
        if key == 'RDPR':
            return Variation_1004
        if key == 'OVLRDP':
            return Variation_1005
        if key == 'OVLXMT':
            return Variation_1006
        if key == 'MSC':
            return Variation_1007
        if key == 'TSV':
            return Variation_1008
        assert_never(key)

    def __init__(self, arg : Variation_1009_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NOGO']) -> Variation_1002:
        ...

    @overload
    def get_item(self, name : Literal['RDPC']) -> Variation_1003:
        ...

    @overload
    def get_item(self, name : Literal['RDPR']) -> Variation_1004:
        ...

    @overload
    def get_item(self, name : Literal['OVLRDP']) -> Variation_1005:
        ...

    @overload
    def get_item(self, name : Literal['OVLXMT']) -> Variation_1006:
        ...

    @overload
    def get_item(self, name : Literal['MSC']) -> Variation_1007:
        ...

    @overload
    def get_item(self, name : Literal['TSV']) -> Variation_1008:
        ...

    def get_item(self, name : Union[Literal['NOGO'], Literal['RDPC'], Literal['RDPR'], Literal['OVLRDP'], Literal['OVLXMT'], Literal['MSC'], Literal['TSV']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NOGO'], val : Union[Variation_1002, Variation_1002_Arg]) -> 'Variation_1009':
        ...

    @overload
    def set_item(self, name : Literal['RDPC'], val : Union[Variation_1003, Variation_1003_Arg]) -> 'Variation_1009':
        ...

    @overload
    def set_item(self, name : Literal['RDPR'], val : Union[Variation_1004, Variation_1004_Arg]) -> 'Variation_1009':
        ...

    @overload
    def set_item(self, name : Literal['OVLRDP'], val : Union[Variation_1005, Variation_1005_Arg]) -> 'Variation_1009':
        ...

    @overload
    def set_item(self, name : Literal['OVLXMT'], val : Union[Variation_1006, Variation_1006_Arg]) -> 'Variation_1009':
        ...

    @overload
    def set_item(self, name : Literal['MSC'], val : Union[Variation_1007, Variation_1007_Arg]) -> 'Variation_1009':
        ...

    @overload
    def set_item(self, name : Literal['TSV'], val : Union[Variation_1008, Variation_1008_Arg]) -> 'Variation_1009':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NOGO'], f : Any) -> 'Variation_1009':
        ...

    @overload
    def modify_item(self, name : Literal['RDPC'], f : Any) -> 'Variation_1009':
        ...

    @overload
    def modify_item(self, name : Literal['RDPR'], f : Any) -> 'Variation_1009':
        ...

    @overload
    def modify_item(self, name : Literal['OVLRDP'], f : Any) -> 'Variation_1009':
        ...

    @overload
    def modify_item(self, name : Literal['OVLXMT'], f : Any) -> 'Variation_1009':
        ...

    @overload
    def modify_item(self, name : Literal['MSC'], f : Any) -> 'Variation_1009':
        ...

    @overload
    def modify_item(self, name : Literal['TSV'], f : Any) -> 'Variation_1009':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1010_Arg : TypeAlias = Raw
class Variation_1010(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Antenna 1',
        1: 'Antenna 2',
    }

    def __init__(self, arg : Variation_1010_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1011_Arg : TypeAlias = Raw
class Variation_1011(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'No channel selected',
        1: 'Channel A only selected',
        2: 'Channel B only selected',
        3: 'Diversity mode ; Channel A and B selected',
    }

    def __init__(self, arg : Variation_1011_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1012_Arg : TypeAlias = Raw
class Variation_1012(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'No overload',
        1: 'Overload',
    }

    def __init__(self, arg : Variation_1012_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1013_Arg : TypeAlias = Raw
class Variation_1013(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Monitoring system connected',
        1: 'Monitoring system disconnected',
    }

    def __init__(self, arg : Variation_1013_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1014_Arg_Group = TypedDict('Variation_1014_Arg_Group', {
    'ANT': Union[Variation_1010, Variation_1010_Arg],
    'CHAB': Union[Variation_1011, Variation_1011_Arg],
    'OVL': Union[Variation_1012, Variation_1012_Arg],
    'MSC': Union[Variation_1013, Variation_1013_Arg],
})
Variation_1014_Arg : TypeAlias = Union[Raw, Variation_1014_Arg_Group]
class Variation_1014(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('ANT', Variation_1010),
        ('CHAB', Variation_1011),
        ('OVL', Variation_1012),
        ('MSC', Variation_1013),
        Spare(5, 3),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ANT': ('Selected Antenna', Variation_1010, 0, 1),
        'CHAB': ('Channel A/B Selection Status', Variation_1011, 1, 2),
        'OVL': ('Overload Condition', Variation_1012, 3, 1),
        'MSC': ('Monitoring System Connected Status', Variation_1013, 4, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ANT']) -> Type[Variation_1010]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHAB']) -> Type[Variation_1011]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVL']) -> Type[Variation_1012]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSC']) -> Type[Variation_1013]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ANT'], Literal['CHAB'], Literal['OVL'], Literal['MSC']]) -> Union[Type['Variation_1010'], Type['Variation_1011'], Type['Variation_1012'], Type['Variation_1013']]:
        if key == 'ANT':
            return Variation_1010
        if key == 'CHAB':
            return Variation_1011
        if key == 'OVL':
            return Variation_1012
        if key == 'MSC':
            return Variation_1013
        assert_never(key)

    def __init__(self, arg : Variation_1014_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ANT']) -> Variation_1010:
        ...

    @overload
    def get_item(self, name : Literal['CHAB']) -> Variation_1011:
        ...

    @overload
    def get_item(self, name : Literal['OVL']) -> Variation_1012:
        ...

    @overload
    def get_item(self, name : Literal['MSC']) -> Variation_1013:
        ...

    def get_item(self, name : Union[Literal['ANT'], Literal['CHAB'], Literal['OVL'], Literal['MSC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ANT'], val : Union[Variation_1010, Variation_1010_Arg]) -> 'Variation_1014':
        ...

    @overload
    def set_item(self, name : Literal['CHAB'], val : Union[Variation_1011, Variation_1011_Arg]) -> 'Variation_1014':
        ...

    @overload
    def set_item(self, name : Literal['OVL'], val : Union[Variation_1012, Variation_1012_Arg]) -> 'Variation_1014':
        ...

    @overload
    def set_item(self, name : Literal['MSC'], val : Union[Variation_1013, Variation_1013_Arg]) -> 'Variation_1014':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ANT'], f : Any) -> 'Variation_1014':
        ...

    @overload
    def modify_item(self, name : Literal['CHAB'], f : Any) -> 'Variation_1014':
        ...

    @overload
    def modify_item(self, name : Literal['OVL'], f : Any) -> 'Variation_1014':
        ...

    @overload
    def modify_item(self, name : Literal['MSC'], f : Any) -> 'Variation_1014':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1015_Arg : TypeAlias = Raw
class Variation_1015(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'No channel selected',
        1: 'Channel A only selected',
        2: 'Channel B only selected',
        3: 'Invalid combination',
    }

    def __init__(self, arg : Variation_1015_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1016_Arg_Group = TypedDict('Variation_1016_Arg_Group', {
    'ANT': Union[Variation_1010, Variation_1010_Arg],
    'CHAB': Union[Variation_1015, Variation_1015_Arg],
    'OVL': Union[Variation_1012, Variation_1012_Arg],
    'MSC': Union[Variation_1013, Variation_1013_Arg],
})
Variation_1016_Arg : TypeAlias = Union[Raw, Variation_1016_Arg_Group]
class Variation_1016(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('ANT', Variation_1010),
        ('CHAB', Variation_1015),
        ('OVL', Variation_1012),
        ('MSC', Variation_1013),
        Spare(5, 3),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ANT': ('Selected Antenna', Variation_1010, 0, 1),
        'CHAB': ('Channel A/B Selection Status', Variation_1015, 1, 2),
        'OVL': ('Overload Condition', Variation_1012, 3, 1),
        'MSC': ('Monitoring System Connected Status:', Variation_1013, 4, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ANT']) -> Type[Variation_1010]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHAB']) -> Type[Variation_1015]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVL']) -> Type[Variation_1012]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSC']) -> Type[Variation_1013]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ANT'], Literal['CHAB'], Literal['OVL'], Literal['MSC']]) -> Union[Type['Variation_1010'], Type['Variation_1015'], Type['Variation_1012'], Type['Variation_1013']]:
        if key == 'ANT':
            return Variation_1010
        if key == 'CHAB':
            return Variation_1015
        if key == 'OVL':
            return Variation_1012
        if key == 'MSC':
            return Variation_1013
        assert_never(key)

    def __init__(self, arg : Variation_1016_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ANT']) -> Variation_1010:
        ...

    @overload
    def get_item(self, name : Literal['CHAB']) -> Variation_1015:
        ...

    @overload
    def get_item(self, name : Literal['OVL']) -> Variation_1012:
        ...

    @overload
    def get_item(self, name : Literal['MSC']) -> Variation_1013:
        ...

    def get_item(self, name : Union[Literal['ANT'], Literal['CHAB'], Literal['OVL'], Literal['MSC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ANT'], val : Union[Variation_1010, Variation_1010_Arg]) -> 'Variation_1016':
        ...

    @overload
    def set_item(self, name : Literal['CHAB'], val : Union[Variation_1015, Variation_1015_Arg]) -> 'Variation_1016':
        ...

    @overload
    def set_item(self, name : Literal['OVL'], val : Union[Variation_1012, Variation_1012_Arg]) -> 'Variation_1016':
        ...

    @overload
    def set_item(self, name : Literal['MSC'], val : Union[Variation_1013, Variation_1013_Arg]) -> 'Variation_1016':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ANT'], f : Any) -> 'Variation_1016':
        ...

    @overload
    def modify_item(self, name : Literal['CHAB'], f : Any) -> 'Variation_1016':
        ...

    @overload
    def modify_item(self, name : Literal['OVL'], f : Any) -> 'Variation_1016':
        ...

    @overload
    def modify_item(self, name : Literal['MSC'], f : Any) -> 'Variation_1016':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1017_Arg : TypeAlias = Raw
class Variation_1017(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'No channel selected',
        1: 'Channel A only selected',
        2: 'Channel B only selected',
        3: 'Illegal combination',
    }

    def __init__(self, arg : Variation_1017_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1018_Arg : TypeAlias = Raw
class Variation_1018(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Channel A in use',
        1: 'Channel B in use',
    }

    def __init__(self, arg : Variation_1018_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1019_Arg : TypeAlias = Raw
class Variation_1019(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Channel A in use',
        1: 'Channel B in use',
    }

    def __init__(self, arg : Variation_1019_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1020_Arg : TypeAlias = Raw
class Variation_1020(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'No overload',
        1: 'Overload',
    }

    def __init__(self, arg : Variation_1020_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1021_Arg : TypeAlias = Raw
class Variation_1021(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No overload',
        1: 'Overload',
    }

    def __init__(self, arg : Variation_1021_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1022_Arg_Group = TypedDict('Variation_1022_Arg_Group', {
    'ANT': Union[Variation_1010, Variation_1010_Arg],
    'CHAB': Union[Variation_1017, Variation_1017_Arg],
    'OVLSUR': Union[Variation_1012, Variation_1012_Arg],
    'MSC': Union[Variation_1013, Variation_1013_Arg],
    'SCF': Union[Variation_1018, Variation_1018_Arg],
    'DLF': Union[Variation_1019, Variation_1019_Arg],
    'OVLSCF': Union[Variation_1020, Variation_1020_Arg],
    'OVLDLF': Union[Variation_1021, Variation_1021_Arg],
})
Variation_1022_Arg : TypeAlias = Union[Raw, Variation_1022_Arg_Group]
class Variation_1022(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('ANT', Variation_1010),
        ('CHAB', Variation_1017),
        ('OVLSUR', Variation_1012),
        ('MSC', Variation_1013),
        ('SCF', Variation_1018),
        ('DLF', Variation_1019),
        ('OVLSCF', Variation_1020),
        ('OVLDLF', Variation_1021),
        Spare(1, 7),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ANT': ('Selected Antenna', Variation_1010, 0, 1),
        'CHAB': ('Channel A/B Selection Status', Variation_1017, 1, 2),
        'OVLSUR': ('Overload Condition', Variation_1012, 3, 1),
        'MSC': ('Monitoring System Connected Status:', Variation_1013, 4, 1),
        'SCF': ('Channel A/B Selection Status for Surveillance Co-ordination Function', Variation_1018, 5, 1),
        'DLF': ('Channel A/B Selection Status for Data Link Function', Variation_1019, 6, 1),
        'OVLSCF': ('Overload in Surveillance Co-ordination Function', Variation_1020, 7, 1),
        'OVLDLF': ('Overload in Data Link Function', Variation_1021, 8, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ANT']) -> Type[Variation_1010]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHAB']) -> Type[Variation_1017]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVLSUR']) -> Type[Variation_1012]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSC']) -> Type[Variation_1013]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SCF']) -> Type[Variation_1018]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DLF']) -> Type[Variation_1019]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVLSCF']) -> Type[Variation_1020]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVLDLF']) -> Type[Variation_1021]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ANT'], Literal['CHAB'], Literal['OVLSUR'], Literal['MSC'], Literal['SCF'], Literal['DLF'], Literal['OVLSCF'], Literal['OVLDLF']]) -> Union[Type['Variation_1010'], Type['Variation_1017'], Type['Variation_1012'], Type['Variation_1013'], Type['Variation_1018'], Type['Variation_1019'], Type['Variation_1020'], Type['Variation_1021']]:
        if key == 'ANT':
            return Variation_1010
        if key == 'CHAB':
            return Variation_1017
        if key == 'OVLSUR':
            return Variation_1012
        if key == 'MSC':
            return Variation_1013
        if key == 'SCF':
            return Variation_1018
        if key == 'DLF':
            return Variation_1019
        if key == 'OVLSCF':
            return Variation_1020
        if key == 'OVLDLF':
            return Variation_1021
        assert_never(key)

    def __init__(self, arg : Variation_1022_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ANT']) -> Variation_1010:
        ...

    @overload
    def get_item(self, name : Literal['CHAB']) -> Variation_1017:
        ...

    @overload
    def get_item(self, name : Literal['OVLSUR']) -> Variation_1012:
        ...

    @overload
    def get_item(self, name : Literal['MSC']) -> Variation_1013:
        ...

    @overload
    def get_item(self, name : Literal['SCF']) -> Variation_1018:
        ...

    @overload
    def get_item(self, name : Literal['DLF']) -> Variation_1019:
        ...

    @overload
    def get_item(self, name : Literal['OVLSCF']) -> Variation_1020:
        ...

    @overload
    def get_item(self, name : Literal['OVLDLF']) -> Variation_1021:
        ...

    def get_item(self, name : Union[Literal['ANT'], Literal['CHAB'], Literal['OVLSUR'], Literal['MSC'], Literal['SCF'], Literal['DLF'], Literal['OVLSCF'], Literal['OVLDLF']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ANT'], val : Union[Variation_1010, Variation_1010_Arg]) -> 'Variation_1022':
        ...

    @overload
    def set_item(self, name : Literal['CHAB'], val : Union[Variation_1017, Variation_1017_Arg]) -> 'Variation_1022':
        ...

    @overload
    def set_item(self, name : Literal['OVLSUR'], val : Union[Variation_1012, Variation_1012_Arg]) -> 'Variation_1022':
        ...

    @overload
    def set_item(self, name : Literal['MSC'], val : Union[Variation_1013, Variation_1013_Arg]) -> 'Variation_1022':
        ...

    @overload
    def set_item(self, name : Literal['SCF'], val : Union[Variation_1018, Variation_1018_Arg]) -> 'Variation_1022':
        ...

    @overload
    def set_item(self, name : Literal['DLF'], val : Union[Variation_1019, Variation_1019_Arg]) -> 'Variation_1022':
        ...

    @overload
    def set_item(self, name : Literal['OVLSCF'], val : Union[Variation_1020, Variation_1020_Arg]) -> 'Variation_1022':
        ...

    @overload
    def set_item(self, name : Literal['OVLDLF'], val : Union[Variation_1021, Variation_1021_Arg]) -> 'Variation_1022':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ANT'], f : Any) -> 'Variation_1022':
        ...

    @overload
    def modify_item(self, name : Literal['CHAB'], f : Any) -> 'Variation_1022':
        ...

    @overload
    def modify_item(self, name : Literal['OVLSUR'], f : Any) -> 'Variation_1022':
        ...

    @overload
    def modify_item(self, name : Literal['MSC'], f : Any) -> 'Variation_1022':
        ...

    @overload
    def modify_item(self, name : Literal['SCF'], f : Any) -> 'Variation_1022':
        ...

    @overload
    def modify_item(self, name : Literal['DLF'], f : Any) -> 'Variation_1022':
        ...

    @overload
    def modify_item(self, name : Literal['OVLSCF'], f : Any) -> 'Variation_1022':
        ...

    @overload
    def modify_item(self, name : Literal['OVLDLF'], f : Any) -> 'Variation_1022':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1023_Arg = TypedDict('Variation_1023_Arg', {
    'COM': Union[Variation_1009, Variation_1009_Arg],
    'PSR': Union[Variation_1014, Variation_1014_Arg],
    'SSR': Union[Variation_1016, Variation_1016_Arg],
    'MDS': Union[Variation_1022, Variation_1022_Arg],
}, total=False)
class Variation_1023(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('COM', Variation_1009),
        None,
        None,
        ('PSR', Variation_1014),
        ('SSR', Variation_1016),
        ('MDS', Variation_1022),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'COM': ('Common Part', Variation_1009, 0x80),
        'PSR': ('Specific Status Information for a PSR Sensor', Variation_1014, 0x10),
        'SSR': ('Specific Status Information for a SSR Sensor', Variation_1016, 0x08),
        'MDS': ('Specific Status Information for a Mode S Sensor', Variation_1022, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_1009]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_1014]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_1016]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_1022]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COM'], Literal['PSR'], Literal['SSR'], Literal['MDS']]) -> Union[Type['Variation_1009'], Type['Variation_1014'], Type['Variation_1016'], Type['Variation_1022']]:
        if key == 'COM':
            return Variation_1009
        if key == 'PSR':
            return Variation_1014
        if key == 'SSR':
            return Variation_1016
        if key == 'MDS':
            return Variation_1022
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1023_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_1009, Variation_1009_Arg]) -> 'Variation_1023':
        ...

    @overload
    def set_item(self, name : Literal['PSR'], val : Union[Variation_1014, Variation_1014_Arg]) -> 'Variation_1023':
        ...

    @overload
    def set_item(self, name : Literal['SSR'], val : Union[Variation_1016, Variation_1016_Arg]) -> 'Variation_1023':
        ...

    @overload
    def set_item(self, name : Literal['MDS'], val : Union[Variation_1022, Variation_1022_Arg]) -> 'Variation_1023':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['COM']) -> 'Variation_1023':
        ...

    @overload
    def del_item(self, name : Literal['PSR']) -> 'Variation_1023':
        ...

    @overload
    def del_item(self, name : Literal['SSR']) -> 'Variation_1023':
        ...

    @overload
    def del_item(self, name : Literal['MDS']) -> 'Variation_1023':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_1009:
        ...

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_1014:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_1016:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_1022:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1023':
        ...

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_1023':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_1023':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_1023':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1024_Arg : TypeAlias = Raw
class Variation_1024(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 3
    table = {
        0: 'No reduction active',
        1: 'Reduction step 1 active',
        2: 'Reduction step 2 active',
        3: 'Reduction step 3 active',
        4: 'Reduction step 4 active',
        5: 'Reduction step 5 active',
        6: 'Reduction step 6 active',
        7: 'Reduction step 7 active',
    }

    def __init__(self, arg : Variation_1024_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1025_Arg : TypeAlias = Raw
class Variation_1025(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 3
    table = {
        0: 'No reduction active',
        1: 'Reduction step 1 active',
        2: 'Reduction step 2 active',
        3: 'Reduction step 3 active',
        4: 'Reduction step 4 active',
        5: 'Reduction step 5 active',
        6: 'Reduction step 6 active',
        7: 'Reduction step 7 active',
    }

    def __init__(self, arg : Variation_1025_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1026_Arg_Group = TypedDict('Variation_1026_Arg_Group', {
    'REDRDP': Union[Variation_1024, Variation_1024_Arg],
    'REDXMT': Union[Variation_1025, Variation_1025_Arg],
})
Variation_1026_Arg : TypeAlias = Union[Raw, Variation_1026_Arg_Group]
class Variation_1026(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 1),
        ('REDRDP', Variation_1024),
        ('REDXMT', Variation_1025),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'REDRDP': ('Reduction Steps in Use for An Overload of the RDP', Variation_1024, 1, 3),
        'REDXMT': ('Reduction Steps in Use for An Overload of the Transmission Subsystem', Variation_1025, 4, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['REDRDP']) -> Type[Variation_1024]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['REDXMT']) -> Type[Variation_1025]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['REDRDP'], Literal['REDXMT']]) -> Union[Type['Variation_1024'], Type['Variation_1025']]:
        if key == 'REDRDP':
            return Variation_1024
        if key == 'REDXMT':
            return Variation_1025
        assert_never(key)

    def __init__(self, arg : Variation_1026_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['REDRDP']) -> Variation_1024:
        ...

    @overload
    def get_item(self, name : Literal['REDXMT']) -> Variation_1025:
        ...

    def get_item(self, name : Union[Literal['REDRDP'], Literal['REDXMT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['REDRDP'], val : Union[Variation_1024, Variation_1024_Arg]) -> 'Variation_1026':
        ...

    @overload
    def set_item(self, name : Literal['REDXMT'], val : Union[Variation_1025, Variation_1025_Arg]) -> 'Variation_1026':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['REDRDP'], f : Any) -> 'Variation_1026':
        ...

    @overload
    def modify_item(self, name : Literal['REDXMT'], f : Any) -> 'Variation_1026':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1027_Arg : TypeAlias = Raw
class Variation_1027(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Linear polarization',
        1: 'Circular polarization',
    }

    def __init__(self, arg : Variation_1027_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1028_Arg : TypeAlias = Raw
class Variation_1028(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        0: 'STC Map-1',
        1: 'STC Map-2',
        2: 'STC Map-3',
        3: 'STC Map-4',
    }

    def __init__(self, arg : Variation_1028_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1029_Arg_Group = TypedDict('Variation_1029_Arg_Group', {
    'POL': Union[Variation_1027, Variation_1027_Arg],
    'REDRAD': Union[Variation_1024, Variation_1024_Arg],
    'STC': Union[Variation_1028, Variation_1028_Arg],
})
Variation_1029_Arg : TypeAlias = Union[Raw, Variation_1029_Arg_Group]
class Variation_1029(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('POL', Variation_1027),
        ('REDRAD', Variation_1024),
        ('STC', Variation_1028),
        Spare(6, 2),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'POL': ('Polarization in Use by PSR', Variation_1027, 0, 1),
        'REDRAD': ('Reduction Steps in Use as Result of An Overload Within the PSR Subsystem', Variation_1024, 1, 3),
        'STC': ('Sensitivity Time Control Map in Use', Variation_1028, 4, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['POL']) -> Type[Variation_1027]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['REDRAD']) -> Type[Variation_1024]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STC']) -> Type[Variation_1028]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['POL'], Literal['REDRAD'], Literal['STC']]) -> Union[Type['Variation_1027'], Type['Variation_1024'], Type['Variation_1028']]:
        if key == 'POL':
            return Variation_1027
        if key == 'REDRAD':
            return Variation_1024
        if key == 'STC':
            return Variation_1028
        assert_never(key)

    def __init__(self, arg : Variation_1029_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['POL']) -> Variation_1027:
        ...

    @overload
    def get_item(self, name : Literal['REDRAD']) -> Variation_1024:
        ...

    @overload
    def get_item(self, name : Literal['STC']) -> Variation_1028:
        ...

    def get_item(self, name : Union[Literal['POL'], Literal['REDRAD'], Literal['STC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['POL'], val : Union[Variation_1027, Variation_1027_Arg]) -> 'Variation_1029':
        ...

    @overload
    def set_item(self, name : Literal['REDRAD'], val : Union[Variation_1024, Variation_1024_Arg]) -> 'Variation_1029':
        ...

    @overload
    def set_item(self, name : Literal['STC'], val : Union[Variation_1028, Variation_1028_Arg]) -> 'Variation_1029':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['POL'], f : Any) -> 'Variation_1029':
        ...

    @overload
    def modify_item(self, name : Literal['REDRAD'], f : Any) -> 'Variation_1029':
        ...

    @overload
    def modify_item(self, name : Literal['STC'], f : Any) -> 'Variation_1029':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1030_Arg : TypeAlias = Raw
class Variation_1030(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: 'No reduction active',
        1: 'Reduction step 1 active',
        2: 'Reduction step 2 active',
        3: 'Reduction step 3 active',
        4: 'Reduction step 4 active',
        5: 'Reduction step 5 active',
        6: 'Reduction step 6 active',
        7: 'Reduction step 7 active',
    }

    def __init__(self, arg : Variation_1030_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1031_Arg_Group = TypedDict('Variation_1031_Arg_Group', {
    'REDRAD': Union[Variation_1030, Variation_1030_Arg],
})
Variation_1031_Arg : TypeAlias = Union[Raw, Variation_1031_Arg_Group]
class Variation_1031(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('REDRAD', Variation_1030),
        Spare(3, 5),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'REDRAD': ('Reduction Steps in Use as Result of An Overload Within the SSR Subsystem', Variation_1030, 0, 3),
    }


    @classmethod
    def spec(cls, key : Union[Literal['REDRAD']]) -> Union[Type['Variation_1030']]:
        if key == 'REDRAD':
            return Variation_1030
        assert_never(key)

    def __init__(self, arg : Variation_1031_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['REDRAD']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['REDRAD'], val : Union[Variation_1030, Variation_1030_Arg]) -> 'Variation_1031':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['REDRAD'], f : Any) -> 'Variation_1031':
        return self._modify_item(name, f) # type: ignore

Variation_1032_Arg : TypeAlias = Raw
class Variation_1032(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Autonomous',
        1: 'Not autonomous',
    }

    def __init__(self, arg : Variation_1032_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1033_Arg_Group = TypedDict('Variation_1033_Arg_Group', {
    'REDRAD': Union[Variation_1030, Variation_1030_Arg],
    'CLU': Union[Variation_1032, Variation_1032_Arg],
})
Variation_1033_Arg : TypeAlias = Union[Raw, Variation_1033_Arg_Group]
class Variation_1033(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('REDRAD', Variation_1030),
        ('CLU', Variation_1032),
        Spare(4, 4),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'REDRAD': ('Reduction Steps in Use as Result of An Overload Within the Mode S Subsystem', Variation_1030, 0, 3),
        'CLU': ('Cluster State', Variation_1032, 3, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['REDRAD']) -> Type[Variation_1030]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CLU']) -> Type[Variation_1032]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['REDRAD'], Literal['CLU']]) -> Union[Type['Variation_1030'], Type['Variation_1032']]:
        if key == 'REDRAD':
            return Variation_1030
        if key == 'CLU':
            return Variation_1032
        assert_never(key)

    def __init__(self, arg : Variation_1033_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['REDRAD']) -> Variation_1030:
        ...

    @overload
    def get_item(self, name : Literal['CLU']) -> Variation_1032:
        ...

    def get_item(self, name : Union[Literal['REDRAD'], Literal['CLU']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['REDRAD'], val : Union[Variation_1030, Variation_1030_Arg]) -> 'Variation_1033':
        ...

    @overload
    def set_item(self, name : Literal['CLU'], val : Union[Variation_1032, Variation_1032_Arg]) -> 'Variation_1033':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['REDRAD'], f : Any) -> 'Variation_1033':
        ...

    @overload
    def modify_item(self, name : Literal['CLU'], f : Any) -> 'Variation_1033':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1034_Arg = TypedDict('Variation_1034_Arg', {
    'COM': Union[Variation_1026, Variation_1026_Arg],
    'PSR': Union[Variation_1029, Variation_1029_Arg],
    'SSR': Union[Variation_1031, Variation_1031_Arg],
    'MDS': Union[Variation_1033, Variation_1033_Arg],
}, total=False)
class Variation_1034(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('COM', Variation_1026),
        None,
        None,
        ('PSR', Variation_1029),
        ('SSR', Variation_1031),
        ('MDS', Variation_1033),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'COM': ('Common Part', Variation_1026, 0x80),
        'PSR': ('Specific Processing Mode Information for a PSR Sensor', Variation_1029, 0x10),
        'SSR': ('Specific Processing Mode Information for a SSR Sensor', Variation_1031, 0x08),
        'MDS': ('Specific Processing Mode Information for a Mode S Sensor', Variation_1033, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_1026]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_1029]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_1031]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_1033]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COM'], Literal['PSR'], Literal['SSR'], Literal['MDS']]) -> Union[Type['Variation_1026'], Type['Variation_1029'], Type['Variation_1031'], Type['Variation_1033']]:
        if key == 'COM':
            return Variation_1026
        if key == 'PSR':
            return Variation_1029
        if key == 'SSR':
            return Variation_1031
        if key == 'MDS':
            return Variation_1033
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1034_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_1026, Variation_1026_Arg]) -> 'Variation_1034':
        ...

    @overload
    def set_item(self, name : Literal['PSR'], val : Union[Variation_1029, Variation_1029_Arg]) -> 'Variation_1034':
        ...

    @overload
    def set_item(self, name : Literal['SSR'], val : Union[Variation_1031, Variation_1031_Arg]) -> 'Variation_1034':
        ...

    @overload
    def set_item(self, name : Literal['MDS'], val : Union[Variation_1033, Variation_1033_Arg]) -> 'Variation_1034':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['COM']) -> 'Variation_1034':
        ...

    @overload
    def del_item(self, name : Literal['PSR']) -> 'Variation_1034':
        ...

    @overload
    def del_item(self, name : Literal['SSR']) -> 'Variation_1034':
        ...

    @overload
    def del_item(self, name : Literal['MDS']) -> 'Variation_1034':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_1026:
        ...

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_1029:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_1031:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_1033:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1034':
        ...

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_1034':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_1034':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_1034':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1035_Arg : TypeAlias = Raw
class Variation_1035(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 5
    table = {
        0: 'No detection (number of misses)',
        1: 'Single PSR target reports',
        2: 'Single SSR target reports (Non-Mode S)',
        3: 'SSR+PSR target reports (Non-Mode S)',
        4: 'Single All-Call target reports (Mode S)',
        5: 'Single Roll-Call target reports (Mode S)',
        6: 'All-Call + PSR (Mode S) target reports',
        7: 'Roll-Call + PSR (Mode S) target reports',
        8: 'Filter for Weather data',
        9: 'Filter for Jamming Strobe',
        10: 'Filter for PSR data',
        11: 'Filter for SSR/Mode S data',
        12: 'Filter for SSR/Mode S+PSR data',
        13: 'Filter for Enhanced Surveillance data',
        14: 'Filter for PSR+Enhanced Surveillance',
        15: 'Filter for PSR+Enhanced Surveillance + SSR/Mode S data not in Area of Prime Interest',
        16: 'Filter for PSR+Enhanced Surveillance + all SSR/Mode S data',
    }

    def __init__(self, arg : Variation_1035_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1036_Arg_Group = TypedDict('Variation_1036_Arg_Group', {
    'TYP': Union[Variation_1035, Variation_1035_Arg],
    'COUNT': Union[Variation_791, Variation_791_Arg],
})
Variation_1036_Arg : TypeAlias = Union[Raw, Variation_1036_Arg_Group]
class Variation_1036(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('TYP', Variation_1035),
        ('COUNT', Variation_791),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('Type of Message Counter', Variation_1035, 0, 5),
        'COUNT': ('COUNTER', Variation_791, 5, 11),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_1035]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COUNT']) -> Type[Variation_791]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['COUNT']]) -> Union[Type['Variation_1035'], Type['Variation_791']]:
        if key == 'TYP':
            return Variation_1035
        if key == 'COUNT':
            return Variation_791
        assert_never(key)

    def __init__(self, arg : Variation_1036_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_1035:
        ...

    @overload
    def get_item(self, name : Literal['COUNT']) -> Variation_791:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['COUNT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_1035, Variation_1035_Arg]) -> 'Variation_1036':
        ...

    @overload
    def set_item(self, name : Literal['COUNT'], val : Union[Variation_791, Variation_791_Arg]) -> 'Variation_1036':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1036':
        ...

    @overload
    def modify_item(self, name : Literal['COUNT'], f : Any) -> 'Variation_1036':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1037_Arg : TypeAlias = Union[Variation_1036, Variation_1036_Arg]
class Variation_1037(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_1036

    @classmethod
    def spec(cls) -> Type[Variation_1036]:
        return Variation_1036

    def __init__(self, arg : List[Union[Variation_1036, Variation_1036_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1036, Variation_1036_Arg]) -> 'Variation_1037':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1036, Variation_1036_Arg]) -> 'Variation_1037':
        return self._prepend_item(arg) # type: ignore

Variation_1038_Arg_Group = TypedDict('Variation_1038_Arg_Group', {
    'RHOST': Union[Variation_594, Variation_594_Arg],
    'RHOEND': Union[Variation_594, Variation_594_Arg],
    'THETAST': Union[Variation_14, Variation_14_Arg],
    'THETAEND': Union[Variation_14, Variation_14_Arg],
})
Variation_1038_Arg : TypeAlias = Union[Raw, Variation_1038_Arg_Group]
class Variation_1038(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('RHOST', Variation_594),
        ('RHOEND', Variation_594),
        ('THETAST', Variation_14),
        ('THETAEND', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RHOST': ('Rho Start', Variation_594, 0, 16),
        'RHOEND': ('Rho End', Variation_594, 16, 16),
        'THETAST': ('Theta Start', Variation_14, 32, 16),
        'THETAEND': ('Theta End', Variation_14, 48, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RHOST']) -> Type[Variation_594]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RHOEND']) -> Type[Variation_594]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['THETAST']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['THETAEND']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RHOST'], Literal['RHOEND'], Literal['THETAST'], Literal['THETAEND']]) -> Union[Type['Variation_594'], Type['Variation_594'], Type['Variation_14'], Type['Variation_14']]:
        if key == 'RHOST':
            return Variation_594
        if key == 'RHOEND':
            return Variation_594
        if key == 'THETAST':
            return Variation_14
        if key == 'THETAEND':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_1038_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RHOST']) -> Variation_594:
        ...

    @overload
    def get_item(self, name : Literal['RHOEND']) -> Variation_594:
        ...

    @overload
    def get_item(self, name : Literal['THETAST']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['THETAEND']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['RHOST'], Literal['RHOEND'], Literal['THETAST'], Literal['THETAEND']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RHOST'], val : Union[Variation_594, Variation_594_Arg]) -> 'Variation_1038':
        ...

    @overload
    def set_item(self, name : Literal['RHOEND'], val : Union[Variation_594, Variation_594_Arg]) -> 'Variation_1038':
        ...

    @overload
    def set_item(self, name : Literal['THETAST'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1038':
        ...

    @overload
    def set_item(self, name : Literal['THETAEND'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1038':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RHOST'], f : Any) -> 'Variation_1038':
        ...

    @overload
    def modify_item(self, name : Literal['RHOEND'], f : Any) -> 'Variation_1038':
        ...

    @overload
    def modify_item(self, name : Literal['THETAST'], f : Any) -> 'Variation_1038':
        ...

    @overload
    def modify_item(self, name : Literal['THETAEND'], f : Any) -> 'Variation_1038':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1039_Arg : TypeAlias = Raw
class Variation_1039(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'Invalid value',
        1: 'Filter for Weather data',
        2: 'Filter for Jamming Strobe',
        3: 'Filter for PSR data',
        4: 'Filter for SSR/Mode S data',
        5: 'Filter for SSR/Mode S + PSR data',
        6: 'Enhanced Surveillance data',
        7: 'Filter for PSR+Enhanced Surveillance data',
        8: 'Filter for PSR+Enhanced Surveillance + SSR/Mode S data not in Area of Prime Interest',
        9: 'Filter for PSR+Enhanced Surveillance + all SSR/Mode S data',
    }

    def __init__(self, arg : Variation_1039_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1040_Arg_Group = TypedDict('Variation_1040_Arg_Group', {
    'HGT': Union[Variation_259, Variation_259_Arg],
    'LAT': Union[Variation_704, Variation_704_Arg],
    'LON': Union[Variation_704, Variation_704_Arg],
})
Variation_1040_Arg : TypeAlias = Union[Raw, Variation_1040_Arg_Group]
class Variation_1040(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('HGT', Variation_259),
        ('LAT', Variation_704),
        ('LON', Variation_704),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'HGT': ('Height of Data Source', Variation_259, 0, 16),
        'LAT': ('Latitude', Variation_704, 16, 24),
        'LON': ('Longitude', Variation_704, 40, 24),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['HGT']) -> Type[Variation_259]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_704]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_704]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['HGT'], Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_259'], Type['Variation_704'], Type['Variation_704']]:
        if key == 'HGT':
            return Variation_259
        if key == 'LAT':
            return Variation_704
        if key == 'LON':
            return Variation_704
        assert_never(key)

    def __init__(self, arg : Variation_1040_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['HGT']) -> Variation_259:
        ...

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_704:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_704:
        ...

    def get_item(self, name : Union[Literal['HGT'], Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['HGT'], val : Union[Variation_259, Variation_259_Arg]) -> 'Variation_1040':
        ...

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_1040':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_1040':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['HGT'], f : Any) -> 'Variation_1040':
        ...

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_1040':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_1040':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1041_Arg_Group = TypedDict('Variation_1041_Arg_Group', {
    'RNG': Union[Variation_87, Variation_87_Arg],
    'AZM': Union[Variation_88, Variation_88_Arg],
})
Variation_1041_Arg : TypeAlias = Union[Raw, Variation_1041_Arg_Group]
class Variation_1041(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('RNG', Variation_87),
        ('AZM', Variation_88),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RNG': ('Range Error', Variation_87, 0, 8),
        'AZM': ('Azimuth Error', Variation_88, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RNG']) -> Type[Variation_87]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AZM']) -> Type[Variation_88]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RNG'], Literal['AZM']]) -> Union[Type['Variation_87'], Type['Variation_88']]:
        if key == 'RNG':
            return Variation_87
        if key == 'AZM':
            return Variation_88
        assert_never(key)

    def __init__(self, arg : Variation_1041_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RNG']) -> Variation_87:
        ...

    @overload
    def get_item(self, name : Literal['AZM']) -> Variation_88:
        ...

    def get_item(self, name : Union[Literal['RNG'], Literal['AZM']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RNG'], val : Union[Variation_87, Variation_87_Arg]) -> 'Variation_1041':
        ...

    @overload
    def set_item(self, name : Literal['AZM'], val : Union[Variation_88, Variation_88_Arg]) -> 'Variation_1041':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RNG'], f : Any) -> 'Variation_1041':
        ...

    @overload
    def modify_item(self, name : Literal['AZM'], f : Any) -> 'Variation_1041':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1042_Arg = TypedDict('Variation_1042_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_1001, Variation_1001_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '020': Union[Variation_79, Variation_79_Arg],
    '041': Union[Variation_25, Variation_25_Arg],
    '050': Union[Variation_1023, Variation_1023_Arg],
    '060': Union[Variation_1034, Variation_1034_Arg],
    '070': Union[Variation_1037, Variation_1037_Arg],
    '100': Union[Variation_1038, Variation_1038_Arg],
    '110': Union[Variation_1039, Variation_1039_Arg],
    '120': Union[Variation_1040, Variation_1040_Arg],
    '090': Union[Variation_1041, Variation_1041_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1042(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_1001),
        ('030', Variation_80),
        ('020', Variation_79),
        ('041', Variation_25),
        ('050', Variation_1023),
        ('060', Variation_1034),
        ('070', Variation_1037),
        ('100', Variation_1038),
        ('110', Variation_1039),
        ('120', Variation_1040),
        ('090', Variation_1041),
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Message Type', Variation_1001, 0x4000),
        '030': ('Time of Day', Variation_80, 0x2000),
        '020': ('Sector Number', Variation_79, 0x1000),
        '041': ('Antenna Rotation Speed', Variation_25, 0x0800),
        '050': ('System Configuration and Status', Variation_1023, 0x0400),
        '060': ('System Processing Mode', Variation_1034, 0x0200),
        '070': ('Message Count Values', Variation_1037, 0x0180),
        '100': ('Generic Polar Window', Variation_1038, 0x0140),
        '110': ('Data Filter', Variation_1039, 0x0120),
        '120': ('3D-Position Of Data Source', Variation_1040, 0x0110),
        '090': ('Collimation Error', Variation_1041, 0x0108),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0104),
        'SP': ('Special Purpose Field', Variation_62, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_1001]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_79]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_25]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_1023]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_1034]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_1037]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_1038]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1039]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1040]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_1041]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['030'], Literal['020'], Literal['041'], Literal['050'], Literal['060'], Literal['070'], Literal['100'], Literal['110'], Literal['120'], Literal['090'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_1001'], Type['Variation_80'], Type['Variation_79'], Type['Variation_25'], Type['Variation_1023'], Type['Variation_1034'], Type['Variation_1037'], Type['Variation_1038'], Type['Variation_1039'], Type['Variation_1040'], Type['Variation_1041'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_1001
        if key == '030':
            return Variation_80
        if key == '020':
            return Variation_79
        if key == '041':
            return Variation_25
        if key == '050':
            return Variation_1023
        if key == '060':
            return Variation_1034
        if key == '070':
            return Variation_1037
        if key == '100':
            return Variation_1038
        if key == '110':
            return Variation_1039
        if key == '120':
            return Variation_1040
        if key == '090':
            return Variation_1041
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1042_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_1001, Variation_1001_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_79, Variation_79_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_25, Variation_25_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_1023, Variation_1023_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_1034, Variation_1034_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_1037, Variation_1037_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_1038, Variation_1038_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1039, Variation_1039_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1040, Variation_1040_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_1041, Variation_1041_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1042':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1042':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1042':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1042':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_1001:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_79:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_25:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_1023:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_1034:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_1037:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_1038:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1039:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1040:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_1041:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1042':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1042':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1043_Arg : TypeAlias = Raw
class Variation_1043(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'North marker message',
        2: 'Sector crossing message',
        3: 'Geographical filtering message',
        4: 'Jamming strobe message',
        5: 'Solar Storm Message',
    }

    def __init__(self, arg : Variation_1043_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1044_Arg : TypeAlias = Raw
class Variation_1044(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 5
    table = {
        0: 'No detection (number of misses)',
        1: 'Single PSR target reports',
        2: 'Single SSR target reports (Non-Mode S)',
        3: 'SSR+PSR target reports (Non-Mode S)',
        4: 'Single All-Call target reports (Mode S)',
        5: 'Single Roll-Call target reports (Mode S)',
        6: 'All-Call + PSR (Mode S) target reports',
        7: 'Roll-Call + PSR (Mode S) target reports',
        8: 'Filter for Weather data',
        9: 'Filter for Jamming Strobe',
        10: 'Filter for PSR data',
        11: 'Filter for SSR/Mode S data',
        12: 'Filter for SSR/Mode S+PSR data',
        13: 'Filter for Enhanced Surveillance data',
        14: 'Filter for PSR+Enhanced Surveillance',
        15: 'Filter for PSR+Enhanced Surveillance + SSR/Mode S data not in Area of Prime Interest',
        16: 'Filter for PSR+Enhanced Surveillance + all SSR/Mode S data',
        17: 'Re-Interrogations (per sector)',
        18: 'BDS Swap and wrong DF replies(per sector)',
        19: 'Mode A/C FRUIT (per sector)',
        20: 'Mode S FRUIT (per sector)',
    }

    def __init__(self, arg : Variation_1044_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1045_Arg_Group = TypedDict('Variation_1045_Arg_Group', {
    'TYP': Union[Variation_1044, Variation_1044_Arg],
    'COUNT': Union[Variation_791, Variation_791_Arg],
})
Variation_1045_Arg : TypeAlias = Union[Raw, Variation_1045_Arg_Group]
class Variation_1045(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('TYP', Variation_1044),
        ('COUNT', Variation_791),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('Type of Message Counter', Variation_1044, 0, 5),
        'COUNT': ('COUNTER', Variation_791, 5, 11),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_1044]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COUNT']) -> Type[Variation_791]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['COUNT']]) -> Union[Type['Variation_1044'], Type['Variation_791']]:
        if key == 'TYP':
            return Variation_1044
        if key == 'COUNT':
            return Variation_791
        assert_never(key)

    def __init__(self, arg : Variation_1045_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_1044:
        ...

    @overload
    def get_item(self, name : Literal['COUNT']) -> Variation_791:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['COUNT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_1044, Variation_1044_Arg]) -> 'Variation_1045':
        ...

    @overload
    def set_item(self, name : Literal['COUNT'], val : Union[Variation_791, Variation_791_Arg]) -> 'Variation_1045':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1045':
        ...

    @overload
    def modify_item(self, name : Literal['COUNT'], f : Any) -> 'Variation_1045':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1046_Arg : TypeAlias = Union[Variation_1045, Variation_1045_Arg]
class Variation_1046(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_1045

    @classmethod
    def spec(cls) -> Type[Variation_1045]:
        return Variation_1045

    def __init__(self, arg : List[Union[Variation_1045, Variation_1045_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1045, Variation_1045_Arg]) -> 'Variation_1046':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1045, Variation_1045_Arg]) -> 'Variation_1046':
        return self._prepend_item(arg) # type: ignore

Variation_1047_Arg = TypedDict('Variation_1047_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_1043, Variation_1043_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '020': Union[Variation_79, Variation_79_Arg],
    '041': Union[Variation_25, Variation_25_Arg],
    '050': Union[Variation_1023, Variation_1023_Arg],
    '060': Union[Variation_1034, Variation_1034_Arg],
    '070': Union[Variation_1046, Variation_1046_Arg],
    '100': Union[Variation_1038, Variation_1038_Arg],
    '110': Union[Variation_1039, Variation_1039_Arg],
    '120': Union[Variation_1040, Variation_1040_Arg],
    '090': Union[Variation_1041, Variation_1041_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1047(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_1043),
        ('030', Variation_80),
        ('020', Variation_79),
        ('041', Variation_25),
        ('050', Variation_1023),
        ('060', Variation_1034),
        ('070', Variation_1046),
        ('100', Variation_1038),
        ('110', Variation_1039),
        ('120', Variation_1040),
        ('090', Variation_1041),
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Message Type', Variation_1043, 0x4000),
        '030': ('Time of Day', Variation_80, 0x2000),
        '020': ('Sector Number', Variation_79, 0x1000),
        '041': ('Antenna Rotation Speed', Variation_25, 0x0800),
        '050': ('System Configuration and Status', Variation_1023, 0x0400),
        '060': ('System Processing Mode', Variation_1034, 0x0200),
        '070': ('Message Count Values', Variation_1046, 0x0180),
        '100': ('Generic Polar Window', Variation_1038, 0x0140),
        '110': ('Data Filter', Variation_1039, 0x0120),
        '120': ('3D-Position Of Data Source', Variation_1040, 0x0110),
        '090': ('Collimation Error', Variation_1041, 0x0108),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0104),
        'SP': ('Special Purpose Field', Variation_62, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_1043]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_79]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_25]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_1023]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_1034]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_1046]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_1038]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1039]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1040]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_1041]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['030'], Literal['020'], Literal['041'], Literal['050'], Literal['060'], Literal['070'], Literal['100'], Literal['110'], Literal['120'], Literal['090'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_1043'], Type['Variation_80'], Type['Variation_79'], Type['Variation_25'], Type['Variation_1023'], Type['Variation_1034'], Type['Variation_1046'], Type['Variation_1038'], Type['Variation_1039'], Type['Variation_1040'], Type['Variation_1041'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_1043
        if key == '030':
            return Variation_80
        if key == '020':
            return Variation_79
        if key == '041':
            return Variation_25
        if key == '050':
            return Variation_1023
        if key == '060':
            return Variation_1034
        if key == '070':
            return Variation_1046
        if key == '100':
            return Variation_1038
        if key == '110':
            return Variation_1039
        if key == '120':
            return Variation_1040
        if key == '090':
            return Variation_1041
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1047_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_1043, Variation_1043_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_79, Variation_79_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_25, Variation_25_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_1023, Variation_1023_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_1034, Variation_1034_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_1046, Variation_1046_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_1038, Variation_1038_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1039, Variation_1039_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1040, Variation_1040_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_1041, Variation_1041_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1047':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1047':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1047':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1047':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_1043:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_79:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_25:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_1023:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_1034:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_1046:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_1038:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1039:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1040:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_1041:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1047':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1047':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1048_Arg : TypeAlias = Raw
class Variation_1048(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'North marker message',
        2: 'Sector crossing message',
        3: 'Geographical filtering message',
        4: 'Jamming strobe message',
        5: 'Solar Storm Message',
        6: 'SSR Jamming Strobe Message',
        7: 'Mode S Jamming Strobe Message',
    }

    def __init__(self, arg : Variation_1048_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1049_Arg = TypedDict('Variation_1049_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_1048, Variation_1048_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '020': Union[Variation_79, Variation_79_Arg],
    '041': Union[Variation_25, Variation_25_Arg],
    '050': Union[Variation_1023, Variation_1023_Arg],
    '060': Union[Variation_1034, Variation_1034_Arg],
    '070': Union[Variation_1046, Variation_1046_Arg],
    '100': Union[Variation_1038, Variation_1038_Arg],
    '110': Union[Variation_1039, Variation_1039_Arg],
    '120': Union[Variation_1040, Variation_1040_Arg],
    '090': Union[Variation_1041, Variation_1041_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1049(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_1048),
        ('030', Variation_80),
        ('020', Variation_79),
        ('041', Variation_25),
        ('050', Variation_1023),
        ('060', Variation_1034),
        ('070', Variation_1046),
        ('100', Variation_1038),
        ('110', Variation_1039),
        ('120', Variation_1040),
        ('090', Variation_1041),
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Message Type', Variation_1048, 0x4000),
        '030': ('Time of Day', Variation_80, 0x2000),
        '020': ('Sector Number', Variation_79, 0x1000),
        '041': ('Antenna Rotation Speed', Variation_25, 0x0800),
        '050': ('System Configuration and Status', Variation_1023, 0x0400),
        '060': ('System Processing Mode', Variation_1034, 0x0200),
        '070': ('Message Count Values', Variation_1046, 0x0180),
        '100': ('Generic Polar Window', Variation_1038, 0x0140),
        '110': ('Data Filter', Variation_1039, 0x0120),
        '120': ('3D-Position Of Data Source', Variation_1040, 0x0110),
        '090': ('Collimation Error', Variation_1041, 0x0108),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0104),
        'SP': ('Special Purpose Field', Variation_62, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_1048]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_79]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_25]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_1023]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_1034]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_1046]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_1038]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1039]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1040]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_1041]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['030'], Literal['020'], Literal['041'], Literal['050'], Literal['060'], Literal['070'], Literal['100'], Literal['110'], Literal['120'], Literal['090'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_1048'], Type['Variation_80'], Type['Variation_79'], Type['Variation_25'], Type['Variation_1023'], Type['Variation_1034'], Type['Variation_1046'], Type['Variation_1038'], Type['Variation_1039'], Type['Variation_1040'], Type['Variation_1041'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_1048
        if key == '030':
            return Variation_80
        if key == '020':
            return Variation_79
        if key == '041':
            return Variation_25
        if key == '050':
            return Variation_1023
        if key == '060':
            return Variation_1034
        if key == '070':
            return Variation_1046
        if key == '100':
            return Variation_1038
        if key == '110':
            return Variation_1039
        if key == '120':
            return Variation_1040
        if key == '090':
            return Variation_1041
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1049_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_1048, Variation_1048_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_79, Variation_79_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_25, Variation_25_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_1023, Variation_1023_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_1034, Variation_1034_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_1046, Variation_1046_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_1038, Variation_1038_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1039, Variation_1039_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1040, Variation_1040_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_1041, Variation_1041_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1049':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1049':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1049':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1049':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_1048:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_79:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_25:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_1023:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_1034:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_1046:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_1038:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1039:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1040:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_1041:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1049':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1049':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1050_Arg : TypeAlias = Raw
class Variation_1050(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'No authenticated Mode 5 Data reply/report',
        1: 'Authenticated Mode 5 Data reply/report (i.e any valid Mode 5 reply type other than ID)',
    }

    def __init__(self, arg : Variation_1050_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1051_Arg : TypeAlias = Raw
class Variation_1051(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Mode C altitude not present or not from Mode 5 reply/report',
        1: 'Mode C altitude from Mode 5 reply/report',
    }

    def __init__(self, arg : Variation_1051_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1052_Arg_Group = TypedDict('Variation_1052_Arg_Group', {
    'M5': Union[Variation_781, Variation_781_Arg],
    'ID': Union[Variation_782, Variation_782_Arg],
    'DA': Union[Variation_1050, Variation_1050_Arg],
    'M1': Union[Variation_784, Variation_784_Arg],
    'M2': Union[Variation_785, Variation_785_Arg],
    'M3': Union[Variation_786, Variation_786_Arg],
    'MC': Union[Variation_1051, Variation_1051_Arg],
})
Variation_1052_Arg : TypeAlias = Union[Raw, Variation_1052_Arg_Group]
class Variation_1052(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('M5', Variation_781),
        ('ID', Variation_782),
        ('DA', Variation_1050),
        ('M1', Variation_784),
        ('M2', Variation_785),
        ('M3', Variation_786),
        ('MC', Variation_1051),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'M5': ('', Variation_781, 0, 1),
        'ID': ('', Variation_782, 1, 1),
        'DA': ('', Variation_1050, 2, 1),
        'M1': ('', Variation_784, 3, 1),
        'M2': ('', Variation_785, 4, 1),
        'M3': ('', Variation_786, 5, 1),
        'MC': ('', Variation_1051, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['M5']) -> Type[Variation_781]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ID']) -> Type[Variation_782]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DA']) -> Type[Variation_1050]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M1']) -> Type[Variation_784]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M2']) -> Type[Variation_785]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M3']) -> Type[Variation_786]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MC']) -> Type[Variation_1051]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['M5'], Literal['ID'], Literal['DA'], Literal['M1'], Literal['M2'], Literal['M3'], Literal['MC']]) -> Union[Type['Variation_781'], Type['Variation_782'], Type['Variation_1050'], Type['Variation_784'], Type['Variation_785'], Type['Variation_786'], Type['Variation_1051']]:
        if key == 'M5':
            return Variation_781
        if key == 'ID':
            return Variation_782
        if key == 'DA':
            return Variation_1050
        if key == 'M1':
            return Variation_784
        if key == 'M2':
            return Variation_785
        if key == 'M3':
            return Variation_786
        if key == 'MC':
            return Variation_1051
        assert_never(key)

    def __init__(self, arg : Variation_1052_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['M5']) -> Variation_781:
        ...

    @overload
    def get_item(self, name : Literal['ID']) -> Variation_782:
        ...

    @overload
    def get_item(self, name : Literal['DA']) -> Variation_1050:
        ...

    @overload
    def get_item(self, name : Literal['M1']) -> Variation_784:
        ...

    @overload
    def get_item(self, name : Literal['M2']) -> Variation_785:
        ...

    @overload
    def get_item(self, name : Literal['M3']) -> Variation_786:
        ...

    @overload
    def get_item(self, name : Literal['MC']) -> Variation_1051:
        ...

    def get_item(self, name : Union[Literal['M5'], Literal['ID'], Literal['DA'], Literal['M1'], Literal['M2'], Literal['M3'], Literal['MC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['M5'], val : Union[Variation_781, Variation_781_Arg]) -> 'Variation_1052':
        ...

    @overload
    def set_item(self, name : Literal['ID'], val : Union[Variation_782, Variation_782_Arg]) -> 'Variation_1052':
        ...

    @overload
    def set_item(self, name : Literal['DA'], val : Union[Variation_1050, Variation_1050_Arg]) -> 'Variation_1052':
        ...

    @overload
    def set_item(self, name : Literal['M1'], val : Union[Variation_784, Variation_784_Arg]) -> 'Variation_1052':
        ...

    @overload
    def set_item(self, name : Literal['M2'], val : Union[Variation_785, Variation_785_Arg]) -> 'Variation_1052':
        ...

    @overload
    def set_item(self, name : Literal['M3'], val : Union[Variation_786, Variation_786_Arg]) -> 'Variation_1052':
        ...

    @overload
    def set_item(self, name : Literal['MC'], val : Union[Variation_1051, Variation_1051_Arg]) -> 'Variation_1052':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['M5'], f : Any) -> 'Variation_1052':
        ...

    @overload
    def modify_item(self, name : Literal['ID'], f : Any) -> 'Variation_1052':
        ...

    @overload
    def modify_item(self, name : Literal['DA'], f : Any) -> 'Variation_1052':
        ...

    @overload
    def modify_item(self, name : Literal['M1'], f : Any) -> 'Variation_1052':
        ...

    @overload
    def modify_item(self, name : Literal['M2'], f : Any) -> 'Variation_1052':
        ...

    @overload
    def modify_item(self, name : Literal['M3'], f : Any) -> 'Variation_1052':
        ...

    @overload
    def modify_item(self, name : Literal['MC'], f : Any) -> 'Variation_1052':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1053_Arg : TypeAlias = Raw
class Variation_1053(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'National Origin is valid',
        1: 'National Origin is invalid',
    }

    def __init__(self, arg : Variation_1053_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1054_Arg_Group = TypedDict('Variation_1054_Arg_Group', {
    'PIN': Union[Variation_790, Variation_790_Arg],
    'NAV': Union[Variation_1053, Variation_1053_Arg],
    'NAT': Union[Variation_375, Variation_375_Arg],
    'MIS': Union[Variation_376, Variation_376_Arg],
})
Variation_1054_Arg : TypeAlias = Union[Raw, Variation_1054_Arg_Group]
class Variation_1054(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        Spare(0, 2),
        ('PIN', Variation_790),
        Spare(0, 2),
        ('NAV', Variation_1053),
        ('NAT', Variation_375),
        Spare(0, 2),
        ('MIS', Variation_376),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PIN': ('PIN Code', Variation_790, 2, 14),
        'NAV': ('Validity of NAT', Variation_1053, 18, 1),
        'NAT': ('National Origin', Variation_375, 19, 5),
        'MIS': ('Mission Code', Variation_376, 26, 6),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PIN']) -> Type[Variation_790]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NAV']) -> Type[Variation_1053]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NAT']) -> Type[Variation_375]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MIS']) -> Type[Variation_376]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PIN'], Literal['NAV'], Literal['NAT'], Literal['MIS']]) -> Union[Type['Variation_790'], Type['Variation_1053'], Type['Variation_375'], Type['Variation_376']]:
        if key == 'PIN':
            return Variation_790
        if key == 'NAV':
            return Variation_1053
        if key == 'NAT':
            return Variation_375
        if key == 'MIS':
            return Variation_376
        assert_never(key)

    def __init__(self, arg : Variation_1054_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PIN']) -> Variation_790:
        ...

    @overload
    def get_item(self, name : Literal['NAV']) -> Variation_1053:
        ...

    @overload
    def get_item(self, name : Literal['NAT']) -> Variation_375:
        ...

    @overload
    def get_item(self, name : Literal['MIS']) -> Variation_376:
        ...

    def get_item(self, name : Union[Literal['PIN'], Literal['NAV'], Literal['NAT'], Literal['MIS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PIN'], val : Union[Variation_790, Variation_790_Arg]) -> 'Variation_1054':
        ...

    @overload
    def set_item(self, name : Literal['NAV'], val : Union[Variation_1053, Variation_1053_Arg]) -> 'Variation_1054':
        ...

    @overload
    def set_item(self, name : Literal['NAT'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_1054':
        ...

    @overload
    def set_item(self, name : Literal['MIS'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_1054':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PIN'], f : Any) -> 'Variation_1054':
        ...

    @overload
    def modify_item(self, name : Literal['NAV'], f : Any) -> 'Variation_1054':
        ...

    @overload
    def modify_item(self, name : Literal['NAT'], f : Any) -> 'Variation_1054':
        ...

    @overload
    def modify_item(self, name : Literal['MIS'], f : Any) -> 'Variation_1054':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1055_Arg_Group = TypedDict('Variation_1055_Arg_Group', {
    'LAT': Union[Variation_704, Variation_704_Arg],
    'LON': Union[Variation_704, Variation_704_Arg],
})
Variation_1055_Arg : TypeAlias = Union[Raw, Variation_1055_Arg_Group]
class Variation_1055(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('LAT', Variation_704),
        ('LON', Variation_704),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude in WGS 84', Variation_704, 0, 24),
        'LON': ('Longitude in WGS 84', Variation_704, 24, 24),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_704]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_704]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_704'], Type['Variation_704']]:
        if key == 'LAT':
            return Variation_704
        if key == 'LON':
            return Variation_704
        assert_never(key)

    def __init__(self, arg : Variation_1055_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_704:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_704:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_1055':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_1055':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_1055':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_1055':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1056_Arg : TypeAlias = Raw
class Variation_1056(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'GA reported in 100 ft increments',
        1: 'GA reported in 25 ft increments',
    }

    def __init__(self, arg : Variation_1056_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1057_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft']]]
class Variation_1057(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 14
    quantity = Quantity('Signed', 25.0, 'ft')

    def __init__(self, arg : Variation_1057_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1058_Arg_Group = TypedDict('Variation_1058_Arg_Group', {
    'RES': Union[Variation_1056, Variation_1056_Arg],
    'GA': Union[Variation_1057, Variation_1057_Arg],
})
Variation_1058_Arg : TypeAlias = Union[Raw, Variation_1058_Arg_Group]
class Variation_1058(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 1),
        ('RES', Variation_1056),
        ('GA', Variation_1057),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RES': ('', Variation_1056, 1, 1),
        'GA': ('', Variation_1057, 2, 14),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RES']) -> Type[Variation_1056]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GA']) -> Type[Variation_1057]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RES'], Literal['GA']]) -> Union[Type['Variation_1056'], Type['Variation_1057']]:
        if key == 'RES':
            return Variation_1056
        if key == 'GA':
            return Variation_1057
        assert_never(key)

    def __init__(self, arg : Variation_1058_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RES']) -> Variation_1056:
        ...

    @overload
    def get_item(self, name : Literal['GA']) -> Variation_1057:
        ...

    def get_item(self, name : Union[Literal['RES'], Literal['GA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RES'], val : Union[Variation_1056, Variation_1056_Arg]) -> 'Variation_1058':
        ...

    @overload
    def set_item(self, name : Literal['GA'], val : Union[Variation_1057, Variation_1057_Arg]) -> 'Variation_1058':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RES'], f : Any) -> 'Variation_1058':
        ...

    @overload
    def modify_item(self, name : Literal['GA'], f : Any) -> 'Variation_1058':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1059_Arg : TypeAlias = Raw
class Variation_1059(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Code not validated',
        1: 'Code validated',
    }

    def __init__(self, arg : Variation_1059_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1060_Arg : TypeAlias = Raw
class Variation_1060(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode 1 Code derived from the reply of the transponder',
        1: 'Mode 1 Code not extracted during the last scan',
    }

    def __init__(self, arg : Variation_1060_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1061_Arg_Group = TypedDict('Variation_1061_Arg_Group', {
    'V': Union[Variation_1059, Variation_1059_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_1060, Variation_1060_Arg],
    'EM1': Union[Variation_19, Variation_19_Arg],
})
Variation_1061_Arg : TypeAlias = Union[Raw, Variation_1061_Arg_Group]
class Variation_1061(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_1059),
        ('G', Variation_17),
        ('L', Variation_1060),
        Spare(3, 1),
        ('EM1', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_1059, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'L': ('', Variation_1060, 2, 1),
        'EM1': ('Extended Mode 1 Code in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_1059]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_1060]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EM1']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['EM1']]) -> Union[Type['Variation_1059'], Type['Variation_17'], Type['Variation_1060'], Type['Variation_19']]:
        if key == 'V':
            return Variation_1059
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_1060
        if key == 'EM1':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_1061_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_1059:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_1060:
        ...

    @overload
    def get_item(self, name : Literal['EM1']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['EM1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_1059, Variation_1059_Arg]) -> 'Variation_1061':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_1061':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_1060, Variation_1060_Arg]) -> 'Variation_1061':
        ...

    @overload
    def set_item(self, name : Literal['EM1'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_1061':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_1061':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_1061':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_1061':
        ...

    @overload
    def modify_item(self, name : Literal['EM1'], f : Any) -> 'Variation_1061':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1062_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_1062(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 7.8125e-3, 's')

    def __init__(self, arg : Variation_1062_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1063_Arg : TypeAlias = Raw
class Variation_1063(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'X-pulse set to zero or no Mode 2 reply',
        1: 'X-pulse set to one (present)',
    }

    def __init__(self, arg : Variation_1063_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1064_Arg_Group = TypedDict('Variation_1064_Arg_Group', {
    'XP': Union[Variation_795, Variation_795_Arg],
    'X5': Union[Variation_796, Variation_796_Arg],
    'XC': Union[Variation_797, Variation_797_Arg],
    'X3': Union[Variation_798, Variation_798_Arg],
    'X2': Union[Variation_1063, Variation_1063_Arg],
    'X1': Union[Variation_800, Variation_800_Arg],
})
Variation_1064_Arg : TypeAlias = Union[Raw, Variation_1064_Arg_Group]
class Variation_1064(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 2),
        ('XP', Variation_795),
        ('X5', Variation_796),
        ('XC', Variation_797),
        ('X3', Variation_798),
        ('X2', Variation_1063),
        ('X1', Variation_800),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'XP': ('X-pulse from Mode 5 PIN Reply/Report', Variation_795, 2, 1),
        'X5': ('X-pulse from Mode 5 Data Reply or Report', Variation_796, 3, 1),
        'XC': ('X-pulse from Mode C Reply', Variation_797, 4, 1),
        'X3': ('X-pulse from Mode 3/A Reply', Variation_798, 5, 1),
        'X2': ('X-pulse from Mode 2 Reply', Variation_1063, 6, 1),
        'X1': ('X-pulse from Mode 1 Reply', Variation_800, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['XP']) -> Type[Variation_795]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X5']) -> Type[Variation_796]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XC']) -> Type[Variation_797]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X3']) -> Type[Variation_798]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X2']) -> Type[Variation_1063]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X1']) -> Type[Variation_800]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['XP'], Literal['X5'], Literal['XC'], Literal['X3'], Literal['X2'], Literal['X1']]) -> Union[Type['Variation_795'], Type['Variation_796'], Type['Variation_797'], Type['Variation_798'], Type['Variation_1063'], Type['Variation_800']]:
        if key == 'XP':
            return Variation_795
        if key == 'X5':
            return Variation_796
        if key == 'XC':
            return Variation_797
        if key == 'X3':
            return Variation_798
        if key == 'X2':
            return Variation_1063
        if key == 'X1':
            return Variation_800
        assert_never(key)

    def __init__(self, arg : Variation_1064_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['XP']) -> Variation_795:
        ...

    @overload
    def get_item(self, name : Literal['X5']) -> Variation_796:
        ...

    @overload
    def get_item(self, name : Literal['XC']) -> Variation_797:
        ...

    @overload
    def get_item(self, name : Literal['X3']) -> Variation_798:
        ...

    @overload
    def get_item(self, name : Literal['X2']) -> Variation_1063:
        ...

    @overload
    def get_item(self, name : Literal['X1']) -> Variation_800:
        ...

    def get_item(self, name : Union[Literal['XP'], Literal['X5'], Literal['XC'], Literal['X3'], Literal['X2'], Literal['X1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['XP'], val : Union[Variation_795, Variation_795_Arg]) -> 'Variation_1064':
        ...

    @overload
    def set_item(self, name : Literal['X5'], val : Union[Variation_796, Variation_796_Arg]) -> 'Variation_1064':
        ...

    @overload
    def set_item(self, name : Literal['XC'], val : Union[Variation_797, Variation_797_Arg]) -> 'Variation_1064':
        ...

    @overload
    def set_item(self, name : Literal['X3'], val : Union[Variation_798, Variation_798_Arg]) -> 'Variation_1064':
        ...

    @overload
    def set_item(self, name : Literal['X2'], val : Union[Variation_1063, Variation_1063_Arg]) -> 'Variation_1064':
        ...

    @overload
    def set_item(self, name : Literal['X1'], val : Union[Variation_800, Variation_800_Arg]) -> 'Variation_1064':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['XP'], f : Any) -> 'Variation_1064':
        ...

    @overload
    def modify_item(self, name : Literal['X5'], f : Any) -> 'Variation_1064':
        ...

    @overload
    def modify_item(self, name : Literal['XC'], f : Any) -> 'Variation_1064':
        ...

    @overload
    def modify_item(self, name : Literal['X3'], f : Any) -> 'Variation_1064':
        ...

    @overload
    def modify_item(self, name : Literal['X2'], f : Any) -> 'Variation_1064':
        ...

    @overload
    def modify_item(self, name : Literal['X1'], f : Any) -> 'Variation_1064':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1065_Arg = TypedDict('Variation_1065_Arg', {
    'SUM': Union[Variation_1052, Variation_1052_Arg],
    'PMN': Union[Variation_1054, Variation_1054_Arg],
    'POS': Union[Variation_1055, Variation_1055_Arg],
    'GA': Union[Variation_1058, Variation_1058_Arg],
    'EM1': Union[Variation_1061, Variation_1061_Arg],
    'TOS': Union[Variation_1062, Variation_1062_Arg],
    'XP': Union[Variation_1064, Variation_1064_Arg],
}, total=False)
class Variation_1065(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('SUM', Variation_1052),
        ('PMN', Variation_1054),
        ('POS', Variation_1055),
        ('GA', Variation_1058),
        ('EM1', Variation_1061),
        ('TOS', Variation_1062),
        ('XP', Variation_1064),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'SUM': ('Mode 5 Summary', Variation_1052, 0x80),
        'PMN': ('PIN/ National Origin/Mission Code', Variation_1054, 0x40),
        'POS': ('Mode 5 Reported Position', Variation_1055, 0x20),
        'GA': ('Mode 5 GNSS-derived Altitude', Variation_1058, 0x10),
        'EM1': ('Extended Mode 1 Code in Octal Representation', Variation_1061, 0x08),
        'TOS': ('Time Offset for POS and GA', Variation_1062, 0x04),
        'XP': ('X Pulse Presence', Variation_1064, 0x02),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SUM']) -> Type[Variation_1052]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PMN']) -> Type[Variation_1054]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_1055]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GA']) -> Type[Variation_1058]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EM1']) -> Type[Variation_1061]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOS']) -> Type[Variation_1062]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XP']) -> Type[Variation_1064]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SUM'], Literal['PMN'], Literal['POS'], Literal['GA'], Literal['EM1'], Literal['TOS'], Literal['XP']]) -> Union[Type['Variation_1052'], Type['Variation_1054'], Type['Variation_1055'], Type['Variation_1058'], Type['Variation_1061'], Type['Variation_1062'], Type['Variation_1064']]:
        if key == 'SUM':
            return Variation_1052
        if key == 'PMN':
            return Variation_1054
        if key == 'POS':
            return Variation_1055
        if key == 'GA':
            return Variation_1058
        if key == 'EM1':
            return Variation_1061
        if key == 'TOS':
            return Variation_1062
        if key == 'XP':
            return Variation_1064
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1065_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['SUM'], val : Union[Variation_1052, Variation_1052_Arg]) -> 'Variation_1065':
        ...

    @overload
    def set_item(self, name : Literal['PMN'], val : Union[Variation_1054, Variation_1054_Arg]) -> 'Variation_1065':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_1055, Variation_1055_Arg]) -> 'Variation_1065':
        ...

    @overload
    def set_item(self, name : Literal['GA'], val : Union[Variation_1058, Variation_1058_Arg]) -> 'Variation_1065':
        ...

    @overload
    def set_item(self, name : Literal['EM1'], val : Union[Variation_1061, Variation_1061_Arg]) -> 'Variation_1065':
        ...

    @overload
    def set_item(self, name : Literal['TOS'], val : Union[Variation_1062, Variation_1062_Arg]) -> 'Variation_1065':
        ...

    @overload
    def set_item(self, name : Literal['XP'], val : Union[Variation_1064, Variation_1064_Arg]) -> 'Variation_1065':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['SUM']) -> 'Variation_1065':
        ...

    @overload
    def del_item(self, name : Literal['PMN']) -> 'Variation_1065':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1065':
        ...

    @overload
    def del_item(self, name : Literal['GA']) -> 'Variation_1065':
        ...

    @overload
    def del_item(self, name : Literal['EM1']) -> 'Variation_1065':
        ...

    @overload
    def del_item(self, name : Literal['TOS']) -> 'Variation_1065':
        ...

    @overload
    def del_item(self, name : Literal['XP']) -> 'Variation_1065':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['SUM']) -> Variation_1052:
        ...

    @overload
    def get_item(self, name : Literal['PMN']) -> Variation_1054:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_1055:
        ...

    @overload
    def get_item(self, name : Literal['GA']) -> Variation_1058:
        ...

    @overload
    def get_item(self, name : Literal['EM1']) -> Variation_1061:
        ...

    @overload
    def get_item(self, name : Literal['TOS']) -> Variation_1062:
        ...

    @overload
    def get_item(self, name : Literal['XP']) -> Variation_1064:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['SUM'], f : Any) -> 'Variation_1065':
        ...

    @overload
    def modify_item(self, name : Literal['PMN'], f : Any) -> 'Variation_1065':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1065':
        ...

    @overload
    def modify_item(self, name : Literal['GA'], f : Any) -> 'Variation_1065':
        ...

    @overload
    def modify_item(self, name : Literal['EM1'], f : Any) -> 'Variation_1065':
        ...

    @overload
    def modify_item(self, name : Literal['TOS'], f : Any) -> 'Variation_1065':
        ...

    @overload
    def modify_item(self, name : Literal['XP'], f : Any) -> 'Variation_1065':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1066_Arg : TypeAlias = Raw
class Variation_1066(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'National Origin is valid',
        1: 'National Origin is invalid',
    }

    def __init__(self, arg : Variation_1066_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1067_Arg_Group = TypedDict('Variation_1067_Arg_Group', {
    'PIN': Union[Variation_790, Variation_790_Arg],
    'NOV': Union[Variation_1066, Variation_1066_Arg],
    'NO': Union[Variation_791, Variation_791_Arg],
})
Variation_1067_Arg : TypeAlias = Union[Raw, Variation_1067_Arg_Group]
class Variation_1067(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        Spare(0, 2),
        ('PIN', Variation_790),
        Spare(0, 4),
        ('NOV', Variation_1066),
        ('NO', Variation_791),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PIN': ('PIN Code', Variation_790, 2, 14),
        'NOV': ('Validity of NO', Variation_1066, 20, 1),
        'NO': ('National Origin', Variation_791, 21, 11),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PIN']) -> Type[Variation_790]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOV']) -> Type[Variation_1066]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NO']) -> Type[Variation_791]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PIN'], Literal['NOV'], Literal['NO']]) -> Union[Type['Variation_790'], Type['Variation_1066'], Type['Variation_791']]:
        if key == 'PIN':
            return Variation_790
        if key == 'NOV':
            return Variation_1066
        if key == 'NO':
            return Variation_791
        assert_never(key)

    def __init__(self, arg : Variation_1067_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PIN']) -> Variation_790:
        ...

    @overload
    def get_item(self, name : Literal['NOV']) -> Variation_1066:
        ...

    @overload
    def get_item(self, name : Literal['NO']) -> Variation_791:
        ...

    def get_item(self, name : Union[Literal['PIN'], Literal['NOV'], Literal['NO']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PIN'], val : Union[Variation_790, Variation_790_Arg]) -> 'Variation_1067':
        ...

    @overload
    def set_item(self, name : Literal['NOV'], val : Union[Variation_1066, Variation_1066_Arg]) -> 'Variation_1067':
        ...

    @overload
    def set_item(self, name : Literal['NO'], val : Union[Variation_791, Variation_791_Arg]) -> 'Variation_1067':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PIN'], f : Any) -> 'Variation_1067':
        ...

    @overload
    def modify_item(self, name : Literal['NOV'], f : Any) -> 'Variation_1067':
        ...

    @overload
    def modify_item(self, name : Literal['NO'], f : Any) -> 'Variation_1067':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1068_Arg_Group = TypedDict('Variation_1068_Arg_Group', {
    'FOM': Union[Variation_375, Variation_375_Arg],
})
Variation_1068_Arg : TypeAlias = Union[Raw, Variation_1068_Arg_Group]
class Variation_1068(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 3),
        ('FOM', Variation_375),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FOM': ('', Variation_375, 3, 5),
    }


    @classmethod
    def spec(cls, key : Union[Literal['FOM']]) -> Union[Type['Variation_375']]:
        if key == 'FOM':
            return Variation_375
        assert_never(key)

    def __init__(self, arg : Variation_1068_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['FOM']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['FOM'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_1068':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['FOM'], f : Any) -> 'Variation_1068':
        return self._modify_item(name, f) # type: ignore

Variation_1069_Arg = TypedDict('Variation_1069_Arg', {
    'SUM': Union[Variation_1052, Variation_1052_Arg],
    'PMN': Union[Variation_1067, Variation_1067_Arg],
    'POS': Union[Variation_1055, Variation_1055_Arg],
    'GA': Union[Variation_1058, Variation_1058_Arg],
    'EM1': Union[Variation_1061, Variation_1061_Arg],
    'TOS': Union[Variation_1062, Variation_1062_Arg],
    'XP': Union[Variation_1064, Variation_1064_Arg],
    'FOM': Union[Variation_1068, Variation_1068_Arg],
}, total=False)
class Variation_1069(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('SUM', Variation_1052),
        ('PMN', Variation_1067),
        ('POS', Variation_1055),
        ('GA', Variation_1058),
        ('EM1', Variation_1061),
        ('TOS', Variation_1062),
        ('XP', Variation_1064),
        ('FOM', Variation_1068),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'SUM': ('Mode 5 Summary', Variation_1052, 0x8000),
        'PMN': ('PIN/ National Origin/Mission Code', Variation_1067, 0x4000),
        'POS': ('Mode 5 Reported Position', Variation_1055, 0x2000),
        'GA': ('Mode 5 GNSS-derived Altitude', Variation_1058, 0x1000),
        'EM1': ('Extended Mode 1 Code in Octal Representation', Variation_1061, 0x0800),
        'TOS': ('Time Offset for POS and GA', Variation_1062, 0x0400),
        'XP': ('X Pulse Presence', Variation_1064, 0x0200),
        'FOM': ('Figure of Merit', Variation_1068, 0x0180),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SUM']) -> Type[Variation_1052]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PMN']) -> Type[Variation_1067]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_1055]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GA']) -> Type[Variation_1058]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EM1']) -> Type[Variation_1061]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOS']) -> Type[Variation_1062]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XP']) -> Type[Variation_1064]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FOM']) -> Type[Variation_1068]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SUM'], Literal['PMN'], Literal['POS'], Literal['GA'], Literal['EM1'], Literal['TOS'], Literal['XP'], Literal['FOM']]) -> Union[Type['Variation_1052'], Type['Variation_1067'], Type['Variation_1055'], Type['Variation_1058'], Type['Variation_1061'], Type['Variation_1062'], Type['Variation_1064'], Type['Variation_1068']]:
        if key == 'SUM':
            return Variation_1052
        if key == 'PMN':
            return Variation_1067
        if key == 'POS':
            return Variation_1055
        if key == 'GA':
            return Variation_1058
        if key == 'EM1':
            return Variation_1061
        if key == 'TOS':
            return Variation_1062
        if key == 'XP':
            return Variation_1064
        if key == 'FOM':
            return Variation_1068
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1069_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['SUM'], val : Union[Variation_1052, Variation_1052_Arg]) -> 'Variation_1069':
        ...

    @overload
    def set_item(self, name : Literal['PMN'], val : Union[Variation_1067, Variation_1067_Arg]) -> 'Variation_1069':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_1055, Variation_1055_Arg]) -> 'Variation_1069':
        ...

    @overload
    def set_item(self, name : Literal['GA'], val : Union[Variation_1058, Variation_1058_Arg]) -> 'Variation_1069':
        ...

    @overload
    def set_item(self, name : Literal['EM1'], val : Union[Variation_1061, Variation_1061_Arg]) -> 'Variation_1069':
        ...

    @overload
    def set_item(self, name : Literal['TOS'], val : Union[Variation_1062, Variation_1062_Arg]) -> 'Variation_1069':
        ...

    @overload
    def set_item(self, name : Literal['XP'], val : Union[Variation_1064, Variation_1064_Arg]) -> 'Variation_1069':
        ...

    @overload
    def set_item(self, name : Literal['FOM'], val : Union[Variation_1068, Variation_1068_Arg]) -> 'Variation_1069':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['SUM']) -> 'Variation_1069':
        ...

    @overload
    def del_item(self, name : Literal['PMN']) -> 'Variation_1069':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1069':
        ...

    @overload
    def del_item(self, name : Literal['GA']) -> 'Variation_1069':
        ...

    @overload
    def del_item(self, name : Literal['EM1']) -> 'Variation_1069':
        ...

    @overload
    def del_item(self, name : Literal['TOS']) -> 'Variation_1069':
        ...

    @overload
    def del_item(self, name : Literal['XP']) -> 'Variation_1069':
        ...

    @overload
    def del_item(self, name : Literal['FOM']) -> 'Variation_1069':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['SUM']) -> Variation_1052:
        ...

    @overload
    def get_item(self, name : Literal['PMN']) -> Variation_1067:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_1055:
        ...

    @overload
    def get_item(self, name : Literal['GA']) -> Variation_1058:
        ...

    @overload
    def get_item(self, name : Literal['EM1']) -> Variation_1061:
        ...

    @overload
    def get_item(self, name : Literal['TOS']) -> Variation_1062:
        ...

    @overload
    def get_item(self, name : Literal['XP']) -> Variation_1064:
        ...

    @overload
    def get_item(self, name : Literal['FOM']) -> Variation_1068:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['SUM'], f : Any) -> 'Variation_1069':
        ...

    @overload
    def modify_item(self, name : Literal['PMN'], f : Any) -> 'Variation_1069':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1069':
        ...

    @overload
    def modify_item(self, name : Literal['GA'], f : Any) -> 'Variation_1069':
        ...

    @overload
    def modify_item(self, name : Literal['EM1'], f : Any) -> 'Variation_1069':
        ...

    @overload
    def modify_item(self, name : Literal['TOS'], f : Any) -> 'Variation_1069':
        ...

    @overload
    def modify_item(self, name : Literal['XP'], f : Any) -> 'Variation_1069':
        ...

    @overload
    def modify_item(self, name : Literal['FOM'], f : Any) -> 'Variation_1069':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1070_Arg : TypeAlias = Raw
class Variation_1070(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'No Mode 4 interrogation',
        1: 'Possibly friendly target',
        2: 'Probably friendly target',
        3: 'Friendly target',
    }

    def __init__(self, arg : Variation_1070_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1071_Arg_Group_1 = TypedDict('Variation_1071_Arg_Group_1', {
    'FOEFRI': Union[Variation_1070, Variation_1070_Arg],
})
Variation_1071_Arg : TypeAlias = Union[
    int,
    Variation_1071_Arg_Group_1,
    Tuple[int],
]
class Variation_1071(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            Spare(0, 5),
            ('FOEFRI', Variation_1070),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FOEFRI': ('Indication Foe/Friend (Mode4)', Variation_1070, 5, 2),
    }


    @classmethod
    def spec(cls, key : Union[Literal['FOEFRI']]) -> Union[Type['Variation_1070']]:
        if key == 'FOEFRI':
            return Variation_1070
        assert_never(key)

    def __init__(self, arg : Variation_1071_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1071_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    def get_item(self, name : Literal['FOEFRI']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['FOEFRI'], val : Union[Variation_1070, Variation_1070_Arg]) -> 'Variation_1071':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['FOEFRI'], f : Any) -> 'Variation_1071':
        return self._modify_item(name, f) # type: ignore

Variation_1072_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['dB']]]
class Variation_1072(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 0.1, 'dB')

    def __init__(self, arg : Variation_1072_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1073_Arg = TypedDict('Variation_1073_Arg', {
    'SCO': Union[Variation_0, Variation_0_Arg],
    'SRC': Union[Variation_1072, Variation_1072_Arg],
    'RW': Union[Variation_594, Variation_594_Arg],
    'AR': Union[Variation_594, Variation_594_Arg],
}, total=False)
class Variation_1073(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('SCO', Variation_0),
        ('SRC', Variation_1072),
        ('RW', Variation_594),
        ('AR', Variation_594),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'SCO': ('Score', Variation_0, 0x80),
        'SRC': ('Signal/Clutter Ratio', Variation_1072, 0x40),
        'RW': ('Range Width', Variation_594, 0x20),
        'AR': ('Ambiguous Range', Variation_594, 0x10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SCO']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRC']) -> Type[Variation_1072]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RW']) -> Type[Variation_594]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AR']) -> Type[Variation_594]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SCO'], Literal['SRC'], Literal['RW'], Literal['AR']]) -> Union[Type['Variation_0'], Type['Variation_1072'], Type['Variation_594'], Type['Variation_594']]:
        if key == 'SCO':
            return Variation_0
        if key == 'SRC':
            return Variation_1072
        if key == 'RW':
            return Variation_594
        if key == 'AR':
            return Variation_594
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1073_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['SCO'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1073':
        ...

    @overload
    def set_item(self, name : Literal['SRC'], val : Union[Variation_1072, Variation_1072_Arg]) -> 'Variation_1073':
        ...

    @overload
    def set_item(self, name : Literal['RW'], val : Union[Variation_594, Variation_594_Arg]) -> 'Variation_1073':
        ...

    @overload
    def set_item(self, name : Literal['AR'], val : Union[Variation_594, Variation_594_Arg]) -> 'Variation_1073':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['SCO']) -> 'Variation_1073':
        ...

    @overload
    def del_item(self, name : Literal['SRC']) -> 'Variation_1073':
        ...

    @overload
    def del_item(self, name : Literal['RW']) -> 'Variation_1073':
        ...

    @overload
    def del_item(self, name : Literal['AR']) -> 'Variation_1073':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['SCO']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SRC']) -> Variation_1072:
        ...

    @overload
    def get_item(self, name : Literal['RW']) -> Variation_594:
        ...

    @overload
    def get_item(self, name : Literal['AR']) -> Variation_594:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['SCO'], f : Any) -> 'Variation_1073':
        ...

    @overload
    def modify_item(self, name : Literal['SRC'], f : Any) -> 'Variation_1073':
        ...

    @overload
    def modify_item(self, name : Literal['RW'], f : Any) -> 'Variation_1073':
        ...

    @overload
    def modify_item(self, name : Literal['AR'], f : Any) -> 'Variation_1073':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1074_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_1074(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 24
    quantity = Quantity('Unsigned', 3.90625e-3, 'NM')

    def __init__(self, arg : Variation_1074_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1075_Arg : TypeAlias = Raw
class Variation_1075(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Track is not associated with an SCN Plot',
        1: 'Track is associated with an SCN Plot',
    }

    def __init__(self, arg : Variation_1075_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1076_Arg : TypeAlias = Raw
class Variation_1076(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Associated Plot does not contain a Roll Call component',
        1: 'Associated Plot contains at least a Roll Call component',
    }

    def __init__(self, arg : Variation_1076_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1077_Arg : TypeAlias = Raw
class Variation_1077(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Associated Plot does not contain an All Call component',
        1: 'Associated Plot contains at least an All Call component',
    }

    def __init__(self, arg : Variation_1077_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1078_Arg : TypeAlias = Raw
class Variation_1078(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Associated Plot does not contain an SSR component',
        1: 'Associated Plot contains at least an SSR component',
    }

    def __init__(self, arg : Variation_1078_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1079_Arg : TypeAlias = Raw
class Variation_1079(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'Associated Plot does not contain a PSR component',
        1: 'Associated Plot contains at least a PSR component',
    }

    def __init__(self, arg : Variation_1079_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1080_Arg_Group = TypedDict('Variation_1080_Arg_Group', {
    'SCN': Union[Variation_1075, Variation_1075_Arg],
    'RC': Union[Variation_1076, Variation_1076_Arg],
    'AC': Union[Variation_1077, Variation_1077_Arg],
    'SSR': Union[Variation_1078, Variation_1078_Arg],
    'PSR': Union[Variation_1079, Variation_1079_Arg],
    'PLOTNR': Union[Variation_64, Variation_64_Arg],
})
Variation_1080_Arg : TypeAlias = Union[Raw, Variation_1080_Arg_Group]
class Variation_1080(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        Spare(0, 3),
        ('SCN', Variation_1075),
        ('RC', Variation_1076),
        ('AC', Variation_1077),
        ('SSR', Variation_1078),
        ('PSR', Variation_1079),
        ('PLOTNR', Variation_64),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SCN': ('Track / SCN Association', Variation_1075, 3, 1),
        'RC': ('Roll Call Component', Variation_1076, 4, 1),
        'AC': ('All Call Component', Variation_1077, 5, 1),
        'SSR': ('SSR Component', Variation_1078, 6, 1),
        'PSR': ('PSR Component', Variation_1079, 7, 1),
        'PLOTNR': ('', Variation_64, 8, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SCN']) -> Type[Variation_1075]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RC']) -> Type[Variation_1076]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AC']) -> Type[Variation_1077]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_1078]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_1079]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PLOTNR']) -> Type[Variation_64]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SCN'], Literal['RC'], Literal['AC'], Literal['SSR'], Literal['PSR'], Literal['PLOTNR']]) -> Union[Type['Variation_1075'], Type['Variation_1076'], Type['Variation_1077'], Type['Variation_1078'], Type['Variation_1079'], Type['Variation_64']]:
        if key == 'SCN':
            return Variation_1075
        if key == 'RC':
            return Variation_1076
        if key == 'AC':
            return Variation_1077
        if key == 'SSR':
            return Variation_1078
        if key == 'PSR':
            return Variation_1079
        if key == 'PLOTNR':
            return Variation_64
        assert_never(key)

    def __init__(self, arg : Variation_1080_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SCN']) -> Variation_1075:
        ...

    @overload
    def get_item(self, name : Literal['RC']) -> Variation_1076:
        ...

    @overload
    def get_item(self, name : Literal['AC']) -> Variation_1077:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_1078:
        ...

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_1079:
        ...

    @overload
    def get_item(self, name : Literal['PLOTNR']) -> Variation_64:
        ...

    def get_item(self, name : Union[Literal['SCN'], Literal['RC'], Literal['AC'], Literal['SSR'], Literal['PSR'], Literal['PLOTNR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SCN'], val : Union[Variation_1075, Variation_1075_Arg]) -> 'Variation_1080':
        ...

    @overload
    def set_item(self, name : Literal['RC'], val : Union[Variation_1076, Variation_1076_Arg]) -> 'Variation_1080':
        ...

    @overload
    def set_item(self, name : Literal['AC'], val : Union[Variation_1077, Variation_1077_Arg]) -> 'Variation_1080':
        ...

    @overload
    def set_item(self, name : Literal['SSR'], val : Union[Variation_1078, Variation_1078_Arg]) -> 'Variation_1080':
        ...

    @overload
    def set_item(self, name : Literal['PSR'], val : Union[Variation_1079, Variation_1079_Arg]) -> 'Variation_1080':
        ...

    @overload
    def set_item(self, name : Literal['PLOTNR'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1080':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SCN'], f : Any) -> 'Variation_1080':
        ...

    @overload
    def modify_item(self, name : Literal['RC'], f : Any) -> 'Variation_1080':
        ...

    @overload
    def modify_item(self, name : Literal['AC'], f : Any) -> 'Variation_1080':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_1080':
        ...

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_1080':
        ...

    @overload
    def modify_item(self, name : Literal['PLOTNR'], f : Any) -> 'Variation_1080':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1081_Arg : TypeAlias = Union[Variation_64, Variation_64_Arg]
class Variation_1081(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 16
    variation_type = Variation_64

    @classmethod
    def spec(cls) -> Type[Variation_64]:
        return Variation_64

    def __init__(self, arg : List[Union[Variation_64, Variation_64_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1081':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1081':
        return self._prepend_item(arg) # type: ignore

Variation_1082_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['%']]]
class Variation_1082(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 1.0, '%')

    def __init__(self, arg : Variation_1082_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1083_Arg_Group = TypedDict('Variation_1083_Arg_Group', {
    'PREDRHO': Union[Variation_13, Variation_13_Arg],
    'PREDTHETA': Union[Variation_14, Variation_14_Arg],
    'EVOLRHOSTART': Union[Variation_13, Variation_13_Arg],
    'EVOLRHOEND': Union[Variation_13, Variation_13_Arg],
    'EVOLTHETASTART': Union[Variation_14, Variation_14_Arg],
    'EVOLTHETAEND': Union[Variation_14, Variation_14_Arg],
    'NOISERHOSTART': Union[Variation_13, Variation_13_Arg],
    'NOISERHOEND': Union[Variation_13, Variation_13_Arg],
    'NOISETHETASTART': Union[Variation_14, Variation_14_Arg],
    'NOISETHETAEND': Union[Variation_14, Variation_14_Arg],
    'PREDTIME': Union[Variation_25, Variation_25_Arg],
})
Variation_1083_Arg : TypeAlias = Union[Raw, Variation_1083_Arg_Group]
class Variation_1083(Group):
    variation = 'Group'

    bit_size = 176

    subitems_list = [
        ('PREDRHO', Variation_13),
        ('PREDTHETA', Variation_14),
        ('EVOLRHOSTART', Variation_13),
        ('EVOLRHOEND', Variation_13),
        ('EVOLTHETASTART', Variation_14),
        ('EVOLTHETAEND', Variation_14),
        ('NOISERHOSTART', Variation_13),
        ('NOISERHOEND', Variation_13),
        ('NOISETHETASTART', Variation_14),
        ('NOISETHETAEND', Variation_14),
        ('PREDTIME', Variation_25),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PREDRHO': ('Predicted Range', Variation_13, 0, 16),
        'PREDTHETA': ('Predicted Azimuth', Variation_14, 16, 16),
        'EVOLRHOSTART': ('Predicted Closest Range', Variation_13, 32, 16),
        'EVOLRHOEND': ('Predicted Largest Range', Variation_13, 48, 16),
        'EVOLTHETASTART': ('Predicted Smallest Azimuth', Variation_14, 64, 16),
        'EVOLTHETAEND': ('Predicted Largest Azimuth', Variation_14, 80, 16),
        'NOISERHOSTART': ('Predicted Closest Range', Variation_13, 96, 16),
        'NOISERHOEND': ('Predicted Largest Range', Variation_13, 112, 16),
        'NOISETHETASTART': ('Predicted Smallest Azimuth', Variation_14, 128, 16),
        'NOISETHETAEND': ('Predicted Largest Azimuth', Variation_14, 144, 16),
        'PREDTIME': ('Predicted Detection Time', Variation_25, 160, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PREDRHO']) -> Type[Variation_13]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PREDTHETA']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EVOLRHOSTART']) -> Type[Variation_13]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EVOLRHOEND']) -> Type[Variation_13]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EVOLTHETASTART']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EVOLTHETAEND']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOISERHOSTART']) -> Type[Variation_13]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOISERHOEND']) -> Type[Variation_13]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOISETHETASTART']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NOISETHETAEND']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PREDTIME']) -> Type[Variation_25]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PREDRHO'], Literal['PREDTHETA'], Literal['EVOLRHOSTART'], Literal['EVOLRHOEND'], Literal['EVOLTHETASTART'], Literal['EVOLTHETAEND'], Literal['NOISERHOSTART'], Literal['NOISERHOEND'], Literal['NOISETHETASTART'], Literal['NOISETHETAEND'], Literal['PREDTIME']]) -> Union[Type['Variation_13'], Type['Variation_14'], Type['Variation_13'], Type['Variation_13'], Type['Variation_14'], Type['Variation_14'], Type['Variation_13'], Type['Variation_13'], Type['Variation_14'], Type['Variation_14'], Type['Variation_25']]:
        if key == 'PREDRHO':
            return Variation_13
        if key == 'PREDTHETA':
            return Variation_14
        if key == 'EVOLRHOSTART':
            return Variation_13
        if key == 'EVOLRHOEND':
            return Variation_13
        if key == 'EVOLTHETASTART':
            return Variation_14
        if key == 'EVOLTHETAEND':
            return Variation_14
        if key == 'NOISERHOSTART':
            return Variation_13
        if key == 'NOISERHOEND':
            return Variation_13
        if key == 'NOISETHETASTART':
            return Variation_14
        if key == 'NOISETHETAEND':
            return Variation_14
        if key == 'PREDTIME':
            return Variation_25
        assert_never(key)

    def __init__(self, arg : Variation_1083_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PREDRHO']) -> Variation_13:
        ...

    @overload
    def get_item(self, name : Literal['PREDTHETA']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['EVOLRHOSTART']) -> Variation_13:
        ...

    @overload
    def get_item(self, name : Literal['EVOLRHOEND']) -> Variation_13:
        ...

    @overload
    def get_item(self, name : Literal['EVOLTHETASTART']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['EVOLTHETAEND']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['NOISERHOSTART']) -> Variation_13:
        ...

    @overload
    def get_item(self, name : Literal['NOISERHOEND']) -> Variation_13:
        ...

    @overload
    def get_item(self, name : Literal['NOISETHETASTART']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['NOISETHETAEND']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['PREDTIME']) -> Variation_25:
        ...

    def get_item(self, name : Union[Literal['PREDRHO'], Literal['PREDTHETA'], Literal['EVOLRHOSTART'], Literal['EVOLRHOEND'], Literal['EVOLTHETASTART'], Literal['EVOLTHETAEND'], Literal['NOISERHOSTART'], Literal['NOISERHOEND'], Literal['NOISETHETASTART'], Literal['NOISETHETAEND'], Literal['PREDTIME']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PREDRHO'], val : Union[Variation_13, Variation_13_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['PREDTHETA'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['EVOLRHOSTART'], val : Union[Variation_13, Variation_13_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['EVOLRHOEND'], val : Union[Variation_13, Variation_13_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['EVOLTHETASTART'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['EVOLTHETAEND'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['NOISERHOSTART'], val : Union[Variation_13, Variation_13_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['NOISERHOEND'], val : Union[Variation_13, Variation_13_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['NOISETHETASTART'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['NOISETHETAEND'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1083':
        ...

    @overload
    def set_item(self, name : Literal['PREDTIME'], val : Union[Variation_25, Variation_25_Arg]) -> 'Variation_1083':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PREDRHO'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['PREDTHETA'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['EVOLRHOSTART'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['EVOLRHOEND'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['EVOLTHETASTART'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['EVOLTHETAEND'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['NOISERHOSTART'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['NOISERHOEND'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['NOISETHETASTART'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['NOISETHETAEND'], f : Any) -> 'Variation_1083':
        ...

    @overload
    def modify_item(self, name : Literal['PREDTIME'], f : Any) -> 'Variation_1083':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1084_Arg : TypeAlias = Raw
class Variation_1084(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 4
    table = {
        0: 'Surveillance Mode A (alert bit or periodic)',
        1: 'Comm-A',
        2: 'Ground Initiated Comm-B',
        3: 'Air Initiated Comm-B',
        4: 'Broadcast Comm-B',
        5: 'Comm-C',
        6: 'Comm-D',
        7: 'Reserved for future use',
        8: 'Reserved for future use',
        9: 'Reserved for future use',
        10: 'Reserved for future use',
        11: 'Reserved for future use',
        12: 'Reserved for future use',
        13: 'Reserved for future use',
        14: 'Reserved for future use',
        15: 'Reserved for future use',
    }

    def __init__(self, arg : Variation_1084_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1085_Arg : TypeAlias = Raw
class Variation_1085(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        0: 'From previous scan',
        1: 'New in current scan',
        2: 'Requested in the beam by transponder',
        3: 'Invalid ASTERIX value',
    }

    def __init__(self, arg : Variation_1085_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1086_Arg : TypeAlias = Raw
class Variation_1086(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 2
    table = {
        0: 'In progress',
        1: 'Completed',
        2: 'Cancelled',
        3: 'Invalid ASTERIX value',
    }

    def __init__(self, arg : Variation_1086_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1087_Arg_Group = TypedDict('Variation_1087_Arg_Group', {
    'TYPE': Union[Variation_1084, Variation_1084_Arg],
    'ORIGIN': Union[Variation_1085, Variation_1085_Arg],
    'STATE': Union[Variation_1086, Variation_1086_Arg],
})
Variation_1087_Arg : TypeAlias = Union[Raw, Variation_1087_Arg_Group]
class Variation_1087(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('TYPE', Variation_1084),
        ('ORIGIN', Variation_1085),
        ('STATE', Variation_1086),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYPE': ('', Variation_1084, 0, 4),
        'ORIGIN': ('', Variation_1085, 4, 2),
        'STATE': ('', Variation_1086, 6, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYPE']) -> Type[Variation_1084]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ORIGIN']) -> Type[Variation_1085]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STATE']) -> Type[Variation_1086]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYPE'], Literal['ORIGIN'], Literal['STATE']]) -> Union[Type['Variation_1084'], Type['Variation_1085'], Type['Variation_1086']]:
        if key == 'TYPE':
            return Variation_1084
        if key == 'ORIGIN':
            return Variation_1085
        if key == 'STATE':
            return Variation_1086
        assert_never(key)

    def __init__(self, arg : Variation_1087_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYPE']) -> Variation_1084:
        ...

    @overload
    def get_item(self, name : Literal['ORIGIN']) -> Variation_1085:
        ...

    @overload
    def get_item(self, name : Literal['STATE']) -> Variation_1086:
        ...

    def get_item(self, name : Union[Literal['TYPE'], Literal['ORIGIN'], Literal['STATE']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYPE'], val : Union[Variation_1084, Variation_1084_Arg]) -> 'Variation_1087':
        ...

    @overload
    def set_item(self, name : Literal['ORIGIN'], val : Union[Variation_1085, Variation_1085_Arg]) -> 'Variation_1087':
        ...

    @overload
    def set_item(self, name : Literal['STATE'], val : Union[Variation_1086, Variation_1086_Arg]) -> 'Variation_1087':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYPE'], f : Any) -> 'Variation_1087':
        ...

    @overload
    def modify_item(self, name : Literal['ORIGIN'], f : Any) -> 'Variation_1087':
        ...

    @overload
    def modify_item(self, name : Literal['STATE'], f : Any) -> 'Variation_1087':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1088_Arg : TypeAlias = Union[Variation_1087, Variation_1087_Arg]
class Variation_1088(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 8
    variation_type = Variation_1087

    @classmethod
    def spec(cls) -> Type[Variation_1087]:
        return Variation_1087

    def __init__(self, arg : List[Union[Variation_1087, Variation_1087_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1087, Variation_1087_Arg]) -> 'Variation_1088':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1087, Variation_1087_Arg]) -> 'Variation_1088':
        return self._prepend_item(arg) # type: ignore

Variation_1089_Arg : TypeAlias = Raw
class Variation_1089(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Target not locked out by this radar',
        1: 'Target locked out by this radar',
    }

    def __init__(self, arg : Variation_1089_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1090_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ms']]]
class Variation_1090(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 15
    quantity = Quantity('Unsigned', 1.0, 'ms')

    def __init__(self, arg : Variation_1090_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1091_Arg_Group = TypedDict('Variation_1091_Arg_Group', {
    'LS': Union[Variation_1089, Variation_1089_Arg],
    'LOCTIM': Union[Variation_1090, Variation_1090_Arg],
})
Variation_1091_Arg : TypeAlias = Union[Raw, Variation_1091_Arg_Group]
class Variation_1091(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('LS', Variation_1089),
        ('LOCTIM', Variation_1090),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LS': ('Lockout State', Variation_1089, 0, 1),
        'LOCTIM': ('Lockout Time', Variation_1090, 1, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LS']) -> Type[Variation_1089]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LOCTIM']) -> Type[Variation_1090]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LS'], Literal['LOCTIM']]) -> Union[Type['Variation_1089'], Type['Variation_1090']]:
        if key == 'LS':
            return Variation_1089
        if key == 'LOCTIM':
            return Variation_1090
        assert_never(key)

    def __init__(self, arg : Variation_1091_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LS']) -> Variation_1089:
        ...

    @overload
    def get_item(self, name : Literal['LOCTIM']) -> Variation_1090:
        ...

    def get_item(self, name : Union[Literal['LS'], Literal['LOCTIM']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LS'], val : Union[Variation_1089, Variation_1089_Arg]) -> 'Variation_1091':
        ...

    @overload
    def set_item(self, name : Literal['LOCTIM'], val : Union[Variation_1090, Variation_1090_Arg]) -> 'Variation_1091':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LS'], f : Any) -> 'Variation_1091':
        ...

    @overload
    def modify_item(self, name : Literal['LOCTIM'], f : Any) -> 'Variation_1091':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1092_Arg : TypeAlias = Raw
class Variation_1092(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 4

    def __init__(self, arg : Variation_1092_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_1093_Arg_Group = TypedDict('Variation_1093_Arg_Group', {
    'TCOUNT1': Union[Variation_1092, Variation_1092_Arg],
    'TCODE1': Union[Variation_375, Variation_375_Arg],
    'TCOUNT2': Union[Variation_187, Variation_187_Arg],
    'TCODE2': Union[Variation_19, Variation_19_Arg],
    'TCOUNT3': Union[Variation_187, Variation_187_Arg],
    'TCODE3': Union[Variation_19, Variation_19_Arg],
})
Variation_1093_Arg : TypeAlias = Union[Raw, Variation_1093_Arg_Group]
class Variation_1093(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        Spare(0, 7),
        ('TCOUNT1', Variation_1092),
        ('TCODE1', Variation_375),
        ('TCOUNT2', Variation_187),
        ('TCODE2', Variation_19),
        ('TCOUNT3', Variation_187),
        ('TCODE3', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TCOUNT1': ('', Variation_1092, 7, 4),
        'TCODE1': ('', Variation_375, 11, 5),
        'TCOUNT2': ('', Variation_187, 16, 4),
        'TCODE2': ('', Variation_19, 20, 12),
        'TCOUNT3': ('', Variation_187, 32, 4),
        'TCODE3': ('', Variation_19, 36, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TCOUNT1']) -> Type[Variation_1092]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCODE1']) -> Type[Variation_375]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCOUNT2']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCODE2']) -> Type[Variation_19]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCOUNT3']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCODE3']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TCOUNT1'], Literal['TCODE1'], Literal['TCOUNT2'], Literal['TCODE2'], Literal['TCOUNT3'], Literal['TCODE3']]) -> Union[Type['Variation_1092'], Type['Variation_375'], Type['Variation_187'], Type['Variation_19'], Type['Variation_187'], Type['Variation_19']]:
        if key == 'TCOUNT1':
            return Variation_1092
        if key == 'TCODE1':
            return Variation_375
        if key == 'TCOUNT2':
            return Variation_187
        if key == 'TCODE2':
            return Variation_19
        if key == 'TCOUNT3':
            return Variation_187
        if key == 'TCODE3':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_1093_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TCOUNT1']) -> Variation_1092:
        ...

    @overload
    def get_item(self, name : Literal['TCODE1']) -> Variation_375:
        ...

    @overload
    def get_item(self, name : Literal['TCOUNT2']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['TCODE2']) -> Variation_19:
        ...

    @overload
    def get_item(self, name : Literal['TCOUNT3']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['TCODE3']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['TCOUNT1'], Literal['TCODE1'], Literal['TCOUNT2'], Literal['TCODE2'], Literal['TCOUNT3'], Literal['TCODE3']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TCOUNT1'], val : Union[Variation_1092, Variation_1092_Arg]) -> 'Variation_1093':
        ...

    @overload
    def set_item(self, name : Literal['TCODE1'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_1093':
        ...

    @overload
    def set_item(self, name : Literal['TCOUNT2'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_1093':
        ...

    @overload
    def set_item(self, name : Literal['TCODE2'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_1093':
        ...

    @overload
    def set_item(self, name : Literal['TCOUNT3'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_1093':
        ...

    @overload
    def set_item(self, name : Literal['TCODE3'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_1093':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TCOUNT1'], f : Any) -> 'Variation_1093':
        ...

    @overload
    def modify_item(self, name : Literal['TCODE1'], f : Any) -> 'Variation_1093':
        ...

    @overload
    def modify_item(self, name : Literal['TCOUNT2'], f : Any) -> 'Variation_1093':
        ...

    @overload
    def modify_item(self, name : Literal['TCODE2'], f : Any) -> 'Variation_1093':
        ...

    @overload
    def modify_item(self, name : Literal['TCOUNT3'], f : Any) -> 'Variation_1093':
        ...

    @overload
    def modify_item(self, name : Literal['TCODE3'], f : Any) -> 'Variation_1093':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1094_Arg : TypeAlias = Raw
class Variation_1094(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Tentative Track with One Plot',
        1: 'Tentative Track with at least Two Plots',
        2: 'Pre-Confirmed Track',
        3: 'Confirmed Track',
    }

    def __init__(self, arg : Variation_1094_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1095_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ms']]]
class Variation_1095(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0, 'ms')

    def __init__(self, arg : Variation_1095_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1096_Arg_Group = TypedDict('Variation_1096_Arg_Group', {
    'ACQI': Union[Variation_1094, Variation_1094_Arg],
    'TRKUPDCTR': Union[Variation_790, Variation_790_Arg],
    'LASTTRKUPD': Union[Variation_1095, Variation_1095_Arg],
})
Variation_1096_Arg : TypeAlias = Union[Raw, Variation_1096_Arg_Group]
class Variation_1096(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('ACQI', Variation_1094),
        ('TRKUPDCTR', Variation_790),
        ('LASTTRKUPD', Variation_1095),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'ACQI': ('', Variation_1094, 0, 2),
        'TRKUPDCTR': ('', Variation_790, 2, 14),
        'LASTTRKUPD': ('', Variation_1095, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ACQI']) -> Type[Variation_1094]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRKUPDCTR']) -> Type[Variation_790]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LASTTRKUPD']) -> Type[Variation_1095]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ACQI'], Literal['TRKUPDCTR'], Literal['LASTTRKUPD']]) -> Union[Type['Variation_1094'], Type['Variation_790'], Type['Variation_1095']]:
        if key == 'ACQI':
            return Variation_1094
        if key == 'TRKUPDCTR':
            return Variation_790
        if key == 'LASTTRKUPD':
            return Variation_1095
        assert_never(key)

    def __init__(self, arg : Variation_1096_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['ACQI']) -> Variation_1094:
        ...

    @overload
    def get_item(self, name : Literal['TRKUPDCTR']) -> Variation_790:
        ...

    @overload
    def get_item(self, name : Literal['LASTTRKUPD']) -> Variation_1095:
        ...

    def get_item(self, name : Union[Literal['ACQI'], Literal['TRKUPDCTR'], Literal['LASTTRKUPD']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['ACQI'], val : Union[Variation_1094, Variation_1094_Arg]) -> 'Variation_1096':
        ...

    @overload
    def set_item(self, name : Literal['TRKUPDCTR'], val : Union[Variation_790, Variation_790_Arg]) -> 'Variation_1096':
        ...

    @overload
    def set_item(self, name : Literal['LASTTRKUPD'], val : Union[Variation_1095, Variation_1095_Arg]) -> 'Variation_1096':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['ACQI'], f : Any) -> 'Variation_1096':
        ...

    @overload
    def modify_item(self, name : Literal['TRKUPDCTR'], f : Any) -> 'Variation_1096':
        ...

    @overload
    def modify_item(self, name : Literal['LASTTRKUPD'], f : Any) -> 'Variation_1096':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1097_Arg : TypeAlias = Raw
class Variation_1097(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    table = {
        0: 'Data used by Tracker',
        1: 'Data not used by Tracker',
        2: '2-127: Reserved for future use',
    }

    def __init__(self, arg : Variation_1097_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1098_Arg : TypeAlias = Raw
class Variation_1098(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'DRN not available',
        1: 'DRN available',
    }

    def __init__(self, arg : Variation_1098_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1099_Arg_Group = TypedDict('Variation_1099_Arg_Group', {
    'SACADJS': Union[Variation_0, Variation_0_Arg],
    'SICADJS': Union[Variation_0, Variation_0_Arg],
    'TIMEOFDAYSCN': Union[Variation_25, Variation_25_Arg],
    'DATAUSE': Union[Variation_1097, Variation_1097_Arg],
    'DRNA': Union[Variation_1098, Variation_1098_Arg],
    'DRN': Union[Variation_64, Variation_64_Arg],
})
Variation_1099_Arg : TypeAlias = Union[Raw, Variation_1099_Arg_Group]
class Variation_1099(Group):
    variation = 'Group'

    bit_size = 56

    subitems_list = [
        ('SACADJS', Variation_0),
        ('SICADJS', Variation_0),
        ('TIMEOFDAYSCN', Variation_25),
        ('DATAUSE', Variation_1097),
        ('DRNA', Variation_1098),
        ('DRN', Variation_64),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SACADJS': ('SAC of the Adjacent Sensor', Variation_0, 0, 8),
        'SICADJS': ('SIC of the Adjacent Sensor', Variation_0, 8, 8),
        'TIMEOFDAYSCN': ('Absolute Timestamp in UTC Provided by the SCN', Variation_25, 16, 16),
        'DATAUSE': ('Use of Adjacent Sensor Data', Variation_1097, 32, 7),
        'DRNA': ('DRN Availability', Variation_1098, 39, 1),
        'DRN': ('', Variation_64, 40, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SACADJS']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SICADJS']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TIMEOFDAYSCN']) -> Type[Variation_25]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DATAUSE']) -> Type[Variation_1097]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DRNA']) -> Type[Variation_1098]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DRN']) -> Type[Variation_64]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SACADJS'], Literal['SICADJS'], Literal['TIMEOFDAYSCN'], Literal['DATAUSE'], Literal['DRNA'], Literal['DRN']]) -> Union[Type['Variation_0'], Type['Variation_0'], Type['Variation_25'], Type['Variation_1097'], Type['Variation_1098'], Type['Variation_64']]:
        if key == 'SACADJS':
            return Variation_0
        if key == 'SICADJS':
            return Variation_0
        if key == 'TIMEOFDAYSCN':
            return Variation_25
        if key == 'DATAUSE':
            return Variation_1097
        if key == 'DRNA':
            return Variation_1098
        if key == 'DRN':
            return Variation_64
        assert_never(key)

    def __init__(self, arg : Variation_1099_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SACADJS']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SICADJS']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['TIMEOFDAYSCN']) -> Variation_25:
        ...

    @overload
    def get_item(self, name : Literal['DATAUSE']) -> Variation_1097:
        ...

    @overload
    def get_item(self, name : Literal['DRNA']) -> Variation_1098:
        ...

    @overload
    def get_item(self, name : Literal['DRN']) -> Variation_64:
        ...

    def get_item(self, name : Union[Literal['SACADJS'], Literal['SICADJS'], Literal['TIMEOFDAYSCN'], Literal['DATAUSE'], Literal['DRNA'], Literal['DRN']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SACADJS'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1099':
        ...

    @overload
    def set_item(self, name : Literal['SICADJS'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1099':
        ...

    @overload
    def set_item(self, name : Literal['TIMEOFDAYSCN'], val : Union[Variation_25, Variation_25_Arg]) -> 'Variation_1099':
        ...

    @overload
    def set_item(self, name : Literal['DATAUSE'], val : Union[Variation_1097, Variation_1097_Arg]) -> 'Variation_1099':
        ...

    @overload
    def set_item(self, name : Literal['DRNA'], val : Union[Variation_1098, Variation_1098_Arg]) -> 'Variation_1099':
        ...

    @overload
    def set_item(self, name : Literal['DRN'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1099':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SACADJS'], f : Any) -> 'Variation_1099':
        ...

    @overload
    def modify_item(self, name : Literal['SICADJS'], f : Any) -> 'Variation_1099':
        ...

    @overload
    def modify_item(self, name : Literal['TIMEOFDAYSCN'], f : Any) -> 'Variation_1099':
        ...

    @overload
    def modify_item(self, name : Literal['DATAUSE'], f : Any) -> 'Variation_1099':
        ...

    @overload
    def modify_item(self, name : Literal['DRNA'], f : Any) -> 'Variation_1099':
        ...

    @overload
    def modify_item(self, name : Literal['DRN'], f : Any) -> 'Variation_1099':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1100_Arg : TypeAlias = Union[Variation_1099, Variation_1099_Arg]
class Variation_1100(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 56
    variation_type = Variation_1099

    @classmethod
    def spec(cls) -> Type[Variation_1099]:
        return Variation_1099

    def __init__(self, arg : List[Union[Variation_1099, Variation_1099_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1099, Variation_1099_Arg]) -> 'Variation_1100':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1099, Variation_1099_Arg]) -> 'Variation_1100':
        return self._prepend_item(arg) # type: ignore

Variation_1101_Arg : TypeAlias = Raw
class Variation_1101(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'Radar tracker calculation',
        1: 'Integrated ADS-B',
        2: 'External ADS-B',
        3: 'SCN',
    }

    def __init__(self, arg : Variation_1101_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1102_Arg : TypeAlias = Raw
class Variation_1102(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Identity not requested',
        1: 'Identity requested',
    }

    def __init__(self, arg : Variation_1102_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1103_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_1103(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 7
    quantity = Quantity('Unsigned', 1.0, 's')

    def __init__(self, arg : Variation_1103_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1104_Arg_Group = TypedDict('Variation_1104_Arg_Group', {
    'IR': Union[Variation_1102, Variation_1102_Arg],
    'M3A': Union[Variation_1103, Variation_1103_Arg],
})
Variation_1104_Arg : TypeAlias = Union[Raw, Variation_1104_Arg_Group]
class Variation_1104(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('IR', Variation_1102),
        ('M3A', Variation_1103),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'IR': ('', Variation_1102, 0, 1),
        'M3A': ('Age of Mode 3/A Code (I048/070)', Variation_1103, 1, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['IR']) -> Type[Variation_1102]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M3A']) -> Type[Variation_1103]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['IR'], Literal['M3A']]) -> Union[Type['Variation_1102'], Type['Variation_1103']]:
        if key == 'IR':
            return Variation_1102
        if key == 'M3A':
            return Variation_1103
        assert_never(key)

    def __init__(self, arg : Variation_1104_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['IR']) -> Variation_1102:
        ...

    @overload
    def get_item(self, name : Literal['M3A']) -> Variation_1103:
        ...

    def get_item(self, name : Union[Literal['IR'], Literal['M3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['IR'], val : Union[Variation_1102, Variation_1102_Arg]) -> 'Variation_1104':
        ...

    @overload
    def set_item(self, name : Literal['M3A'], val : Union[Variation_1103, Variation_1103_Arg]) -> 'Variation_1104':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['IR'], f : Any) -> 'Variation_1104':
        ...

    @overload
    def modify_item(self, name : Literal['M3A'], f : Any) -> 'Variation_1104':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1105_Arg = TypedDict('Variation_1105_Arg', {
    'PTL': Union[Variation_1080, Variation_1080_Arg],
    'ATL': Union[Variation_1081, Variation_1081_Arg],
    'TRN': Union[Variation_1082, Variation_1082_Arg],
    'NPP': Union[Variation_1083, Variation_1083_Arg],
    'DLK': Union[Variation_1088, Variation_1088_Arg],
    'LCK': Union[Variation_1091, Variation_1091_Arg],
    'TC': Union[Variation_1093, Variation_1093_Arg],
    'TLC': Union[Variation_1096, Variation_1096_Arg],
    'ASI': Union[Variation_1100, Variation_1100_Arg],
    'TES': Union[Variation_1101, Variation_1101_Arg],
    'IR': Union[Variation_1104, Variation_1104_Arg],
}, total=False)
class Variation_1105(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('PTL', Variation_1080),
        ('ATL', Variation_1081),
        ('TRN', Variation_1082),
        ('NPP', Variation_1083),
        ('DLK', Variation_1088),
        ('LCK', Variation_1091),
        ('TC', Variation_1093),
        ('TLC', Variation_1096),
        ('ASI', Variation_1100),
        ('TES', Variation_1101),
        ('IR', Variation_1104),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'PTL': ('Plot/Track Link', Variation_1080, 0x8000),
        'ATL': ('ADS-B/Track Link', Variation_1081, 0x4000),
        'TRN': ('Turn State', Variation_1082, 0x2000),
        'NPP': ('Next Predicted Position', Variation_1083, 0x1000),
        'DLK': ('Data Link Characteristics', Variation_1088, 0x0800),
        'LCK': ('Lockout Characteristics', Variation_1091, 0x0400),
        'TC': ('Transition Code', Variation_1093, 0x0200),
        'TLC': ('Track Life Cycle', Variation_1096, 0x0180),
        'ASI': ('Adjacent Sensor Information', Variation_1100, 0x0140),
        'TES': ('Track Extrapolation Source', Variation_1101, 0x0120),
        'IR': ('Identity Requested', Variation_1104, 0x0110),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PTL']) -> Type[Variation_1080]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ATL']) -> Type[Variation_1081]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRN']) -> Type[Variation_1082]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NPP']) -> Type[Variation_1083]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DLK']) -> Type[Variation_1088]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LCK']) -> Type[Variation_1091]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TC']) -> Type[Variation_1093]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TLC']) -> Type[Variation_1096]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ASI']) -> Type[Variation_1100]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TES']) -> Type[Variation_1101]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IR']) -> Type[Variation_1104]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PTL'], Literal['ATL'], Literal['TRN'], Literal['NPP'], Literal['DLK'], Literal['LCK'], Literal['TC'], Literal['TLC'], Literal['ASI'], Literal['TES'], Literal['IR']]) -> Union[Type['Variation_1080'], Type['Variation_1081'], Type['Variation_1082'], Type['Variation_1083'], Type['Variation_1088'], Type['Variation_1091'], Type['Variation_1093'], Type['Variation_1096'], Type['Variation_1100'], Type['Variation_1101'], Type['Variation_1104']]:
        if key == 'PTL':
            return Variation_1080
        if key == 'ATL':
            return Variation_1081
        if key == 'TRN':
            return Variation_1082
        if key == 'NPP':
            return Variation_1083
        if key == 'DLK':
            return Variation_1088
        if key == 'LCK':
            return Variation_1091
        if key == 'TC':
            return Variation_1093
        if key == 'TLC':
            return Variation_1096
        if key == 'ASI':
            return Variation_1100
        if key == 'TES':
            return Variation_1101
        if key == 'IR':
            return Variation_1104
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1105_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['PTL'], val : Union[Variation_1080, Variation_1080_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['ATL'], val : Union[Variation_1081, Variation_1081_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['TRN'], val : Union[Variation_1082, Variation_1082_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['NPP'], val : Union[Variation_1083, Variation_1083_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['DLK'], val : Union[Variation_1088, Variation_1088_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['LCK'], val : Union[Variation_1091, Variation_1091_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['TC'], val : Union[Variation_1093, Variation_1093_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['TLC'], val : Union[Variation_1096, Variation_1096_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['ASI'], val : Union[Variation_1100, Variation_1100_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['TES'], val : Union[Variation_1101, Variation_1101_Arg]) -> 'Variation_1105':
        ...

    @overload
    def set_item(self, name : Literal['IR'], val : Union[Variation_1104, Variation_1104_Arg]) -> 'Variation_1105':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['PTL']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['ATL']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['TRN']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['NPP']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['DLK']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['LCK']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['TC']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['TLC']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['ASI']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['TES']) -> 'Variation_1105':
        ...

    @overload
    def del_item(self, name : Literal['IR']) -> 'Variation_1105':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['PTL']) -> Variation_1080:
        ...

    @overload
    def get_item(self, name : Literal['ATL']) -> Variation_1081:
        ...

    @overload
    def get_item(self, name : Literal['TRN']) -> Variation_1082:
        ...

    @overload
    def get_item(self, name : Literal['NPP']) -> Variation_1083:
        ...

    @overload
    def get_item(self, name : Literal['DLK']) -> Variation_1088:
        ...

    @overload
    def get_item(self, name : Literal['LCK']) -> Variation_1091:
        ...

    @overload
    def get_item(self, name : Literal['TC']) -> Variation_1093:
        ...

    @overload
    def get_item(self, name : Literal['TLC']) -> Variation_1096:
        ...

    @overload
    def get_item(self, name : Literal['ASI']) -> Variation_1100:
        ...

    @overload
    def get_item(self, name : Literal['TES']) -> Variation_1101:
        ...

    @overload
    def get_item(self, name : Literal['IR']) -> Variation_1104:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['PTL'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['ATL'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['TRN'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['NPP'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['DLK'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['LCK'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['TC'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['TLC'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['ASI'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['TES'], f : Any) -> 'Variation_1105':
        ...

    @overload
    def modify_item(self, name : Literal['IR'], f : Any) -> 'Variation_1105':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1106_Arg : TypeAlias = Raw
class Variation_1106(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        0: 'PSR Echo',
        1: 'SSR Reply',
        2: 'All Call Reply',
        3: 'Roll Call Reply',
    }

    def __init__(self, arg : Variation_1106_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1107_Arg_Group = TypedDict('Variation_1107_Arg_Group', {
    'TYPE': Union[Variation_1106, Variation_1106_Arg],
    'REPLYNBR': Union[Variation_64, Variation_64_Arg],
})
Variation_1107_Arg : TypeAlias = Union[Raw, Variation_1107_Arg_Group]
class Variation_1107(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('TYPE', Variation_1106),
        ('REPLYNBR', Variation_64),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYPE': ('Reply Type', Variation_1106, 0, 8),
        'REPLYNBR': ('', Variation_64, 8, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYPE']) -> Type[Variation_1106]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['REPLYNBR']) -> Type[Variation_64]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYPE'], Literal['REPLYNBR']]) -> Union[Type['Variation_1106'], Type['Variation_64']]:
        if key == 'TYPE':
            return Variation_1106
        if key == 'REPLYNBR':
            return Variation_64
        assert_never(key)

    def __init__(self, arg : Variation_1107_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYPE']) -> Variation_1106:
        ...

    @overload
    def get_item(self, name : Literal['REPLYNBR']) -> Variation_64:
        ...

    def get_item(self, name : Union[Literal['TYPE'], Literal['REPLYNBR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYPE'], val : Union[Variation_1106, Variation_1106_Arg]) -> 'Variation_1107':
        ...

    @overload
    def set_item(self, name : Literal['REPLYNBR'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1107':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYPE'], f : Any) -> 'Variation_1107':
        ...

    @overload
    def modify_item(self, name : Literal['REPLYNBR'], f : Any) -> 'Variation_1107':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1108_Arg : TypeAlias = Union[Variation_1107, Variation_1107_Arg]
class Variation_1108(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 24
    variation_type = Variation_1107

    @classmethod
    def spec(cls) -> Type[Variation_1107]:
        return Variation_1107

    def __init__(self, arg : List[Union[Variation_1107, Variation_1107_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1107, Variation_1107_Arg]) -> 'Variation_1108':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1107, Variation_1107_Arg]) -> 'Variation_1108':
        return self._prepend_item(arg) # type: ignore

Variation_1109_Arg_Group = TypedDict('Variation_1109_Arg_Group', {
    'Y1': Union[Variation_187, Variation_187_Arg],
    'Y2': Union[Variation_282, Variation_282_Arg],
    'Y3': Union[Variation_187, Variation_187_Arg],
    'Y4': Union[Variation_282, Variation_282_Arg],
    'M1': Union[Variation_187, Variation_187_Arg],
    'M2': Union[Variation_282, Variation_282_Arg],
    'D1': Union[Variation_187, Variation_187_Arg],
    'D2': Union[Variation_282, Variation_282_Arg],
})
Variation_1109_Arg : TypeAlias = Union[Raw, Variation_1109_Arg_Group]
class Variation_1109(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('Y1', Variation_187),
        ('Y2', Variation_282),
        ('Y3', Variation_187),
        ('Y4', Variation_282),
        ('M1', Variation_187),
        ('M2', Variation_282),
        ('D1', Variation_187),
        ('D2', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'Y1': ('', Variation_187, 0, 4),
        'Y2': ('', Variation_282, 4, 4),
        'Y3': ('', Variation_187, 8, 4),
        'Y4': ('', Variation_282, 12, 4),
        'M1': ('', Variation_187, 16, 4),
        'M2': ('', Variation_282, 20, 4),
        'D1': ('', Variation_187, 24, 4),
        'D2': ('', Variation_282, 28, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['Y1']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y2']) -> Type[Variation_282]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y3']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y4']) -> Type[Variation_282]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M1']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M2']) -> Type[Variation_282]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['D1']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['D2']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['Y1'], Literal['Y2'], Literal['Y3'], Literal['Y4'], Literal['M1'], Literal['M2'], Literal['D1'], Literal['D2']]) -> Union[Type['Variation_187'], Type['Variation_282'], Type['Variation_187'], Type['Variation_282'], Type['Variation_187'], Type['Variation_282'], Type['Variation_187'], Type['Variation_282']]:
        if key == 'Y1':
            return Variation_187
        if key == 'Y2':
            return Variation_282
        if key == 'Y3':
            return Variation_187
        if key == 'Y4':
            return Variation_282
        if key == 'M1':
            return Variation_187
        if key == 'M2':
            return Variation_282
        if key == 'D1':
            return Variation_187
        if key == 'D2':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_1109_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['Y1']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['Y2']) -> Variation_282:
        ...

    @overload
    def get_item(self, name : Literal['Y3']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['Y4']) -> Variation_282:
        ...

    @overload
    def get_item(self, name : Literal['M1']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['M2']) -> Variation_282:
        ...

    @overload
    def get_item(self, name : Literal['D1']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['D2']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['Y1'], Literal['Y2'], Literal['Y3'], Literal['Y4'], Literal['M1'], Literal['M2'], Literal['D1'], Literal['D2']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['Y1'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_1109':
        ...

    @overload
    def set_item(self, name : Literal['Y2'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_1109':
        ...

    @overload
    def set_item(self, name : Literal['Y3'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_1109':
        ...

    @overload
    def set_item(self, name : Literal['Y4'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_1109':
        ...

    @overload
    def set_item(self, name : Literal['M1'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_1109':
        ...

    @overload
    def set_item(self, name : Literal['M2'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_1109':
        ...

    @overload
    def set_item(self, name : Literal['D1'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_1109':
        ...

    @overload
    def set_item(self, name : Literal['D2'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_1109':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['Y1'], f : Any) -> 'Variation_1109':
        ...

    @overload
    def modify_item(self, name : Literal['Y2'], f : Any) -> 'Variation_1109':
        ...

    @overload
    def modify_item(self, name : Literal['Y3'], f : Any) -> 'Variation_1109':
        ...

    @overload
    def modify_item(self, name : Literal['Y4'], f : Any) -> 'Variation_1109':
        ...

    @overload
    def modify_item(self, name : Literal['M1'], f : Any) -> 'Variation_1109':
        ...

    @overload
    def modify_item(self, name : Literal['M2'], f : Any) -> 'Variation_1109':
        ...

    @overload
    def modify_item(self, name : Literal['D1'], f : Any) -> 'Variation_1109':
        ...

    @overload
    def modify_item(self, name : Literal['D2'], f : Any) -> 'Variation_1109':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1110_Arg = TypedDict('Variation_1110_Arg', {
    'PNB': Union[Variation_64, Variation_64_Arg],
    'RPL': Union[Variation_1108, Variation_1108_Arg],
    'SNB': Union[Variation_0, Variation_0_Arg],
    'DATE': Union[Variation_1109, Variation_1109_Arg],
}, total=False)
class Variation_1110(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('PNB', Variation_64),
        ('RPL', Variation_1108),
        ('SNB', Variation_0),
        ('DATE', Variation_1109),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'PNB': ('Plot Number', Variation_64, 0x80),
        'RPL': ('Replies/Plot Link', Variation_1108, 0x40),
        'SNB': ('Scan Number', Variation_0, 0x20),
        'DATE': ('Common and Plot Characteristics Date', Variation_1109, 0x10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PNB']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RPL']) -> Type[Variation_1108]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SNB']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DATE']) -> Type[Variation_1109]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PNB'], Literal['RPL'], Literal['SNB'], Literal['DATE']]) -> Union[Type['Variation_64'], Type['Variation_1108'], Type['Variation_0'], Type['Variation_1109']]:
        if key == 'PNB':
            return Variation_64
        if key == 'RPL':
            return Variation_1108
        if key == 'SNB':
            return Variation_0
        if key == 'DATE':
            return Variation_1109
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1110_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['PNB'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1110':
        ...

    @overload
    def set_item(self, name : Literal['RPL'], val : Union[Variation_1108, Variation_1108_Arg]) -> 'Variation_1110':
        ...

    @overload
    def set_item(self, name : Literal['SNB'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1110':
        ...

    @overload
    def set_item(self, name : Literal['DATE'], val : Union[Variation_1109, Variation_1109_Arg]) -> 'Variation_1110':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['PNB']) -> 'Variation_1110':
        ...

    @overload
    def del_item(self, name : Literal['RPL']) -> 'Variation_1110':
        ...

    @overload
    def del_item(self, name : Literal['SNB']) -> 'Variation_1110':
        ...

    @overload
    def del_item(self, name : Literal['DATE']) -> 'Variation_1110':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['PNB']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['RPL']) -> Variation_1108:
        ...

    @overload
    def get_item(self, name : Literal['SNB']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['DATE']) -> Variation_1109:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['PNB'], f : Any) -> 'Variation_1110':
        ...

    @overload
    def modify_item(self, name : Literal['RPL'], f : Any) -> 'Variation_1110':
        ...

    @overload
    def modify_item(self, name : Literal['SNB'], f : Any) -> 'Variation_1110':
        ...

    @overload
    def modify_item(self, name : Literal['DATE'], f : Any) -> 'Variation_1110':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1111_Arg = TypedDict('Variation_1111_Arg', {
    'MD5': Union[Variation_1065, Variation_1065_Arg],
    'M5N': Union[Variation_1069, Variation_1069_Arg],
    'M4E': Union[Variation_1071, Variation_1071_Arg],
    'RPC': Union[Variation_1073, Variation_1073_Arg],
    'ERR': Union[Variation_1074, Variation_1074_Arg],
    'RTC': Union[Variation_1105, Variation_1105_Arg],
    'CPC': Union[Variation_1110, Variation_1110_Arg],
}, total=False)
class Variation_1111(Compound):
    variation = 'Compound'

    fspec_fx = False
    fspec_max_bytes = 1

    subitems_list = [
        ('MD5', Variation_1065),
        ('M5N', Variation_1069),
        ('M4E', Variation_1071),
        ('RPC', Variation_1073),
        ('ERR', Variation_1074),
        ('RTC', Variation_1105),
        ('CPC', Variation_1110),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'MD5': ('Mode 5 Reports', Variation_1065, 0x80),
        'M5N': ('Mode 5 Reports, New Format', Variation_1069, 0x40),
        'M4E': ('Extended Mode 4 Report', Variation_1071, 0x20),
        'RPC': ('Radar Plot Characteristics', Variation_1073, 0x10),
        'ERR': ('Extended Range Report', Variation_1074, 0x08),
        'RTC': ('Radar Track Characteristics', Variation_1105, 0x04),
        'CPC': ('Common and Plot Characteristics', Variation_1110, 0x02),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MD5']) -> Type[Variation_1065]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M5N']) -> Type[Variation_1069]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M4E']) -> Type[Variation_1071]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RPC']) -> Type[Variation_1073]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ERR']) -> Type[Variation_1074]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RTC']) -> Type[Variation_1105]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CPC']) -> Type[Variation_1110]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MD5'], Literal['M5N'], Literal['M4E'], Literal['RPC'], Literal['ERR'], Literal['RTC'], Literal['CPC']]) -> Union[Type['Variation_1065'], Type['Variation_1069'], Type['Variation_1071'], Type['Variation_1073'], Type['Variation_1074'], Type['Variation_1105'], Type['Variation_1110']]:
        if key == 'MD5':
            return Variation_1065
        if key == 'M5N':
            return Variation_1069
        if key == 'M4E':
            return Variation_1071
        if key == 'RPC':
            return Variation_1073
        if key == 'ERR':
            return Variation_1074
        if key == 'RTC':
            return Variation_1105
        if key == 'CPC':
            return Variation_1110
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1111_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['MD5'], val : Union[Variation_1065, Variation_1065_Arg]) -> 'Variation_1111':
        ...

    @overload
    def set_item(self, name : Literal['M5N'], val : Union[Variation_1069, Variation_1069_Arg]) -> 'Variation_1111':
        ...

    @overload
    def set_item(self, name : Literal['M4E'], val : Union[Variation_1071, Variation_1071_Arg]) -> 'Variation_1111':
        ...

    @overload
    def set_item(self, name : Literal['RPC'], val : Union[Variation_1073, Variation_1073_Arg]) -> 'Variation_1111':
        ...

    @overload
    def set_item(self, name : Literal['ERR'], val : Union[Variation_1074, Variation_1074_Arg]) -> 'Variation_1111':
        ...

    @overload
    def set_item(self, name : Literal['RTC'], val : Union[Variation_1105, Variation_1105_Arg]) -> 'Variation_1111':
        ...

    @overload
    def set_item(self, name : Literal['CPC'], val : Union[Variation_1110, Variation_1110_Arg]) -> 'Variation_1111':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['MD5']) -> 'Variation_1111':
        ...

    @overload
    def del_item(self, name : Literal['M5N']) -> 'Variation_1111':
        ...

    @overload
    def del_item(self, name : Literal['M4E']) -> 'Variation_1111':
        ...

    @overload
    def del_item(self, name : Literal['RPC']) -> 'Variation_1111':
        ...

    @overload
    def del_item(self, name : Literal['ERR']) -> 'Variation_1111':
        ...

    @overload
    def del_item(self, name : Literal['RTC']) -> 'Variation_1111':
        ...

    @overload
    def del_item(self, name : Literal['CPC']) -> 'Variation_1111':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['MD5']) -> Variation_1065:
        ...

    @overload
    def get_item(self, name : Literal['M5N']) -> Variation_1069:
        ...

    @overload
    def get_item(self, name : Literal['M4E']) -> Variation_1071:
        ...

    @overload
    def get_item(self, name : Literal['RPC']) -> Variation_1073:
        ...

    @overload
    def get_item(self, name : Literal['ERR']) -> Variation_1074:
        ...

    @overload
    def get_item(self, name : Literal['RTC']) -> Variation_1105:
        ...

    @overload
    def get_item(self, name : Literal['CPC']) -> Variation_1110:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['MD5'], f : Any) -> 'Variation_1111':
        ...

    @overload
    def modify_item(self, name : Literal['M5N'], f : Any) -> 'Variation_1111':
        ...

    @overload
    def modify_item(self, name : Literal['M4E'], f : Any) -> 'Variation_1111':
        ...

    @overload
    def modify_item(self, name : Literal['RPC'], f : Any) -> 'Variation_1111':
        ...

    @overload
    def modify_item(self, name : Literal['ERR'], f : Any) -> 'Variation_1111':
        ...

    @overload
    def modify_item(self, name : Literal['RTC'], f : Any) -> 'Variation_1111':
        ...

    @overload
    def modify_item(self, name : Literal['CPC'], f : Any) -> 'Variation_1111':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1112_Arg : TypeAlias = Raw
class Variation_1112(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: 'No detection',
        1: 'Single PSR detection',
        2: 'Single SSR detection',
        3: 'SSR + PSR detection',
        4: 'Single ModeS All-Call',
        5: 'Single ModeS Roll-Call',
        6: 'ModeS All-Call + PSR',
        7: 'ModeS Roll-Call +PSR',
    }

    def __init__(self, arg : Variation_1112_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1113_Arg : TypeAlias = Raw
class Variation_1113(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Actual target report',
        1: 'Simulated target report',
    }

    def __init__(self, arg : Variation_1113_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1114_Arg : TypeAlias = Raw
class Variation_1114(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Report from RDP Chain 1',
        1: 'Report from RDP Chain 2',
    }

    def __init__(self, arg : Variation_1114_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1115_Arg : TypeAlias = Raw
class Variation_1115(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Absence of SPI',
        1: 'Special Position Identification',
    }

    def __init__(self, arg : Variation_1115_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1116_Arg : TypeAlias = Raw
class Variation_1116(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Report from aircraft transponder',
        1: 'Report from field monitor (fixed transponder)',
    }

    def __init__(self, arg : Variation_1116_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1117_Arg : TypeAlias = Raw
class Variation_1117(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Real target report',
        1: 'Test target report',
    }

    def __init__(self, arg : Variation_1117_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1118_Arg : TypeAlias = Raw
class Variation_1118(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'No Extended Range',
        1: 'Extended Range present',
    }

    def __init__(self, arg : Variation_1118_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1119_Arg : TypeAlias = Raw
class Variation_1119(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'No X-Pulse present',
        1: 'X-Pulse present',
    }

    def __init__(self, arg : Variation_1119_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1120_Arg : TypeAlias = Raw
class Variation_1120(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'No military emergency',
        1: 'Military emergency',
    }

    def __init__(self, arg : Variation_1120_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1121_Arg : TypeAlias = Raw
class Variation_1121(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'No military identification',
        1: 'Military identification',
    }

    def __init__(self, arg : Variation_1121_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1122_Arg : TypeAlias = Raw
class Variation_1122(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'No Mode 4 interrogation',
        1: 'Friendly target',
        2: 'Unknown target',
        3: 'No reply',
    }

    def __init__(self, arg : Variation_1122_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1123_Arg_Group_1 = TypedDict('Variation_1123_Arg_Group_1', {
    'TYP': Union[Variation_1112, Variation_1112_Arg],
    'SIM': Union[Variation_1113, Variation_1113_Arg],
    'RDP': Union[Variation_1114, Variation_1114_Arg],
    'SPI': Union[Variation_1115, Variation_1115_Arg],
    'RAB': Union[Variation_1116, Variation_1116_Arg],
})
Variation_1123_Arg_Group_2 = TypedDict('Variation_1123_Arg_Group_2', {
    'TYP': Union[Variation_1112, Variation_1112_Arg],
    'SIM': Union[Variation_1113, Variation_1113_Arg],
    'RDP': Union[Variation_1114, Variation_1114_Arg],
    'SPI': Union[Variation_1115, Variation_1115_Arg],
    'RAB': Union[Variation_1116, Variation_1116_Arg],
    'TST': Union[Variation_1117, Variation_1117_Arg],
    'ERR': Union[Variation_1118, Variation_1118_Arg],
    'XPP': Union[Variation_1119, Variation_1119_Arg],
    'ME': Union[Variation_1120, Variation_1120_Arg],
    'MI': Union[Variation_1121, Variation_1121_Arg],
    'FOEFRI': Union[Variation_1122, Variation_1122_Arg],
})
Variation_1123_Arg : TypeAlias = Union[
    int,
    Variation_1123_Arg_Group_1,
    Tuple[int],
    Variation_1123_Arg_Group_2,
    Tuple[int,int],
]
class Variation_1123(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('TYP', Variation_1112),
            ('SIM', Variation_1113),
            ('RDP', Variation_1114),
            ('SPI', Variation_1115),
            ('RAB', Variation_1116),
        ],
        [
            ('TST', Variation_1117),
            ('ERR', Variation_1118),
            ('XPP', Variation_1119),
            ('ME', Variation_1120),
            ('MI', Variation_1121),
            ('FOEFRI', Variation_1122),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('', Variation_1112, 0, 3),
        'SIM': ('', Variation_1113, 3, 1),
        'RDP': ('', Variation_1114, 4, 1),
        'SPI': ('', Variation_1115, 5, 1),
        'RAB': ('', Variation_1116, 6, 1),
        'TST': ('', Variation_1117, 0, 1),
        'ERR': ('', Variation_1118, 1, 1),
        'XPP': ('', Variation_1119, 2, 1),
        'ME': ('', Variation_1120, 3, 1),
        'MI': ('', Variation_1121, 4, 1),
        'FOEFRI': ('', Variation_1122, 5, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_1112]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_1113]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RDP']) -> Type[Variation_1114]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_1115]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_1116]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_1117]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ERR']) -> Type[Variation_1118]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XPP']) -> Type[Variation_1119]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ME']) -> Type[Variation_1120]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MI']) -> Type[Variation_1121]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FOEFRI']) -> Type[Variation_1122]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['SIM'], Literal['RDP'], Literal['SPI'], Literal['RAB'], Literal['TST'], Literal['ERR'], Literal['XPP'], Literal['ME'], Literal['MI'], Literal['FOEFRI']]) -> Union[Type['Variation_1112'], Type['Variation_1113'], Type['Variation_1114'], Type['Variation_1115'], Type['Variation_1116'], Type['Variation_1117'], Type['Variation_1118'], Type['Variation_1119'], Type['Variation_1120'], Type['Variation_1121'], Type['Variation_1122']]:
        if key == 'TYP':
            return Variation_1112
        if key == 'SIM':
            return Variation_1113
        if key == 'RDP':
            return Variation_1114
        if key == 'SPI':
            return Variation_1115
        if key == 'RAB':
            return Variation_1116
        if key == 'TST':
            return Variation_1117
        if key == 'ERR':
            return Variation_1118
        if key == 'XPP':
            return Variation_1119
        if key == 'ME':
            return Variation_1120
        if key == 'MI':
            return Variation_1121
        if key == 'FOEFRI':
            return Variation_1122
        assert_never(key)

    def __init__(self, arg : Variation_1123_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1123_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_1123_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_1112:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_1113:
        ...

    @overload
    def get_item(self, name : Literal['RDP']) -> Variation_1114:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_1115:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_1116:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_1117:
        ...

    @overload
    def get_item(self, name : Literal['ERR']) -> Variation_1118:
        ...

    @overload
    def get_item(self, name : Literal['XPP']) -> Variation_1119:
        ...

    @overload
    def get_item(self, name : Literal['ME']) -> Variation_1120:
        ...

    @overload
    def get_item(self, name : Literal['MI']) -> Variation_1121:
        ...

    @overload
    def get_item(self, name : Literal['FOEFRI']) -> Variation_1122:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['SIM'], Literal['RDP'], Literal['SPI'], Literal['RAB'], Literal['TST'], Literal['ERR'], Literal['XPP'], Literal['ME'], Literal['MI'], Literal['FOEFRI']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_1112, Variation_1112_Arg]) -> 'Variation_1123':
        ...

    @overload
    def set_item(self, name : Literal['SIM'], val : Union[Variation_1113, Variation_1113_Arg]) -> 'Variation_1123':
        ...

    @overload
    def set_item(self, name : Literal['RDP'], val : Union[Variation_1114, Variation_1114_Arg]) -> 'Variation_1123':
        ...

    @overload
    def set_item(self, name : Literal['SPI'], val : Union[Variation_1115, Variation_1115_Arg]) -> 'Variation_1123':
        ...

    @overload
    def set_item(self, name : Literal['RAB'], val : Union[Variation_1116, Variation_1116_Arg]) -> 'Variation_1123':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['RDP'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['ERR'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['XPP'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['ME'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['MI'], f : Any) -> 'Variation_1123':
        ...

    @overload
    def modify_item(self, name : Literal['FOEFRI'], f : Any) -> 'Variation_1123':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1124_Arg_Group = TypedDict('Variation_1124_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_276, Variation_276_Arg],
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_1124_Arg : TypeAlias = Union[Raw, Variation_1124_Arg_Group]
class Variation_1124(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_276),
        Spare(3, 1),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'L': ('', Variation_276, 2, 1),
        'MODE3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_276]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_276'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_276
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_1124_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_276:
        ...

    @overload
    def get_item(self, name : Literal['MODE3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_1124':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_1124':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_276, Variation_276_Arg]) -> 'Variation_1124':
        ...

    @overload
    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_1124':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_1124':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_1124':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_1124':
        ...

    @overload
    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_1124':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1125_Arg_Group = TypedDict('Variation_1125_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'FL': Union[Variation_541, Variation_541_Arg],
})
Variation_1125_Arg : TypeAlias = Union[Raw, Variation_1125_Arg_Group]
class Variation_1125(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('FL', Variation_541),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'FL': ('', Variation_541, 2, 14),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FL']) -> Type[Variation_541]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['FL']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_541']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'FL':
            return Variation_541
        assert_never(key)

    def __init__(self, arg : Variation_1125_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['FL']) -> Variation_541:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['FL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_1125':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_1125':
        ...

    @overload
    def set_item(self, name : Literal['FL'], val : Union[Variation_541, Variation_541_Arg]) -> 'Variation_1125':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_1125':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_1125':
        ...

    @overload
    def modify_item(self, name : Literal['FL'], f : Any) -> 'Variation_1125':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1126_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_1126(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 4.39453125e-2, '°')

    def __init__(self, arg : Variation_1126_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1127_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_1127(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 3.90625e-3, 'NM')

    def __init__(self, arg : Variation_1127_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1128_Arg = TypedDict('Variation_1128_Arg', {
    'SRL': Union[Variation_1126, Variation_1126_Arg],
    'SRR': Union[Variation_0, Variation_0_Arg],
    'SAM': Union[Variation_29, Variation_29_Arg],
    'PRL': Union[Variation_1126, Variation_1126_Arg],
    'PAM': Union[Variation_29, Variation_29_Arg],
    'RPD': Union[Variation_1127, Variation_1127_Arg],
    'APD': Union[Variation_88, Variation_88_Arg],
}, total=False)
class Variation_1128(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('SRL', Variation_1126),
        ('SRR', Variation_0),
        ('SAM', Variation_29),
        ('PRL', Variation_1126),
        ('PAM', Variation_29),
        ('RPD', Variation_1127),
        ('APD', Variation_88),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'SRL': ('SSR Plot Runlength', Variation_1126, 0x80),
        'SRR': ('Number of Received Replies for (M)SSR', Variation_0, 0x40),
        'SAM': ('Amplitude of (M)SSR Reply', Variation_29, 0x20),
        'PRL': ('Primary Plot Runlength', Variation_1126, 0x10),
        'PAM': ('Amplitude of Primary Plot', Variation_29, 0x08),
        'RPD': ('Difference in Range Between PSR and SSR Plot', Variation_1127, 0x04),
        'APD': ('Difference in Azimuth Between PSR and SSR Plot', Variation_88, 0x02),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SRL']) -> Type[Variation_1126]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRR']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAM']) -> Type[Variation_29]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PRL']) -> Type[Variation_1126]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PAM']) -> Type[Variation_29]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RPD']) -> Type[Variation_1127]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['APD']) -> Type[Variation_88]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SRL'], Literal['SRR'], Literal['SAM'], Literal['PRL'], Literal['PAM'], Literal['RPD'], Literal['APD']]) -> Union[Type['Variation_1126'], Type['Variation_0'], Type['Variation_29'], Type['Variation_1126'], Type['Variation_29'], Type['Variation_1127'], Type['Variation_88']]:
        if key == 'SRL':
            return Variation_1126
        if key == 'SRR':
            return Variation_0
        if key == 'SAM':
            return Variation_29
        if key == 'PRL':
            return Variation_1126
        if key == 'PAM':
            return Variation_29
        if key == 'RPD':
            return Variation_1127
        if key == 'APD':
            return Variation_88
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1128_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['SRL'], val : Union[Variation_1126, Variation_1126_Arg]) -> 'Variation_1128':
        ...

    @overload
    def set_item(self, name : Literal['SRR'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1128':
        ...

    @overload
    def set_item(self, name : Literal['SAM'], val : Union[Variation_29, Variation_29_Arg]) -> 'Variation_1128':
        ...

    @overload
    def set_item(self, name : Literal['PRL'], val : Union[Variation_1126, Variation_1126_Arg]) -> 'Variation_1128':
        ...

    @overload
    def set_item(self, name : Literal['PAM'], val : Union[Variation_29, Variation_29_Arg]) -> 'Variation_1128':
        ...

    @overload
    def set_item(self, name : Literal['RPD'], val : Union[Variation_1127, Variation_1127_Arg]) -> 'Variation_1128':
        ...

    @overload
    def set_item(self, name : Literal['APD'], val : Union[Variation_88, Variation_88_Arg]) -> 'Variation_1128':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['SRL']) -> 'Variation_1128':
        ...

    @overload
    def del_item(self, name : Literal['SRR']) -> 'Variation_1128':
        ...

    @overload
    def del_item(self, name : Literal['SAM']) -> 'Variation_1128':
        ...

    @overload
    def del_item(self, name : Literal['PRL']) -> 'Variation_1128':
        ...

    @overload
    def del_item(self, name : Literal['PAM']) -> 'Variation_1128':
        ...

    @overload
    def del_item(self, name : Literal['RPD']) -> 'Variation_1128':
        ...

    @overload
    def del_item(self, name : Literal['APD']) -> 'Variation_1128':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['SRL']) -> Variation_1126:
        ...

    @overload
    def get_item(self, name : Literal['SRR']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SAM']) -> Variation_29:
        ...

    @overload
    def get_item(self, name : Literal['PRL']) -> Variation_1126:
        ...

    @overload
    def get_item(self, name : Literal['PAM']) -> Variation_29:
        ...

    @overload
    def get_item(self, name : Literal['RPD']) -> Variation_1127:
        ...

    @overload
    def get_item(self, name : Literal['APD']) -> Variation_88:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['SRL'], f : Any) -> 'Variation_1128':
        ...

    @overload
    def modify_item(self, name : Literal['SRR'], f : Any) -> 'Variation_1128':
        ...

    @overload
    def modify_item(self, name : Literal['SAM'], f : Any) -> 'Variation_1128':
        ...

    @overload
    def modify_item(self, name : Literal['PRL'], f : Any) -> 'Variation_1128':
        ...

    @overload
    def modify_item(self, name : Literal['PAM'], f : Any) -> 'Variation_1128':
        ...

    @overload
    def modify_item(self, name : Literal['RPD'], f : Any) -> 'Variation_1128':
        ...

    @overload
    def modify_item(self, name : Literal['APD'], f : Any) -> 'Variation_1128':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1129_Arg_Group = TypedDict('Variation_1129_Arg_Group', {
    'MBDATA': Union[Variation_281, Variation_281_Arg],
    'BDS1': Union[Variation_187, Variation_187_Arg],
    'BDS2': Union[Variation_282, Variation_282_Arg],
})
Variation_1129_Arg : TypeAlias = Union[Raw, Variation_1129_Arg_Group]
class Variation_1129(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('MBDATA', Variation_281),
        ('BDS1', Variation_187),
        ('BDS2', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MBDATA': ('Mode S Comm B Message Data', Variation_281, 0, 56),
        'BDS1': ('Comm B Data Buffer Store 1 Address', Variation_187, 56, 4),
        'BDS2': ('Comm B Data Buffer Store 2 Address', Variation_282, 60, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MBDATA']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BDS1']) -> Type[Variation_187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BDS2']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MBDATA'], Literal['BDS1'], Literal['BDS2']]) -> Union[Type['Variation_281'], Type['Variation_187'], Type['Variation_282']]:
        if key == 'MBDATA':
            return Variation_281
        if key == 'BDS1':
            return Variation_187
        if key == 'BDS2':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_1129_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MBDATA']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['BDS1']) -> Variation_187:
        ...

    @overload
    def get_item(self, name : Literal['BDS2']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['MBDATA'], Literal['BDS1'], Literal['BDS2']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MBDATA'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_1129':
        ...

    @overload
    def set_item(self, name : Literal['BDS1'], val : Union[Variation_187, Variation_187_Arg]) -> 'Variation_1129':
        ...

    @overload
    def set_item(self, name : Literal['BDS2'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_1129':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MBDATA'], f : Any) -> 'Variation_1129':
        ...

    @overload
    def modify_item(self, name : Literal['BDS1'], f : Any) -> 'Variation_1129':
        ...

    @overload
    def modify_item(self, name : Literal['BDS2'], f : Any) -> 'Variation_1129':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1130_Arg : TypeAlias = Union[Variation_1129, Variation_1129_Arg]
class Variation_1130(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 64
    variation_type = Variation_1129

    @classmethod
    def spec(cls) -> Type[Variation_1129]:
        return Variation_1129

    def __init__(self, arg : List[Union[Variation_1129, Variation_1129_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1129, Variation_1129_Arg]) -> 'Variation_1130':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1129, Variation_1129_Arg]) -> 'Variation_1130':
        return self._prepend_item(arg) # type: ignore

Variation_1131_Arg_Group = TypedDict('Variation_1131_Arg_Group', {
    'X': Union[Variation_596, Variation_596_Arg],
    'Y': Union[Variation_596, Variation_596_Arg],
})
Variation_1131_Arg : TypeAlias = Union[Raw, Variation_1131_Arg_Group]
class Variation_1131(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('X', Variation_596),
        ('Y', Variation_596),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('X-Component', Variation_596, 0, 16),
        'Y': ('X-Component', Variation_596, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_596]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_596]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_596'], Type['Variation_596']]:
        if key == 'X':
            return Variation_596
        if key == 'Y':
            return Variation_596
        assert_never(key)

    def __init__(self, arg : Variation_1131_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_596:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_596:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_596, Variation_596_Arg]) -> 'Variation_1131':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_596, Variation_596_Arg]) -> 'Variation_1131':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_1131':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_1131':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1132_Arg : TypeAlias = Raw
class Variation_1132(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Confirmed Track',
        1: 'Tentative Track',
    }

    def __init__(self, arg : Variation_1132_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1133_Arg : TypeAlias = Raw
class Variation_1133(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'Combined Track',
        1: 'PSR Track',
        2: 'SSR/Mode S Track',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_1133_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1134_Arg : TypeAlias = Raw
class Variation_1134(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Normal confidence',
        1: 'Low confidence in plot to track association',
    }

    def __init__(self, arg : Variation_1134_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1135_Arg : TypeAlias = Raw
class Variation_1135(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'No horizontal man.sensed',
        1: 'Horizontal man. sensed',
    }

    def __init__(self, arg : Variation_1135_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1136_Arg : TypeAlias = Raw
class Variation_1136(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'Maintaining',
        1: 'Climbing',
        2: 'Descending',
        3: 'Unknown',
    }

    def __init__(self, arg : Variation_1136_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1137_Arg : TypeAlias = Raw
class Variation_1137(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Track still alive',
        1: 'End of track lifetime(last report for this track)',
    }

    def __init__(self, arg : Variation_1137_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1138_Arg : TypeAlias = Raw
class Variation_1138(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'True target track',
        1: 'Ghost target track',
    }

    def __init__(self, arg : Variation_1138_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1139_Arg : TypeAlias = Raw
class Variation_1139(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Tracking performed in so-called \'Radar Plane\', i.e. neither slant range correction nor stereographical projection was applied',
        1: 'Slant range correction and a suitable projection technique are used to track in a 2D.reference plane, tangential to the earth model at the Radar Site co-ordinates',
    }

    def __init__(self, arg : Variation_1139_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1140_Arg_Group_1 = TypedDict('Variation_1140_Arg_Group_1', {
    'CNF': Union[Variation_1132, Variation_1132_Arg],
    'RAD': Union[Variation_1133, Variation_1133_Arg],
    'DOU': Union[Variation_1134, Variation_1134_Arg],
    'MAH': Union[Variation_1135, Variation_1135_Arg],
    'CDM': Union[Variation_1136, Variation_1136_Arg],
})
Variation_1140_Arg_Group_2 = TypedDict('Variation_1140_Arg_Group_2', {
    'CNF': Union[Variation_1132, Variation_1132_Arg],
    'RAD': Union[Variation_1133, Variation_1133_Arg],
    'DOU': Union[Variation_1134, Variation_1134_Arg],
    'MAH': Union[Variation_1135, Variation_1135_Arg],
    'CDM': Union[Variation_1136, Variation_1136_Arg],
    'TRE': Union[Variation_1137, Variation_1137_Arg],
    'GHO': Union[Variation_1138, Variation_1138_Arg],
    'SUP': Union[Variation_326, Variation_326_Arg],
    'TCC': Union[Variation_1139, Variation_1139_Arg],
})
Variation_1140_Arg : TypeAlias = Union[
    int,
    Variation_1140_Arg_Group_1,
    Tuple[int],
    Variation_1140_Arg_Group_2,
    Tuple[int,int],
]
class Variation_1140(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('CNF', Variation_1132),
            ('RAD', Variation_1133),
            ('DOU', Variation_1134),
            ('MAH', Variation_1135),
            ('CDM', Variation_1136),
        ],
        [
            ('TRE', Variation_1137),
            ('GHO', Variation_1138),
            ('SUP', Variation_326),
            ('TCC', Variation_1139),
            Spare(4, 3),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CNF': ('Confirmed Vs. Tentative Track', Variation_1132, 0, 1),
        'RAD': ('Type of Sensor(s) Maintaining Track', Variation_1133, 1, 2),
        'DOU': ('Signals Level of Confidence in Plot to Track Association Process', Variation_1134, 3, 1),
        'MAH': ('Manoeuvre Detection in Horizontal Sense', Variation_1135, 4, 1),
        'CDM': ('Climbing / Descending Mode', Variation_1136, 5, 2),
        'TRE': ('Signal for End_of_Track', Variation_1137, 0, 1),
        'GHO': ('Ghost Vs. True Target', Variation_1138, 1, 1),
        'SUP': ('Track Maintained with Track Information from Neighbouring Node B on the Cluster, or Network', Variation_326, 2, 1),
        'TCC': ('Type of Plot Coordinate Transformation Mechanism:', Variation_1139, 3, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_1132]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAD']) -> Type[Variation_1133]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DOU']) -> Type[Variation_1134]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAH']) -> Type[Variation_1135]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CDM']) -> Type[Variation_1136]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRE']) -> Type[Variation_1137]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GHO']) -> Type[Variation_1138]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SUP']) -> Type[Variation_326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCC']) -> Type[Variation_1139]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CNF'], Literal['RAD'], Literal['DOU'], Literal['MAH'], Literal['CDM'], Literal['TRE'], Literal['GHO'], Literal['SUP'], Literal['TCC']]) -> Union[Type['Variation_1132'], Type['Variation_1133'], Type['Variation_1134'], Type['Variation_1135'], Type['Variation_1136'], Type['Variation_1137'], Type['Variation_1138'], Type['Variation_326'], Type['Variation_1139']]:
        if key == 'CNF':
            return Variation_1132
        if key == 'RAD':
            return Variation_1133
        if key == 'DOU':
            return Variation_1134
        if key == 'MAH':
            return Variation_1135
        if key == 'CDM':
            return Variation_1136
        if key == 'TRE':
            return Variation_1137
        if key == 'GHO':
            return Variation_1138
        if key == 'SUP':
            return Variation_326
        if key == 'TCC':
            return Variation_1139
        assert_never(key)

    def __init__(self, arg : Variation_1140_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1140_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_1140_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_1132:
        ...

    @overload
    def get_item(self, name : Literal['RAD']) -> Variation_1133:
        ...

    @overload
    def get_item(self, name : Literal['DOU']) -> Variation_1134:
        ...

    @overload
    def get_item(self, name : Literal['MAH']) -> Variation_1135:
        ...

    @overload
    def get_item(self, name : Literal['CDM']) -> Variation_1136:
        ...

    @overload
    def get_item(self, name : Literal['TRE']) -> Variation_1137:
        ...

    @overload
    def get_item(self, name : Literal['GHO']) -> Variation_1138:
        ...

    @overload
    def get_item(self, name : Literal['SUP']) -> Variation_326:
        ...

    @overload
    def get_item(self, name : Literal['TCC']) -> Variation_1139:
        ...

    def get_item(self, name : Union[Literal['CNF'], Literal['RAD'], Literal['DOU'], Literal['MAH'], Literal['CDM'], Literal['TRE'], Literal['GHO'], Literal['SUP'], Literal['TCC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_1132, Variation_1132_Arg]) -> 'Variation_1140':
        ...

    @overload
    def set_item(self, name : Literal['RAD'], val : Union[Variation_1133, Variation_1133_Arg]) -> 'Variation_1140':
        ...

    @overload
    def set_item(self, name : Literal['DOU'], val : Union[Variation_1134, Variation_1134_Arg]) -> 'Variation_1140':
        ...

    @overload
    def set_item(self, name : Literal['MAH'], val : Union[Variation_1135, Variation_1135_Arg]) -> 'Variation_1140':
        ...

    @overload
    def set_item(self, name : Literal['CDM'], val : Union[Variation_1136, Variation_1136_Arg]) -> 'Variation_1140':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_1140':
        ...

    @overload
    def modify_item(self, name : Literal['RAD'], f : Any) -> 'Variation_1140':
        ...

    @overload
    def modify_item(self, name : Literal['DOU'], f : Any) -> 'Variation_1140':
        ...

    @overload
    def modify_item(self, name : Literal['MAH'], f : Any) -> 'Variation_1140':
        ...

    @overload
    def modify_item(self, name : Literal['CDM'], f : Any) -> 'Variation_1140':
        ...

    @overload
    def modify_item(self, name : Literal['TRE'], f : Any) -> 'Variation_1140':
        ...

    @overload
    def modify_item(self, name : Literal['GHO'], f : Any) -> 'Variation_1140':
        ...

    @overload
    def modify_item(self, name : Literal['SUP'], f : Any) -> 'Variation_1140':
        ...

    @overload
    def modify_item(self, name : Literal['TCC'], f : Any) -> 'Variation_1140':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1141_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM']]]
class Variation_1141(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 7.8125e-3, 'NM')

    def __init__(self, arg : Variation_1141_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1142_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['NM/s']]]
class Variation_1142(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 6.103515625e-5, 'NM/s')

    def __init__(self, arg : Variation_1142_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1143_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_1143(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 8.7890625e-2, '°')

    def __init__(self, arg : Variation_1143_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1144_Arg_Group = TypedDict('Variation_1144_Arg_Group', {
    'SIGX': Union[Variation_1141, Variation_1141_Arg],
    'SIGY': Union[Variation_1141, Variation_1141_Arg],
    'SIGV': Union[Variation_1142, Variation_1142_Arg],
    'SIGH': Union[Variation_1143, Variation_1143_Arg],
})
Variation_1144_Arg : TypeAlias = Union[Raw, Variation_1144_Arg_Group]
class Variation_1144(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('SIGX', Variation_1141),
        ('SIGY', Variation_1141),
        ('SIGV', Variation_1142),
        ('SIGH', Variation_1143),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SIGX': ('Sigma (X)) Standard Deviation on the Horizontal Axis of the Local Grid System', Variation_1141, 0, 8),
        'SIGY': ('Sigma (Y)) Standard Deviation on the Vertical Axis of the Local Grid System', Variation_1141, 8, 8),
        'SIGV': ('Sigma (V)) Standard Deviation on the Groundspeed Within the Local Grid System', Variation_1142, 16, 8),
        'SIGH': ('Sigma (H)) Standard Deviation on the Heading Within the Local Grid System', Variation_1143, 24, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SIGX']) -> Type[Variation_1141]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIGY']) -> Type[Variation_1141]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIGV']) -> Type[Variation_1142]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIGH']) -> Type[Variation_1143]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SIGX'], Literal['SIGY'], Literal['SIGV'], Literal['SIGH']]) -> Union[Type['Variation_1141'], Type['Variation_1141'], Type['Variation_1142'], Type['Variation_1143']]:
        if key == 'SIGX':
            return Variation_1141
        if key == 'SIGY':
            return Variation_1141
        if key == 'SIGV':
            return Variation_1142
        if key == 'SIGH':
            return Variation_1143
        assert_never(key)

    def __init__(self, arg : Variation_1144_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SIGX']) -> Variation_1141:
        ...

    @overload
    def get_item(self, name : Literal['SIGY']) -> Variation_1141:
        ...

    @overload
    def get_item(self, name : Literal['SIGV']) -> Variation_1142:
        ...

    @overload
    def get_item(self, name : Literal['SIGH']) -> Variation_1143:
        ...

    def get_item(self, name : Union[Literal['SIGX'], Literal['SIGY'], Literal['SIGV'], Literal['SIGH']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SIGX'], val : Union[Variation_1141, Variation_1141_Arg]) -> 'Variation_1144':
        ...

    @overload
    def set_item(self, name : Literal['SIGY'], val : Union[Variation_1141, Variation_1141_Arg]) -> 'Variation_1144':
        ...

    @overload
    def set_item(self, name : Literal['SIGV'], val : Union[Variation_1142, Variation_1142_Arg]) -> 'Variation_1144':
        ...

    @overload
    def set_item(self, name : Literal['SIGH'], val : Union[Variation_1143, Variation_1143_Arg]) -> 'Variation_1144':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SIGX'], f : Any) -> 'Variation_1144':
        ...

    @overload
    def modify_item(self, name : Literal['SIGY'], f : Any) -> 'Variation_1144':
        ...

    @overload
    def modify_item(self, name : Literal['SIGV'], f : Any) -> 'Variation_1144':
        ...

    @overload
    def modify_item(self, name : Literal['SIGH'], f : Any) -> 'Variation_1144':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1145_Arg : TypeAlias = Raw
class Variation_1145(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    table = {
        0: 'Not defined; never used',
        1: 'Multipath Reply (Reflection)',
        2: 'Reply due to sidelobe interrogation/reception',
        3: 'Split plot',
        4: 'Second time around reply',
        5: 'Angel',
        6: 'Slow moving target correlated with road infrastructure (terrestrial vehicle)',
        7: 'Fixed PSR plot',
        8: 'Slow PSR target',
        9: 'Low quality PSR plot',
        10: 'Phantom SSR plot',
        11: 'Non-Matching Mode-3/A Code',
        12: 'Mode C code / Mode S altitude code abnormal value compared to the track',
        13: 'Target in Clutter Area',
        14: 'Maximum Doppler Response in Zero Filter',
        15: 'Transponder anomaly detected',
        16: 'Duplicated or Illegal Mode S Aircraft Address',
        17: 'Mode S error correction applied',
        18: 'Undecodable Mode C code / Mode S altitude code',
        19: 'Birds',
        20: 'Flock of Birds',
        21: 'Mode-1 was present in original reply',
        22: 'Mode-2 was present in original reply',
        23: 'Plot potentially caused by Wind Turbine',
        24: 'Helicopter',
        25: 'Maximum number of re-interrogations reached (surveillance information)',
        26: 'Maximum number of re-interrogations reached (BDS Extractions)',
        27: 'BDS Overlay Incoherence',
        28: 'Potential BDS Swap Detected',
        29: 'Track Update in the Zenithal Gap',
        30: 'Mode S Track re-acquired',
        31: 'Duplicated Mode 5 Pair NO/PIN detected',
    }

    def __init__(self, arg : Variation_1145_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1146_Arg : TypeAlias = Union[Variation_1145, Variation_1145_Arg]
class Variation_1146(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = None
    variation_bit_size = 7
    variation_type = Variation_1145

    @classmethod
    def spec(cls) -> Type[Variation_1145]:
        return Variation_1145

    def __init__(self, arg : List[Union[Variation_1145, Variation_1145_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1145, Variation_1145_Arg]) -> 'Variation_1146':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1145, Variation_1145_Arg]) -> 'Variation_1146':
        return self._prepend_item(arg) # type: ignore

Variation_1147_Arg_Group = TypedDict('Variation_1147_Arg_Group', {
    '3DH': Union[Variation_1057, Variation_1057_Arg],
})
Variation_1147_Arg : TypeAlias = Union[Raw, Variation_1147_Arg_Group]
class Variation_1147(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 2),
        ('3DH', Variation_1057),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        '3DH': ('3D Height, in Binary Notation. Negative Values Are Expressed in Two\'s Complement', Variation_1057, 2, 14),
    }


    @classmethod
    def spec(cls, key : Union[Literal['3DH']]) -> Union[Type['Variation_1057']]:
        if key == '3DH':
            return Variation_1057
        assert_never(key)

    def __init__(self, arg : Variation_1147_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['3DH']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['3DH'], val : Union[Variation_1057, Variation_1057_Arg]) -> 'Variation_1147':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['3DH'], f : Any) -> 'Variation_1147':
        return self._modify_item(name, f) # type: ignore

Variation_1148_Arg : TypeAlias = Raw
class Variation_1148(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Doppler speed is valid',
        1: 'Doppler speed is doubtful',
    }

    def __init__(self, arg : Variation_1148_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1149_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_1149(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 10
    quantity = Quantity('Signed', 1.0, 'm/s')

    def __init__(self, arg : Variation_1149_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1150_Arg_Group = TypedDict('Variation_1150_Arg_Group', {
    'D': Union[Variation_1148, Variation_1148_Arg],
    'CAL': Union[Variation_1149, Variation_1149_Arg],
})
Variation_1150_Arg : TypeAlias = Union[Raw, Variation_1150_Arg_Group]
class Variation_1150(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('D', Variation_1148),
        Spare(1, 5),
        ('CAL', Variation_1149),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'D': ('', Variation_1148, 0, 1),
        'CAL': ('Calculated Doppler Speed, Coded in Two\'s Complement', Variation_1149, 6, 10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['D']) -> Type[Variation_1148]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CAL']) -> Type[Variation_1149]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['D'], Literal['CAL']]) -> Union[Type['Variation_1148'], Type['Variation_1149']]:
        if key == 'D':
            return Variation_1148
        if key == 'CAL':
            return Variation_1149
        assert_never(key)

    def __init__(self, arg : Variation_1150_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['D']) -> Variation_1148:
        ...

    @overload
    def get_item(self, name : Literal['CAL']) -> Variation_1149:
        ...

    def get_item(self, name : Union[Literal['D'], Literal['CAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['D'], val : Union[Variation_1148, Variation_1148_Arg]) -> 'Variation_1150':
        ...

    @overload
    def set_item(self, name : Literal['CAL'], val : Union[Variation_1149, Variation_1149_Arg]) -> 'Variation_1150':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['D'], f : Any) -> 'Variation_1150':
        ...

    @overload
    def modify_item(self, name : Literal['CAL'], f : Any) -> 'Variation_1150':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1151_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_1151(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0, 'm/s')

    def __init__(self, arg : Variation_1151_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1152_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['MHz']]]
class Variation_1152(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0, 'MHz')

    def __init__(self, arg : Variation_1152_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1153_Arg_Group = TypedDict('Variation_1153_Arg_Group', {
    'DOP': Union[Variation_1151, Variation_1151_Arg],
    'AMB': Union[Variation_1151, Variation_1151_Arg],
    'FRQ': Union[Variation_1152, Variation_1152_Arg],
})
Variation_1153_Arg : TypeAlias = Union[Raw, Variation_1153_Arg_Group]
class Variation_1153(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('DOP', Variation_1151),
        ('AMB', Variation_1151),
        ('FRQ', Variation_1152),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'DOP': ('Doppler Speed', Variation_1151, 0, 16),
        'AMB': ('Ambiguity Range', Variation_1151, 16, 16),
        'FRQ': ('Transmitter Frequency', Variation_1152, 32, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['DOP']) -> Type[Variation_1151]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AMB']) -> Type[Variation_1151]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FRQ']) -> Type[Variation_1152]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['DOP'], Literal['AMB'], Literal['FRQ']]) -> Union[Type['Variation_1151'], Type['Variation_1151'], Type['Variation_1152']]:
        if key == 'DOP':
            return Variation_1151
        if key == 'AMB':
            return Variation_1151
        if key == 'FRQ':
            return Variation_1152
        assert_never(key)

    def __init__(self, arg : Variation_1153_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['DOP']) -> Variation_1151:
        ...

    @overload
    def get_item(self, name : Literal['AMB']) -> Variation_1151:
        ...

    @overload
    def get_item(self, name : Literal['FRQ']) -> Variation_1152:
        ...

    def get_item(self, name : Union[Literal['DOP'], Literal['AMB'], Literal['FRQ']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['DOP'], val : Union[Variation_1151, Variation_1151_Arg]) -> 'Variation_1153':
        ...

    @overload
    def set_item(self, name : Literal['AMB'], val : Union[Variation_1151, Variation_1151_Arg]) -> 'Variation_1153':
        ...

    @overload
    def set_item(self, name : Literal['FRQ'], val : Union[Variation_1152, Variation_1152_Arg]) -> 'Variation_1153':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['DOP'], f : Any) -> 'Variation_1153':
        ...

    @overload
    def modify_item(self, name : Literal['AMB'], f : Any) -> 'Variation_1153':
        ...

    @overload
    def modify_item(self, name : Literal['FRQ'], f : Any) -> 'Variation_1153':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1154_Arg : TypeAlias = Union[Variation_1153, Variation_1153_Arg]
class Variation_1154(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 48
    variation_type = Variation_1153

    @classmethod
    def spec(cls) -> Type[Variation_1153]:
        return Variation_1153

    def __init__(self, arg : List[Union[Variation_1153, Variation_1153_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1153, Variation_1153_Arg]) -> 'Variation_1154':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1153, Variation_1153_Arg]) -> 'Variation_1154':
        return self._prepend_item(arg) # type: ignore

Variation_1155_Arg = TypedDict('Variation_1155_Arg', {
    'CAL': Union[Variation_1150, Variation_1150_Arg],
    'RDS': Union[Variation_1154, Variation_1154_Arg],
}, total=False)
class Variation_1155(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('CAL', Variation_1150),
        ('RDS', Variation_1154),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'CAL': ('Calculated Doppler Speed', Variation_1150, 0x80),
        'RDS': ('Raw Doppler Speed', Variation_1154, 0x40),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CAL']) -> Type[Variation_1150]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RDS']) -> Type[Variation_1154]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CAL'], Literal['RDS']]) -> Union[Type['Variation_1150'], Type['Variation_1154']]:
        if key == 'CAL':
            return Variation_1150
        if key == 'RDS':
            return Variation_1154
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1155_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['CAL'], val : Union[Variation_1150, Variation_1150_Arg]) -> 'Variation_1155':
        ...

    @overload
    def set_item(self, name : Literal['RDS'], val : Union[Variation_1154, Variation_1154_Arg]) -> 'Variation_1155':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['CAL']) -> 'Variation_1155':
        ...

    @overload
    def del_item(self, name : Literal['RDS']) -> 'Variation_1155':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['CAL']) -> Variation_1150:
        ...

    @overload
    def get_item(self, name : Literal['RDS']) -> Variation_1154:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['CAL'], f : Any) -> 'Variation_1155':
        ...

    @overload
    def modify_item(self, name : Literal['RDS'], f : Any) -> 'Variation_1155':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1156_Arg : TypeAlias = Raw
class Variation_1156(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: 'No communications capability (surveillance only)',
        1: 'Comm. A and Comm. B capability',
        2: 'Comm. A, Comm. B and Uplink ELM',
        3: 'Comm. A, Comm. B, Uplink ELM and Downlink ELM',
        4: 'Level 5 Transponder capability',
    }

    def __init__(self, arg : Variation_1156_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1157_Arg : TypeAlias = Raw
class Variation_1157(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 3
    table = {
        0: 'No alert, no SPI, aircraft airborne',
        1: 'No alert, no SPI, aircraft on ground',
        2: 'Alert, no SPI, aircraft airborne',
        3: 'Alert, no SPI, aircraft on ground',
        4: 'Alert, SPI, aircraft airborne or on ground',
        5: 'No alert, SPI, aircraft airborne or on ground',
        7: 'Unknown',
    }

    def __init__(self, arg : Variation_1157_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1158_Arg : TypeAlias = Raw
class Variation_1158(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'SI-Code Capable',
        1: 'II-Code Capable',
    }

    def __init__(self, arg : Variation_1158_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1159_Arg_Group = TypedDict('Variation_1159_Arg_Group', {
    'COM': Union[Variation_1156, Variation_1156_Arg],
    'STAT': Union[Variation_1157, Variation_1157_Arg],
    'SI': Union[Variation_1158, Variation_1158_Arg],
    'MSSC': Union[Variation_324, Variation_324_Arg],
    'ARC': Union[Variation_325, Variation_325_Arg],
    'AIC': Union[Variation_326, Variation_326_Arg],
    'B1A': Union[Variation_237, Variation_237_Arg],
    'B1B': Union[Variation_282, Variation_282_Arg],
})
Variation_1159_Arg : TypeAlias = Union[Raw, Variation_1159_Arg_Group]
class Variation_1159(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('COM', Variation_1156),
        ('STAT', Variation_1157),
        ('SI', Variation_1158),
        Spare(7, 1),
        ('MSSC', Variation_324),
        ('ARC', Variation_325),
        ('AIC', Variation_326),
        ('B1A', Variation_237),
        ('B1B', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COM': ('Communications Capability of the Transponder', Variation_1156, 0, 3),
        'STAT': ('Flight Status', Variation_1157, 3, 3),
        'SI': ('SI/II Transponder Capability', Variation_1158, 6, 1),
        'MSSC': ('Mode-S Specific Service Capability', Variation_324, 8, 1),
        'ARC': ('Altitude Reporting Capability', Variation_325, 9, 1),
        'AIC': ('Aircraft Identification Capability', Variation_326, 10, 1),
        'B1A': ('BDS 1,0 Bit 16', Variation_237, 11, 1),
        'B1B': ('BDS 1,0 Bits 37/40', Variation_282, 12, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_1156]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STAT']) -> Type[Variation_1157]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SI']) -> Type[Variation_1158]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSSC']) -> Type[Variation_324]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_325]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AIC']) -> Type[Variation_326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1A']) -> Type[Variation_237]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1B']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COM'], Literal['STAT'], Literal['SI'], Literal['MSSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B']]) -> Union[Type['Variation_1156'], Type['Variation_1157'], Type['Variation_1158'], Type['Variation_324'], Type['Variation_325'], Type['Variation_326'], Type['Variation_237'], Type['Variation_282']]:
        if key == 'COM':
            return Variation_1156
        if key == 'STAT':
            return Variation_1157
        if key == 'SI':
            return Variation_1158
        if key == 'MSSC':
            return Variation_324
        if key == 'ARC':
            return Variation_325
        if key == 'AIC':
            return Variation_326
        if key == 'B1A':
            return Variation_237
        if key == 'B1B':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_1159_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_1156:
        ...

    @overload
    def get_item(self, name : Literal['STAT']) -> Variation_1157:
        ...

    @overload
    def get_item(self, name : Literal['SI']) -> Variation_1158:
        ...

    @overload
    def get_item(self, name : Literal['MSSC']) -> Variation_324:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_325:
        ...

    @overload
    def get_item(self, name : Literal['AIC']) -> Variation_326:
        ...

    @overload
    def get_item(self, name : Literal['B1A']) -> Variation_237:
        ...

    @overload
    def get_item(self, name : Literal['B1B']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['COM'], Literal['STAT'], Literal['SI'], Literal['MSSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_1156, Variation_1156_Arg]) -> 'Variation_1159':
        ...

    @overload
    def set_item(self, name : Literal['STAT'], val : Union[Variation_1157, Variation_1157_Arg]) -> 'Variation_1159':
        ...

    @overload
    def set_item(self, name : Literal['SI'], val : Union[Variation_1158, Variation_1158_Arg]) -> 'Variation_1159':
        ...

    @overload
    def set_item(self, name : Literal['MSSC'], val : Union[Variation_324, Variation_324_Arg]) -> 'Variation_1159':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_325, Variation_325_Arg]) -> 'Variation_1159':
        ...

    @overload
    def set_item(self, name : Literal['AIC'], val : Union[Variation_326, Variation_326_Arg]) -> 'Variation_1159':
        ...

    @overload
    def set_item(self, name : Literal['B1A'], val : Union[Variation_237, Variation_237_Arg]) -> 'Variation_1159':
        ...

    @overload
    def set_item(self, name : Literal['B1B'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_1159':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1159':
        ...

    @overload
    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_1159':
        ...

    @overload
    def modify_item(self, name : Literal['SI'], f : Any) -> 'Variation_1159':
        ...

    @overload
    def modify_item(self, name : Literal['MSSC'], f : Any) -> 'Variation_1159':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_1159':
        ...

    @overload
    def modify_item(self, name : Literal['AIC'], f : Any) -> 'Variation_1159':
        ...

    @overload
    def modify_item(self, name : Literal['B1A'], f : Any) -> 'Variation_1159':
        ...

    @overload
    def modify_item(self, name : Literal['B1B'], f : Any) -> 'Variation_1159':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1160_Arg : TypeAlias = Raw
class Variation_1160(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode-1 code as derived from the reply of the transponder',
        1: 'Smoothed Mode-1 code as provided by a local tracker',
    }

    def __init__(self, arg : Variation_1160_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1161_Arg_Group = TypedDict('Variation_1161_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_1160, Variation_1160_Arg],
    'MODE1': Union[Variation_375, Variation_375_Arg],
})
Variation_1161_Arg : TypeAlias = Union[Raw, Variation_1161_Arg_Group]
class Variation_1161(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_1160),
        ('MODE1', Variation_375),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('', Variation_16, 0, 1),
        'G': ('', Variation_17, 1, 1),
        'L': ('', Variation_1160, 2, 1),
        'MODE1': ('Mode-1 Code', Variation_375, 3, 5),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_1160]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE1']) -> Type[Variation_375]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE1']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_1160'], Type['Variation_375']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_1160
        if key == 'MODE1':
            return Variation_375
        assert_never(key)

    def __init__(self, arg : Variation_1161_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_1160:
        ...

    @overload
    def get_item(self, name : Literal['MODE1']) -> Variation_375:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_1161':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_1161':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_1160, Variation_1160_Arg]) -> 'Variation_1161':
        ...

    @overload
    def set_item(self, name : Literal['MODE1'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_1161':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_1161':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_1161':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_1161':
        ...

    @overload
    def modify_item(self, name : Literal['MODE1'], f : Any) -> 'Variation_1161':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1162_Arg : TypeAlias = Raw
class Variation_1162(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'High quality pulse A4',
        1: 'Low quality pulse A4',
    }

    def __init__(self, arg : Variation_1162_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1163_Arg : TypeAlias = Raw
class Variation_1163(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'High quality pulse A2',
        1: 'Low quality pulse A2',
    }

    def __init__(self, arg : Variation_1163_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1164_Arg : TypeAlias = Raw
class Variation_1164(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'High quality pulse B2',
        1: 'Low quality pulse B2',
    }

    def __init__(self, arg : Variation_1164_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1165_Arg : TypeAlias = Raw
class Variation_1165(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'High quality pulse B1',
        1: 'Low quality pulse B1',
    }

    def __init__(self, arg : Variation_1165_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1166_Arg_Group = TypedDict('Variation_1166_Arg_Group', {
    'QA4': Union[Variation_1162, Variation_1162_Arg],
    'QA2': Union[Variation_1163, Variation_1163_Arg],
    'QA1': Union[Variation_44, Variation_44_Arg],
    'QB2': Union[Variation_1164, Variation_1164_Arg],
    'QB1': Union[Variation_1165, Variation_1165_Arg],
})
Variation_1166_Arg : TypeAlias = Union[Raw, Variation_1166_Arg_Group]
class Variation_1166(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 3),
        ('QA4', Variation_1162),
        ('QA2', Variation_1163),
        ('QA1', Variation_44),
        ('QB2', Variation_1164),
        ('QB1', Variation_1165),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'QA4': ('', Variation_1162, 3, 1),
        'QA2': ('', Variation_1163, 4, 1),
        'QA1': ('', Variation_44, 5, 1),
        'QB2': ('', Variation_1164, 6, 1),
        'QB1': ('', Variation_1165, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['QA4']) -> Type[Variation_1162]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA2']) -> Type[Variation_1163]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QA1']) -> Type[Variation_44]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB2']) -> Type[Variation_1164]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['QB1']) -> Type[Variation_1165]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['QA4'], Literal['QA2'], Literal['QA1'], Literal['QB2'], Literal['QB1']]) -> Union[Type['Variation_1162'], Type['Variation_1163'], Type['Variation_44'], Type['Variation_1164'], Type['Variation_1165']]:
        if key == 'QA4':
            return Variation_1162
        if key == 'QA2':
            return Variation_1163
        if key == 'QA1':
            return Variation_44
        if key == 'QB2':
            return Variation_1164
        if key == 'QB1':
            return Variation_1165
        assert_never(key)

    def __init__(self, arg : Variation_1166_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['QA4']) -> Variation_1162:
        ...

    @overload
    def get_item(self, name : Literal['QA2']) -> Variation_1163:
        ...

    @overload
    def get_item(self, name : Literal['QA1']) -> Variation_44:
        ...

    @overload
    def get_item(self, name : Literal['QB2']) -> Variation_1164:
        ...

    @overload
    def get_item(self, name : Literal['QB1']) -> Variation_1165:
        ...

    def get_item(self, name : Union[Literal['QA4'], Literal['QA2'], Literal['QA1'], Literal['QB2'], Literal['QB1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['QA4'], val : Union[Variation_1162, Variation_1162_Arg]) -> 'Variation_1166':
        ...

    @overload
    def set_item(self, name : Literal['QA2'], val : Union[Variation_1163, Variation_1163_Arg]) -> 'Variation_1166':
        ...

    @overload
    def set_item(self, name : Literal['QA1'], val : Union[Variation_44, Variation_44_Arg]) -> 'Variation_1166':
        ...

    @overload
    def set_item(self, name : Literal['QB2'], val : Union[Variation_1164, Variation_1164_Arg]) -> 'Variation_1166':
        ...

    @overload
    def set_item(self, name : Literal['QB1'], val : Union[Variation_1165, Variation_1165_Arg]) -> 'Variation_1166':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['QA4'], f : Any) -> 'Variation_1166':
        ...

    @overload
    def modify_item(self, name : Literal['QA2'], f : Any) -> 'Variation_1166':
        ...

    @overload
    def modify_item(self, name : Literal['QA1'], f : Any) -> 'Variation_1166':
        ...

    @overload
    def modify_item(self, name : Literal['QB2'], f : Any) -> 'Variation_1166':
        ...

    @overload
    def modify_item(self, name : Literal['QB1'], f : Any) -> 'Variation_1166':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1167_Arg = TypedDict('Variation_1167_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '020': Union[Variation_1123, Variation_1123_Arg],
    '040': Union[Variation_595, Variation_595_Arg],
    '070': Union[Variation_1124, Variation_1124_Arg],
    '090': Union[Variation_1125, Variation_1125_Arg],
    '130': Union[Variation_1128, Variation_1128_Arg],
    '220': Union[Variation_278, Variation_278_Arg],
    '240': Union[Variation_196, Variation_196_Arg],
    '250': Union[Variation_1130, Variation_1130_Arg],
    '161': Union[Variation_651, Variation_651_Arg],
    '042': Union[Variation_1131, Variation_1131_Arg],
    '200': Union[Variation_68, Variation_68_Arg],
    '170': Union[Variation_1140, Variation_1140_Arg],
    '210': Union[Variation_1144, Variation_1144_Arg],
    '030': Union[Variation_1146, Variation_1146_Arg],
    '080': Union[Variation_42, Variation_42_Arg],
    '100': Union[Variation_55, Variation_55_Arg],
    '110': Union[Variation_1147, Variation_1147_Arg],
    '120': Union[Variation_1155, Variation_1155_Arg],
    '230': Union[Variation_1159, Variation_1159_Arg],
    '260': Union[Variation_281, Variation_281_Arg],
    '055': Union[Variation_1161, Variation_1161_Arg],
    '050': Union[Variation_27, Variation_27_Arg],
    '065': Union[Variation_1166, Variation_1166_Arg],
    '060': Union[Variation_42, Variation_42_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
}, total=False)
class Variation_1167(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('140', Variation_80),
        ('020', Variation_1123),
        ('040', Variation_595),
        ('070', Variation_1124),
        ('090', Variation_1125),
        ('130', Variation_1128),
        ('220', Variation_278),
        ('240', Variation_196),
        ('250', Variation_1130),
        ('161', Variation_651),
        ('042', Variation_1131),
        ('200', Variation_68),
        ('170', Variation_1140),
        ('210', Variation_1144),
        ('030', Variation_1146),
        ('080', Variation_42),
        ('100', Variation_55),
        ('110', Variation_1147),
        ('120', Variation_1155),
        ('230', Variation_1159),
        ('260', Variation_281),
        ('055', Variation_1161),
        ('050', Variation_27),
        ('065', Variation_1166),
        ('060', Variation_42),
        ('SP', Variation_62),
        ('RE', Variation_202),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '140': ('Time of Day', Variation_80, 0x40000000),
        '020': ('Target Report Descriptor', Variation_1123, 0x20000000),
        '040': ('Measured Position in Polar Co-ordinates', Variation_595, 0x10000000),
        '070': ('Mode-3/A Code in Octal Representation', Variation_1124, 0x08000000),
        '090': ('Flight Level in Binary Representation', Variation_1125, 0x04000000),
        '130': ('Radar Plot Characteristics', Variation_1128, 0x02000000),
        '220': ('Aircraft Address', Variation_278, 0x01800000),
        '240': ('Aircraft Identification', Variation_196, 0x01400000),
        '250': ('Mode S MB Data', Variation_1130, 0x01200000),
        '161': ('Track Number', Variation_651, 0x01100000),
        '042': ('Calculated Position in Cartesian Co-ordinates', Variation_1131, 0x01080000),
        '200': ('Calculated Track Velocity in Polar Co-ordinates', Variation_68, 0x01040000),
        '170': ('Track Status', Variation_1140, 0x01020000),
        '210': ('Track Quality', Variation_1144, 0x01018000),
        '030': ('Warning/Error Conditions and Target Classification', Variation_1146, 0x01014000),
        '080': ('Mode-3/A Code Confidence Indicator', Variation_42, 0x01012000),
        '100': ('Mode-C Code and Code Confidence Indicator', Variation_55, 0x01011000),
        '110': ('Height Measured by a 3D Radar', Variation_1147, 0x01010800),
        '120': ('Radial Doppler Speed', Variation_1155, 0x01010400),
        '230': ('Communications/ACAS Capability and Flight Status', Variation_1159, 0x01010200),
        '260': ('ACAS Resolution Advisory Report', Variation_281, 0x01010180),
        '055': ('Mode-1 Code in Octal Representation', Variation_1161, 0x01010140),
        '050': ('Mode-2 Code in Octal Representation', Variation_27, 0x01010120),
        '065': ('Mode-1 Code Confidence Indicator', Variation_1166, 0x01010110),
        '060': ('Mode-2 Code Confidence Indicator', Variation_42, 0x01010108),
        'SP': ('Special Purpose Field', Variation_62, 0x01010104),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_1123]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_595]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_1124]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_1125]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_1128]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['240']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_1130]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_651]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_1131]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_68]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_1140]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_1144]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_1146]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_55]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1147]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1155]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_1159]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['055']) -> Type[Variation_1161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_27]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['065']) -> Type[Variation_1166]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['140'], Literal['020'], Literal['040'], Literal['070'], Literal['090'], Literal['130'], Literal['220'], Literal['240'], Literal['250'], Literal['161'], Literal['042'], Literal['200'], Literal['170'], Literal['210'], Literal['030'], Literal['080'], Literal['100'], Literal['110'], Literal['120'], Literal['230'], Literal['260'], Literal['055'], Literal['050'], Literal['065'], Literal['060'], Literal['SP'], Literal['RE']]) -> Union[Type['Variation_1'], Type['Variation_80'], Type['Variation_1123'], Type['Variation_595'], Type['Variation_1124'], Type['Variation_1125'], Type['Variation_1128'], Type['Variation_278'], Type['Variation_196'], Type['Variation_1130'], Type['Variation_651'], Type['Variation_1131'], Type['Variation_68'], Type['Variation_1140'], Type['Variation_1144'], Type['Variation_1146'], Type['Variation_42'], Type['Variation_55'], Type['Variation_1147'], Type['Variation_1155'], Type['Variation_1159'], Type['Variation_281'], Type['Variation_1161'], Type['Variation_27'], Type['Variation_1166'], Type['Variation_42'], Type['Variation_62'], Type['Variation_202']]:
        if key == '010':
            return Variation_1
        if key == '140':
            return Variation_80
        if key == '020':
            return Variation_1123
        if key == '040':
            return Variation_595
        if key == '070':
            return Variation_1124
        if key == '090':
            return Variation_1125
        if key == '130':
            return Variation_1128
        if key == '220':
            return Variation_278
        if key == '240':
            return Variation_196
        if key == '250':
            return Variation_1130
        if key == '161':
            return Variation_651
        if key == '042':
            return Variation_1131
        if key == '200':
            return Variation_68
        if key == '170':
            return Variation_1140
        if key == '210':
            return Variation_1144
        if key == '030':
            return Variation_1146
        if key == '080':
            return Variation_42
        if key == '100':
            return Variation_55
        if key == '110':
            return Variation_1147
        if key == '120':
            return Variation_1155
        if key == '230':
            return Variation_1159
        if key == '260':
            return Variation_281
        if key == '055':
            return Variation_1161
        if key == '050':
            return Variation_27
        if key == '065':
            return Variation_1166
        if key == '060':
            return Variation_42
        if key == 'SP':
            return Variation_62
        if key == 'RE':
            return Variation_202
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1167_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_1123, Variation_1123_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_595, Variation_595_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_1124, Variation_1124_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_1125, Variation_1125_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_1128, Variation_1128_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['240'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_1130, Variation_1130_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_651, Variation_651_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_1131, Variation_1131_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_68, Variation_68_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_1140, Variation_1140_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_1144, Variation_1144_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_1146, Variation_1146_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_55, Variation_55_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1147, Variation_1147_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1155, Variation_1155_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_1159, Variation_1159_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['055'], val : Union[Variation_1161, Variation_1161_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_27, Variation_27_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['065'], val : Union[Variation_1166, Variation_1166_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1167':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1167':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['240']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['055']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['065']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1167':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1167':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_1123:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_595:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_1124:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_1125:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_1128:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['240']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_1130:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_651:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_1131:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_68:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_1140:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_1144:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_1146:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_55:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1147:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1155:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_1159:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['055']) -> Variation_1161:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_27:
        ...

    @overload
    def get_item(self, name : Literal['065']) -> Variation_1166:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['240'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['055'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['065'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1167':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1167':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1168_Arg : TypeAlias = Raw
class Variation_1168(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    table = {
        0: 'Not defined; never used',
        1: 'Multipath Reply (Reflection)',
        2: 'Reply due to sidelobe interrogation/reception',
        3: 'Split plot',
        4: 'Second time around reply',
        5: 'Angel',
        6: 'Slow moving target correlated with road infrastructure (terrestrial vehicle)',
        7: 'Fixed PSR plot',
        8: 'Slow PSR target',
        9: 'Low quality PSR plot',
        10: 'Phantom SSR plot',
        11: 'Non-Matching Mode-3/A Code',
        12: 'Mode C code / Mode S altitude code abnormal value compared to the track',
        13: 'Target in Clutter Area',
        14: 'Maximum Doppler Response in Zero Filter',
        15: 'Transponder anomaly detected',
        16: 'Duplicated or Illegal Mode S Aircraft Address',
        17: 'Mode S error correction applied',
        18: 'Undecodable Mode C code / Mode S altitude code',
        19: 'Birds',
        20: 'Flock of Birds',
        21: 'Mode-1 was present in original reply',
        22: 'Mode-2 was present in original reply',
        23: 'Plot potentially caused by Wind Turbine',
        24: 'Helicopter',
        25: 'Maximum number of re-interrogations reached (surveillance information)',
        26: 'Maximum number of re-interrogations reached (BDS Extractions)',
        27: 'BDS Overlay Incoherence',
        28: 'Potential BDS Swap Detected',
        29: 'Track Update in the Zenithal Gap',
        30: 'Mode S Track re-acquired',
        31: 'Duplicated Mode 5 Pair NO/PIN detected',
        32: 'Wrong DF reply format detected',
        33: 'Transponder anomaly (MS XPD replies with Mode A/C to Mode A/C-only all-call)',
        34: 'Transponder anomaly (SI capability report wrong)',
    }

    def __init__(self, arg : Variation_1168_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1169_Arg : TypeAlias = Union[Variation_1168, Variation_1168_Arg]
class Variation_1169(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = None
    variation_bit_size = 7
    variation_type = Variation_1168

    @classmethod
    def spec(cls) -> Type[Variation_1168]:
        return Variation_1168

    def __init__(self, arg : List[Union[Variation_1168, Variation_1168_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1168, Variation_1168_Arg]) -> 'Variation_1169':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1168, Variation_1168_Arg]) -> 'Variation_1169':
        return self._prepend_item(arg) # type: ignore

Variation_1170_Arg = TypedDict('Variation_1170_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '020': Union[Variation_1123, Variation_1123_Arg],
    '040': Union[Variation_595, Variation_595_Arg],
    '070': Union[Variation_1124, Variation_1124_Arg],
    '090': Union[Variation_1125, Variation_1125_Arg],
    '130': Union[Variation_1128, Variation_1128_Arg],
    '220': Union[Variation_278, Variation_278_Arg],
    '240': Union[Variation_196, Variation_196_Arg],
    '250': Union[Variation_1130, Variation_1130_Arg],
    '161': Union[Variation_651, Variation_651_Arg],
    '042': Union[Variation_1131, Variation_1131_Arg],
    '200': Union[Variation_68, Variation_68_Arg],
    '170': Union[Variation_1140, Variation_1140_Arg],
    '210': Union[Variation_1144, Variation_1144_Arg],
    '030': Union[Variation_1169, Variation_1169_Arg],
    '080': Union[Variation_42, Variation_42_Arg],
    '100': Union[Variation_55, Variation_55_Arg],
    '110': Union[Variation_1147, Variation_1147_Arg],
    '120': Union[Variation_1155, Variation_1155_Arg],
    '230': Union[Variation_1159, Variation_1159_Arg],
    '260': Union[Variation_281, Variation_281_Arg],
    '055': Union[Variation_1161, Variation_1161_Arg],
    '050': Union[Variation_27, Variation_27_Arg],
    '065': Union[Variation_1166, Variation_1166_Arg],
    '060': Union[Variation_42, Variation_42_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
}, total=False)
class Variation_1170(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('140', Variation_80),
        ('020', Variation_1123),
        ('040', Variation_595),
        ('070', Variation_1124),
        ('090', Variation_1125),
        ('130', Variation_1128),
        ('220', Variation_278),
        ('240', Variation_196),
        ('250', Variation_1130),
        ('161', Variation_651),
        ('042', Variation_1131),
        ('200', Variation_68),
        ('170', Variation_1140),
        ('210', Variation_1144),
        ('030', Variation_1169),
        ('080', Variation_42),
        ('100', Variation_55),
        ('110', Variation_1147),
        ('120', Variation_1155),
        ('230', Variation_1159),
        ('260', Variation_281),
        ('055', Variation_1161),
        ('050', Variation_27),
        ('065', Variation_1166),
        ('060', Variation_42),
        ('SP', Variation_62),
        ('RE', Variation_202),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '140': ('Time of Day', Variation_80, 0x40000000),
        '020': ('Target Report Descriptor', Variation_1123, 0x20000000),
        '040': ('Measured Position in Polar Co-ordinates', Variation_595, 0x10000000),
        '070': ('Mode-3/A Code in Octal Representation', Variation_1124, 0x08000000),
        '090': ('Flight Level in Binary Representation', Variation_1125, 0x04000000),
        '130': ('Radar Plot Characteristics', Variation_1128, 0x02000000),
        '220': ('Aircraft Address', Variation_278, 0x01800000),
        '240': ('Aircraft Identification', Variation_196, 0x01400000),
        '250': ('Mode S MB Data', Variation_1130, 0x01200000),
        '161': ('Track Number', Variation_651, 0x01100000),
        '042': ('Calculated Position in Cartesian Co-ordinates', Variation_1131, 0x01080000),
        '200': ('Calculated Track Velocity in Polar Co-ordinates', Variation_68, 0x01040000),
        '170': ('Track Status', Variation_1140, 0x01020000),
        '210': ('Track Quality', Variation_1144, 0x01018000),
        '030': ('Warning/Error Conditions and Target Classification', Variation_1169, 0x01014000),
        '080': ('Mode-3/A Code Confidence Indicator', Variation_42, 0x01012000),
        '100': ('Mode-C Code and Code Confidence Indicator', Variation_55, 0x01011000),
        '110': ('Height Measured by a 3D Radar', Variation_1147, 0x01010800),
        '120': ('Radial Doppler Speed', Variation_1155, 0x01010400),
        '230': ('Communications/ACAS Capability and Flight Status', Variation_1159, 0x01010200),
        '260': ('ACAS Resolution Advisory Report', Variation_281, 0x01010180),
        '055': ('Mode-1 Code in Octal Representation', Variation_1161, 0x01010140),
        '050': ('Mode-2 Code in Octal Representation', Variation_27, 0x01010120),
        '065': ('Mode-1 Code Confidence Indicator', Variation_1166, 0x01010110),
        '060': ('Mode-2 Code Confidence Indicator', Variation_42, 0x01010108),
        'SP': ('Special Purpose Field', Variation_62, 0x01010104),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_1123]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_595]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_1124]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_1125]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_1128]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['240']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_1130]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_651]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_1131]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_68]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_1140]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_1144]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_1169]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_55]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1147]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1155]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_1159]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['055']) -> Type[Variation_1161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_27]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['065']) -> Type[Variation_1166]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['140'], Literal['020'], Literal['040'], Literal['070'], Literal['090'], Literal['130'], Literal['220'], Literal['240'], Literal['250'], Literal['161'], Literal['042'], Literal['200'], Literal['170'], Literal['210'], Literal['030'], Literal['080'], Literal['100'], Literal['110'], Literal['120'], Literal['230'], Literal['260'], Literal['055'], Literal['050'], Literal['065'], Literal['060'], Literal['SP'], Literal['RE']]) -> Union[Type['Variation_1'], Type['Variation_80'], Type['Variation_1123'], Type['Variation_595'], Type['Variation_1124'], Type['Variation_1125'], Type['Variation_1128'], Type['Variation_278'], Type['Variation_196'], Type['Variation_1130'], Type['Variation_651'], Type['Variation_1131'], Type['Variation_68'], Type['Variation_1140'], Type['Variation_1144'], Type['Variation_1169'], Type['Variation_42'], Type['Variation_55'], Type['Variation_1147'], Type['Variation_1155'], Type['Variation_1159'], Type['Variation_281'], Type['Variation_1161'], Type['Variation_27'], Type['Variation_1166'], Type['Variation_42'], Type['Variation_62'], Type['Variation_202']]:
        if key == '010':
            return Variation_1
        if key == '140':
            return Variation_80
        if key == '020':
            return Variation_1123
        if key == '040':
            return Variation_595
        if key == '070':
            return Variation_1124
        if key == '090':
            return Variation_1125
        if key == '130':
            return Variation_1128
        if key == '220':
            return Variation_278
        if key == '240':
            return Variation_196
        if key == '250':
            return Variation_1130
        if key == '161':
            return Variation_651
        if key == '042':
            return Variation_1131
        if key == '200':
            return Variation_68
        if key == '170':
            return Variation_1140
        if key == '210':
            return Variation_1144
        if key == '030':
            return Variation_1169
        if key == '080':
            return Variation_42
        if key == '100':
            return Variation_55
        if key == '110':
            return Variation_1147
        if key == '120':
            return Variation_1155
        if key == '230':
            return Variation_1159
        if key == '260':
            return Variation_281
        if key == '055':
            return Variation_1161
        if key == '050':
            return Variation_27
        if key == '065':
            return Variation_1166
        if key == '060':
            return Variation_42
        if key == 'SP':
            return Variation_62
        if key == 'RE':
            return Variation_202
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1170_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_1123, Variation_1123_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_595, Variation_595_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_1124, Variation_1124_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_1125, Variation_1125_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_1128, Variation_1128_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['240'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_1130, Variation_1130_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_651, Variation_651_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_1131, Variation_1131_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_68, Variation_68_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_1140, Variation_1140_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_1144, Variation_1144_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_1169, Variation_1169_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_55, Variation_55_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1147, Variation_1147_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1155, Variation_1155_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_1159, Variation_1159_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['055'], val : Union[Variation_1161, Variation_1161_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_27, Variation_27_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['065'], val : Union[Variation_1166, Variation_1166_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1170':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1170':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['240']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['055']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['065']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1170':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1170':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_1123:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_595:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_1124:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_1125:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_1128:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['240']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_1130:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_651:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_1131:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_68:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_1140:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_1144:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_1169:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_55:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1147:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1155:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_1159:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['055']) -> Variation_1161:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_27:
        ...

    @overload
    def get_item(self, name : Literal['065']) -> Variation_1166:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['240'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['055'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['065'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1170':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1170':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1171_Arg = TypedDict('Variation_1171_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '020': Union[Variation_1123, Variation_1123_Arg],
    '040': Union[Variation_595, Variation_595_Arg],
    '070': Union[Variation_1124, Variation_1124_Arg],
    '090': Union[Variation_1125, Variation_1125_Arg],
    '130': Union[Variation_1128, Variation_1128_Arg],
    '220': Union[Variation_278, Variation_278_Arg],
    '240': Union[Variation_196, Variation_196_Arg],
    '250': Union[Variation_1130, Variation_1130_Arg],
    '161': Union[Variation_651, Variation_651_Arg],
    '042': Union[Variation_1131, Variation_1131_Arg],
    '200': Union[Variation_68, Variation_68_Arg],
    '170': Union[Variation_1140, Variation_1140_Arg],
    '210': Union[Variation_1144, Variation_1144_Arg],
    '030': Union[Variation_1169, Variation_1169_Arg],
    '080': Union[Variation_42, Variation_42_Arg],
    '100': Union[Variation_55, Variation_55_Arg],
    '110': Union[Variation_1147, Variation_1147_Arg],
    '120': Union[Variation_1155, Variation_1155_Arg],
    '230': Union[Variation_1159, Variation_1159_Arg],
    '260': Union[Variation_281, Variation_281_Arg],
    '055': Union[Variation_1161, Variation_1161_Arg],
    '050': Union[Variation_27, Variation_27_Arg],
    '065': Union[Variation_1166, Variation_1166_Arg],
    '060': Union[Variation_42, Variation_42_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
}, total=False)
class Variation_1171(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('140', Variation_80),
        ('020', Variation_1123),
        ('040', Variation_595),
        ('070', Variation_1124),
        ('090', Variation_1125),
        ('130', Variation_1128),
        ('220', Variation_278),
        ('240', Variation_196),
        ('250', Variation_1130),
        ('161', Variation_651),
        ('042', Variation_1131),
        ('200', Variation_68),
        ('170', Variation_1140),
        ('210', Variation_1144),
        ('030', Variation_1169),
        ('080', Variation_42),
        ('100', Variation_55),
        ('110', Variation_1147),
        ('120', Variation_1155),
        ('230', Variation_1159),
        ('260', Variation_281),
        ('055', Variation_1161),
        ('050', Variation_27),
        ('065', Variation_1166),
        ('060', Variation_42),
        ('SP', Variation_62),
        ('RE', Variation_202),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '140': ('Time of Day', Variation_80, 0x40000000),
        '020': ('Target Report Descriptor', Variation_1123, 0x20000000),
        '040': ('Measured Position in Polar Co-ordinates', Variation_595, 0x10000000),
        '070': ('Mode-3/A Code in Octal Representation', Variation_1124, 0x08000000),
        '090': ('Flight Level in Binary Representation', Variation_1125, 0x04000000),
        '130': ('Radar Plot Characteristics', Variation_1128, 0x02000000),
        '220': ('Aircraft Address', Variation_278, 0x01800000),
        '240': ('Aircraft Identification', Variation_196, 0x01400000),
        '250': ('BDS Register Data', Variation_1130, 0x01200000),
        '161': ('Track Number', Variation_651, 0x01100000),
        '042': ('Calculated Position in Cartesian Co-ordinates', Variation_1131, 0x01080000),
        '200': ('Calculated Track Velocity in Polar Co-ordinates', Variation_68, 0x01040000),
        '170': ('Track Status', Variation_1140, 0x01020000),
        '210': ('Track Quality', Variation_1144, 0x01018000),
        '030': ('Warning/Error Conditions and Target Classification', Variation_1169, 0x01014000),
        '080': ('Mode-3/A Code Confidence Indicator', Variation_42, 0x01012000),
        '100': ('Mode-C Code and Code Confidence Indicator', Variation_55, 0x01011000),
        '110': ('Height Measured by a 3D Radar', Variation_1147, 0x01010800),
        '120': ('Radial Doppler Speed', Variation_1155, 0x01010400),
        '230': ('Communications/ACAS Capability and Flight Status', Variation_1159, 0x01010200),
        '260': ('ACAS Resolution Advisory Report', Variation_281, 0x01010180),
        '055': ('Mode-1 Code in Octal Representation', Variation_1161, 0x01010140),
        '050': ('Mode-2 Code in Octal Representation', Variation_27, 0x01010120),
        '065': ('Mode-1 Code Confidence Indicator', Variation_1166, 0x01010110),
        '060': ('Mode-2 Code Confidence Indicator', Variation_42, 0x01010108),
        'SP': ('Special Purpose Field', Variation_62, 0x01010104),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_1123]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_595]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_1124]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_1125]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_1128]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['240']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_1130]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_651]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_1131]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_68]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_1140]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_1144]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_1169]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_55]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1147]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1155]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_1159]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['055']) -> Type[Variation_1161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_27]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['065']) -> Type[Variation_1166]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['140'], Literal['020'], Literal['040'], Literal['070'], Literal['090'], Literal['130'], Literal['220'], Literal['240'], Literal['250'], Literal['161'], Literal['042'], Literal['200'], Literal['170'], Literal['210'], Literal['030'], Literal['080'], Literal['100'], Literal['110'], Literal['120'], Literal['230'], Literal['260'], Literal['055'], Literal['050'], Literal['065'], Literal['060'], Literal['SP'], Literal['RE']]) -> Union[Type['Variation_1'], Type['Variation_80'], Type['Variation_1123'], Type['Variation_595'], Type['Variation_1124'], Type['Variation_1125'], Type['Variation_1128'], Type['Variation_278'], Type['Variation_196'], Type['Variation_1130'], Type['Variation_651'], Type['Variation_1131'], Type['Variation_68'], Type['Variation_1140'], Type['Variation_1144'], Type['Variation_1169'], Type['Variation_42'], Type['Variation_55'], Type['Variation_1147'], Type['Variation_1155'], Type['Variation_1159'], Type['Variation_281'], Type['Variation_1161'], Type['Variation_27'], Type['Variation_1166'], Type['Variation_42'], Type['Variation_62'], Type['Variation_202']]:
        if key == '010':
            return Variation_1
        if key == '140':
            return Variation_80
        if key == '020':
            return Variation_1123
        if key == '040':
            return Variation_595
        if key == '070':
            return Variation_1124
        if key == '090':
            return Variation_1125
        if key == '130':
            return Variation_1128
        if key == '220':
            return Variation_278
        if key == '240':
            return Variation_196
        if key == '250':
            return Variation_1130
        if key == '161':
            return Variation_651
        if key == '042':
            return Variation_1131
        if key == '200':
            return Variation_68
        if key == '170':
            return Variation_1140
        if key == '210':
            return Variation_1144
        if key == '030':
            return Variation_1169
        if key == '080':
            return Variation_42
        if key == '100':
            return Variation_55
        if key == '110':
            return Variation_1147
        if key == '120':
            return Variation_1155
        if key == '230':
            return Variation_1159
        if key == '260':
            return Variation_281
        if key == '055':
            return Variation_1161
        if key == '050':
            return Variation_27
        if key == '065':
            return Variation_1166
        if key == '060':
            return Variation_42
        if key == 'SP':
            return Variation_62
        if key == 'RE':
            return Variation_202
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1171_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_1123, Variation_1123_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_595, Variation_595_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_1124, Variation_1124_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_1125, Variation_1125_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_1128, Variation_1128_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['240'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_1130, Variation_1130_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_651, Variation_651_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_1131, Variation_1131_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_68, Variation_68_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_1140, Variation_1140_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_1144, Variation_1144_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_1169, Variation_1169_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_55, Variation_55_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1147, Variation_1147_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1155, Variation_1155_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_1159, Variation_1159_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['055'], val : Union[Variation_1161, Variation_1161_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_27, Variation_27_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['065'], val : Union[Variation_1166, Variation_1166_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1171':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1171':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['240']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['055']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['065']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1171':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1171':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_1123:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_595:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_1124:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_1125:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_1128:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['240']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_1130:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_651:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_1131:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_68:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_1140:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_1144:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_1169:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_55:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1147:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1155:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_1159:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['055']) -> Variation_1161:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_27:
        ...

    @overload
    def get_item(self, name : Literal['065']) -> Variation_1166:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['240'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['055'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['065'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1171':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1171':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1172_Arg : TypeAlias = Raw
class Variation_1172(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'ADSB not populated',
        1: 'ADSB populated',
    }

    def __init__(self, arg : Variation_1172_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1173_Arg : TypeAlias = Raw
class Variation_1173(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Not available',
        1: 'Available',
    }

    def __init__(self, arg : Variation_1173_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1174_Arg_Group = TypedDict('Variation_1174_Arg_Group', {
    'EP': Union[Variation_1172, Variation_1172_Arg],
    'VAL': Union[Variation_1173, Variation_1173_Arg],
})
Variation_1174_Arg : TypeAlias = Union[Raw, Variation_1174_Arg_Group]
class Variation_1174(Group):
    variation = 'Group'

    bit_size = 2

    subitems_list = [
        ('EP', Variation_1172),
        ('VAL', Variation_1173),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('ADSB Element Populated Bit', Variation_1172, 0, 1),
        'VAL': ('On-Site ADS-B Information', Variation_1173, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_1172]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1173]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_1172'], Type['Variation_1173']]:
        if key == 'EP':
            return Variation_1172
        if key == 'VAL':
            return Variation_1173
        assert_never(key)

    def __init__(self, arg : Variation_1174_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_1172:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1173:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_1172, Variation_1172_Arg]) -> 'Variation_1174':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1173, Variation_1173_Arg]) -> 'Variation_1174':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1174':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1174':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1175_Arg : TypeAlias = Raw
class Variation_1175(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'SCN not populated',
        1: 'SCN populated',
    }

    def __init__(self, arg : Variation_1175_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1176_Arg : TypeAlias = Raw
class Variation_1176(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Not available',
        1: 'Available',
    }

    def __init__(self, arg : Variation_1176_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1177_Arg_Group = TypedDict('Variation_1177_Arg_Group', {
    'EP': Union[Variation_1175, Variation_1175_Arg],
    'VAL': Union[Variation_1176, Variation_1176_Arg],
})
Variation_1177_Arg : TypeAlias = Union[Raw, Variation_1177_Arg_Group]
class Variation_1177(Group):
    variation = 'Group'

    bit_size = 2

    subitems_list = [
        ('EP', Variation_1175),
        ('VAL', Variation_1176),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('SCN Element Populated Bit', Variation_1175, 0, 1),
        'VAL': ('Surveillance Cluster Network Information', Variation_1176, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_1175]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1176]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_1175'], Type['Variation_1176']]:
        if key == 'EP':
            return Variation_1175
        if key == 'VAL':
            return Variation_1176
        assert_never(key)

    def __init__(self, arg : Variation_1177_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_1175:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1176:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_1175, Variation_1175_Arg]) -> 'Variation_1177':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1176, Variation_1176_Arg]) -> 'Variation_1177':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1177':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1177':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1178_Arg : TypeAlias = Raw
class Variation_1178(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'PAI not populated',
        1: 'PAI populated',
    }

    def __init__(self, arg : Variation_1178_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1179_Arg : TypeAlias = Raw
class Variation_1179(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Not available',
        1: 'Available',
    }

    def __init__(self, arg : Variation_1179_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1180_Arg_Group = TypedDict('Variation_1180_Arg_Group', {
    'EP': Union[Variation_1178, Variation_1178_Arg],
    'VAL': Union[Variation_1179, Variation_1179_Arg],
})
Variation_1180_Arg : TypeAlias = Union[Raw, Variation_1180_Arg_Group]
class Variation_1180(Group):
    variation = 'Group'

    bit_size = 2

    subitems_list = [
        ('EP', Variation_1178),
        ('VAL', Variation_1179),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('PAI Element Populated Bit', Variation_1178, 0, 1),
        'VAL': ('Passive Acquisition Interface Information', Variation_1179, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_1178]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1179]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_1178'], Type['Variation_1179']]:
        if key == 'EP':
            return Variation_1178
        if key == 'VAL':
            return Variation_1179
        assert_never(key)

    def __init__(self, arg : Variation_1180_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_1178:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1179:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_1178, Variation_1178_Arg]) -> 'Variation_1180':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1179, Variation_1179_Arg]) -> 'Variation_1180':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1180':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1180':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1181_Arg_Group_1 = TypedDict('Variation_1181_Arg_Group_1', {
    'TYP': Union[Variation_1112, Variation_1112_Arg],
    'SIM': Union[Variation_1113, Variation_1113_Arg],
    'RDP': Union[Variation_1114, Variation_1114_Arg],
    'SPI': Union[Variation_1115, Variation_1115_Arg],
    'RAB': Union[Variation_1116, Variation_1116_Arg],
})
Variation_1181_Arg_Group_2 = TypedDict('Variation_1181_Arg_Group_2', {
    'TYP': Union[Variation_1112, Variation_1112_Arg],
    'SIM': Union[Variation_1113, Variation_1113_Arg],
    'RDP': Union[Variation_1114, Variation_1114_Arg],
    'SPI': Union[Variation_1115, Variation_1115_Arg],
    'RAB': Union[Variation_1116, Variation_1116_Arg],
    'TST': Union[Variation_1117, Variation_1117_Arg],
    'ERR': Union[Variation_1118, Variation_1118_Arg],
    'XPP': Union[Variation_1119, Variation_1119_Arg],
    'ME': Union[Variation_1120, Variation_1120_Arg],
    'MI': Union[Variation_1121, Variation_1121_Arg],
    'FOEFRI': Union[Variation_1122, Variation_1122_Arg],
})
Variation_1181_Arg_Group_3 = TypedDict('Variation_1181_Arg_Group_3', {
    'TYP': Union[Variation_1112, Variation_1112_Arg],
    'SIM': Union[Variation_1113, Variation_1113_Arg],
    'RDP': Union[Variation_1114, Variation_1114_Arg],
    'SPI': Union[Variation_1115, Variation_1115_Arg],
    'RAB': Union[Variation_1116, Variation_1116_Arg],
    'TST': Union[Variation_1117, Variation_1117_Arg],
    'ERR': Union[Variation_1118, Variation_1118_Arg],
    'XPP': Union[Variation_1119, Variation_1119_Arg],
    'ME': Union[Variation_1120, Variation_1120_Arg],
    'MI': Union[Variation_1121, Variation_1121_Arg],
    'FOEFRI': Union[Variation_1122, Variation_1122_Arg],
    'ADSB': Union[Variation_1174, Variation_1174_Arg],
    'SCN': Union[Variation_1177, Variation_1177_Arg],
    'PAI': Union[Variation_1180, Variation_1180_Arg],
})
Variation_1181_Arg : TypeAlias = Union[
    int,
    Variation_1181_Arg_Group_1,
    Tuple[int],
    Variation_1181_Arg_Group_2,
    Tuple[int,int],
    Variation_1181_Arg_Group_3,
    Tuple[int,int,int],
]
class Variation_1181(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('TYP', Variation_1112),
            ('SIM', Variation_1113),
            ('RDP', Variation_1114),
            ('SPI', Variation_1115),
            ('RAB', Variation_1116),
        ],
        [
            ('TST', Variation_1117),
            ('ERR', Variation_1118),
            ('XPP', Variation_1119),
            ('ME', Variation_1120),
            ('MI', Variation_1121),
            ('FOEFRI', Variation_1122),
        ],
        [
            ('ADSB', Variation_1174),
            ('SCN', Variation_1177),
            ('PAI', Variation_1180),
            Spare(6, 1),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('', Variation_1112, 0, 3),
        'SIM': ('', Variation_1113, 3, 1),
        'RDP': ('', Variation_1114, 4, 1),
        'SPI': ('', Variation_1115, 5, 1),
        'RAB': ('', Variation_1116, 6, 1),
        'TST': ('', Variation_1117, 0, 1),
        'ERR': ('', Variation_1118, 1, 1),
        'XPP': ('', Variation_1119, 2, 1),
        'ME': ('', Variation_1120, 3, 1),
        'MI': ('', Variation_1121, 4, 1),
        'FOEFRI': ('', Variation_1122, 5, 2),
        'ADSB': ('On-Site ADS-B Information', Variation_1174, 0, 2),
        'SCN': ('Surveillance Cluster Network Information', Variation_1177, 2, 2),
        'PAI': ('Passive Acquisition Interface Information', Variation_1180, 4, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_1112]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_1113]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RDP']) -> Type[Variation_1114]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_1115]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_1116]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_1117]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ERR']) -> Type[Variation_1118]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XPP']) -> Type[Variation_1119]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ME']) -> Type[Variation_1120]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MI']) -> Type[Variation_1121]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FOEFRI']) -> Type[Variation_1122]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADSB']) -> Type[Variation_1174]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SCN']) -> Type[Variation_1177]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PAI']) -> Type[Variation_1180]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['SIM'], Literal['RDP'], Literal['SPI'], Literal['RAB'], Literal['TST'], Literal['ERR'], Literal['XPP'], Literal['ME'], Literal['MI'], Literal['FOEFRI'], Literal['ADSB'], Literal['SCN'], Literal['PAI']]) -> Union[Type['Variation_1112'], Type['Variation_1113'], Type['Variation_1114'], Type['Variation_1115'], Type['Variation_1116'], Type['Variation_1117'], Type['Variation_1118'], Type['Variation_1119'], Type['Variation_1120'], Type['Variation_1121'], Type['Variation_1122'], Type['Variation_1174'], Type['Variation_1177'], Type['Variation_1180']]:
        if key == 'TYP':
            return Variation_1112
        if key == 'SIM':
            return Variation_1113
        if key == 'RDP':
            return Variation_1114
        if key == 'SPI':
            return Variation_1115
        if key == 'RAB':
            return Variation_1116
        if key == 'TST':
            return Variation_1117
        if key == 'ERR':
            return Variation_1118
        if key == 'XPP':
            return Variation_1119
        if key == 'ME':
            return Variation_1120
        if key == 'MI':
            return Variation_1121
        if key == 'FOEFRI':
            return Variation_1122
        if key == 'ADSB':
            return Variation_1174
        if key == 'SCN':
            return Variation_1177
        if key == 'PAI':
            return Variation_1180
        assert_never(key)

    def __init__(self, arg : Variation_1181_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1181_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_1181_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_1181_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_1112:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_1113:
        ...

    @overload
    def get_item(self, name : Literal['RDP']) -> Variation_1114:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_1115:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_1116:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_1117:
        ...

    @overload
    def get_item(self, name : Literal['ERR']) -> Variation_1118:
        ...

    @overload
    def get_item(self, name : Literal['XPP']) -> Variation_1119:
        ...

    @overload
    def get_item(self, name : Literal['ME']) -> Variation_1120:
        ...

    @overload
    def get_item(self, name : Literal['MI']) -> Variation_1121:
        ...

    @overload
    def get_item(self, name : Literal['FOEFRI']) -> Variation_1122:
        ...

    @overload
    def get_item(self, name : Literal['ADSB']) -> Variation_1174:
        ...

    @overload
    def get_item(self, name : Literal['SCN']) -> Variation_1177:
        ...

    @overload
    def get_item(self, name : Literal['PAI']) -> Variation_1180:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['SIM'], Literal['RDP'], Literal['SPI'], Literal['RAB'], Literal['TST'], Literal['ERR'], Literal['XPP'], Literal['ME'], Literal['MI'], Literal['FOEFRI'], Literal['ADSB'], Literal['SCN'], Literal['PAI']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_1112, Variation_1112_Arg]) -> 'Variation_1181':
        ...

    @overload
    def set_item(self, name : Literal['SIM'], val : Union[Variation_1113, Variation_1113_Arg]) -> 'Variation_1181':
        ...

    @overload
    def set_item(self, name : Literal['RDP'], val : Union[Variation_1114, Variation_1114_Arg]) -> 'Variation_1181':
        ...

    @overload
    def set_item(self, name : Literal['SPI'], val : Union[Variation_1115, Variation_1115_Arg]) -> 'Variation_1181':
        ...

    @overload
    def set_item(self, name : Literal['RAB'], val : Union[Variation_1116, Variation_1116_Arg]) -> 'Variation_1181':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['RDP'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['ERR'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['XPP'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['ME'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['MI'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['FOEFRI'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['ADSB'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['SCN'], f : Any) -> 'Variation_1181':
        ...

    @overload
    def modify_item(self, name : Literal['PAI'], f : Any) -> 'Variation_1181':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1182_Arg : TypeAlias = Raw
class Variation_1182(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 7
    table = {
        0: 'Not defined; never used',
        1: 'Multipath Reply (Reflection)',
        2: 'Reply due to sidelobe interrogation/reception',
        3: 'Split plot',
        4: 'Second time around reply',
        5: 'Angel',
        6: 'Slow moving target correlated with road infrastructure (terrestrial vehicle)',
        7: 'Fixed PSR plot',
        8: 'Slow PSR target',
        9: 'Low quality PSR plot',
        10: 'Phantom SSR plot',
        11: 'Non-Matching Mode-3/A Code',
        12: 'Mode C code / Mode S altitude code abnormal value compared to the track',
        13: 'Target in Clutter Area',
        14: 'Maximum Doppler Response in Zero Filter',
        15: 'Transponder anomaly detected',
        16: 'Duplicated or Illegal Mode S Aircraft Address',
        17: 'Mode S error correction applied',
        18: 'Undecodable Mode C code / Mode S altitude code',
        19: 'Birds',
        20: 'Flock of Birds',
        21: 'Mode-1 was present in original reply',
        22: 'Mode-2 was present in original reply',
        23: 'Plot potentially caused by Wind Turbine',
        24: 'Helicopter',
        25: 'Maximum number of re-interrogations reached (surveillance information)',
        26: 'Maximum number of re-interrogations reached (BDS Extractions)',
        27: 'BDS Overlay Incoherence',
        28: 'Potential BDS Swap Detected',
        29: 'Track Update in the Zenithal Gap',
        30: 'Mode S Track re-acquired',
        31: 'Duplicated Mode 5 Pair NO/PIN detected',
        32: 'Wrong DF reply format detected',
        33: 'Transponder anomaly (MS XPD replies with Mode A/C to Mode A/C-only all-call)',
        34: 'Transponder anomaly (SI capability report wrong)',
        35: 'Potential IC Conflict',
        36: 'IC Conflict detection possible-no conflict currently detected',
    }

    def __init__(self, arg : Variation_1182_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1183_Arg : TypeAlias = Union[Variation_1182, Variation_1182_Arg]
class Variation_1183(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = None
    variation_bit_size = 7
    variation_type = Variation_1182

    @classmethod
    def spec(cls) -> Type[Variation_1182]:
        return Variation_1182

    def __init__(self, arg : List[Union[Variation_1182, Variation_1182_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1182, Variation_1182_Arg]) -> 'Variation_1183':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1182, Variation_1182_Arg]) -> 'Variation_1183':
        return self._prepend_item(arg) # type: ignore

Variation_1184_Arg = TypedDict('Variation_1184_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '020': Union[Variation_1181, Variation_1181_Arg],
    '040': Union[Variation_595, Variation_595_Arg],
    '070': Union[Variation_1124, Variation_1124_Arg],
    '090': Union[Variation_1125, Variation_1125_Arg],
    '130': Union[Variation_1128, Variation_1128_Arg],
    '220': Union[Variation_278, Variation_278_Arg],
    '240': Union[Variation_196, Variation_196_Arg],
    '250': Union[Variation_1130, Variation_1130_Arg],
    '161': Union[Variation_651, Variation_651_Arg],
    '042': Union[Variation_1131, Variation_1131_Arg],
    '200': Union[Variation_68, Variation_68_Arg],
    '170': Union[Variation_1140, Variation_1140_Arg],
    '210': Union[Variation_1144, Variation_1144_Arg],
    '030': Union[Variation_1183, Variation_1183_Arg],
    '080': Union[Variation_42, Variation_42_Arg],
    '100': Union[Variation_55, Variation_55_Arg],
    '110': Union[Variation_1147, Variation_1147_Arg],
    '120': Union[Variation_1155, Variation_1155_Arg],
    '230': Union[Variation_1159, Variation_1159_Arg],
    '260': Union[Variation_281, Variation_281_Arg],
    '055': Union[Variation_1161, Variation_1161_Arg],
    '050': Union[Variation_27, Variation_27_Arg],
    '065': Union[Variation_1166, Variation_1166_Arg],
    '060': Union[Variation_42, Variation_42_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
}, total=False)
class Variation_1184(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('140', Variation_80),
        ('020', Variation_1181),
        ('040', Variation_595),
        ('070', Variation_1124),
        ('090', Variation_1125),
        ('130', Variation_1128),
        ('220', Variation_278),
        ('240', Variation_196),
        ('250', Variation_1130),
        ('161', Variation_651),
        ('042', Variation_1131),
        ('200', Variation_68),
        ('170', Variation_1140),
        ('210', Variation_1144),
        ('030', Variation_1183),
        ('080', Variation_42),
        ('100', Variation_55),
        ('110', Variation_1147),
        ('120', Variation_1155),
        ('230', Variation_1159),
        ('260', Variation_281),
        ('055', Variation_1161),
        ('050', Variation_27),
        ('065', Variation_1166),
        ('060', Variation_42),
        ('SP', Variation_62),
        ('RE', Variation_202),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '140': ('Time of Day', Variation_80, 0x40000000),
        '020': ('Target Report Descriptor', Variation_1181, 0x20000000),
        '040': ('Measured Position in Polar Co-ordinates', Variation_595, 0x10000000),
        '070': ('Mode-3/A Code in Octal Representation', Variation_1124, 0x08000000),
        '090': ('Flight Level in Binary Representation', Variation_1125, 0x04000000),
        '130': ('Radar Plot Characteristics', Variation_1128, 0x02000000),
        '220': ('Aircraft Address', Variation_278, 0x01800000),
        '240': ('Aircraft Identification', Variation_196, 0x01400000),
        '250': ('BDS Register Data', Variation_1130, 0x01200000),
        '161': ('Track Number', Variation_651, 0x01100000),
        '042': ('Calculated Position in Cartesian Co-ordinates', Variation_1131, 0x01080000),
        '200': ('Calculated Track Velocity in Polar Co-ordinates', Variation_68, 0x01040000),
        '170': ('Track Status', Variation_1140, 0x01020000),
        '210': ('Track Quality', Variation_1144, 0x01018000),
        '030': ('Warning/Error Conditions and Target Classification', Variation_1183, 0x01014000),
        '080': ('Mode-3/A Code Confidence Indicator', Variation_42, 0x01012000),
        '100': ('Mode-C Code and Code Confidence Indicator', Variation_55, 0x01011000),
        '110': ('Height Measured by a 3D Radar', Variation_1147, 0x01010800),
        '120': ('Radial Doppler Speed', Variation_1155, 0x01010400),
        '230': ('Communications/ACAS Capability and Flight Status', Variation_1159, 0x01010200),
        '260': ('ACAS Resolution Advisory Report', Variation_281, 0x01010180),
        '055': ('Mode-1 Code in Octal Representation', Variation_1161, 0x01010140),
        '050': ('Mode-2 Code in Octal Representation', Variation_27, 0x01010120),
        '065': ('Mode-1 Code Confidence Indicator', Variation_1166, 0x01010110),
        '060': ('Mode-2 Code Confidence Indicator', Variation_42, 0x01010108),
        'SP': ('Special Purpose Field', Variation_62, 0x01010104),
        'RE': ('Reserved Expansion Field', Variation_202, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_1181]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_595]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_1124]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_1125]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_1128]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['240']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['250']) -> Type[Variation_1130]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['161']) -> Type[Variation_651]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['042']) -> Type[Variation_1131]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_68]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_1140]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_1144]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_1183]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_55]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1147]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1155]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['230']) -> Type[Variation_1159]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['260']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['055']) -> Type[Variation_1161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_27]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['065']) -> Type[Variation_1166]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_42]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['140'], Literal['020'], Literal['040'], Literal['070'], Literal['090'], Literal['130'], Literal['220'], Literal['240'], Literal['250'], Literal['161'], Literal['042'], Literal['200'], Literal['170'], Literal['210'], Literal['030'], Literal['080'], Literal['100'], Literal['110'], Literal['120'], Literal['230'], Literal['260'], Literal['055'], Literal['050'], Literal['065'], Literal['060'], Literal['SP'], Literal['RE']]) -> Union[Type['Variation_1'], Type['Variation_80'], Type['Variation_1181'], Type['Variation_595'], Type['Variation_1124'], Type['Variation_1125'], Type['Variation_1128'], Type['Variation_278'], Type['Variation_196'], Type['Variation_1130'], Type['Variation_651'], Type['Variation_1131'], Type['Variation_68'], Type['Variation_1140'], Type['Variation_1144'], Type['Variation_1183'], Type['Variation_42'], Type['Variation_55'], Type['Variation_1147'], Type['Variation_1155'], Type['Variation_1159'], Type['Variation_281'], Type['Variation_1161'], Type['Variation_27'], Type['Variation_1166'], Type['Variation_42'], Type['Variation_62'], Type['Variation_202']]:
        if key == '010':
            return Variation_1
        if key == '140':
            return Variation_80
        if key == '020':
            return Variation_1181
        if key == '040':
            return Variation_595
        if key == '070':
            return Variation_1124
        if key == '090':
            return Variation_1125
        if key == '130':
            return Variation_1128
        if key == '220':
            return Variation_278
        if key == '240':
            return Variation_196
        if key == '250':
            return Variation_1130
        if key == '161':
            return Variation_651
        if key == '042':
            return Variation_1131
        if key == '200':
            return Variation_68
        if key == '170':
            return Variation_1140
        if key == '210':
            return Variation_1144
        if key == '030':
            return Variation_1183
        if key == '080':
            return Variation_42
        if key == '100':
            return Variation_55
        if key == '110':
            return Variation_1147
        if key == '120':
            return Variation_1155
        if key == '230':
            return Variation_1159
        if key == '260':
            return Variation_281
        if key == '055':
            return Variation_1161
        if key == '050':
            return Variation_27
        if key == '065':
            return Variation_1166
        if key == '060':
            return Variation_42
        if key == 'SP':
            return Variation_62
        if key == 'RE':
            return Variation_202
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1184_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_1181, Variation_1181_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_595, Variation_595_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_1124, Variation_1124_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_1125, Variation_1125_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_1128, Variation_1128_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['240'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['250'], val : Union[Variation_1130, Variation_1130_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['161'], val : Union[Variation_651, Variation_651_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['042'], val : Union[Variation_1131, Variation_1131_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_68, Variation_68_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_1140, Variation_1140_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_1144, Variation_1144_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_1183, Variation_1183_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_55, Variation_55_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1147, Variation_1147_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1155, Variation_1155_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['230'], val : Union[Variation_1159, Variation_1159_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['260'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['055'], val : Union[Variation_1161, Variation_1161_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_27, Variation_27_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['065'], val : Union[Variation_1166, Variation_1166_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_42, Variation_42_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1184':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1184':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['240']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['250']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['161']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['042']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['230']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['260']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['055']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['065']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1184':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1184':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_1181:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_595:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_1124:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_1125:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_1128:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['240']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['250']) -> Variation_1130:
        ...

    @overload
    def get_item(self, name : Literal['161']) -> Variation_651:
        ...

    @overload
    def get_item(self, name : Literal['042']) -> Variation_1131:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_68:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_1140:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_1144:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_1183:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_55:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1147:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1155:
        ...

    @overload
    def get_item(self, name : Literal['230']) -> Variation_1159:
        ...

    @overload
    def get_item(self, name : Literal['260']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['055']) -> Variation_1161:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_27:
        ...

    @overload
    def get_item(self, name : Literal['065']) -> Variation_1166:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_42:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['240'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['250'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['161'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['042'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['230'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['260'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['055'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['065'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1184':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1184':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1185_Arg : TypeAlias = Raw
class Variation_1185(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 4
    table = {
        0: 'No detection',
        1: 'Single PSR detection',
        2: 'Single SSR detection',
        3: 'SSR+PSR detection',
        4: 'Single Mode S All-Call',
        5: 'Single Mode S Roll-Call',
        6: 'Mode S All-Call + PSR',
        7: 'Mode S Roll-Call + PSR',
        8: 'ADS-B',
        9: 'WAM',
    }

    def __init__(self, arg : Variation_1185_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1186_Arg_Group = TypedDict('Variation_1186_Arg_Group', {
    'SAC': Union[Variation_0, Variation_0_Arg],
    'SIC': Union[Variation_0, Variation_0_Arg],
    'TYP': Union[Variation_1185, Variation_1185_Arg],
    'LTN': Union[Variation_64, Variation_64_Arg],
})
Variation_1186_Arg : TypeAlias = Union[Raw, Variation_1186_Arg_Group]
class Variation_1186(Group):
    variation = 'Group'

    bit_size = 40

    subitems_list = [
        ('SAC', Variation_0),
        ('SIC', Variation_0),
        Spare(0, 4),
        ('TYP', Variation_1185),
        ('LTN', Variation_64),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SAC': ('System Area Code', Variation_0, 0, 8),
        'SIC': ('System Identification Code', Variation_0, 8, 8),
        'TYP': ('', Variation_1185, 20, 4),
        'LTN': ('Local Track Number', Variation_64, 24, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SAC']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIC']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_1185]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LTN']) -> Type[Variation_64]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SAC'], Literal['SIC'], Literal['TYP'], Literal['LTN']]) -> Union[Type['Variation_0'], Type['Variation_0'], Type['Variation_1185'], Type['Variation_64']]:
        if key == 'SAC':
            return Variation_0
        if key == 'SIC':
            return Variation_0
        if key == 'TYP':
            return Variation_1185
        if key == 'LTN':
            return Variation_64
        assert_never(key)

    def __init__(self, arg : Variation_1186_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SAC']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SIC']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_1185:
        ...

    @overload
    def get_item(self, name : Literal['LTN']) -> Variation_64:
        ...

    def get_item(self, name : Union[Literal['SAC'], Literal['SIC'], Literal['TYP'], Literal['LTN']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SAC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1186':
        ...

    @overload
    def set_item(self, name : Literal['SIC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1186':
        ...

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_1185, Variation_1185_Arg]) -> 'Variation_1186':
        ...

    @overload
    def set_item(self, name : Literal['LTN'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1186':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SAC'], f : Any) -> 'Variation_1186':
        ...

    @overload
    def modify_item(self, name : Literal['SIC'], f : Any) -> 'Variation_1186':
        ...

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1186':
        ...

    @overload
    def modify_item(self, name : Literal['LTN'], f : Any) -> 'Variation_1186':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1187_Arg : TypeAlias = Union[Variation_1186, Variation_1186_Arg]
class Variation_1187(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 40
    variation_type = Variation_1186

    @classmethod
    def spec(cls) -> Type[Variation_1186]:
        return Variation_1186

    def __init__(self, arg : List[Union[Variation_1186, Variation_1186_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1186, Variation_1186_Arg]) -> 'Variation_1187':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1186, Variation_1186_Arg]) -> 'Variation_1187':
        return self._prepend_item(arg) # type: ignore

Variation_1188_Arg_Group = TypedDict('Variation_1188_Arg_Group', {
    'SAC': Union[Variation_0, Variation_0_Arg],
    'SIC': Union[Variation_0, Variation_0_Arg],
    'TYP': Union[Variation_1185, Variation_1185_Arg],
})
Variation_1188_Arg : TypeAlias = Union[Raw, Variation_1188_Arg_Group]
class Variation_1188(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('SAC', Variation_0),
        ('SIC', Variation_0),
        Spare(0, 4),
        ('TYP', Variation_1185),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SAC': ('System Area Code', Variation_0, 0, 8),
        'SIC': ('System Identification Code', Variation_0, 8, 8),
        'TYP': ('', Variation_1185, 20, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SAC']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIC']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_1185]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SAC'], Literal['SIC'], Literal['TYP']]) -> Union[Type['Variation_0'], Type['Variation_0'], Type['Variation_1185']]:
        if key == 'SAC':
            return Variation_0
        if key == 'SIC':
            return Variation_0
        if key == 'TYP':
            return Variation_1185
        assert_never(key)

    def __init__(self, arg : Variation_1188_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SAC']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SIC']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_1185:
        ...

    def get_item(self, name : Union[Literal['SAC'], Literal['SIC'], Literal['TYP']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SAC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1188':
        ...

    @overload
    def set_item(self, name : Literal['SIC'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1188':
        ...

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_1185, Variation_1185_Arg]) -> 'Variation_1188':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SAC'], f : Any) -> 'Variation_1188':
        ...

    @overload
    def modify_item(self, name : Literal['SIC'], f : Any) -> 'Variation_1188':
        ...

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1188':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1189_Arg : TypeAlias = Union[Variation_1188, Variation_1188_Arg]
class Variation_1189(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 24
    variation_type = Variation_1188

    @classmethod
    def spec(cls) -> Type[Variation_1188]:
        return Variation_1188

    def __init__(self, arg : List[Union[Variation_1188, Variation_1188_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1188, Variation_1188_Arg]) -> 'Variation_1189':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1188, Variation_1188_Arg]) -> 'Variation_1189':
        return self._prepend_item(arg) # type: ignore

Variation_1190_Arg : TypeAlias = Raw
class Variation_1190(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Flight plan data from active FDPS',
        1: 'Flight plan data retained from no longer active FDPS',
    }

    def __init__(self, arg : Variation_1190_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1191_Arg_Group_1 = TypedDict('Variation_1191_Arg_Group_1', {
    'FDR': Union[Variation_1190, Variation_1190_Arg],
})
Variation_1191_Arg : TypeAlias = Union[
    int,
    Variation_1191_Arg_Group_1,
    Tuple[int],
]
class Variation_1191(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            ('FDR', Variation_1190),
            Spare(1, 6),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FDR': ('Flight Data Retained', Variation_1190, 0, 1),
    }


    @classmethod
    def spec(cls, key : Union[Literal['FDR']]) -> Union[Type['Variation_1190']]:
        if key == 'FDR':
            return Variation_1190
        assert_never(key)

    def __init__(self, arg : Variation_1191_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1191_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    def get_item(self, name : Literal['FDR']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['FDR'], val : Union[Variation_1190, Variation_1190_Arg]) -> 'Variation_1191':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['FDR'], f : Any) -> 'Variation_1191':
        return self._modify_item(name, f) # type: ignore

Variation_1192_Arg = TypedDict('Variation_1192_Arg', {
    'CST': Union[Variation_1187, Variation_1187_Arg],
    'CSN': Union[Variation_1189, Variation_1189_Arg],
    'TVS': Union[Variation_659, Variation_659_Arg],
    'STS': Union[Variation_1191, Variation_1191_Arg],
}, total=False)
class Variation_1192(Compound):
    variation = 'Compound'

    fspec_fx = False
    fspec_max_bytes = 1

    subitems_list = [
        ('CST', Variation_1187),
        ('CSN', Variation_1189),
        ('TVS', Variation_659),
        ('STS', Variation_1191),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'CST': ('Contributing Sensors With Local Tracknumbers', Variation_1187, 0x80),
        'CSN': ('Contributing Sensors No Local Tracknumbers', Variation_1189, 0x40),
        'TVS': ('Calculated Track Velocity Relative to System Reference Point', Variation_659, 0x20),
        'STS': ('Supplementary Track Status', Variation_1191, 0x10),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_1187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CSN']) -> Type[Variation_1189]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TVS']) -> Type[Variation_659]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STS']) -> Type[Variation_1191]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CST'], Literal['CSN'], Literal['TVS'], Literal['STS']]) -> Union[Type['Variation_1187'], Type['Variation_1189'], Type['Variation_659'], Type['Variation_1191']]:
        if key == 'CST':
            return Variation_1187
        if key == 'CSN':
            return Variation_1189
        if key == 'TVS':
            return Variation_659
        if key == 'STS':
            return Variation_1191
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1192_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['CST'], val : Union[Variation_1187, Variation_1187_Arg]) -> 'Variation_1192':
        ...

    @overload
    def set_item(self, name : Literal['CSN'], val : Union[Variation_1189, Variation_1189_Arg]) -> 'Variation_1192':
        ...

    @overload
    def set_item(self, name : Literal['TVS'], val : Union[Variation_659, Variation_659_Arg]) -> 'Variation_1192':
        ...

    @overload
    def set_item(self, name : Literal['STS'], val : Union[Variation_1191, Variation_1191_Arg]) -> 'Variation_1192':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['CST']) -> 'Variation_1192':
        ...

    @overload
    def del_item(self, name : Literal['CSN']) -> 'Variation_1192':
        ...

    @overload
    def del_item(self, name : Literal['TVS']) -> 'Variation_1192':
        ...

    @overload
    def del_item(self, name : Literal['STS']) -> 'Variation_1192':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_1187:
        ...

    @overload
    def get_item(self, name : Literal['CSN']) -> Variation_1189:
        ...

    @overload
    def get_item(self, name : Literal['TVS']) -> Variation_659:
        ...

    @overload
    def get_item(self, name : Literal['STS']) -> Variation_1191:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_1192':
        ...

    @overload
    def modify_item(self, name : Literal['CSN'], f : Any) -> 'Variation_1192':
        ...

    @overload
    def modify_item(self, name : Literal['TVS'], f : Any) -> 'Variation_1192':
        ...

    @overload
    def modify_item(self, name : Literal['STS'], f : Any) -> 'Variation_1192':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1193_Arg : TypeAlias = Raw
class Variation_1193(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'LNAV not populated',
        1: 'LNAV populated',
    }

    def __init__(self, arg : Variation_1193_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1194_Arg : TypeAlias = Raw
class Variation_1194(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'LNAV Mode Engaged',
        1: 'LNAV Mode not Engaged',
    }

    def __init__(self, arg : Variation_1194_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1195_Arg_Group = TypedDict('Variation_1195_Arg_Group', {
    'EP': Union[Variation_1193, Variation_1193_Arg],
    'VAL': Union[Variation_1194, Variation_1194_Arg],
})
Variation_1195_Arg : TypeAlias = Union[Raw, Variation_1195_Arg_Group]
class Variation_1195(Group):
    variation = 'Group'

    bit_size = 2

    subitems_list = [
        ('EP', Variation_1193),
        ('VAL', Variation_1194),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('LNAV Element Populated', Variation_1193, 0, 1),
        'VAL': ('LNAV Mode', Variation_1194, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_1193]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1194]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_1193'], Type['Variation_1194']]:
        if key == 'EP':
            return Variation_1193
        if key == 'VAL':
            return Variation_1194
        assert_never(key)

    def __init__(self, arg : Variation_1195_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_1193:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1194:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_1193, Variation_1193_Arg]) -> 'Variation_1195':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1194, Variation_1194_Arg]) -> 'Variation_1195':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1195':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1195':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1196_Arg_Group_1 = TypedDict('Variation_1196_Arg_Group_1', {
    'FDR': Union[Variation_1190, Variation_1190_Arg],
    'LNAV': Union[Variation_1195, Variation_1195_Arg],
})
Variation_1196_Arg : TypeAlias = Union[
    int,
    Variation_1196_Arg_Group_1,
    Tuple[int],
]
class Variation_1196(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            ('FDR', Variation_1190),
            ('LNAV', Variation_1195),
            Spare(3, 4),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'FDR': ('Flight Data Retained', Variation_1190, 0, 1),
        'LNAV': ('Lateral Navigation Mode', Variation_1195, 1, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['FDR']) -> Type[Variation_1190]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LNAV']) -> Type[Variation_1195]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['FDR'], Literal['LNAV']]) -> Union[Type['Variation_1190'], Type['Variation_1195']]:
        if key == 'FDR':
            return Variation_1190
        if key == 'LNAV':
            return Variation_1195
        assert_never(key)

    def __init__(self, arg : Variation_1196_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1196_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['FDR']) -> Variation_1190:
        ...

    @overload
    def get_item(self, name : Literal['LNAV']) -> Variation_1195:
        ...

    def get_item(self, name : Union[Literal['FDR'], Literal['LNAV']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['FDR'], val : Union[Variation_1190, Variation_1190_Arg]) -> 'Variation_1196':
        ...

    @overload
    def set_item(self, name : Literal['LNAV'], val : Union[Variation_1195, Variation_1195_Arg]) -> 'Variation_1196':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['FDR'], f : Any) -> 'Variation_1196':
        ...

    @overload
    def modify_item(self, name : Literal['LNAV'], f : Any) -> 'Variation_1196':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1197_Arg : TypeAlias = Raw
class Variation_1197(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'PS3 Element not populated',
        1: 'PS3 Element populated',
    }

    def __init__(self, arg : Variation_1197_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1198_Arg : TypeAlias = Raw
class Variation_1198(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 3
    table = {
        0: 'No emergency / not reported',
        1: 'General emergency',
        2: 'UAS/RPAS - Lost link',
        3: 'Minimum fuel',
        4: 'No communications',
        5: 'Unlawful interference',
        6: 'Aircraft in Distress Automatic Activation',
        7: 'Aircraft in Distress Manual Activation',
    }

    def __init__(self, arg : Variation_1198_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1199_Arg_Group = TypedDict('Variation_1199_Arg_Group', {
    'EP': Union[Variation_1197, Variation_1197_Arg],
    'VAL': Union[Variation_1198, Variation_1198_Arg],
})
Variation_1199_Arg : TypeAlias = Union[Raw, Variation_1199_Arg_Group]
class Variation_1199(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('EP', Variation_1197),
        ('VAL', Variation_1198),
        Spare(4, 4),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Priority Status for Version 3 ADS-B Systems Populated', Variation_1197, 0, 1),
        'VAL': ('Priority Status for Version 3 ADS-B Systems', Variation_1198, 1, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_1197]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1198]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_1197'], Type['Variation_1198']]:
        if key == 'EP':
            return Variation_1197
        if key == 'VAL':
            return Variation_1198
        assert_never(key)

    def __init__(self, arg : Variation_1199_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_1197:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1198:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_1197, Variation_1197_Arg]) -> 'Variation_1199':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1198, Variation_1198_Arg]) -> 'Variation_1199':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1199':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1199':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1200_Arg : TypeAlias = Raw
class Variation_1200(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'Not RCE',
        1: 'TABS',
        2: 'Reserved for future use',
        3: 'Other RCE',
    }

    def __init__(self, arg : Variation_1200_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1201_Arg_Group = TypedDict('Variation_1201_Arg_Group', {
    'EP': Union[Variation_816, Variation_816_Arg],
    'VAL': Union[Variation_1200, Variation_1200_Arg],
})
Variation_1201_Arg : TypeAlias = Union[Raw, Variation_1201_Arg_Group]
class Variation_1201(Group):
    variation = 'Group'

    bit_size = 3

    subitems_list = [
        ('EP', Variation_816),
        ('VAL', Variation_1200),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_816, 0, 1),
        'VAL': ('Value', Variation_1200, 1, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_816]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1200]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_816'], Type['Variation_1200']]:
        if key == 'EP':
            return Variation_816
        if key == 'VAL':
            return Variation_1200
        assert_never(key)

    def __init__(self, arg : Variation_1201_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_816:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1200:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_816, Variation_816_Arg]) -> 'Variation_1201':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1200, Variation_1200_Arg]) -> 'Variation_1201':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1201':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1201':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1202_Arg : TypeAlias = Raw
class Variation_1202(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Reply Rate Limiting is not active',
        1: 'Reply Rate Limiting is active',
    }

    def __init__(self, arg : Variation_1202_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1203_Arg_Group = TypedDict('Variation_1203_Arg_Group', {
    'EP': Union[Variation_823, Variation_823_Arg],
    'VAL': Union[Variation_1202, Variation_1202_Arg],
})
Variation_1203_Arg : TypeAlias = Union[Raw, Variation_1203_Arg_Group]
class Variation_1203(Group):
    variation = 'Group'

    bit_size = 2

    subitems_list = [
        ('EP', Variation_823),
        ('VAL', Variation_1202),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_823, 0, 1),
        'VAL': ('Value', Variation_1202, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_823]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_823'], Type['Variation_1202']]:
        if key == 'EP':
            return Variation_823
        if key == 'VAL':
            return Variation_1202
        assert_never(key)

    def __init__(self, arg : Variation_1203_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_823:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1202:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_823, Variation_823_Arg]) -> 'Variation_1203':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1202, Variation_1202_Arg]) -> 'Variation_1203':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1203':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1203':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1204_Arg : TypeAlias = Raw
class Variation_1204(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 2
    table = {
        0: 'Unavailable, Unknown, or less than 70 W',
        1: '70 W',
        2: '125 W',
        3: '200 W',
    }

    def __init__(self, arg : Variation_1204_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1205_Arg_Group = TypedDict('Variation_1205_Arg_Group', {
    'EP': Union[Variation_813, Variation_813_Arg],
    'VAL': Union[Variation_1204, Variation_1204_Arg],
})
Variation_1205_Arg : TypeAlias = Union[Raw, Variation_1205_Arg_Group]
class Variation_1205(Group):
    variation = 'Group'

    bit_size = 3

    subitems_list = [
        ('EP', Variation_813),
        ('VAL', Variation_1204),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_813, 0, 1),
        'VAL': ('Value', Variation_1204, 1, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_813]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1204]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_813'], Type['Variation_1204']]:
        if key == 'EP':
            return Variation_813
        if key == 'VAL':
            return Variation_1204
        assert_never(key)

    def __init__(self, arg : Variation_1205_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_813:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1204:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_813, Variation_813_Arg]) -> 'Variation_1205':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1204, Variation_1204_Arg]) -> 'Variation_1205':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1205':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1205':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1206_Arg : TypeAlias = Raw
class Variation_1206(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Transponder #1 (left/pilot side or single)',
        2: 'Transponder #2 (right/co-pilot side)',
        3: 'Transponder #3 (auxiliary or Back-up)',
    }

    def __init__(self, arg : Variation_1206_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1207_Arg_Group = TypedDict('Variation_1207_Arg_Group', {
    'EP': Union[Variation_816, Variation_816_Arg],
    'VAL': Union[Variation_1206, Variation_1206_Arg],
})
Variation_1207_Arg : TypeAlias = Union[Raw, Variation_1207_Arg_Group]
class Variation_1207(Group):
    variation = 'Group'

    bit_size = 3

    subitems_list = [
        ('EP', Variation_816),
        ('VAL', Variation_1206),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_816, 0, 1),
        'VAL': ('Value', Variation_1206, 1, 2),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_816]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1206]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['VAL']]) -> Union[Type['Variation_816'], Type['Variation_1206']]:
        if key == 'EP':
            return Variation_816
        if key == 'VAL':
            return Variation_1206
        assert_never(key)

    def __init__(self, arg : Variation_1207_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_816:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1206:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_816, Variation_816_Arg]) -> 'Variation_1207':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1206, Variation_1206_Arg]) -> 'Variation_1207':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1207':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1207':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1208_Arg : TypeAlias = Raw
class Variation_1208(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Value in defined range',
        1: 'Value exceeds defined range',
    }

    def __init__(self, arg : Variation_1208_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1209_Arg : TypeAlias = Raw
class Variation_1209(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 6

    def __init__(self, arg : Variation_1209_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_1210_Arg_Group = TypedDict('Variation_1210_Arg_Group', {
    'EP': Union[Variation_823, Variation_823_Arg],
    'RE': Union[Variation_1208, Variation_1208_Arg],
    'VAL': Union[Variation_1209, Variation_1209_Arg],
})
Variation_1210_Arg : TypeAlias = Union[Raw, Variation_1210_Arg_Group]
class Variation_1210(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('EP', Variation_823),
        ('RE', Variation_1208),
        ('VAL', Variation_1209),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EP': ('Element Populated Bit', Variation_823, 0, 1),
        'RE': ('Range Exceeded', Variation_1208, 1, 1),
        'VAL': ('Value', Variation_1209, 2, 6),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['EP']) -> Type[Variation_823]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_1208]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VAL']) -> Type[Variation_1209]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['EP'], Literal['RE'], Literal['VAL']]) -> Union[Type['Variation_823'], Type['Variation_1208'], Type['Variation_1209']]:
        if key == 'EP':
            return Variation_823
        if key == 'RE':
            return Variation_1208
        if key == 'VAL':
            return Variation_1209
        assert_never(key)

    def __init__(self, arg : Variation_1210_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['EP']) -> Variation_823:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_1208:
        ...

    @overload
    def get_item(self, name : Literal['VAL']) -> Variation_1209:
        ...

    def get_item(self, name : Union[Literal['EP'], Literal['RE'], Literal['VAL']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['EP'], val : Union[Variation_823, Variation_823_Arg]) -> 'Variation_1210':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_1208, Variation_1208_Arg]) -> 'Variation_1210':
        ...

    @overload
    def set_item(self, name : Literal['VAL'], val : Union[Variation_1209, Variation_1209_Arg]) -> 'Variation_1210':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['EP'], f : Any) -> 'Variation_1210':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1210':
        ...

    @overload
    def modify_item(self, name : Literal['VAL'], f : Any) -> 'Variation_1210':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1211_Arg_Group = TypedDict('Variation_1211_Arg_Group', {
    'RCE': Union[Variation_1201, Variation_1201_Arg],
    'RRL': Union[Variation_1203, Variation_1203_Arg],
    'TPW': Union[Variation_1205, Variation_1205_Arg],
    'TSI': Union[Variation_1207, Variation_1207_Arg],
    'TAO': Union[Variation_1210, Variation_1210_Arg],
})
Variation_1211_Arg : TypeAlias = Union[Raw, Variation_1211_Arg_Group]
class Variation_1211(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('RCE', Variation_1201),
        ('RRL', Variation_1203),
        ('TPW', Variation_1205),
        ('TSI', Variation_1207),
        ('TAO', Variation_1210),
        Spare(3, 5),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RCE': ('Reduced Capability Equipment', Variation_1201, 0, 3),
        'RRL': ('Reply Rate Limiting', Variation_1203, 3, 2),
        'TPW': ('Transmit Power', Variation_1205, 5, 3),
        'TSI': ('Transponder Side Indication', Variation_1207, 8, 3),
        'TAO': ('Transponder Antenna Offset', Variation_1210, 11, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RCE']) -> Type[Variation_1201]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RRL']) -> Type[Variation_1203]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TPW']) -> Type[Variation_1205]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSI']) -> Type[Variation_1207]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAO']) -> Type[Variation_1210]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RCE'], Literal['RRL'], Literal['TPW'], Literal['TSI'], Literal['TAO']]) -> Union[Type['Variation_1201'], Type['Variation_1203'], Type['Variation_1205'], Type['Variation_1207'], Type['Variation_1210']]:
        if key == 'RCE':
            return Variation_1201
        if key == 'RRL':
            return Variation_1203
        if key == 'TPW':
            return Variation_1205
        if key == 'TSI':
            return Variation_1207
        if key == 'TAO':
            return Variation_1210
        assert_never(key)

    def __init__(self, arg : Variation_1211_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RCE']) -> Variation_1201:
        ...

    @overload
    def get_item(self, name : Literal['RRL']) -> Variation_1203:
        ...

    @overload
    def get_item(self, name : Literal['TPW']) -> Variation_1205:
        ...

    @overload
    def get_item(self, name : Literal['TSI']) -> Variation_1207:
        ...

    @overload
    def get_item(self, name : Literal['TAO']) -> Variation_1210:
        ...

    def get_item(self, name : Union[Literal['RCE'], Literal['RRL'], Literal['TPW'], Literal['TSI'], Literal['TAO']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RCE'], val : Union[Variation_1201, Variation_1201_Arg]) -> 'Variation_1211':
        ...

    @overload
    def set_item(self, name : Literal['RRL'], val : Union[Variation_1203, Variation_1203_Arg]) -> 'Variation_1211':
        ...

    @overload
    def set_item(self, name : Literal['TPW'], val : Union[Variation_1205, Variation_1205_Arg]) -> 'Variation_1211':
        ...

    @overload
    def set_item(self, name : Literal['TSI'], val : Union[Variation_1207, Variation_1207_Arg]) -> 'Variation_1211':
        ...

    @overload
    def set_item(self, name : Literal['TAO'], val : Union[Variation_1210, Variation_1210_Arg]) -> 'Variation_1211':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RCE'], f : Any) -> 'Variation_1211':
        ...

    @overload
    def modify_item(self, name : Literal['RRL'], f : Any) -> 'Variation_1211':
        ...

    @overload
    def modify_item(self, name : Literal['TPW'], f : Any) -> 'Variation_1211':
        ...

    @overload
    def modify_item(self, name : Literal['TSI'], f : Any) -> 'Variation_1211':
        ...

    @overload
    def modify_item(self, name : Literal['TAO'], f : Any) -> 'Variation_1211':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1212_Arg = TypedDict('Variation_1212_Arg', {
    'PS3': Union[Variation_1199, Variation_1199_Arg],
    'AS': Union[Variation_1211, Variation_1211_Arg],
}, total=False)
class Variation_1212(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('PS3', Variation_1199),
        ('AS', Variation_1211),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'PS3': ('Priority Status for Version 3 ADS-B Systems', Variation_1199, 0x80),
        'AS': ('Aircraft Status', Variation_1211, 0x40),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PS3']) -> Type[Variation_1199]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AS']) -> Type[Variation_1211]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PS3'], Literal['AS']]) -> Union[Type['Variation_1199'], Type['Variation_1211']]:
        if key == 'PS3':
            return Variation_1199
        if key == 'AS':
            return Variation_1211
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1212_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['PS3'], val : Union[Variation_1199, Variation_1199_Arg]) -> 'Variation_1212':
        ...

    @overload
    def set_item(self, name : Literal['AS'], val : Union[Variation_1211, Variation_1211_Arg]) -> 'Variation_1212':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['PS3']) -> 'Variation_1212':
        ...

    @overload
    def del_item(self, name : Literal['AS']) -> 'Variation_1212':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['PS3']) -> Variation_1199:
        ...

    @overload
    def get_item(self, name : Literal['AS']) -> Variation_1211:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['PS3'], f : Any) -> 'Variation_1212':
        ...

    @overload
    def modify_item(self, name : Literal['AS'], f : Any) -> 'Variation_1212':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1213_Arg = TypedDict('Variation_1213_Arg', {
    'CST': Union[Variation_1187, Variation_1187_Arg],
    'CSN': Union[Variation_1189, Variation_1189_Arg],
    'TVS': Union[Variation_659, Variation_659_Arg],
    'STS': Union[Variation_1196, Variation_1196_Arg],
    'V3': Union[Variation_1212, Variation_1212_Arg],
}, total=False)
class Variation_1213(Compound):
    variation = 'Compound'

    fspec_fx = False
    fspec_max_bytes = 1

    subitems_list = [
        ('CST', Variation_1187),
        ('CSN', Variation_1189),
        ('TVS', Variation_659),
        ('STS', Variation_1196),
        ('V3', Variation_1212),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'CST': ('Contributing Sensors With Local Tracknumbers', Variation_1187, 0x80),
        'CSN': ('Contributing Sensors No Local Tracknumbers', Variation_1189, 0x40),
        'TVS': ('Calculated Track Velocity Relative to System Reference Point', Variation_659, 0x20),
        'STS': ('Supplementary Track Status', Variation_1196, 0x10),
        'V3': ('ADS-B Version 3 Data', Variation_1212, 0x08),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_1187]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CSN']) -> Type[Variation_1189]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TVS']) -> Type[Variation_659]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STS']) -> Type[Variation_1196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['V3']) -> Type[Variation_1212]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CST'], Literal['CSN'], Literal['TVS'], Literal['STS'], Literal['V3']]) -> Union[Type['Variation_1187'], Type['Variation_1189'], Type['Variation_659'], Type['Variation_1196'], Type['Variation_1212']]:
        if key == 'CST':
            return Variation_1187
        if key == 'CSN':
            return Variation_1189
        if key == 'TVS':
            return Variation_659
        if key == 'STS':
            return Variation_1196
        if key == 'V3':
            return Variation_1212
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1213_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['CST'], val : Union[Variation_1187, Variation_1187_Arg]) -> 'Variation_1213':
        ...

    @overload
    def set_item(self, name : Literal['CSN'], val : Union[Variation_1189, Variation_1189_Arg]) -> 'Variation_1213':
        ...

    @overload
    def set_item(self, name : Literal['TVS'], val : Union[Variation_659, Variation_659_Arg]) -> 'Variation_1213':
        ...

    @overload
    def set_item(self, name : Literal['STS'], val : Union[Variation_1196, Variation_1196_Arg]) -> 'Variation_1213':
        ...

    @overload
    def set_item(self, name : Literal['V3'], val : Union[Variation_1212, Variation_1212_Arg]) -> 'Variation_1213':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['CST']) -> 'Variation_1213':
        ...

    @overload
    def del_item(self, name : Literal['CSN']) -> 'Variation_1213':
        ...

    @overload
    def del_item(self, name : Literal['TVS']) -> 'Variation_1213':
        ...

    @overload
    def del_item(self, name : Literal['STS']) -> 'Variation_1213':
        ...

    @overload
    def del_item(self, name : Literal['V3']) -> 'Variation_1213':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_1187:
        ...

    @overload
    def get_item(self, name : Literal['CSN']) -> Variation_1189:
        ...

    @overload
    def get_item(self, name : Literal['TVS']) -> Variation_659:
        ...

    @overload
    def get_item(self, name : Literal['STS']) -> Variation_1196:
        ...

    @overload
    def get_item(self, name : Literal['V3']) -> Variation_1212:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_1213':
        ...

    @overload
    def modify_item(self, name : Literal['CSN'], f : Any) -> 'Variation_1213':
        ...

    @overload
    def modify_item(self, name : Literal['TVS'], f : Any) -> 'Variation_1213':
        ...

    @overload
    def modify_item(self, name : Literal['STS'], f : Any) -> 'Variation_1213':
        ...

    @overload
    def modify_item(self, name : Literal['V3'], f : Any) -> 'Variation_1213':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1214_Arg_Group = TypedDict('Variation_1214_Arg_Group', {
    'X': Union[Variation_150, Variation_150_Arg],
    'Y': Union[Variation_150, Variation_150_Arg],
})
Variation_1214_Arg : TypeAlias = Union[Raw, Variation_1214_Arg_Group]
class Variation_1214(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('X', Variation_150),
        ('Y', Variation_150),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('X Coordinate', Variation_150, 0, 24),
        'Y': ('Y Coordinate', Variation_150, 24, 24),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_150]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_150]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_150'], Type['Variation_150']]:
        if key == 'X':
            return Variation_150
        if key == 'Y':
            return Variation_150
        assert_never(key)

    def __init__(self, arg : Variation_1214_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_150:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_150:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_150, Variation_150_Arg]) -> 'Variation_1214':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_150, Variation_150_Arg]) -> 'Variation_1214':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_1214':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_1214':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1215_Arg_Group = TypedDict('Variation_1215_Arg_Group', {
    'VX': Union[Variation_314, Variation_314_Arg],
    'VY': Union[Variation_314, Variation_314_Arg],
})
Variation_1215_Arg : TypeAlias = Union[Raw, Variation_1215_Arg_Group]
class Variation_1215(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('VX', Variation_314),
        ('VY', Variation_314),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'VX': ('Velocity (X-component)', Variation_314, 0, 16),
        'VY': ('Velocity (Y-component)', Variation_314, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VX']) -> Type[Variation_314]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VY']) -> Type[Variation_314]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VX'], Literal['VY']]) -> Union[Type['Variation_314'], Type['Variation_314']]:
        if key == 'VX':
            return Variation_314
        if key == 'VY':
            return Variation_314
        assert_never(key)

    def __init__(self, arg : Variation_1215_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['VX']) -> Variation_314:
        ...

    @overload
    def get_item(self, name : Literal['VY']) -> Variation_314:
        ...

    def get_item(self, name : Union[Literal['VX'], Literal['VY']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['VX'], val : Union[Variation_314, Variation_314_Arg]) -> 'Variation_1215':
        ...

    @overload
    def set_item(self, name : Literal['VY'], val : Union[Variation_314, Variation_314_Arg]) -> 'Variation_1215':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['VX'], f : Any) -> 'Variation_1215':
        ...

    @overload
    def modify_item(self, name : Literal['VY'], f : Any) -> 'Variation_1215':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1216_Arg : TypeAlias = Raw
class Variation_1216(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'No change',
        1: 'Mode 3/A has changed',
    }

    def __init__(self, arg : Variation_1216_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1217_Arg_Group = TypedDict('Variation_1217_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'CH': Union[Variation_1216, Variation_1216_Arg],
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_1217_Arg : TypeAlias = Union[Raw, Variation_1217_Arg_Group]
class Variation_1217(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('CH', Variation_1216),
        Spare(3, 1),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('Validated', Variation_16, 0, 1),
        'G': ('Garbled', Variation_17, 1, 1),
        'CH': ('Change in Mode 3/A', Variation_1216, 2, 1),
        'MODE3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CH']) -> Type[Variation_1216]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['CH'], Literal['MODE3A']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_1216'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'CH':
            return Variation_1216
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_1217_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['CH']) -> Variation_1216:
        ...

    @overload
    def get_item(self, name : Literal['MODE3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['CH'], Literal['MODE3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_1217':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_1217':
        ...

    @overload
    def set_item(self, name : Literal['CH'], val : Union[Variation_1216, Variation_1216_Arg]) -> 'Variation_1217':
        ...

    @overload
    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_1217':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_1217':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_1217':
        ...

    @overload
    def modify_item(self, name : Literal['CH'], f : Any) -> 'Variation_1217':
        ...

    @overload
    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_1217':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1218_Arg : TypeAlias = Raw
class Variation_1218(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Callsign or registration downlinked from target',
        1: 'Callsign not downlinked from target',
        2: 'Registration not downlinked from target',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_1218_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1219_Arg_Group = TypedDict('Variation_1219_Arg_Group', {
    'STI': Union[Variation_1218, Variation_1218_Arg],
    'CHR': Union[Variation_196, Variation_196_Arg],
})
Variation_1219_Arg : TypeAlias = Union[Raw, Variation_1219_Arg_Group]
class Variation_1219(Group):
    variation = 'Group'

    bit_size = 56

    subitems_list = [
        ('STI', Variation_1218),
        Spare(2, 6),
        ('CHR', Variation_196),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STI': ('', Variation_1218, 0, 2),
        'CHR': ('Characters 1-8 (Coded on 6 Bits Each) Defining Target Identification', Variation_196, 8, 48),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['STI']) -> Type[Variation_1218]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CHR']) -> Type[Variation_196]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['STI'], Literal['CHR']]) -> Union[Type['Variation_1218'], Type['Variation_196']]:
        if key == 'STI':
            return Variation_1218
        if key == 'CHR':
            return Variation_196
        assert_never(key)

    def __init__(self, arg : Variation_1219_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['STI']) -> Variation_1218:
        ...

    @overload
    def get_item(self, name : Literal['CHR']) -> Variation_196:
        ...

    def get_item(self, name : Union[Literal['STI'], Literal['CHR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['STI'], val : Union[Variation_1218, Variation_1218_Arg]) -> 'Variation_1219':
        ...

    @overload
    def set_item(self, name : Literal['CHR'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_1219':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['STI'], f : Any) -> 'Variation_1219':
        ...

    @overload
    def modify_item(self, name : Literal['CHR'], f : Any) -> 'Variation_1219':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1220_Arg : TypeAlias = Raw
class Variation_1220(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Air Speed = IAS, LSB (Bit-1) = 2^-14 NM/s',
        1: 'Air Speed = Mach, LSB (Bit-1) = 0.001',
    }

    def __init__(self, arg : Variation_1220_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1221_Arg_Group = TypedDict('Variation_1221_Arg_Group', {
    'IM': Union[Variation_1220, Variation_1220_Arg],
    'IAS': Union[Variation_337, Variation_337_Arg],
})
Variation_1221_Arg : TypeAlias = Union[Raw, Variation_1221_Arg_Group]
class Variation_1221(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('IM', Variation_1220),
        ('IAS', Variation_337),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'IM': ('', Variation_1220, 0, 1),
        'IAS': ('', Variation_337, 1, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['IM']) -> Type[Variation_1220]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAS']) -> Type[Variation_337]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['IM'], Literal['IAS']]) -> Union[Type['Variation_1220'], Type['Variation_337']]:
        if key == 'IM':
            return Variation_1220
        if key == 'IAS':
            return Variation_337
        assert_never(key)

    def __init__(self, arg : Variation_1221_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['IM']) -> Variation_1220:
        ...

    @overload
    def get_item(self, name : Literal['IAS']) -> Variation_337:
        ...

    def get_item(self, name : Union[Literal['IM'], Literal['IAS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['IM'], val : Union[Variation_1220, Variation_1220_Arg]) -> 'Variation_1221':
        ...

    @overload
    def set_item(self, name : Literal['IAS'], val : Union[Variation_337, Variation_337_Arg]) -> 'Variation_1221':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['IM'], f : Any) -> 'Variation_1221':
        ...

    @overload
    def modify_item(self, name : Literal['IAS'], f : Any) -> 'Variation_1221':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1222_Arg : TypeAlias = Raw
class Variation_1222(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No source information provided',
        1: 'Source information provided',
    }

    def __init__(self, arg : Variation_1222_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1223_Arg : TypeAlias = Raw
class Variation_1223(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Aircraft altitude',
        2: 'FCU/MCP selected altitude',
        3: 'FMS selected altitude',
    }

    def __init__(self, arg : Variation_1223_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1224_Arg_Group = TypedDict('Variation_1224_Arg_Group', {
    'SAS': Union[Variation_1222, Variation_1222_Arg],
    'SRC': Union[Variation_1223, Variation_1223_Arg],
    'ALT': Union[Variation_734, Variation_734_Arg],
})
Variation_1224_Arg : TypeAlias = Union[Raw, Variation_1224_Arg_Group]
class Variation_1224(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('SAS', Variation_1222),
        ('SRC', Variation_1223),
        ('ALT', Variation_734),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SAS': ('', Variation_1222, 0, 1),
        'SRC': ('', Variation_1223, 1, 2),
        'ALT': ('Altitude in Two\'s Complement Form', Variation_734, 3, 13),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SAS']) -> Type[Variation_1222]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRC']) -> Type[Variation_1223]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_734]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SAS'], Literal['SRC'], Literal['ALT']]) -> Union[Type['Variation_1222'], Type['Variation_1223'], Type['Variation_734']]:
        if key == 'SAS':
            return Variation_1222
        if key == 'SRC':
            return Variation_1223
        if key == 'ALT':
            return Variation_734
        assert_never(key)

    def __init__(self, arg : Variation_1224_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SAS']) -> Variation_1222:
        ...

    @overload
    def get_item(self, name : Literal['SRC']) -> Variation_1223:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_734:
        ...

    def get_item(self, name : Union[Literal['SAS'], Literal['SRC'], Literal['ALT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SAS'], val : Union[Variation_1222, Variation_1222_Arg]) -> 'Variation_1224':
        ...

    @overload
    def set_item(self, name : Literal['SRC'], val : Union[Variation_1223, Variation_1223_Arg]) -> 'Variation_1224':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_734, Variation_734_Arg]) -> 'Variation_1224':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SAS'], f : Any) -> 'Variation_1224':
        ...

    @overload
    def modify_item(self, name : Literal['SRC'], f : Any) -> 'Variation_1224':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_1224':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1225_Arg_Group = TypedDict('Variation_1225_Arg_Group', {
    'MV': Union[Variation_736, Variation_736_Arg],
    'AH': Union[Variation_737, Variation_737_Arg],
    'AM': Union[Variation_738, Variation_738_Arg],
    'ALT': Union[Variation_734, Variation_734_Arg],
})
Variation_1225_Arg : TypeAlias = Union[Raw, Variation_1225_Arg_Group]
class Variation_1225(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('MV', Variation_736),
        ('AH', Variation_737),
        ('AM', Variation_738),
        ('ALT', Variation_734),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MV': ('Manage Vertical Mode', Variation_736, 0, 1),
        'AH': ('Altitude Hold', Variation_737, 1, 1),
        'AM': ('Approach Mode', Variation_738, 2, 1),
        'ALT': ('Altitude in Two\'s Complement Form', Variation_734, 3, 13),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MV']) -> Type[Variation_736]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AH']) -> Type[Variation_737]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AM']) -> Type[Variation_738]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_734]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MV'], Literal['AH'], Literal['AM'], Literal['ALT']]) -> Union[Type['Variation_736'], Type['Variation_737'], Type['Variation_738'], Type['Variation_734']]:
        if key == 'MV':
            return Variation_736
        if key == 'AH':
            return Variation_737
        if key == 'AM':
            return Variation_738
        if key == 'ALT':
            return Variation_734
        assert_never(key)

    def __init__(self, arg : Variation_1225_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MV']) -> Variation_736:
        ...

    @overload
    def get_item(self, name : Literal['AH']) -> Variation_737:
        ...

    @overload
    def get_item(self, name : Literal['AM']) -> Variation_738:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_734:
        ...

    def get_item(self, name : Union[Literal['MV'], Literal['AH'], Literal['AM'], Literal['ALT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MV'], val : Union[Variation_736, Variation_736_Arg]) -> 'Variation_1225':
        ...

    @overload
    def set_item(self, name : Literal['AH'], val : Union[Variation_737, Variation_737_Arg]) -> 'Variation_1225':
        ...

    @overload
    def set_item(self, name : Literal['AM'], val : Union[Variation_738, Variation_738_Arg]) -> 'Variation_1225':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_734, Variation_734_Arg]) -> 'Variation_1225':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MV'], f : Any) -> 'Variation_1225':
        ...

    @overload
    def modify_item(self, name : Literal['AH'], f : Any) -> 'Variation_1225':
        ...

    @overload
    def modify_item(self, name : Literal['AM'], f : Any) -> 'Variation_1225':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_1225':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1226_Arg : TypeAlias = Raw
class Variation_1226(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Trajectory intent data is available for this aircraft',
        1: 'Trajectory intent data is not available for this aircraft',
    }

    def __init__(self, arg : Variation_1226_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1227_Arg : TypeAlias = Raw
class Variation_1227(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Trajectory intent data is valid',
        1: 'Trajectory intent data is not valid',
    }

    def __init__(self, arg : Variation_1227_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1228_Arg_Group_1 = TypedDict('Variation_1228_Arg_Group_1', {
    'NAV': Union[Variation_1226, Variation_1226_Arg],
    'NVB': Union[Variation_1227, Variation_1227_Arg],
})
Variation_1228_Arg : TypeAlias = Union[
    int,
    Variation_1228_Arg_Group_1,
    Tuple[int],
]
class Variation_1228(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
    ]

    subitems_list = [
        [
            ('NAV', Variation_1226),
            ('NVB', Variation_1227),
            Spare(2, 5),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NAV': ('TID Available', Variation_1226, 0, 1),
        'NVB': ('TID Valid', Variation_1227, 1, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NAV']) -> Type[Variation_1226]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NVB']) -> Type[Variation_1227]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NAV'], Literal['NVB']]) -> Union[Type['Variation_1226'], Type['Variation_1227']]:
        if key == 'NAV':
            return Variation_1226
        if key == 'NVB':
            return Variation_1227
        assert_never(key)

    def __init__(self, arg : Variation_1228_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1228_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NAV']) -> Variation_1226:
        ...

    @overload
    def get_item(self, name : Literal['NVB']) -> Variation_1227:
        ...

    def get_item(self, name : Union[Literal['NAV'], Literal['NVB']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NAV'], val : Union[Variation_1226, Variation_1226_Arg]) -> 'Variation_1228':
        ...

    @overload
    def set_item(self, name : Literal['NVB'], val : Union[Variation_1227, Variation_1227_Arg]) -> 'Variation_1228':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NAV'], f : Any) -> 'Variation_1228':
        ...

    @overload
    def modify_item(self, name : Literal['NVB'], f : Any) -> 'Variation_1228':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1229_Arg_Group = TypedDict('Variation_1229_Arg_Group', {
    'TCA': Union[Variation_743, Variation_743_Arg],
    'NC': Union[Variation_744, Variation_744_Arg],
    'TCPN': Union[Variation_376, Variation_376_Arg],
    'ALT': Union[Variation_745, Variation_745_Arg],
    'LAT': Union[Variation_704, Variation_704_Arg],
    'LON': Union[Variation_704, Variation_704_Arg],
    'PT': Union[Variation_746, Variation_746_Arg],
    'TD': Union[Variation_747, Variation_747_Arg],
    'TRA': Union[Variation_748, Variation_748_Arg],
    'TOA': Union[Variation_749, Variation_749_Arg],
    'TOV': Union[Variation_750, Variation_750_Arg],
    'TTR': Union[Variation_751, Variation_751_Arg],
})
Variation_1229_Arg : TypeAlias = Union[Raw, Variation_1229_Arg_Group]
class Variation_1229(Group):
    variation = 'Group'

    bit_size = 120

    subitems_list = [
        ('TCA', Variation_743),
        ('NC', Variation_744),
        ('TCPN', Variation_376),
        ('ALT', Variation_745),
        ('LAT', Variation_704),
        ('LON', Variation_704),
        ('PT', Variation_746),
        ('TD', Variation_747),
        ('TRA', Variation_748),
        ('TOA', Variation_749),
        ('TOV', Variation_750),
        ('TTR', Variation_751),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TCA': ('TCP Number Availability', Variation_743, 0, 1),
        'NC': ('TCP Compliance', Variation_744, 1, 1),
        'TCPN': ('Trajectory Change Point Number', Variation_376, 2, 6),
        'ALT': ('Altitude in Two\'s Complement Form', Variation_745, 8, 16),
        'LAT': ('Latitude in WGS.84 in Two\'s Complement', Variation_704, 24, 24),
        'LON': ('Longitude in WGS.84 in Two\'s Complement', Variation_704, 48, 24),
        'PT': ('Point Type', Variation_746, 72, 4),
        'TD': ('Turn Direction', Variation_747, 76, 2),
        'TRA': ('Turn Radius Availability', Variation_748, 78, 1),
        'TOA': ('TOV Available', Variation_749, 79, 1),
        'TOV': ('Time Over Point', Variation_750, 80, 24),
        'TTR': ('TCP Turn Radius', Variation_751, 104, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TCA']) -> Type[Variation_743]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NC']) -> Type[Variation_744]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TCPN']) -> Type[Variation_376]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ALT']) -> Type[Variation_745]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_704]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_704]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PT']) -> Type[Variation_746]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TD']) -> Type[Variation_747]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRA']) -> Type[Variation_748]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOA']) -> Type[Variation_749]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOV']) -> Type[Variation_750]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TTR']) -> Type[Variation_751]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TCA'], Literal['NC'], Literal['TCPN'], Literal['ALT'], Literal['LAT'], Literal['LON'], Literal['PT'], Literal['TD'], Literal['TRA'], Literal['TOA'], Literal['TOV'], Literal['TTR']]) -> Union[Type['Variation_743'], Type['Variation_744'], Type['Variation_376'], Type['Variation_745'], Type['Variation_704'], Type['Variation_704'], Type['Variation_746'], Type['Variation_747'], Type['Variation_748'], Type['Variation_749'], Type['Variation_750'], Type['Variation_751']]:
        if key == 'TCA':
            return Variation_743
        if key == 'NC':
            return Variation_744
        if key == 'TCPN':
            return Variation_376
        if key == 'ALT':
            return Variation_745
        if key == 'LAT':
            return Variation_704
        if key == 'LON':
            return Variation_704
        if key == 'PT':
            return Variation_746
        if key == 'TD':
            return Variation_747
        if key == 'TRA':
            return Variation_748
        if key == 'TOA':
            return Variation_749
        if key == 'TOV':
            return Variation_750
        if key == 'TTR':
            return Variation_751
        assert_never(key)

    def __init__(self, arg : Variation_1229_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TCA']) -> Variation_743:
        ...

    @overload
    def get_item(self, name : Literal['NC']) -> Variation_744:
        ...

    @overload
    def get_item(self, name : Literal['TCPN']) -> Variation_376:
        ...

    @overload
    def get_item(self, name : Literal['ALT']) -> Variation_745:
        ...

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_704:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_704:
        ...

    @overload
    def get_item(self, name : Literal['PT']) -> Variation_746:
        ...

    @overload
    def get_item(self, name : Literal['TD']) -> Variation_747:
        ...

    @overload
    def get_item(self, name : Literal['TRA']) -> Variation_748:
        ...

    @overload
    def get_item(self, name : Literal['TOA']) -> Variation_749:
        ...

    @overload
    def get_item(self, name : Literal['TOV']) -> Variation_750:
        ...

    @overload
    def get_item(self, name : Literal['TTR']) -> Variation_751:
        ...

    def get_item(self, name : Union[Literal['TCA'], Literal['NC'], Literal['TCPN'], Literal['ALT'], Literal['LAT'], Literal['LON'], Literal['PT'], Literal['TD'], Literal['TRA'], Literal['TOA'], Literal['TOV'], Literal['TTR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TCA'], val : Union[Variation_743, Variation_743_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['NC'], val : Union[Variation_744, Variation_744_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['TCPN'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['ALT'], val : Union[Variation_745, Variation_745_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['PT'], val : Union[Variation_746, Variation_746_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['TD'], val : Union[Variation_747, Variation_747_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['TRA'], val : Union[Variation_748, Variation_748_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['TOA'], val : Union[Variation_749, Variation_749_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['TOV'], val : Union[Variation_750, Variation_750_Arg]) -> 'Variation_1229':
        ...

    @overload
    def set_item(self, name : Literal['TTR'], val : Union[Variation_751, Variation_751_Arg]) -> 'Variation_1229':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TCA'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['NC'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['TCPN'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['ALT'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['PT'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['TD'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['TRA'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['TOA'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['TOV'], f : Any) -> 'Variation_1229':
        ...

    @overload
    def modify_item(self, name : Literal['TTR'], f : Any) -> 'Variation_1229':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1230_Arg : TypeAlias = Union[Variation_1229, Variation_1229_Arg]
class Variation_1230(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 120
    variation_type = Variation_1229

    @classmethod
    def spec(cls) -> Type[Variation_1229]:
        return Variation_1229

    def __init__(self, arg : List[Union[Variation_1229, Variation_1229_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1229, Variation_1229_Arg]) -> 'Variation_1230':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1229, Variation_1229_Arg]) -> 'Variation_1230':
        return self._prepend_item(arg) # type: ignore

Variation_1231_Arg : TypeAlias = Raw
class Variation_1231(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 3
    table = {
        0: 'No alert, no SPI, aircraft airborne',
        1: 'No alert, no SPI, aircraft on ground',
        2: 'Alert, no SPI, aircraft airborne',
        3: 'Alert, no SPI, aircraft on ground',
        4: 'Alert, SPI, aircraft airborne or on ground',
        5: 'No alert, SPI, aircraft airborne or on ground',
    }

    def __init__(self, arg : Variation_1231_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1232_Arg_Group = TypedDict('Variation_1232_Arg_Group', {
    'COM': Union[Variation_322, Variation_322_Arg],
    'STAT': Union[Variation_1231, Variation_1231_Arg],
    'SSC': Union[Variation_324, Variation_324_Arg],
    'ARC': Union[Variation_325, Variation_325_Arg],
    'AIC': Union[Variation_326, Variation_326_Arg],
    'B1A': Union[Variation_237, Variation_237_Arg],
    'B1B': Union[Variation_282, Variation_282_Arg],
})
Variation_1232_Arg : TypeAlias = Union[Raw, Variation_1232_Arg_Group]
class Variation_1232(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('COM', Variation_322),
        ('STAT', Variation_1231),
        Spare(6, 2),
        ('SSC', Variation_324),
        ('ARC', Variation_325),
        ('AIC', Variation_326),
        ('B1A', Variation_237),
        ('B1B', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COM': ('Communications Capability of the Transponder', Variation_322, 0, 3),
        'STAT': ('Flight Status', Variation_1231, 3, 3),
        'SSC': ('Specific Service Capability', Variation_324, 8, 1),
        'ARC': ('Altitude Reporting Capability', Variation_325, 9, 1),
        'AIC': ('Aircraft Identification Capability', Variation_326, 10, 1),
        'B1A': ('BDS 1,0 Bit 16', Variation_237, 11, 1),
        'B1B': ('BDS BDS 1,0 Bits 37/40', Variation_282, 12, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_322]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STAT']) -> Type[Variation_1231]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSC']) -> Type[Variation_324]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_325]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AIC']) -> Type[Variation_326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1A']) -> Type[Variation_237]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1B']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COM'], Literal['STAT'], Literal['SSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B']]) -> Union[Type['Variation_322'], Type['Variation_1231'], Type['Variation_324'], Type['Variation_325'], Type['Variation_326'], Type['Variation_237'], Type['Variation_282']]:
        if key == 'COM':
            return Variation_322
        if key == 'STAT':
            return Variation_1231
        if key == 'SSC':
            return Variation_324
        if key == 'ARC':
            return Variation_325
        if key == 'AIC':
            return Variation_326
        if key == 'B1A':
            return Variation_237
        if key == 'B1B':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_1232_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_322:
        ...

    @overload
    def get_item(self, name : Literal['STAT']) -> Variation_1231:
        ...

    @overload
    def get_item(self, name : Literal['SSC']) -> Variation_324:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_325:
        ...

    @overload
    def get_item(self, name : Literal['AIC']) -> Variation_326:
        ...

    @overload
    def get_item(self, name : Literal['B1A']) -> Variation_237:
        ...

    @overload
    def get_item(self, name : Literal['B1B']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['COM'], Literal['STAT'], Literal['SSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_322, Variation_322_Arg]) -> 'Variation_1232':
        ...

    @overload
    def set_item(self, name : Literal['STAT'], val : Union[Variation_1231, Variation_1231_Arg]) -> 'Variation_1232':
        ...

    @overload
    def set_item(self, name : Literal['SSC'], val : Union[Variation_324, Variation_324_Arg]) -> 'Variation_1232':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_325, Variation_325_Arg]) -> 'Variation_1232':
        ...

    @overload
    def set_item(self, name : Literal['AIC'], val : Union[Variation_326, Variation_326_Arg]) -> 'Variation_1232':
        ...

    @overload
    def set_item(self, name : Literal['B1A'], val : Union[Variation_237, Variation_237_Arg]) -> 'Variation_1232':
        ...

    @overload
    def set_item(self, name : Literal['B1B'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_1232':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1232':
        ...

    @overload
    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_1232':
        ...

    @overload
    def modify_item(self, name : Literal['SSC'], f : Any) -> 'Variation_1232':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_1232':
        ...

    @overload
    def modify_item(self, name : Literal['AIC'], f : Any) -> 'Variation_1232':
        ...

    @overload
    def modify_item(self, name : Literal['B1A'], f : Any) -> 'Variation_1232':
        ...

    @overload
    def modify_item(self, name : Literal['B1B'], f : Any) -> 'Variation_1232':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1233_Arg : TypeAlias = Raw
class Variation_1233(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'ACAS not operational',
        2: 'ACAS operational',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_1233_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1234_Arg : TypeAlias = Raw
class Variation_1234(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Multiple navigational aids not operating',
        2: 'Multiple navigational aids operating',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_1234_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1235_Arg : TypeAlias = Raw
class Variation_1235(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        0: 'Unknown',
        1: 'Differential correction',
        2: 'No differential correction',
        3: 'Invalid',
    }

    def __init__(self, arg : Variation_1235_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1236_Arg : TypeAlias = Raw
class Variation_1236(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Transponder ground bit not set or unknown',
        1: 'Transponder Ground Bit set',
    }

    def __init__(self, arg : Variation_1236_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1237_Arg : TypeAlias = Raw
class Variation_1237(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 3
    table = {
        0: 'No emergency',
        1: 'General emergency',
        2: 'Lifeguard / medical',
        3: 'Minimum fuel',
        4: 'No communications',
        5: 'Unlawful interference',
        6: 'Downed Aircraft',
        7: 'Unknown',
    }

    def __init__(self, arg : Variation_1237_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1238_Arg_Group = TypedDict('Variation_1238_Arg_Group', {
    'AC': Union[Variation_1233, Variation_1233_Arg],
    'MN': Union[Variation_1234, Variation_1234_Arg],
    'DC': Union[Variation_1235, Variation_1235_Arg],
    'GBS': Union[Variation_1236, Variation_1236_Arg],
    'STAT': Union[Variation_1237, Variation_1237_Arg],
})
Variation_1238_Arg : TypeAlias = Union[Raw, Variation_1238_Arg_Group]
class Variation_1238(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('AC', Variation_1233),
        ('MN', Variation_1234),
        ('DC', Variation_1235),
        ('GBS', Variation_1236),
        Spare(7, 6),
        ('STAT', Variation_1237),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'AC': ('ACAS Status', Variation_1233, 0, 2),
        'MN': ('Multiple Navigational Aids Status', Variation_1234, 2, 2),
        'DC': ('Differential Correction Status', Variation_1235, 4, 2),
        'GBS': ('Ground Bit Set', Variation_1236, 6, 1),
        'STAT': ('Flight Status', Variation_1237, 13, 3),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['AC']) -> Type[Variation_1233]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MN']) -> Type[Variation_1234]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DC']) -> Type[Variation_1235]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GBS']) -> Type[Variation_1236]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STAT']) -> Type[Variation_1237]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['AC'], Literal['MN'], Literal['DC'], Literal['GBS'], Literal['STAT']]) -> Union[Type['Variation_1233'], Type['Variation_1234'], Type['Variation_1235'], Type['Variation_1236'], Type['Variation_1237']]:
        if key == 'AC':
            return Variation_1233
        if key == 'MN':
            return Variation_1234
        if key == 'DC':
            return Variation_1235
        if key == 'GBS':
            return Variation_1236
        if key == 'STAT':
            return Variation_1237
        assert_never(key)

    def __init__(self, arg : Variation_1238_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['AC']) -> Variation_1233:
        ...

    @overload
    def get_item(self, name : Literal['MN']) -> Variation_1234:
        ...

    @overload
    def get_item(self, name : Literal['DC']) -> Variation_1235:
        ...

    @overload
    def get_item(self, name : Literal['GBS']) -> Variation_1236:
        ...

    @overload
    def get_item(self, name : Literal['STAT']) -> Variation_1237:
        ...

    def get_item(self, name : Union[Literal['AC'], Literal['MN'], Literal['DC'], Literal['GBS'], Literal['STAT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['AC'], val : Union[Variation_1233, Variation_1233_Arg]) -> 'Variation_1238':
        ...

    @overload
    def set_item(self, name : Literal['MN'], val : Union[Variation_1234, Variation_1234_Arg]) -> 'Variation_1238':
        ...

    @overload
    def set_item(self, name : Literal['DC'], val : Union[Variation_1235, Variation_1235_Arg]) -> 'Variation_1238':
        ...

    @overload
    def set_item(self, name : Literal['GBS'], val : Union[Variation_1236, Variation_1236_Arg]) -> 'Variation_1238':
        ...

    @overload
    def set_item(self, name : Literal['STAT'], val : Union[Variation_1237, Variation_1237_Arg]) -> 'Variation_1238':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['AC'], f : Any) -> 'Variation_1238':
        ...

    @overload
    def modify_item(self, name : Literal['MN'], f : Any) -> 'Variation_1238':
        ...

    @overload
    def modify_item(self, name : Literal['DC'], f : Any) -> 'Variation_1238':
        ...

    @overload
    def modify_item(self, name : Literal['GBS'], f : Any) -> 'Variation_1238':
        ...

    @overload
    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_1238':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1239_Arg_Group = TypedDict('Variation_1239_Arg_Group', {
    'TI': Union[Variation_723, Variation_723_Arg],
    'ROT': Union[Variation_724, Variation_724_Arg],
})
Variation_1239_Arg : TypeAlias = Union[Raw, Variation_1239_Arg_Group]
class Variation_1239(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('TI', Variation_723),
        Spare(2, 6),
        ('ROT', Variation_724),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TI': ('Turn Indicator', Variation_723, 0, 2),
        'ROT': ('Rate of Turn in Two\'s Complement Form', Variation_724, 8, 7),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TI']) -> Type[Variation_723]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ROT']) -> Type[Variation_724]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TI'], Literal['ROT']]) -> Union[Type['Variation_723'], Type['Variation_724']]:
        if key == 'TI':
            return Variation_723
        if key == 'ROT':
            return Variation_724
        assert_never(key)

    def __init__(self, arg : Variation_1239_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TI']) -> Variation_723:
        ...

    @overload
    def get_item(self, name : Literal['ROT']) -> Variation_724:
        ...

    def get_item(self, name : Union[Literal['TI'], Literal['ROT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TI'], val : Union[Variation_723, Variation_723_Arg]) -> 'Variation_1239':
        ...

    @overload
    def set_item(self, name : Literal['ROT'], val : Union[Variation_724, Variation_724_Arg]) -> 'Variation_1239':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TI'], f : Any) -> 'Variation_1239':
        ...

    @overload
    def modify_item(self, name : Literal['ROT'], f : Any) -> 'Variation_1239':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1240_Arg : TypeAlias = Raw
class Variation_1240(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Not valid Wind Speed',
        1: 'Valid Wind Speed',
    }

    def __init__(self, arg : Variation_1240_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1241_Arg : TypeAlias = Raw
class Variation_1241(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Not valid Wind Direction',
        1: 'Valid Wind Direction',
    }

    def __init__(self, arg : Variation_1241_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1242_Arg : TypeAlias = Raw
class Variation_1242(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Not valid Temperature',
        1: 'Valid Temperature',
    }

    def __init__(self, arg : Variation_1242_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1243_Arg : TypeAlias = Raw
class Variation_1243(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Not valid Turbulence',
        1: 'Valid Turbulence',
    }

    def __init__(self, arg : Variation_1243_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1244_Arg_Group = TypedDict('Variation_1244_Arg_Group', {
    'WS': Union[Variation_1240, Variation_1240_Arg],
    'WD': Union[Variation_1241, Variation_1241_Arg],
    'TMP': Union[Variation_1242, Variation_1242_Arg],
    'TRB': Union[Variation_1243, Variation_1243_Arg],
    'WSD': Union[Variation_720, Variation_720_Arg],
    'WDD': Union[Variation_729, Variation_729_Arg],
    'TMPD': Union[Variation_730, Variation_730_Arg],
    'TRBD': Union[Variation_0, Variation_0_Arg],
})
Variation_1244_Arg : TypeAlias = Union[Raw, Variation_1244_Arg_Group]
class Variation_1244(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('WS', Variation_1240),
        ('WD', Variation_1241),
        ('TMP', Variation_1242),
        ('TRB', Variation_1243),
        Spare(4, 4),
        ('WSD', Variation_720),
        ('WDD', Variation_729),
        ('TMPD', Variation_730),
        ('TRBD', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'WS': ('Wind Speed Valid Flag', Variation_1240, 0, 1),
        'WD': ('Wind Direction Valid Flag', Variation_1241, 1, 1),
        'TMP': ('Temperature Valid Flag', Variation_1242, 2, 1),
        'TRB': ('Turbulence Valid Flag', Variation_1243, 3, 1),
        'WSD': ('Wind Speed', Variation_720, 8, 16),
        'WDD': ('Wind Direction', Variation_729, 24, 16),
        'TMPD': ('Temperature in Degrees Celsius', Variation_730, 40, 16),
        'TRBD': ('Turbulence', Variation_0, 56, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['WS']) -> Type[Variation_1240]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WD']) -> Type[Variation_1241]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TMP']) -> Type[Variation_1242]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRB']) -> Type[Variation_1243]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WSD']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WDD']) -> Type[Variation_729]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TMPD']) -> Type[Variation_730]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TRBD']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['WS'], Literal['WD'], Literal['TMP'], Literal['TRB'], Literal['WSD'], Literal['WDD'], Literal['TMPD'], Literal['TRBD']]) -> Union[Type['Variation_1240'], Type['Variation_1241'], Type['Variation_1242'], Type['Variation_1243'], Type['Variation_720'], Type['Variation_729'], Type['Variation_730'], Type['Variation_0']]:
        if key == 'WS':
            return Variation_1240
        if key == 'WD':
            return Variation_1241
        if key == 'TMP':
            return Variation_1242
        if key == 'TRB':
            return Variation_1243
        if key == 'WSD':
            return Variation_720
        if key == 'WDD':
            return Variation_729
        if key == 'TMPD':
            return Variation_730
        if key == 'TRBD':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_1244_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['WS']) -> Variation_1240:
        ...

    @overload
    def get_item(self, name : Literal['WD']) -> Variation_1241:
        ...

    @overload
    def get_item(self, name : Literal['TMP']) -> Variation_1242:
        ...

    @overload
    def get_item(self, name : Literal['TRB']) -> Variation_1243:
        ...

    @overload
    def get_item(self, name : Literal['WSD']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['WDD']) -> Variation_729:
        ...

    @overload
    def get_item(self, name : Literal['TMPD']) -> Variation_730:
        ...

    @overload
    def get_item(self, name : Literal['TRBD']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['WS'], Literal['WD'], Literal['TMP'], Literal['TRB'], Literal['WSD'], Literal['WDD'], Literal['TMPD'], Literal['TRBD']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['WS'], val : Union[Variation_1240, Variation_1240_Arg]) -> 'Variation_1244':
        ...

    @overload
    def set_item(self, name : Literal['WD'], val : Union[Variation_1241, Variation_1241_Arg]) -> 'Variation_1244':
        ...

    @overload
    def set_item(self, name : Literal['TMP'], val : Union[Variation_1242, Variation_1242_Arg]) -> 'Variation_1244':
        ...

    @overload
    def set_item(self, name : Literal['TRB'], val : Union[Variation_1243, Variation_1243_Arg]) -> 'Variation_1244':
        ...

    @overload
    def set_item(self, name : Literal['WSD'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_1244':
        ...

    @overload
    def set_item(self, name : Literal['WDD'], val : Union[Variation_729, Variation_729_Arg]) -> 'Variation_1244':
        ...

    @overload
    def set_item(self, name : Literal['TMPD'], val : Union[Variation_730, Variation_730_Arg]) -> 'Variation_1244':
        ...

    @overload
    def set_item(self, name : Literal['TRBD'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1244':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['WS'], f : Any) -> 'Variation_1244':
        ...

    @overload
    def modify_item(self, name : Literal['WD'], f : Any) -> 'Variation_1244':
        ...

    @overload
    def modify_item(self, name : Literal['TMP'], f : Any) -> 'Variation_1244':
        ...

    @overload
    def modify_item(self, name : Literal['TRB'], f : Any) -> 'Variation_1244':
        ...

    @overload
    def modify_item(self, name : Literal['WSD'], f : Any) -> 'Variation_1244':
        ...

    @overload
    def modify_item(self, name : Literal['WDD'], f : Any) -> 'Variation_1244':
        ...

    @overload
    def modify_item(self, name : Literal['TMPD'], f : Any) -> 'Variation_1244':
        ...

    @overload
    def modify_item(self, name : Literal['TRBD'], f : Any) -> 'Variation_1244':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1245_Arg : TypeAlias = Raw
class Variation_1245(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Light aircraft =< 7000 kg',
        2: 'Reserved',
        3: '7000 kg < medium aircraft < 136000 kg',
        4: 'Reserved',
        5: '136000 kg <= heavy aircraft',
        6: 'Highly manoeuvrable (5g acceleration capability) and high speed (>400 knots cruise)',
        7: 'Reserved',
        8: 'Reserved',
        9: 'Reserved',
        10: 'Rotocraft',
        11: 'Glider / sailplane',
        12: 'Lighter-than-air',
        13: 'Unmanned aerial vehicle',
        14: 'Space / transatmospheric vehicle',
        15: 'Ultralight / handglider / paraglider',
        16: 'Parachutist / skydiver',
        17: 'Reserved',
        18: 'Reserved',
        19: 'Reserved',
        20: 'Surface emergency vehicle',
        21: 'Surface service vehicle',
        22: 'Fixed ground or tethered obstruction',
        23: 'Reserved',
        24: 'Reserved',
    }

    def __init__(self, arg : Variation_1245_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1246_Arg_Group = TypedDict('Variation_1246_Arg_Group', {
    'LAT': Union[Variation_704, Variation_704_Arg],
    'LON': Union[Variation_704, Variation_704_Arg],
})
Variation_1246_Arg : TypeAlias = Union[Raw, Variation_1246_Arg_Group]
class Variation_1246(Group):
    variation = 'Group'

    bit_size = 48

    subitems_list = [
        ('LAT', Variation_704),
        ('LON', Variation_704),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude in WGS.84 in Two\'s Complement Form', Variation_704, 0, 24),
        'LON': ('Longitude in WGS.84 in Two\'s Complement Form', Variation_704, 24, 24),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_704]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_704]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_704'], Type['Variation_704']]:
        if key == 'LAT':
            return Variation_704
        if key == 'LON':
            return Variation_704
        assert_never(key)

    def __init__(self, arg : Variation_1246_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_704:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_704:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_1246':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_704, Variation_704_Arg]) -> 'Variation_1246':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_1246':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_1246':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1247_Arg_Group = TypedDict('Variation_1247_Arg_Group', {
    'PUN': Union[Variation_282, Variation_282_Arg],
})
Variation_1247_Arg : TypeAlias = Union[Raw, Variation_1247_Arg_Group]
class Variation_1247(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 4),
        ('PUN', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PUN': ('Position Uncertainty', Variation_282, 4, 4),
    }


    @classmethod
    def spec(cls, key : Union[Literal['PUN']]) -> Union[Type['Variation_282']]:
        if key == 'PUN':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_1247_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['PUN']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['PUN'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_1247':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['PUN'], f : Any) -> 'Variation_1247':
        return self._modify_item(name, f) # type: ignore

Variation_1248_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['Mach']]]
class Variation_1248(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 8.0e-3, 'Mach')

    def __init__(self, arg : Variation_1248_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1249_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['mb']]]
class Variation_1249(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 12
    quantity = Quantity('Unsigned', 0.1, 'mb')

    def __init__(self, arg : Variation_1249_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1250_Arg_Group = TypedDict('Variation_1250_Arg_Group', {
    'BPS': Union[Variation_1249, Variation_1249_Arg],
})
Variation_1250_Arg : TypeAlias = Union[Raw, Variation_1250_Arg_Group]
class Variation_1250(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('BPS', Variation_1249),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'BPS': ('', Variation_1249, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['BPS']]) -> Union[Type['Variation_1249']]:
        if key == 'BPS':
            return Variation_1249
        assert_never(key)

    def __init__(self, arg : Variation_1250_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['BPS']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['BPS'], val : Union[Variation_1249, Variation_1249_Arg]) -> 'Variation_1250':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['BPS'], f : Any) -> 'Variation_1250':
        return self._modify_item(name, f) # type: ignore

Variation_1251_Arg = TypedDict('Variation_1251_Arg', {
    'ADR': Union[Variation_278, Variation_278_Arg],
    'ID': Union[Variation_196, Variation_196_Arg],
    'MHG': Union[Variation_14, Variation_14_Arg],
    'IAS': Union[Variation_1221, Variation_1221_Arg],
    'TAS': Union[Variation_720, Variation_720_Arg],
    'SAL': Union[Variation_1224, Variation_1224_Arg],
    'FSS': Union[Variation_1225, Variation_1225_Arg],
    'TIS': Union[Variation_1228, Variation_1228_Arg],
    'TID': Union[Variation_1230, Variation_1230_Arg],
    'COM': Union[Variation_1232, Variation_1232_Arg],
    'SAB': Union[Variation_1238, Variation_1238_Arg],
    'ACS': Union[Variation_281, Variation_281_Arg],
    'BVR': Union[Variation_364, Variation_364_Arg],
    'GVR': Union[Variation_364, Variation_364_Arg],
    'RAN': Union[Variation_717, Variation_717_Arg],
    'TAR': Union[Variation_1239, Variation_1239_Arg],
    'TAN': Union[Variation_14, Variation_14_Arg],
    'GS': Union[Variation_721, Variation_721_Arg],
    'VUN': Union[Variation_0, Variation_0_Arg],
    'MET': Union[Variation_1244, Variation_1244_Arg],
    'EMC': Union[Variation_1245, Variation_1245_Arg],
    'POS': Union[Variation_1246, Variation_1246_Arg],
    'GAL': Union[Variation_287, Variation_287_Arg],
    'PUN': Union[Variation_1247, Variation_1247_Arg],
    'MB': Union[Variation_321, Variation_321_Arg],
    'IAR': Union[Variation_720, Variation_720_Arg],
    'MAC': Union[Variation_1248, Variation_1248_Arg],
    'BPS': Union[Variation_1250, Variation_1250_Arg],
}, total=False)
class Variation_1251(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('ADR', Variation_278),
        ('ID', Variation_196),
        ('MHG', Variation_14),
        ('IAS', Variation_1221),
        ('TAS', Variation_720),
        ('SAL', Variation_1224),
        ('FSS', Variation_1225),
        ('TIS', Variation_1228),
        ('TID', Variation_1230),
        ('COM', Variation_1232),
        ('SAB', Variation_1238),
        ('ACS', Variation_281),
        ('BVR', Variation_364),
        ('GVR', Variation_364),
        ('RAN', Variation_717),
        ('TAR', Variation_1239),
        ('TAN', Variation_14),
        ('GS', Variation_721),
        ('VUN', Variation_0),
        ('MET', Variation_1244),
        ('EMC', Variation_1245),
        ('POS', Variation_1246),
        ('GAL', Variation_287),
        ('PUN', Variation_1247),
        ('MB', Variation_321),
        ('IAR', Variation_720),
        ('MAC', Variation_1248),
        ('BPS', Variation_1250),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'ADR': ('Target Address', Variation_278, 0x80000000),
        'ID': ('Target Identification', Variation_196, 0x40000000),
        'MHG': ('Magnetic Heading', Variation_14, 0x20000000),
        'IAS': ('Indicated Airspeed/Mach No', Variation_1221, 0x10000000),
        'TAS': ('True Airspeed', Variation_720, 0x08000000),
        'SAL': ('Selected Altitude', Variation_1224, 0x04000000),
        'FSS': ('Final State Selected Altitude', Variation_1225, 0x02000000),
        'TIS': ('Trajectory Intent Status', Variation_1228, 0x01800000),
        'TID': ('Trajectory Intent Data', Variation_1230, 0x01400000),
        'COM': ('Communications/ACAS Capability and Flight Status', Variation_1232, 0x01200000),
        'SAB': ('Status Reported by ADS-B', Variation_1238, 0x01100000),
        'ACS': ('ACAS Resolution Advisory Report', Variation_281, 0x01080000),
        'BVR': ('Barometric Vertical Rate', Variation_364, 0x01040000),
        'GVR': ('Geometric Vertical Rate', Variation_364, 0x01020000),
        'RAN': ('Roll Angle', Variation_717, 0x01018000),
        'TAR': ('Track Angle Rate', Variation_1239, 0x01014000),
        'TAN': ('Track Angle', Variation_14, 0x01012000),
        'GS': ('Ground Speed', Variation_721, 0x01011000),
        'VUN': ('Velocity Uncertainty', Variation_0, 0x01010800),
        'MET': ('Meteorological Data', Variation_1244, 0x01010400),
        'EMC': ('Emitter Category', Variation_1245, 0x01010200),
        'POS': ('Position', Variation_1246, 0x01010180),
        'GAL': ('Geometric Altitude', Variation_287, 0x01010140),
        'PUN': ('Position Uncertainty', Variation_1247, 0x01010120),
        'MB': ('MODE S MB DATA', Variation_321, 0x01010110),
        'IAR': ('Indicated Airspeed', Variation_720, 0x01010108),
        'MAC': ('Mach Number', Variation_1248, 0x01010104),
        'BPS': ('Barometric Pressure Setting (derived from Mode S BDS 4,0)', Variation_1250, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ADR']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ID']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MHG']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAS']) -> Type[Variation_1221]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAS']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAL']) -> Type[Variation_1224]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FSS']) -> Type[Variation_1225]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TIS']) -> Type[Variation_1228]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_1230]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_1232]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAB']) -> Type[Variation_1238]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ACS']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BVR']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GVR']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAN']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAR']) -> Type[Variation_1239]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAN']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GS']) -> Type[Variation_721]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VUN']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MET']) -> Type[Variation_1244]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EMC']) -> Type[Variation_1245]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_1246]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GAL']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PUN']) -> Type[Variation_1247]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MB']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAR']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAC']) -> Type[Variation_1248]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BPS']) -> Type[Variation_1250]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ADR'], Literal['ID'], Literal['MHG'], Literal['IAS'], Literal['TAS'], Literal['SAL'], Literal['FSS'], Literal['TIS'], Literal['TID'], Literal['COM'], Literal['SAB'], Literal['ACS'], Literal['BVR'], Literal['GVR'], Literal['RAN'], Literal['TAR'], Literal['TAN'], Literal['GS'], Literal['VUN'], Literal['MET'], Literal['EMC'], Literal['POS'], Literal['GAL'], Literal['PUN'], Literal['MB'], Literal['IAR'], Literal['MAC'], Literal['BPS']]) -> Union[Type['Variation_278'], Type['Variation_196'], Type['Variation_14'], Type['Variation_1221'], Type['Variation_720'], Type['Variation_1224'], Type['Variation_1225'], Type['Variation_1228'], Type['Variation_1230'], Type['Variation_1232'], Type['Variation_1238'], Type['Variation_281'], Type['Variation_364'], Type['Variation_364'], Type['Variation_717'], Type['Variation_1239'], Type['Variation_14'], Type['Variation_721'], Type['Variation_0'], Type['Variation_1244'], Type['Variation_1245'], Type['Variation_1246'], Type['Variation_287'], Type['Variation_1247'], Type['Variation_321'], Type['Variation_720'], Type['Variation_1248'], Type['Variation_1250']]:
        if key == 'ADR':
            return Variation_278
        if key == 'ID':
            return Variation_196
        if key == 'MHG':
            return Variation_14
        if key == 'IAS':
            return Variation_1221
        if key == 'TAS':
            return Variation_720
        if key == 'SAL':
            return Variation_1224
        if key == 'FSS':
            return Variation_1225
        if key == 'TIS':
            return Variation_1228
        if key == 'TID':
            return Variation_1230
        if key == 'COM':
            return Variation_1232
        if key == 'SAB':
            return Variation_1238
        if key == 'ACS':
            return Variation_281
        if key == 'BVR':
            return Variation_364
        if key == 'GVR':
            return Variation_364
        if key == 'RAN':
            return Variation_717
        if key == 'TAR':
            return Variation_1239
        if key == 'TAN':
            return Variation_14
        if key == 'GS':
            return Variation_721
        if key == 'VUN':
            return Variation_0
        if key == 'MET':
            return Variation_1244
        if key == 'EMC':
            return Variation_1245
        if key == 'POS':
            return Variation_1246
        if key == 'GAL':
            return Variation_287
        if key == 'PUN':
            return Variation_1247
        if key == 'MB':
            return Variation_321
        if key == 'IAR':
            return Variation_720
        if key == 'MAC':
            return Variation_1248
        if key == 'BPS':
            return Variation_1250
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1251_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['ADR'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['ID'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['MHG'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['IAS'], val : Union[Variation_1221, Variation_1221_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['TAS'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['SAL'], val : Union[Variation_1224, Variation_1224_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['FSS'], val : Union[Variation_1225, Variation_1225_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['TIS'], val : Union[Variation_1228, Variation_1228_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_1230, Variation_1230_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_1232, Variation_1232_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['SAB'], val : Union[Variation_1238, Variation_1238_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['ACS'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['BVR'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['GVR'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['RAN'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['TAR'], val : Union[Variation_1239, Variation_1239_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['TAN'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['GS'], val : Union[Variation_721, Variation_721_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['VUN'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['MET'], val : Union[Variation_1244, Variation_1244_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['EMC'], val : Union[Variation_1245, Variation_1245_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_1246, Variation_1246_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['GAL'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['PUN'], val : Union[Variation_1247, Variation_1247_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['MB'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['IAR'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['MAC'], val : Union[Variation_1248, Variation_1248_Arg]) -> 'Variation_1251':
        ...

    @overload
    def set_item(self, name : Literal['BPS'], val : Union[Variation_1250, Variation_1250_Arg]) -> 'Variation_1251':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['ADR']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['ID']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['MHG']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['IAS']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['TAS']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['SAL']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['FSS']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['TIS']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['TID']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['COM']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['SAB']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['ACS']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['BVR']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['GVR']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['RAN']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['TAR']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['TAN']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['GS']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['VUN']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['MET']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['EMC']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['GAL']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['PUN']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['MB']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['IAR']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['MAC']) -> 'Variation_1251':
        ...

    @overload
    def del_item(self, name : Literal['BPS']) -> 'Variation_1251':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['ADR']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['ID']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['MHG']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['IAS']) -> Variation_1221:
        ...

    @overload
    def get_item(self, name : Literal['TAS']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['SAL']) -> Variation_1224:
        ...

    @overload
    def get_item(self, name : Literal['FSS']) -> Variation_1225:
        ...

    @overload
    def get_item(self, name : Literal['TIS']) -> Variation_1228:
        ...

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_1230:
        ...

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_1232:
        ...

    @overload
    def get_item(self, name : Literal['SAB']) -> Variation_1238:
        ...

    @overload
    def get_item(self, name : Literal['ACS']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['BVR']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['GVR']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['RAN']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['TAR']) -> Variation_1239:
        ...

    @overload
    def get_item(self, name : Literal['TAN']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['GS']) -> Variation_721:
        ...

    @overload
    def get_item(self, name : Literal['VUN']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['MET']) -> Variation_1244:
        ...

    @overload
    def get_item(self, name : Literal['EMC']) -> Variation_1245:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_1246:
        ...

    @overload
    def get_item(self, name : Literal['GAL']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['PUN']) -> Variation_1247:
        ...

    @overload
    def get_item(self, name : Literal['MB']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['IAR']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['MAC']) -> Variation_1248:
        ...

    @overload
    def get_item(self, name : Literal['BPS']) -> Variation_1250:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['ADR'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['ID'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['MHG'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['IAS'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['TAS'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['SAL'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['FSS'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['TIS'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['SAB'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['ACS'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['BVR'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['GVR'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['RAN'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['TAR'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['TAN'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['GS'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['VUN'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['MET'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['EMC'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['GAL'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['PUN'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['MB'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['IAR'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['MAC'], f : Any) -> 'Variation_1251':
        ...

    @overload
    def modify_item(self, name : Literal['BPS'], f : Any) -> 'Variation_1251':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1252_Arg : TypeAlias = Raw
class Variation_1252(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Multisensor track',
        1: 'Monosensor track',
    }

    def __init__(self, arg : Variation_1252_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1253_Arg : TypeAlias = Raw
class Variation_1253(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 3
    table = {
        0: 'No source',
        1: 'GNSS',
        2: '3D radar',
        3: 'Triangulation',
        4: 'Height from coverage',
        5: 'Speed look-up table',
        6: 'Default height',
        7: 'Multilateration',
    }

    def __init__(self, arg : Variation_1253_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1254_Arg : TypeAlias = Raw
class Variation_1254(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Actual track',
        1: 'Simulated track',
    }

    def __init__(self, arg : Variation_1254_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1255_Arg : TypeAlias = Raw
class Variation_1255(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Last message transmitted to the user for the track',
    }

    def __init__(self, arg : Variation_1255_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1256_Arg : TypeAlias = Raw
class Variation_1256(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'First message transmitted to the user for the track',
    }

    def __init__(self, arg : Variation_1256_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1257_Arg : TypeAlias = Raw
class Variation_1257(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Slave Track Promotion',
    }

    def __init__(self, arg : Variation_1257_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1258_Arg : TypeAlias = Raw
class Variation_1258(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Complementary service used',
        1: 'Background service used',
    }

    def __init__(self, arg : Variation_1258_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1259_Arg : TypeAlias = Raw
class Variation_1259(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 2
    table = {
        0: 'No Mode 4 interrogation',
        1: 'Friendly target',
        2: 'Unknown target',
        3: 'No reply',
    }

    def __init__(self, arg : Variation_1259_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1260_Arg : TypeAlias = Raw
class Variation_1260(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Military Emergency present in the last report received from a sensor capable of decoding this data',
    }

    def __init__(self, arg : Variation_1260_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1261_Arg : TypeAlias = Raw
class Variation_1261(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Military Identification present in the last report received from a sensor capable of decoding this data',
    }

    def __init__(self, arg : Variation_1261_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1262_Arg : TypeAlias = Raw
class Variation_1262(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 2
    table = {
        0: 'No Mode 5 interrogation',
        1: 'Friendly target',
        2: 'Unknown target',
        3: 'No reply',
    }

    def __init__(self, arg : Variation_1262_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1263_Arg : TypeAlias = Raw
class Variation_1263(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Age of the last received track update is higher than system dependent threshold (coasting)',
    }

    def __init__(self, arg : Variation_1263_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1264_Arg : TypeAlias = Raw
class Variation_1264(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Age of the last received ADS-B track update is higher than system dependent threshold',
    }

    def __init__(self, arg : Variation_1264_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1265_Arg : TypeAlias = Raw
class Variation_1265(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Assigned Mode A Code Conflict (same discrete Mode A Code assigned to another track)',
    }

    def __init__(self, arg : Variation_1265_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1266_Arg : TypeAlias = Raw
class Variation_1266(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Combined',
        1: 'Co-operative only',
        2: 'Non-Cooperative only',
        3: 'Not defined',
    }

    def __init__(self, arg : Variation_1266_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1267_Arg : TypeAlias = Raw
class Variation_1267(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 3
    table = {
        0: 'No emergency',
        1: 'General emergency',
        2: 'Lifeguard / medical',
        3: 'Minimum fuel',
        4: 'No communications',
        5: 'Unlawful interference',
        6: 'Downed Aircraft',
        7: 'Undefined',
    }

    def __init__(self, arg : Variation_1267_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1268_Arg : TypeAlias = Raw
class Variation_1268(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'No indication',
        1: 'Potential False Track Indication',
    }

    def __init__(self, arg : Variation_1268_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1269_Arg : TypeAlias = Raw
class Variation_1269(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Track created / updated with FPL data',
    }

    def __init__(self, arg : Variation_1269_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1270_Arg : TypeAlias = Raw
class Variation_1270(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Duplicate Mode 3/A Code',
    }

    def __init__(self, arg : Variation_1270_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1271_Arg : TypeAlias = Raw
class Variation_1271(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Duplicate Flight Plan',
    }

    def __init__(self, arg : Variation_1271_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1272_Arg : TypeAlias = Raw
class Variation_1272(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Duplicate Flight Plan due to manual correlation',
    }

    def __init__(self, arg : Variation_1272_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1273_Arg_Group_1 = TypedDict('Variation_1273_Arg_Group_1', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
})
Variation_1273_Arg_Group_2 = TypedDict('Variation_1273_Arg_Group_2', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
})
Variation_1273_Arg_Group_3 = TypedDict('Variation_1273_Arg_Group_3', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
})
Variation_1273_Arg_Group_4 = TypedDict('Variation_1273_Arg_Group_4', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
    'CST': Union[Variation_1263, Variation_1263_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_1264, Variation_1264_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_1265, Variation_1265_Arg],
})
Variation_1273_Arg_Group_5 = TypedDict('Variation_1273_Arg_Group_5', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
    'CST': Union[Variation_1263, Variation_1263_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_1264, Variation_1264_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_1265, Variation_1265_Arg],
    'SDS': Union[Variation_1266, Variation_1266_Arg],
    'EMS': Union[Variation_1267, Variation_1267_Arg],
    'PFT': Union[Variation_1268, Variation_1268_Arg],
    'FPLT': Union[Variation_1269, Variation_1269_Arg],
})
Variation_1273_Arg_Group_6 = TypedDict('Variation_1273_Arg_Group_6', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
    'CST': Union[Variation_1263, Variation_1263_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_1264, Variation_1264_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_1265, Variation_1265_Arg],
    'SDS': Union[Variation_1266, Variation_1266_Arg],
    'EMS': Union[Variation_1267, Variation_1267_Arg],
    'PFT': Union[Variation_1268, Variation_1268_Arg],
    'FPLT': Union[Variation_1269, Variation_1269_Arg],
    'DUPT': Union[Variation_1270, Variation_1270_Arg],
    'DUPF': Union[Variation_1271, Variation_1271_Arg],
    'DUPM': Union[Variation_1272, Variation_1272_Arg],
})
Variation_1273_Arg : TypeAlias = Union[
    int,
    Variation_1273_Arg_Group_1,
    Tuple[int],
    Variation_1273_Arg_Group_2,
    Tuple[int,int],
    Variation_1273_Arg_Group_3,
    Tuple[int,int,int],
    Variation_1273_Arg_Group_4,
    Tuple[int,int,int,int],
    Variation_1273_Arg_Group_5,
    Tuple[int,int,int,int,int],
    Variation_1273_Arg_Group_6,
    Tuple[int,int,int,int,int,int],
]
class Variation_1273(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('MON', Variation_1252),
            ('SPI', Variation_351),
            ('MRH', Variation_341),
            ('SRC', Variation_1253),
            ('CNF', Variation_343),
        ],
        [
            ('SIM', Variation_1254),
            ('TSE', Variation_1255),
            ('TSB', Variation_1256),
            ('FPC', Variation_353),
            ('AFF', Variation_354),
            ('STP', Variation_1257),
            ('KOS', Variation_1258),
        ],
        [
            ('AMA', Variation_350),
            ('MD4', Variation_1259),
            ('ME', Variation_1260),
            ('MI', Variation_1261),
            ('MD5', Variation_1262),
        ],
        [
            ('CST', Variation_1263),
            ('PSR', Variation_416),
            ('SSR', Variation_417),
            ('MDS', Variation_418),
            ('ADS', Variation_1264),
            ('SUC', Variation_420),
            ('AAC', Variation_1265),
        ],
        [
            ('SDS', Variation_1266),
            ('EMS', Variation_1267),
            ('PFT', Variation_1268),
            ('FPLT', Variation_1269),
        ],
        [
            ('DUPT', Variation_1270),
            ('DUPF', Variation_1271),
            ('DUPM', Variation_1272),
            Spare(3, 4),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MON': ('', Variation_1252, 0, 1),
        'SPI': ('', Variation_351, 1, 1),
        'MRH': ('Most Reliable Height', Variation_341, 2, 1),
        'SRC': ('Source of Calculated Track Altitude for I062/130', Variation_1253, 3, 3),
        'CNF': ('', Variation_343, 6, 1),
        'SIM': ('', Variation_1254, 0, 1),
        'TSE': ('', Variation_1255, 1, 1),
        'TSB': ('', Variation_1256, 2, 1),
        'FPC': ('', Variation_353, 3, 1),
        'AFF': ('', Variation_354, 4, 1),
        'STP': ('', Variation_1257, 5, 1),
        'KOS': ('', Variation_1258, 6, 1),
        'AMA': ('', Variation_350, 0, 1),
        'MD4': ('', Variation_1259, 1, 2),
        'ME': ('', Variation_1260, 3, 1),
        'MI': ('', Variation_1261, 4, 1),
        'MD5': ('', Variation_1262, 5, 2),
        'CST': ('', Variation_1263, 0, 1),
        'PSR': ('', Variation_416, 1, 1),
        'SSR': ('', Variation_417, 2, 1),
        'MDS': ('', Variation_418, 3, 1),
        'ADS': ('', Variation_1264, 4, 1),
        'SUC': ('', Variation_420, 5, 1),
        'AAC': ('', Variation_1265, 6, 1),
        'SDS': ('', Variation_1266, 0, 2),
        'EMS': ('', Variation_1267, 2, 3),
        'PFT': ('', Variation_1268, 5, 1),
        'FPLT': ('', Variation_1269, 6, 1),
        'DUPT': ('', Variation_1270, 0, 1),
        'DUPF': ('', Variation_1271, 1, 1),
        'DUPM': ('', Variation_1272, 2, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MON']) -> Type[Variation_1252]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_351]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MRH']) -> Type[Variation_341]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRC']) -> Type[Variation_1253]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_343]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_1254]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSE']) -> Type[Variation_1255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSB']) -> Type[Variation_1256]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FPC']) -> Type[Variation_353]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AFF']) -> Type[Variation_354]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STP']) -> Type[Variation_1257]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['KOS']) -> Type[Variation_1258]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AMA']) -> Type[Variation_350]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD4']) -> Type[Variation_1259]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ME']) -> Type[Variation_1260]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MI']) -> Type[Variation_1261]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD5']) -> Type[Variation_1262]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_1263]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_416]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_417]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_418]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADS']) -> Type[Variation_1264]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SUC']) -> Type[Variation_420]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AAC']) -> Type[Variation_1265]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDS']) -> Type[Variation_1266]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EMS']) -> Type[Variation_1267]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PFT']) -> Type[Variation_1268]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FPLT']) -> Type[Variation_1269]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DUPT']) -> Type[Variation_1270]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DUPF']) -> Type[Variation_1271]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DUPM']) -> Type[Variation_1272]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MON'], Literal['SPI'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FPC'], Literal['AFF'], Literal['STP'], Literal['KOS'], Literal['AMA'], Literal['MD4'], Literal['ME'], Literal['MI'], Literal['MD5'], Literal['CST'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['SUC'], Literal['AAC'], Literal['SDS'], Literal['EMS'], Literal['PFT'], Literal['FPLT'], Literal['DUPT'], Literal['DUPF'], Literal['DUPM']]) -> Union[Type['Variation_1252'], Type['Variation_351'], Type['Variation_341'], Type['Variation_1253'], Type['Variation_343'], Type['Variation_1254'], Type['Variation_1255'], Type['Variation_1256'], Type['Variation_353'], Type['Variation_354'], Type['Variation_1257'], Type['Variation_1258'], Type['Variation_350'], Type['Variation_1259'], Type['Variation_1260'], Type['Variation_1261'], Type['Variation_1262'], Type['Variation_1263'], Type['Variation_416'], Type['Variation_417'], Type['Variation_418'], Type['Variation_1264'], Type['Variation_420'], Type['Variation_1265'], Type['Variation_1266'], Type['Variation_1267'], Type['Variation_1268'], Type['Variation_1269'], Type['Variation_1270'], Type['Variation_1271'], Type['Variation_1272']]:
        if key == 'MON':
            return Variation_1252
        if key == 'SPI':
            return Variation_351
        if key == 'MRH':
            return Variation_341
        if key == 'SRC':
            return Variation_1253
        if key == 'CNF':
            return Variation_343
        if key == 'SIM':
            return Variation_1254
        if key == 'TSE':
            return Variation_1255
        if key == 'TSB':
            return Variation_1256
        if key == 'FPC':
            return Variation_353
        if key == 'AFF':
            return Variation_354
        if key == 'STP':
            return Variation_1257
        if key == 'KOS':
            return Variation_1258
        if key == 'AMA':
            return Variation_350
        if key == 'MD4':
            return Variation_1259
        if key == 'ME':
            return Variation_1260
        if key == 'MI':
            return Variation_1261
        if key == 'MD5':
            return Variation_1262
        if key == 'CST':
            return Variation_1263
        if key == 'PSR':
            return Variation_416
        if key == 'SSR':
            return Variation_417
        if key == 'MDS':
            return Variation_418
        if key == 'ADS':
            return Variation_1264
        if key == 'SUC':
            return Variation_420
        if key == 'AAC':
            return Variation_1265
        if key == 'SDS':
            return Variation_1266
        if key == 'EMS':
            return Variation_1267
        if key == 'PFT':
            return Variation_1268
        if key == 'FPLT':
            return Variation_1269
        if key == 'DUPT':
            return Variation_1270
        if key == 'DUPF':
            return Variation_1271
        if key == 'DUPM':
            return Variation_1272
        assert_never(key)

    def __init__(self, arg : Variation_1273_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1273_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_1273_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_1273_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            if Variation_1273_Arg_Group_4.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(4, arg)); return
            if Variation_1273_Arg_Group_5.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(5, arg)); return
            if Variation_1273_Arg_Group_6.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(6, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MON']) -> Variation_1252:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_351:
        ...

    @overload
    def get_item(self, name : Literal['MRH']) -> Variation_341:
        ...

    @overload
    def get_item(self, name : Literal['SRC']) -> Variation_1253:
        ...

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_343:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_1254:
        ...

    @overload
    def get_item(self, name : Literal['TSE']) -> Variation_1255:
        ...

    @overload
    def get_item(self, name : Literal['TSB']) -> Variation_1256:
        ...

    @overload
    def get_item(self, name : Literal['FPC']) -> Variation_353:
        ...

    @overload
    def get_item(self, name : Literal['AFF']) -> Variation_354:
        ...

    @overload
    def get_item(self, name : Literal['STP']) -> Variation_1257:
        ...

    @overload
    def get_item(self, name : Literal['KOS']) -> Variation_1258:
        ...

    @overload
    def get_item(self, name : Literal['AMA']) -> Variation_350:
        ...

    @overload
    def get_item(self, name : Literal['MD4']) -> Variation_1259:
        ...

    @overload
    def get_item(self, name : Literal['ME']) -> Variation_1260:
        ...

    @overload
    def get_item(self, name : Literal['MI']) -> Variation_1261:
        ...

    @overload
    def get_item(self, name : Literal['MD5']) -> Variation_1262:
        ...

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_1263:
        ...

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_416:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_417:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_418:
        ...

    @overload
    def get_item(self, name : Literal['ADS']) -> Variation_1264:
        ...

    @overload
    def get_item(self, name : Literal['SUC']) -> Variation_420:
        ...

    @overload
    def get_item(self, name : Literal['AAC']) -> Variation_1265:
        ...

    @overload
    def get_item(self, name : Literal['SDS']) -> Variation_1266:
        ...

    @overload
    def get_item(self, name : Literal['EMS']) -> Variation_1267:
        ...

    @overload
    def get_item(self, name : Literal['PFT']) -> Variation_1268:
        ...

    @overload
    def get_item(self, name : Literal['FPLT']) -> Variation_1269:
        ...

    @overload
    def get_item(self, name : Literal['DUPT']) -> Variation_1270:
        ...

    @overload
    def get_item(self, name : Literal['DUPF']) -> Variation_1271:
        ...

    @overload
    def get_item(self, name : Literal['DUPM']) -> Variation_1272:
        ...

    def get_item(self, name : Union[Literal['MON'], Literal['SPI'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FPC'], Literal['AFF'], Literal['STP'], Literal['KOS'], Literal['AMA'], Literal['MD4'], Literal['ME'], Literal['MI'], Literal['MD5'], Literal['CST'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['SUC'], Literal['AAC'], Literal['SDS'], Literal['EMS'], Literal['PFT'], Literal['FPLT'], Literal['DUPT'], Literal['DUPF'], Literal['DUPM']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MON'], val : Union[Variation_1252, Variation_1252_Arg]) -> 'Variation_1273':
        ...

    @overload
    def set_item(self, name : Literal['SPI'], val : Union[Variation_351, Variation_351_Arg]) -> 'Variation_1273':
        ...

    @overload
    def set_item(self, name : Literal['MRH'], val : Union[Variation_341, Variation_341_Arg]) -> 'Variation_1273':
        ...

    @overload
    def set_item(self, name : Literal['SRC'], val : Union[Variation_1253, Variation_1253_Arg]) -> 'Variation_1273':
        ...

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_343, Variation_343_Arg]) -> 'Variation_1273':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MON'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['MRH'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['SRC'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['TSE'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['TSB'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['FPC'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['AFF'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['STP'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['KOS'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['AMA'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['MD4'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['ME'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['MI'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['MD5'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['ADS'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['SUC'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['AAC'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['SDS'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['EMS'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['PFT'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['FPLT'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['DUPT'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['DUPF'], f : Any) -> 'Variation_1273':
        ...

    @overload
    def modify_item(self, name : Literal['DUPM'], f : Any) -> 'Variation_1273':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1274_Arg = TypedDict('Variation_1274_Arg', {
    'TRK': Union[Variation_356, Variation_356_Arg],
    'PSR': Union[Variation_356, Variation_356_Arg],
    'SSR': Union[Variation_356, Variation_356_Arg],
    'MDS': Union[Variation_356, Variation_356_Arg],
    'ADS': Union[Variation_357, Variation_357_Arg],
    'ES': Union[Variation_356, Variation_356_Arg],
    'VDL': Union[Variation_356, Variation_356_Arg],
    'UAT': Union[Variation_356, Variation_356_Arg],
    'LOP': Union[Variation_356, Variation_356_Arg],
    'MLT': Union[Variation_356, Variation_356_Arg],
}, total=False)
class Variation_1274(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('TRK', Variation_356),
        ('PSR', Variation_356),
        ('SSR', Variation_356),
        ('MDS', Variation_356),
        ('ADS', Variation_357),
        ('ES', Variation_356),
        ('VDL', Variation_356),
        ('UAT', Variation_356),
        ('LOP', Variation_356),
        ('MLT', Variation_356),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'TRK': ('Track Age', Variation_356, 0x8000),
        'PSR': ('PSR Age', Variation_356, 0x4000),
        'SSR': ('SSR Age', Variation_356, 0x2000),
        'MDS': ('Mode S Age', Variation_356, 0x1000),
        'ADS': ('ADS-C Age', Variation_357, 0x0800),
        'ES': ('ADS-B Extended Squitter Age', Variation_356, 0x0400),
        'VDL': ('ADS-B VDL Mode 4 Age', Variation_356, 0x0200),
        'UAT': ('ADS-B UAT Age', Variation_356, 0x0180),
        'LOP': ('Loop Age', Variation_356, 0x0140),
        'MLT': ('Multilateration Age', Variation_356, 0x0120),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TRK']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADS']) -> Type[Variation_357]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ES']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VDL']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['UAT']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LOP']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MLT']) -> Type[Variation_356]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TRK'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['ES'], Literal['VDL'], Literal['UAT'], Literal['LOP'], Literal['MLT']]) -> Union[Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_357'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356']]:
        if key == 'TRK':
            return Variation_356
        if key == 'PSR':
            return Variation_356
        if key == 'SSR':
            return Variation_356
        if key == 'MDS':
            return Variation_356
        if key == 'ADS':
            return Variation_357
        if key == 'ES':
            return Variation_356
        if key == 'VDL':
            return Variation_356
        if key == 'UAT':
            return Variation_356
        if key == 'LOP':
            return Variation_356
        if key == 'MLT':
            return Variation_356
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1274_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['TRK'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1274':
        ...

    @overload
    def set_item(self, name : Literal['PSR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1274':
        ...

    @overload
    def set_item(self, name : Literal['SSR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1274':
        ...

    @overload
    def set_item(self, name : Literal['MDS'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1274':
        ...

    @overload
    def set_item(self, name : Literal['ADS'], val : Union[Variation_357, Variation_357_Arg]) -> 'Variation_1274':
        ...

    @overload
    def set_item(self, name : Literal['ES'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1274':
        ...

    @overload
    def set_item(self, name : Literal['VDL'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1274':
        ...

    @overload
    def set_item(self, name : Literal['UAT'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1274':
        ...

    @overload
    def set_item(self, name : Literal['LOP'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1274':
        ...

    @overload
    def set_item(self, name : Literal['MLT'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1274':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['TRK']) -> 'Variation_1274':
        ...

    @overload
    def del_item(self, name : Literal['PSR']) -> 'Variation_1274':
        ...

    @overload
    def del_item(self, name : Literal['SSR']) -> 'Variation_1274':
        ...

    @overload
    def del_item(self, name : Literal['MDS']) -> 'Variation_1274':
        ...

    @overload
    def del_item(self, name : Literal['ADS']) -> 'Variation_1274':
        ...

    @overload
    def del_item(self, name : Literal['ES']) -> 'Variation_1274':
        ...

    @overload
    def del_item(self, name : Literal['VDL']) -> 'Variation_1274':
        ...

    @overload
    def del_item(self, name : Literal['UAT']) -> 'Variation_1274':
        ...

    @overload
    def del_item(self, name : Literal['LOP']) -> 'Variation_1274':
        ...

    @overload
    def del_item(self, name : Literal['MLT']) -> 'Variation_1274':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['TRK']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['ADS']) -> Variation_357:
        ...

    @overload
    def get_item(self, name : Literal['ES']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['VDL']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['UAT']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['LOP']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MLT']) -> Variation_356:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['TRK'], f : Any) -> 'Variation_1274':
        ...

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_1274':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_1274':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_1274':
        ...

    @overload
    def modify_item(self, name : Literal['ADS'], f : Any) -> 'Variation_1274':
        ...

    @overload
    def modify_item(self, name : Literal['ES'], f : Any) -> 'Variation_1274':
        ...

    @overload
    def modify_item(self, name : Literal['VDL'], f : Any) -> 'Variation_1274':
        ...

    @overload
    def modify_item(self, name : Literal['UAT'], f : Any) -> 'Variation_1274':
        ...

    @overload
    def modify_item(self, name : Literal['LOP'], f : Any) -> 'Variation_1274':
        ...

    @overload
    def modify_item(self, name : Literal['MLT'], f : Any) -> 'Variation_1274':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1275_Arg : TypeAlias = Raw
class Variation_1275(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Constant course',
        1: 'Right turn',
        2: 'Left turn',
        3: 'Undetermined',
    }

    def __init__(self, arg : Variation_1275_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1276_Arg : TypeAlias = Raw
class Variation_1276(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 2
    table = {
        0: 'Constant groundspeed',
        1: 'Increasing groundspeed',
        2: 'Decreasing groundspeed',
        3: 'Undetermined',
    }

    def __init__(self, arg : Variation_1276_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1277_Arg : TypeAlias = Raw
class Variation_1277(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        0: 'Level',
        1: 'Climb',
        2: 'Descent',
        3: 'Undetermined',
    }

    def __init__(self, arg : Variation_1277_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1278_Arg : TypeAlias = Raw
class Variation_1278(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'No altitude discrepancy',
        1: 'Altitude discrepancy',
    }

    def __init__(self, arg : Variation_1278_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1279_Arg_Group = TypedDict('Variation_1279_Arg_Group', {
    'TRANS': Union[Variation_1275, Variation_1275_Arg],
    'LONG': Union[Variation_1276, Variation_1276_Arg],
    'VERT': Union[Variation_1277, Variation_1277_Arg],
    'ADF': Union[Variation_1278, Variation_1278_Arg],
})
Variation_1279_Arg : TypeAlias = Union[Raw, Variation_1279_Arg_Group]
class Variation_1279(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('TRANS', Variation_1275),
        ('LONG', Variation_1276),
        ('VERT', Variation_1277),
        ('ADF', Variation_1278),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TRANS': ('Transversal Acceleration', Variation_1275, 0, 2),
        'LONG': ('Longitudinal Acceleration', Variation_1276, 2, 2),
        'VERT': ('Transversal Acceleration', Variation_1277, 4, 2),
        'ADF': ('Altitude Discrepancy Flag', Variation_1278, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TRANS']) -> Type[Variation_1275]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LONG']) -> Type[Variation_1276]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VERT']) -> Type[Variation_1277]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADF']) -> Type[Variation_1278]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TRANS'], Literal['LONG'], Literal['VERT'], Literal['ADF']]) -> Union[Type['Variation_1275'], Type['Variation_1276'], Type['Variation_1277'], Type['Variation_1278']]:
        if key == 'TRANS':
            return Variation_1275
        if key == 'LONG':
            return Variation_1276
        if key == 'VERT':
            return Variation_1277
        if key == 'ADF':
            return Variation_1278
        assert_never(key)

    def __init__(self, arg : Variation_1279_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TRANS']) -> Variation_1275:
        ...

    @overload
    def get_item(self, name : Literal['LONG']) -> Variation_1276:
        ...

    @overload
    def get_item(self, name : Literal['VERT']) -> Variation_1277:
        ...

    @overload
    def get_item(self, name : Literal['ADF']) -> Variation_1278:
        ...

    def get_item(self, name : Union[Literal['TRANS'], Literal['LONG'], Literal['VERT'], Literal['ADF']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TRANS'], val : Union[Variation_1275, Variation_1275_Arg]) -> 'Variation_1279':
        ...

    @overload
    def set_item(self, name : Literal['LONG'], val : Union[Variation_1276, Variation_1276_Arg]) -> 'Variation_1279':
        ...

    @overload
    def set_item(self, name : Literal['VERT'], val : Union[Variation_1277, Variation_1277_Arg]) -> 'Variation_1279':
        ...

    @overload
    def set_item(self, name : Literal['ADF'], val : Union[Variation_1278, Variation_1278_Arg]) -> 'Variation_1279':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TRANS'], f : Any) -> 'Variation_1279':
        ...

    @overload
    def modify_item(self, name : Literal['LONG'], f : Any) -> 'Variation_1279':
        ...

    @overload
    def modify_item(self, name : Literal['VERT'], f : Any) -> 'Variation_1279':
        ...

    @overload
    def modify_item(self, name : Literal['ADF'], f : Any) -> 'Variation_1279':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1280_Arg = TypedDict('Variation_1280_Arg', {
    'MFL': Union[Variation_356, Variation_356_Arg],
    'MD1': Union[Variation_356, Variation_356_Arg],
    'MD2': Union[Variation_356, Variation_356_Arg],
    'MDA': Union[Variation_356, Variation_356_Arg],
    'MD4': Union[Variation_356, Variation_356_Arg],
    'MD5': Union[Variation_356, Variation_356_Arg],
    'MHG': Union[Variation_356, Variation_356_Arg],
    'IAS': Union[Variation_356, Variation_356_Arg],
    'TAS': Union[Variation_356, Variation_356_Arg],
    'SAL': Union[Variation_356, Variation_356_Arg],
    'FSS': Union[Variation_356, Variation_356_Arg],
    'TID': Union[Variation_356, Variation_356_Arg],
    'COM': Union[Variation_356, Variation_356_Arg],
    'SAB': Union[Variation_356, Variation_356_Arg],
    'ACS': Union[Variation_356, Variation_356_Arg],
    'BVR': Union[Variation_356, Variation_356_Arg],
    'GVR': Union[Variation_356, Variation_356_Arg],
    'RAN': Union[Variation_356, Variation_356_Arg],
    'TAR': Union[Variation_356, Variation_356_Arg],
    'TAN': Union[Variation_356, Variation_356_Arg],
    'GSP': Union[Variation_356, Variation_356_Arg],
    'VUN': Union[Variation_356, Variation_356_Arg],
    'MET': Union[Variation_356, Variation_356_Arg],
    'EMC': Union[Variation_356, Variation_356_Arg],
    'POS': Union[Variation_356, Variation_356_Arg],
    'GAL': Union[Variation_356, Variation_356_Arg],
    'PUN': Union[Variation_356, Variation_356_Arg],
    'MB': Union[Variation_356, Variation_356_Arg],
    'IAR': Union[Variation_356, Variation_356_Arg],
    'MAC': Union[Variation_356, Variation_356_Arg],
    'BPS': Union[Variation_356, Variation_356_Arg],
}, total=False)
class Variation_1280(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('MFL', Variation_356),
        ('MD1', Variation_356),
        ('MD2', Variation_356),
        ('MDA', Variation_356),
        ('MD4', Variation_356),
        ('MD5', Variation_356),
        ('MHG', Variation_356),
        ('IAS', Variation_356),
        ('TAS', Variation_356),
        ('SAL', Variation_356),
        ('FSS', Variation_356),
        ('TID', Variation_356),
        ('COM', Variation_356),
        ('SAB', Variation_356),
        ('ACS', Variation_356),
        ('BVR', Variation_356),
        ('GVR', Variation_356),
        ('RAN', Variation_356),
        ('TAR', Variation_356),
        ('TAN', Variation_356),
        ('GSP', Variation_356),
        ('VUN', Variation_356),
        ('MET', Variation_356),
        ('EMC', Variation_356),
        ('POS', Variation_356),
        ('GAL', Variation_356),
        ('PUN', Variation_356),
        ('MB', Variation_356),
        ('IAR', Variation_356),
        ('MAC', Variation_356),
        ('BPS', Variation_356),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'MFL': ('Measured Flight Level Age', Variation_356, 0x8000000000),
        'MD1': ('Mode 1 Age', Variation_356, 0x4000000000),
        'MD2': ('Mode 2 Age', Variation_356, 0x2000000000),
        'MDA': ('Mode 3/A Age', Variation_356, 0x1000000000),
        'MD4': ('Mode 4 Age', Variation_356, 0x0800000000),
        'MD5': ('Mode 5 Age', Variation_356, 0x0400000000),
        'MHG': ('Magnetic Heading Age', Variation_356, 0x0200000000),
        'IAS': ('Indicated Airspeed / Mach Nb Age', Variation_356, 0x0180000000),
        'TAS': ('True Airspeed Age', Variation_356, 0x0140000000),
        'SAL': ('Selected Altitude Age', Variation_356, 0x0120000000),
        'FSS': ('Final State Selected Altitude Age', Variation_356, 0x0110000000),
        'TID': ('Trajectory Intent Age', Variation_356, 0x0108000000),
        'COM': ('Communication/ACAS Capability and Flight Status Age', Variation_356, 0x0104000000),
        'SAB': ('Status Reported by ADS-B Age', Variation_356, 0x0102000000),
        'ACS': ('ACAS Resolution Advisory Report Age', Variation_356, 0x0101800000),
        'BVR': ('Barometric Vertical Rate Age', Variation_356, 0x0101400000),
        'GVR': ('Geometrical Vertical Rate Age', Variation_356, 0x0101200000),
        'RAN': ('Roll Angle Age', Variation_356, 0x0101100000),
        'TAR': ('Track Angle Rate Age', Variation_356, 0x0101080000),
        'TAN': ('Track Angle Age', Variation_356, 0x0101040000),
        'GSP': ('Ground Speed Age', Variation_356, 0x0101020000),
        'VUN': ('Velocity Uncertainty Age', Variation_356, 0x0101018000),
        'MET': ('Meteorological Data Age', Variation_356, 0x0101014000),
        'EMC': ('Emitter Category Age', Variation_356, 0x0101012000),
        'POS': ('Position Age', Variation_356, 0x0101011000),
        'GAL': ('Geometric Altitude Age', Variation_356, 0x0101010800),
        'PUN': ('Position Uncertainty Age', Variation_356, 0x0101010400),
        'MB': ('Mode S MB Data Age', Variation_356, 0x0101010200),
        'IAR': ('Indicated Airspeed Data Age', Variation_356, 0x0101010180),
        'MAC': ('Mach Number Data Age', Variation_356, 0x0101010140),
        'BPS': ('Barometric Pressure Setting Data Age', Variation_356, 0x0101010120),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MFL']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD1']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD2']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDA']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD4']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD5']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MHG']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAS']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAS']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAL']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FSS']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAB']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ACS']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BVR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GVR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAN']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAN']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GSP']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VUN']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MET']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EMC']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GAL']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PUN']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MB']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAR']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAC']) -> Type[Variation_356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BPS']) -> Type[Variation_356]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MFL'], Literal['MD1'], Literal['MD2'], Literal['MDA'], Literal['MD4'], Literal['MD5'], Literal['MHG'], Literal['IAS'], Literal['TAS'], Literal['SAL'], Literal['FSS'], Literal['TID'], Literal['COM'], Literal['SAB'], Literal['ACS'], Literal['BVR'], Literal['GVR'], Literal['RAN'], Literal['TAR'], Literal['TAN'], Literal['GSP'], Literal['VUN'], Literal['MET'], Literal['EMC'], Literal['POS'], Literal['GAL'], Literal['PUN'], Literal['MB'], Literal['IAR'], Literal['MAC'], Literal['BPS']]) -> Union[Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356'], Type['Variation_356']]:
        if key == 'MFL':
            return Variation_356
        if key == 'MD1':
            return Variation_356
        if key == 'MD2':
            return Variation_356
        if key == 'MDA':
            return Variation_356
        if key == 'MD4':
            return Variation_356
        if key == 'MD5':
            return Variation_356
        if key == 'MHG':
            return Variation_356
        if key == 'IAS':
            return Variation_356
        if key == 'TAS':
            return Variation_356
        if key == 'SAL':
            return Variation_356
        if key == 'FSS':
            return Variation_356
        if key == 'TID':
            return Variation_356
        if key == 'COM':
            return Variation_356
        if key == 'SAB':
            return Variation_356
        if key == 'ACS':
            return Variation_356
        if key == 'BVR':
            return Variation_356
        if key == 'GVR':
            return Variation_356
        if key == 'RAN':
            return Variation_356
        if key == 'TAR':
            return Variation_356
        if key == 'TAN':
            return Variation_356
        if key == 'GSP':
            return Variation_356
        if key == 'VUN':
            return Variation_356
        if key == 'MET':
            return Variation_356
        if key == 'EMC':
            return Variation_356
        if key == 'POS':
            return Variation_356
        if key == 'GAL':
            return Variation_356
        if key == 'PUN':
            return Variation_356
        if key == 'MB':
            return Variation_356
        if key == 'IAR':
            return Variation_356
        if key == 'MAC':
            return Variation_356
        if key == 'BPS':
            return Variation_356
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1280_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['MFL'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['MD1'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['MD2'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['MDA'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['MD4'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['MD5'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['MHG'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['IAS'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['TAS'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['SAL'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['FSS'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['SAB'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['ACS'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['BVR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['GVR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['RAN'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['TAR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['TAN'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['GSP'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['VUN'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['MET'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['EMC'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['GAL'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['PUN'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['MB'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['IAR'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['MAC'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    @overload
    def set_item(self, name : Literal['BPS'], val : Union[Variation_356, Variation_356_Arg]) -> 'Variation_1280':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['MFL']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['MD1']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['MD2']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['MDA']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['MD4']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['MD5']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['MHG']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['IAS']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['TAS']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['SAL']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['FSS']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['TID']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['COM']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['SAB']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['ACS']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['BVR']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['GVR']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['RAN']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['TAR']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['TAN']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['GSP']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['VUN']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['MET']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['EMC']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['GAL']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['PUN']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['MB']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['IAR']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['MAC']) -> 'Variation_1280':
        ...

    @overload
    def del_item(self, name : Literal['BPS']) -> 'Variation_1280':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['MFL']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MD1']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MD2']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MDA']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MD4']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MD5']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MHG']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['IAS']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['TAS']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['SAL']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['FSS']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['SAB']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['ACS']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['BVR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['GVR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['RAN']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['TAR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['TAN']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['GSP']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['VUN']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MET']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['EMC']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['GAL']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['PUN']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MB']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['IAR']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['MAC']) -> Variation_356:
        ...

    @overload
    def get_item(self, name : Literal['BPS']) -> Variation_356:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['MFL'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['MD1'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['MD2'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['MDA'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['MD4'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['MD5'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['MHG'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['IAS'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['TAS'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['SAL'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['FSS'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['SAB'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['ACS'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['BVR'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['GVR'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['RAN'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['TAR'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['TAN'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['GSP'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['VUN'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['MET'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['EMC'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['GAL'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['PUN'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['MB'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['IAR'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['MAC'], f : Any) -> 'Variation_1280':
        ...

    @overload
    def modify_item(self, name : Literal['BPS'], f : Any) -> 'Variation_1280':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1281_Arg_Group = TypedDict('Variation_1281_Arg_Group', {
    'QNH': Union[Variation_361, Variation_361_Arg],
    'CTB': Union[Variation_362, Variation_362_Arg],
})
Variation_1281_Arg : TypeAlias = Union[Raw, Variation_1281_Arg_Group]
class Variation_1281(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('QNH', Variation_361),
        ('CTB', Variation_362),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'QNH': ('', Variation_361, 0, 1),
        'CTB': ('Calculated Track Barometric Altitude', Variation_362, 1, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['QNH']) -> Type[Variation_361]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CTB']) -> Type[Variation_362]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['QNH'], Literal['CTB']]) -> Union[Type['Variation_361'], Type['Variation_362']]:
        if key == 'QNH':
            return Variation_361
        if key == 'CTB':
            return Variation_362
        assert_never(key)

    def __init__(self, arg : Variation_1281_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['QNH']) -> Variation_361:
        ...

    @overload
    def get_item(self, name : Literal['CTB']) -> Variation_362:
        ...

    def get_item(self, name : Union[Literal['QNH'], Literal['CTB']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['QNH'], val : Union[Variation_361, Variation_361_Arg]) -> 'Variation_1281':
        ...

    @overload
    def set_item(self, name : Literal['CTB'], val : Union[Variation_362, Variation_362_Arg]) -> 'Variation_1281':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['QNH'], f : Any) -> 'Variation_1281':
        ...

    @overload
    def modify_item(self, name : Literal['CTB'], f : Any) -> 'Variation_1281':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1282_Arg_Group = TypedDict('Variation_1282_Arg_Group', {
    'TYP': Union[Variation_985, Variation_985_Arg],
    'NBR': Union[Variation_367, Variation_367_Arg],
})
Variation_1282_Arg : TypeAlias = Union[Raw, Variation_1282_Arg_Group]
class Variation_1282(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('TYP', Variation_985),
        Spare(2, 3),
        ('NBR', Variation_367),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('', Variation_985, 0, 2),
        'NBR': ('Number from 0 to 99 999 999', Variation_367, 5, 27),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_985]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NBR']) -> Type[Variation_367]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['NBR']]) -> Union[Type['Variation_985'], Type['Variation_367']]:
        if key == 'TYP':
            return Variation_985
        if key == 'NBR':
            return Variation_367
        assert_never(key)

    def __init__(self, arg : Variation_1282_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_985:
        ...

    @overload
    def get_item(self, name : Literal['NBR']) -> Variation_367:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['NBR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_985, Variation_985_Arg]) -> 'Variation_1282':
        ...

    @overload
    def set_item(self, name : Literal['NBR'], val : Union[Variation_367, Variation_367_Arg]) -> 'Variation_1282':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1282':
        ...

    @overload
    def modify_item(self, name : Literal['NBR'], f : Any) -> 'Variation_1282':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1283_Arg_Group = TypedDict('Variation_1283_Arg_Group', {
    'GATOAT': Union[Variation_153, Variation_153_Arg],
    'FR1FR2': Union[Variation_426, Variation_426_Arg],
    'RVSM': Union[Variation_155, Variation_155_Arg],
    'HPR': Union[Variation_156, Variation_156_Arg],
})
Variation_1283_Arg : TypeAlias = Union[Raw, Variation_1283_Arg_Group]
class Variation_1283(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('GATOAT', Variation_153),
        ('FR1FR2', Variation_426),
        ('RVSM', Variation_155),
        ('HPR', Variation_156),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'GATOAT': ('', Variation_153, 0, 2),
        'FR1FR2': ('', Variation_426, 2, 2),
        'RVSM': ('', Variation_155, 4, 2),
        'HPR': ('', Variation_156, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['GATOAT']) -> Type[Variation_153]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FR1FR2']) -> Type[Variation_426]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RVSM']) -> Type[Variation_155]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HPR']) -> Type[Variation_156]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['RVSM'], Literal['HPR']]) -> Union[Type['Variation_153'], Type['Variation_426'], Type['Variation_155'], Type['Variation_156']]:
        if key == 'GATOAT':
            return Variation_153
        if key == 'FR1FR2':
            return Variation_426
        if key == 'RVSM':
            return Variation_155
        if key == 'HPR':
            return Variation_156
        assert_never(key)

    def __init__(self, arg : Variation_1283_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['GATOAT']) -> Variation_153:
        ...

    @overload
    def get_item(self, name : Literal['FR1FR2']) -> Variation_426:
        ...

    @overload
    def get_item(self, name : Literal['RVSM']) -> Variation_155:
        ...

    @overload
    def get_item(self, name : Literal['HPR']) -> Variation_156:
        ...

    def get_item(self, name : Union[Literal['GATOAT'], Literal['FR1FR2'], Literal['RVSM'], Literal['HPR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['GATOAT'], val : Union[Variation_153, Variation_153_Arg]) -> 'Variation_1283':
        ...

    @overload
    def set_item(self, name : Literal['FR1FR2'], val : Union[Variation_426, Variation_426_Arg]) -> 'Variation_1283':
        ...

    @overload
    def set_item(self, name : Literal['RVSM'], val : Union[Variation_155, Variation_155_Arg]) -> 'Variation_1283':
        ...

    @overload
    def set_item(self, name : Literal['HPR'], val : Union[Variation_156, Variation_156_Arg]) -> 'Variation_1283':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['GATOAT'], f : Any) -> 'Variation_1283':
        ...

    @overload
    def modify_item(self, name : Literal['FR1FR2'], f : Any) -> 'Variation_1283':
        ...

    @overload
    def modify_item(self, name : Literal['RVSM'], f : Any) -> 'Variation_1283':
        ...

    @overload
    def modify_item(self, name : Literal['HPR'], f : Any) -> 'Variation_1283':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1284_Arg_Group = TypedDict('Variation_1284_Arg_Group', {
    'TYP': Union[Variation_373, Variation_373_Arg],
    'DAY': Union[Variation_993, Variation_993_Arg],
    'HOR': Union[Variation_375, Variation_375_Arg],
    'MIN': Union[Variation_376, Variation_376_Arg],
    'AVS': Union[Variation_377, Variation_377_Arg],
    'SEC': Union[Variation_376, Variation_376_Arg],
})
Variation_1284_Arg : TypeAlias = Union[Raw, Variation_1284_Arg_Group]
class Variation_1284(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('TYP', Variation_373),
        ('DAY', Variation_993),
        Spare(7, 4),
        ('HOR', Variation_375),
        Spare(0, 2),
        ('MIN', Variation_376),
        ('AVS', Variation_377),
        Spare(1, 1),
        ('SEC', Variation_376),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('', Variation_373, 0, 5),
        'DAY': ('', Variation_993, 5, 2),
        'HOR': ('Hours', Variation_375, 11, 5),
        'MIN': ('Minutes', Variation_376, 18, 6),
        'AVS': ('Seconds Available Flag', Variation_377, 24, 1),
        'SEC': ('Seconds', Variation_376, 26, 6),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_373]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DAY']) -> Type[Variation_993]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HOR']) -> Type[Variation_375]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MIN']) -> Type[Variation_376]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AVS']) -> Type[Variation_377]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SEC']) -> Type[Variation_376]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['DAY'], Literal['HOR'], Literal['MIN'], Literal['AVS'], Literal['SEC']]) -> Union[Type['Variation_373'], Type['Variation_993'], Type['Variation_375'], Type['Variation_376'], Type['Variation_377'], Type['Variation_376']]:
        if key == 'TYP':
            return Variation_373
        if key == 'DAY':
            return Variation_993
        if key == 'HOR':
            return Variation_375
        if key == 'MIN':
            return Variation_376
        if key == 'AVS':
            return Variation_377
        if key == 'SEC':
            return Variation_376
        assert_never(key)

    def __init__(self, arg : Variation_1284_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_373:
        ...

    @overload
    def get_item(self, name : Literal['DAY']) -> Variation_993:
        ...

    @overload
    def get_item(self, name : Literal['HOR']) -> Variation_375:
        ...

    @overload
    def get_item(self, name : Literal['MIN']) -> Variation_376:
        ...

    @overload
    def get_item(self, name : Literal['AVS']) -> Variation_377:
        ...

    @overload
    def get_item(self, name : Literal['SEC']) -> Variation_376:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['DAY'], Literal['HOR'], Literal['MIN'], Literal['AVS'], Literal['SEC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_373, Variation_373_Arg]) -> 'Variation_1284':
        ...

    @overload
    def set_item(self, name : Literal['DAY'], val : Union[Variation_993, Variation_993_Arg]) -> 'Variation_1284':
        ...

    @overload
    def set_item(self, name : Literal['HOR'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_1284':
        ...

    @overload
    def set_item(self, name : Literal['MIN'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_1284':
        ...

    @overload
    def set_item(self, name : Literal['AVS'], val : Union[Variation_377, Variation_377_Arg]) -> 'Variation_1284':
        ...

    @overload
    def set_item(self, name : Literal['SEC'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_1284':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1284':
        ...

    @overload
    def modify_item(self, name : Literal['DAY'], f : Any) -> 'Variation_1284':
        ...

    @overload
    def modify_item(self, name : Literal['HOR'], f : Any) -> 'Variation_1284':
        ...

    @overload
    def modify_item(self, name : Literal['MIN'], f : Any) -> 'Variation_1284':
        ...

    @overload
    def modify_item(self, name : Literal['AVS'], f : Any) -> 'Variation_1284':
        ...

    @overload
    def modify_item(self, name : Literal['SEC'], f : Any) -> 'Variation_1284':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1285_Arg : TypeAlias = Union[Variation_1284, Variation_1284_Arg]
class Variation_1285(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 32
    variation_type = Variation_1284

    @classmethod
    def spec(cls) -> Type[Variation_1284]:
        return Variation_1284

    def __init__(self, arg : List[Union[Variation_1284, Variation_1284_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1284, Variation_1284_Arg]) -> 'Variation_1285':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1284, Variation_1284_Arg]) -> 'Variation_1285':
        return self._prepend_item(arg) # type: ignore

Variation_1286_Arg : TypeAlias = Raw
class Variation_1286(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'No valid Mode 3/A available',
        1: 'Valid Mode 3/A available',
    }

    def __init__(self, arg : Variation_1286_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1287_Arg_Group = TypedDict('Variation_1287_Arg_Group', {
    'VA': Union[Variation_1286, Variation_1286_Arg],
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_1287_Arg : TypeAlias = Union[Raw, Variation_1287_Arg_Group]
class Variation_1287(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 3),
        ('VA', Variation_1286),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'VA': ('', Variation_1286, 3, 1),
        'MODE3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['VA']) -> Type[Variation_1286]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['VA'], Literal['MODE3A']]) -> Union[Type['Variation_1286'], Type['Variation_19']]:
        if key == 'VA':
            return Variation_1286
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_1287_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['VA']) -> Variation_1286:
        ...

    @overload
    def get_item(self, name : Literal['MODE3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['VA'], Literal['MODE3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['VA'], val : Union[Variation_1286, Variation_1286_Arg]) -> 'Variation_1287':
        ...

    @overload
    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_1287':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['VA'], f : Any) -> 'Variation_1287':
        ...

    @overload
    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_1287':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1288_Arg = TypedDict('Variation_1288_Arg', {
    'TAG': Union[Variation_1, Variation_1_Arg],
    'CS': Union[Variation_145, Variation_145_Arg],
    'IFI': Union[Variation_1282, Variation_1282_Arg],
    'FCT': Union[Variation_1283, Variation_1283_Arg],
    'TAC': Union[Variation_330, Variation_330_Arg],
    'WTC': Union[Variation_990, Variation_990_Arg],
    'DEP': Union[Variation_330, Variation_330_Arg],
    'DST': Union[Variation_330, Variation_330_Arg],
    'RDS': Union[Variation_991, Variation_991_Arg],
    'CFL': Union[Variation_164, Variation_164_Arg],
    'CTL': Union[Variation_372, Variation_372_Arg],
    'TOD': Union[Variation_1285, Variation_1285_Arg],
    'AST': Union[Variation_161, Variation_161_Arg],
    'STS': Union[Variation_998, Variation_998_Arg],
    'STD': Union[Variation_145, Variation_145_Arg],
    'STA': Union[Variation_145, Variation_145_Arg],
    'PEM': Union[Variation_1287, Variation_1287_Arg],
    'PEC': Union[Variation_145, Variation_145_Arg],
}, total=False)
class Variation_1288(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 3

    subitems_list = [
        ('TAG', Variation_1),
        ('CS', Variation_145),
        ('IFI', Variation_1282),
        ('FCT', Variation_1283),
        ('TAC', Variation_330),
        ('WTC', Variation_990),
        ('DEP', Variation_330),
        ('DST', Variation_330),
        ('RDS', Variation_991),
        ('CFL', Variation_164),
        ('CTL', Variation_372),
        ('TOD', Variation_1285),
        ('AST', Variation_161),
        ('STS', Variation_998),
        ('STD', Variation_145),
        ('STA', Variation_145),
        ('PEM', Variation_1287),
        ('PEC', Variation_145),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'TAG': ('FPPS Identification Tag', Variation_1, 0x800000),
        'CS': ('Callsign', Variation_145, 0x400000),
        'IFI': ('IFPS_FLIGHT_ID', Variation_1282, 0x200000),
        'FCT': ('Flight Category', Variation_1283, 0x100000),
        'TAC': ('Type of Aircraft', Variation_330, 0x080000),
        'WTC': ('Wake Turbulence Category', Variation_990, 0x040000),
        'DEP': ('Departure Airport', Variation_330, 0x020000),
        'DST': ('Destination Airport', Variation_330, 0x018000),
        'RDS': ('Runway Designation', Variation_991, 0x014000),
        'CFL': ('Current Cleared Flight Level', Variation_164, 0x012000),
        'CTL': ('Current Control Position', Variation_372, 0x011000),
        'TOD': ('Time of Departure / Arrival', Variation_1285, 0x010800),
        'AST': ('Aircraft Stand', Variation_161, 0x010400),
        'STS': ('Stand Status', Variation_998, 0x010200),
        'STD': ('Standard Instrument Departure', Variation_145, 0x010180),
        'STA': ('Standard Instrument Arrival', Variation_145, 0x010140),
        'PEM': ('Pre-Emergency Mode 3/A', Variation_1287, 0x010120),
        'PEC': ('Pre-Emergency Callsign', Variation_145, 0x010110),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TAG']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CS']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IFI']) -> Type[Variation_1282]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FCT']) -> Type[Variation_1283]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAC']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['WTC']) -> Type[Variation_990]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DEP']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DST']) -> Type[Variation_330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RDS']) -> Type[Variation_991]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CFL']) -> Type[Variation_164]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CTL']) -> Type[Variation_372]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOD']) -> Type[Variation_1285]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AST']) -> Type[Variation_161]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STS']) -> Type[Variation_998]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STD']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STA']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PEM']) -> Type[Variation_1287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PEC']) -> Type[Variation_145]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TAG'], Literal['CS'], Literal['IFI'], Literal['FCT'], Literal['TAC'], Literal['WTC'], Literal['DEP'], Literal['DST'], Literal['RDS'], Literal['CFL'], Literal['CTL'], Literal['TOD'], Literal['AST'], Literal['STS'], Literal['STD'], Literal['STA'], Literal['PEM'], Literal['PEC']]) -> Union[Type['Variation_1'], Type['Variation_145'], Type['Variation_1282'], Type['Variation_1283'], Type['Variation_330'], Type['Variation_990'], Type['Variation_330'], Type['Variation_330'], Type['Variation_991'], Type['Variation_164'], Type['Variation_372'], Type['Variation_1285'], Type['Variation_161'], Type['Variation_998'], Type['Variation_145'], Type['Variation_145'], Type['Variation_1287'], Type['Variation_145']]:
        if key == 'TAG':
            return Variation_1
        if key == 'CS':
            return Variation_145
        if key == 'IFI':
            return Variation_1282
        if key == 'FCT':
            return Variation_1283
        if key == 'TAC':
            return Variation_330
        if key == 'WTC':
            return Variation_990
        if key == 'DEP':
            return Variation_330
        if key == 'DST':
            return Variation_330
        if key == 'RDS':
            return Variation_991
        if key == 'CFL':
            return Variation_164
        if key == 'CTL':
            return Variation_372
        if key == 'TOD':
            return Variation_1285
        if key == 'AST':
            return Variation_161
        if key == 'STS':
            return Variation_998
        if key == 'STD':
            return Variation_145
        if key == 'STA':
            return Variation_145
        if key == 'PEM':
            return Variation_1287
        if key == 'PEC':
            return Variation_145
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1288_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['TAG'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['CS'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['IFI'], val : Union[Variation_1282, Variation_1282_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['FCT'], val : Union[Variation_1283, Variation_1283_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['TAC'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['WTC'], val : Union[Variation_990, Variation_990_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['DEP'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['DST'], val : Union[Variation_330, Variation_330_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['RDS'], val : Union[Variation_991, Variation_991_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['CFL'], val : Union[Variation_164, Variation_164_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['CTL'], val : Union[Variation_372, Variation_372_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['TOD'], val : Union[Variation_1285, Variation_1285_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['AST'], val : Union[Variation_161, Variation_161_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['STS'], val : Union[Variation_998, Variation_998_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['STD'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['STA'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['PEM'], val : Union[Variation_1287, Variation_1287_Arg]) -> 'Variation_1288':
        ...

    @overload
    def set_item(self, name : Literal['PEC'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_1288':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['TAG']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['CS']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['IFI']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['FCT']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['TAC']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['WTC']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['DEP']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['DST']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['RDS']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['CFL']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['CTL']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['TOD']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['AST']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['STS']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['STD']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['STA']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['PEM']) -> 'Variation_1288':
        ...

    @overload
    def del_item(self, name : Literal['PEC']) -> 'Variation_1288':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['TAG']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['CS']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['IFI']) -> Variation_1282:
        ...

    @overload
    def get_item(self, name : Literal['FCT']) -> Variation_1283:
        ...

    @overload
    def get_item(self, name : Literal['TAC']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['WTC']) -> Variation_990:
        ...

    @overload
    def get_item(self, name : Literal['DEP']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['DST']) -> Variation_330:
        ...

    @overload
    def get_item(self, name : Literal['RDS']) -> Variation_991:
        ...

    @overload
    def get_item(self, name : Literal['CFL']) -> Variation_164:
        ...

    @overload
    def get_item(self, name : Literal['CTL']) -> Variation_372:
        ...

    @overload
    def get_item(self, name : Literal['TOD']) -> Variation_1285:
        ...

    @overload
    def get_item(self, name : Literal['AST']) -> Variation_161:
        ...

    @overload
    def get_item(self, name : Literal['STS']) -> Variation_998:
        ...

    @overload
    def get_item(self, name : Literal['STD']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['STA']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['PEM']) -> Variation_1287:
        ...

    @overload
    def get_item(self, name : Literal['PEC']) -> Variation_145:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['TAG'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['CS'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['IFI'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['FCT'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['TAC'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['WTC'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['DEP'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['DST'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['RDS'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['CFL'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['CTL'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['TOD'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['AST'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['STS'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['STD'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['STA'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['PEM'], f : Any) -> 'Variation_1288':
        ...

    @overload
    def modify_item(self, name : Literal['PEC'], f : Any) -> 'Variation_1288':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1289_Arg : TypeAlias = Raw
class Variation_1289(Element):
    variation = 'Element'

    bit_offset8 = 1
    bit_size = 1
    table = {
        0: 'No authenticated Mode 5 ID reply',
        1: 'Authenticated Mode 5 ID reply',
    }

    def __init__(self, arg : Variation_1289_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1290_Arg : TypeAlias = Raw
class Variation_1290(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Mode 1 code not present or not from Mode 5 reply',
        1: 'Mode 1 code from Mode 5 reply',
    }

    def __init__(self, arg : Variation_1290_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1291_Arg : TypeAlias = Raw
class Variation_1291(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Mode 2 code not present or not from Mode 5 reply',
        1: 'Mode 2 code from Mode 5 reply',
    }

    def __init__(self, arg : Variation_1291_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1292_Arg : TypeAlias = Raw
class Variation_1292(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Mode 3 code not present or not from Mode 5 reply',
        1: 'Mode 3 code from Mode 5 reply',
    }

    def __init__(self, arg : Variation_1292_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1293_Arg : TypeAlias = Raw
class Variation_1293(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Mode C altitude code not present or not from Mode 5 reply',
        1: 'Mode C altitude from Mode 5 reply',
    }

    def __init__(self, arg : Variation_1293_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1294_Arg : TypeAlias = Raw
class Variation_1294(Element):
    variation = 'Element'

    bit_offset8 = 7
    bit_size = 1
    table = {
        0: 'X-pulse set to zero or no authenticated Data reply or Report received',
        1: 'X-pulse set to one',
    }

    def __init__(self, arg : Variation_1294_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1295_Arg_Group = TypedDict('Variation_1295_Arg_Group', {
    'M5': Union[Variation_781, Variation_781_Arg],
    'ID': Union[Variation_1289, Variation_1289_Arg],
    'DA': Union[Variation_783, Variation_783_Arg],
    'M1': Union[Variation_1290, Variation_1290_Arg],
    'M2': Union[Variation_1291, Variation_1291_Arg],
    'M3': Union[Variation_1292, Variation_1292_Arg],
    'MC': Union[Variation_1293, Variation_1293_Arg],
    'X': Union[Variation_1294, Variation_1294_Arg],
})
Variation_1295_Arg : TypeAlias = Union[Raw, Variation_1295_Arg_Group]
class Variation_1295(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('M5', Variation_781),
        ('ID', Variation_1289),
        ('DA', Variation_783),
        ('M1', Variation_1290),
        ('M2', Variation_1291),
        ('M3', Variation_1292),
        ('MC', Variation_1293),
        ('X', Variation_1294),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'M5': ('', Variation_781, 0, 1),
        'ID': ('', Variation_1289, 1, 1),
        'DA': ('', Variation_783, 2, 1),
        'M1': ('', Variation_1290, 3, 1),
        'M2': ('', Variation_1291, 4, 1),
        'M3': ('', Variation_1292, 5, 1),
        'MC': ('', Variation_1293, 6, 1),
        'X': ('X-pulse from Mode 5 Data Reply or Report', Variation_1294, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['M5']) -> Type[Variation_781]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ID']) -> Type[Variation_1289]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DA']) -> Type[Variation_783]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M1']) -> Type[Variation_1290]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M2']) -> Type[Variation_1291]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['M3']) -> Type[Variation_1292]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MC']) -> Type[Variation_1293]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_1294]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['M5'], Literal['ID'], Literal['DA'], Literal['M1'], Literal['M2'], Literal['M3'], Literal['MC'], Literal['X']]) -> Union[Type['Variation_781'], Type['Variation_1289'], Type['Variation_783'], Type['Variation_1290'], Type['Variation_1291'], Type['Variation_1292'], Type['Variation_1293'], Type['Variation_1294']]:
        if key == 'M5':
            return Variation_781
        if key == 'ID':
            return Variation_1289
        if key == 'DA':
            return Variation_783
        if key == 'M1':
            return Variation_1290
        if key == 'M2':
            return Variation_1291
        if key == 'M3':
            return Variation_1292
        if key == 'MC':
            return Variation_1293
        if key == 'X':
            return Variation_1294
        assert_never(key)

    def __init__(self, arg : Variation_1295_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['M5']) -> Variation_781:
        ...

    @overload
    def get_item(self, name : Literal['ID']) -> Variation_1289:
        ...

    @overload
    def get_item(self, name : Literal['DA']) -> Variation_783:
        ...

    @overload
    def get_item(self, name : Literal['M1']) -> Variation_1290:
        ...

    @overload
    def get_item(self, name : Literal['M2']) -> Variation_1291:
        ...

    @overload
    def get_item(self, name : Literal['M3']) -> Variation_1292:
        ...

    @overload
    def get_item(self, name : Literal['MC']) -> Variation_1293:
        ...

    @overload
    def get_item(self, name : Literal['X']) -> Variation_1294:
        ...

    def get_item(self, name : Union[Literal['M5'], Literal['ID'], Literal['DA'], Literal['M1'], Literal['M2'], Literal['M3'], Literal['MC'], Literal['X']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['M5'], val : Union[Variation_781, Variation_781_Arg]) -> 'Variation_1295':
        ...

    @overload
    def set_item(self, name : Literal['ID'], val : Union[Variation_1289, Variation_1289_Arg]) -> 'Variation_1295':
        ...

    @overload
    def set_item(self, name : Literal['DA'], val : Union[Variation_783, Variation_783_Arg]) -> 'Variation_1295':
        ...

    @overload
    def set_item(self, name : Literal['M1'], val : Union[Variation_1290, Variation_1290_Arg]) -> 'Variation_1295':
        ...

    @overload
    def set_item(self, name : Literal['M2'], val : Union[Variation_1291, Variation_1291_Arg]) -> 'Variation_1295':
        ...

    @overload
    def set_item(self, name : Literal['M3'], val : Union[Variation_1292, Variation_1292_Arg]) -> 'Variation_1295':
        ...

    @overload
    def set_item(self, name : Literal['MC'], val : Union[Variation_1293, Variation_1293_Arg]) -> 'Variation_1295':
        ...

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_1294, Variation_1294_Arg]) -> 'Variation_1295':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['M5'], f : Any) -> 'Variation_1295':
        ...

    @overload
    def modify_item(self, name : Literal['ID'], f : Any) -> 'Variation_1295':
        ...

    @overload
    def modify_item(self, name : Literal['DA'], f : Any) -> 'Variation_1295':
        ...

    @overload
    def modify_item(self, name : Literal['M1'], f : Any) -> 'Variation_1295':
        ...

    @overload
    def modify_item(self, name : Literal['M2'], f : Any) -> 'Variation_1295':
        ...

    @overload
    def modify_item(self, name : Literal['M3'], f : Any) -> 'Variation_1295':
        ...

    @overload
    def modify_item(self, name : Literal['MC'], f : Any) -> 'Variation_1295':
        ...

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_1295':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1296_Arg_Group = TypedDict('Variation_1296_Arg_Group', {
    'PIN': Union[Variation_790, Variation_790_Arg],
    'NAT': Union[Variation_375, Variation_375_Arg],
    'MIS': Union[Variation_376, Variation_376_Arg],
})
Variation_1296_Arg : TypeAlias = Union[Raw, Variation_1296_Arg_Group]
class Variation_1296(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        Spare(0, 2),
        ('PIN', Variation_790),
        Spare(0, 3),
        ('NAT', Variation_375),
        Spare(0, 2),
        ('MIS', Variation_376),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PIN': ('PIN Code', Variation_790, 2, 14),
        'NAT': ('National Origin', Variation_375, 19, 5),
        'MIS': ('Mission Code', Variation_376, 26, 6),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PIN']) -> Type[Variation_790]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NAT']) -> Type[Variation_375]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MIS']) -> Type[Variation_376]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PIN'], Literal['NAT'], Literal['MIS']]) -> Union[Type['Variation_790'], Type['Variation_375'], Type['Variation_376']]:
        if key == 'PIN':
            return Variation_790
        if key == 'NAT':
            return Variation_375
        if key == 'MIS':
            return Variation_376
        assert_never(key)

    def __init__(self, arg : Variation_1296_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PIN']) -> Variation_790:
        ...

    @overload
    def get_item(self, name : Literal['NAT']) -> Variation_375:
        ...

    @overload
    def get_item(self, name : Literal['MIS']) -> Variation_376:
        ...

    def get_item(self, name : Union[Literal['PIN'], Literal['NAT'], Literal['MIS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PIN'], val : Union[Variation_790, Variation_790_Arg]) -> 'Variation_1296':
        ...

    @overload
    def set_item(self, name : Literal['NAT'], val : Union[Variation_375, Variation_375_Arg]) -> 'Variation_1296':
        ...

    @overload
    def set_item(self, name : Literal['MIS'], val : Union[Variation_376, Variation_376_Arg]) -> 'Variation_1296':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PIN'], f : Any) -> 'Variation_1296':
        ...

    @overload
    def modify_item(self, name : Literal['NAT'], f : Any) -> 'Variation_1296':
        ...

    @overload
    def modify_item(self, name : Literal['MIS'], f : Any) -> 'Variation_1296':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1297_Arg_Group = TypedDict('Variation_1297_Arg_Group', {
    'RES': Union[Variation_1056, Variation_1056_Arg],
    'GA': Union[Variation_1057, Variation_1057_Arg],
})
Variation_1297_Arg : TypeAlias = Union[Raw, Variation_1297_Arg_Group]
class Variation_1297(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 1),
        ('RES', Variation_1056),
        ('GA', Variation_1057),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RES': ('Resolution with which the GNSS-derived Altitude (GA) is Reported', Variation_1056, 1, 1),
        'GA': ('GNSS-derived Altitude of Target, Expressed as Height Above WGS 84 Ellipsoid', Variation_1057, 2, 14),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RES']) -> Type[Variation_1056]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GA']) -> Type[Variation_1057]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RES'], Literal['GA']]) -> Union[Type['Variation_1056'], Type['Variation_1057']]:
        if key == 'RES':
            return Variation_1056
        if key == 'GA':
            return Variation_1057
        assert_never(key)

    def __init__(self, arg : Variation_1297_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RES']) -> Variation_1056:
        ...

    @overload
    def get_item(self, name : Literal['GA']) -> Variation_1057:
        ...

    def get_item(self, name : Union[Literal['RES'], Literal['GA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RES'], val : Union[Variation_1056, Variation_1056_Arg]) -> 'Variation_1297':
        ...

    @overload
    def set_item(self, name : Literal['GA'], val : Union[Variation_1057, Variation_1057_Arg]) -> 'Variation_1297':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RES'], f : Any) -> 'Variation_1297':
        ...

    @overload
    def modify_item(self, name : Literal['GA'], f : Any) -> 'Variation_1297':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1298_Arg_Group = TypedDict('Variation_1298_Arg_Group', {
    'EM1': Union[Variation_19, Variation_19_Arg],
})
Variation_1298_Arg : TypeAlias = Union[Raw, Variation_1298_Arg_Group]
class Variation_1298(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('EM1', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'EM1': ('Extended Mode 1 Reply in Octal Representation', Variation_19, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['EM1']]) -> Union[Type['Variation_19']]:
        if key == 'EM1':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_1298_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['EM1']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['EM1'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_1298':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['EM1'], f : Any) -> 'Variation_1298':
        return self._modify_item(name, f) # type: ignore

Variation_1299_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['s']]]
class Variation_1299(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Signed', 7.8125e-3, 's')

    def __init__(self, arg : Variation_1299_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1300_Arg_Group = TypedDict('Variation_1300_Arg_Group', {
    'X5': Union[Variation_796, Variation_796_Arg],
    'XC': Union[Variation_797, Variation_797_Arg],
    'X3': Union[Variation_798, Variation_798_Arg],
    'X2': Union[Variation_1063, Variation_1063_Arg],
    'X1': Union[Variation_800, Variation_800_Arg],
})
Variation_1300_Arg : TypeAlias = Union[Raw, Variation_1300_Arg_Group]
class Variation_1300(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        Spare(0, 3),
        ('X5', Variation_796),
        ('XC', Variation_797),
        ('X3', Variation_798),
        ('X2', Variation_1063),
        ('X1', Variation_800),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X5': ('X-pulse from Mode 5 Data Reply or Report', Variation_796, 3, 1),
        'XC': ('X-pulse from Mode C Reply', Variation_797, 4, 1),
        'X3': ('X-pulse from Mode 3/A Reply', Variation_798, 5, 1),
        'X2': ('X-pulse from Mode 2 Reply', Variation_1063, 6, 1),
        'X1': ('X-pulse from Mode 1 Reply', Variation_800, 7, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X5']) -> Type[Variation_796]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XC']) -> Type[Variation_797]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X3']) -> Type[Variation_798]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X2']) -> Type[Variation_1063]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['X1']) -> Type[Variation_800]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X5'], Literal['XC'], Literal['X3'], Literal['X2'], Literal['X1']]) -> Union[Type['Variation_796'], Type['Variation_797'], Type['Variation_798'], Type['Variation_1063'], Type['Variation_800']]:
        if key == 'X5':
            return Variation_796
        if key == 'XC':
            return Variation_797
        if key == 'X3':
            return Variation_798
        if key == 'X2':
            return Variation_1063
        if key == 'X1':
            return Variation_800
        assert_never(key)

    def __init__(self, arg : Variation_1300_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X5']) -> Variation_796:
        ...

    @overload
    def get_item(self, name : Literal['XC']) -> Variation_797:
        ...

    @overload
    def get_item(self, name : Literal['X3']) -> Variation_798:
        ...

    @overload
    def get_item(self, name : Literal['X2']) -> Variation_1063:
        ...

    @overload
    def get_item(self, name : Literal['X1']) -> Variation_800:
        ...

    def get_item(self, name : Union[Literal['X5'], Literal['XC'], Literal['X3'], Literal['X2'], Literal['X1']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X5'], val : Union[Variation_796, Variation_796_Arg]) -> 'Variation_1300':
        ...

    @overload
    def set_item(self, name : Literal['XC'], val : Union[Variation_797, Variation_797_Arg]) -> 'Variation_1300':
        ...

    @overload
    def set_item(self, name : Literal['X3'], val : Union[Variation_798, Variation_798_Arg]) -> 'Variation_1300':
        ...

    @overload
    def set_item(self, name : Literal['X2'], val : Union[Variation_1063, Variation_1063_Arg]) -> 'Variation_1300':
        ...

    @overload
    def set_item(self, name : Literal['X1'], val : Union[Variation_800, Variation_800_Arg]) -> 'Variation_1300':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X5'], f : Any) -> 'Variation_1300':
        ...

    @overload
    def modify_item(self, name : Literal['XC'], f : Any) -> 'Variation_1300':
        ...

    @overload
    def modify_item(self, name : Literal['X3'], f : Any) -> 'Variation_1300':
        ...

    @overload
    def modify_item(self, name : Literal['X2'], f : Any) -> 'Variation_1300':
        ...

    @overload
    def modify_item(self, name : Literal['X1'], f : Any) -> 'Variation_1300':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1301_Arg = TypedDict('Variation_1301_Arg', {
    'SUM': Union[Variation_1295, Variation_1295_Arg],
    'PMN': Union[Variation_1296, Variation_1296_Arg],
    'POS': Union[Variation_705, Variation_705_Arg],
    'GA': Union[Variation_1297, Variation_1297_Arg],
    'EM1': Union[Variation_1298, Variation_1298_Arg],
    'TOS': Union[Variation_1299, Variation_1299_Arg],
    'XP': Union[Variation_1300, Variation_1300_Arg],
}, total=False)
class Variation_1301(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('SUM', Variation_1295),
        ('PMN', Variation_1296),
        ('POS', Variation_705),
        ('GA', Variation_1297),
        ('EM1', Variation_1298),
        ('TOS', Variation_1299),
        ('XP', Variation_1300),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'SUM': ('Mode 5 Summary', Variation_1295, 0x80),
        'PMN': ('Mode 5 PIN/ National Origin/Mission Code', Variation_1296, 0x40),
        'POS': ('Mode 5 Reported Position', Variation_705, 0x20),
        'GA': ('Mode 5 GNSS-derived Altitude', Variation_1297, 0x10),
        'EM1': ('Extended Mode 1 Code in Octal Representation', Variation_1298, 0x08),
        'TOS': ('Time Offset for POS and GA', Variation_1299, 0x04),
        'XP': ('X Pulse Presence', Variation_1300, 0x02),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SUM']) -> Type[Variation_1295]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PMN']) -> Type[Variation_1296]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_705]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GA']) -> Type[Variation_1297]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EM1']) -> Type[Variation_1298]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TOS']) -> Type[Variation_1299]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['XP']) -> Type[Variation_1300]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SUM'], Literal['PMN'], Literal['POS'], Literal['GA'], Literal['EM1'], Literal['TOS'], Literal['XP']]) -> Union[Type['Variation_1295'], Type['Variation_1296'], Type['Variation_705'], Type['Variation_1297'], Type['Variation_1298'], Type['Variation_1299'], Type['Variation_1300']]:
        if key == 'SUM':
            return Variation_1295
        if key == 'PMN':
            return Variation_1296
        if key == 'POS':
            return Variation_705
        if key == 'GA':
            return Variation_1297
        if key == 'EM1':
            return Variation_1298
        if key == 'TOS':
            return Variation_1299
        if key == 'XP':
            return Variation_1300
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1301_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['SUM'], val : Union[Variation_1295, Variation_1295_Arg]) -> 'Variation_1301':
        ...

    @overload
    def set_item(self, name : Literal['PMN'], val : Union[Variation_1296, Variation_1296_Arg]) -> 'Variation_1301':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_705, Variation_705_Arg]) -> 'Variation_1301':
        ...

    @overload
    def set_item(self, name : Literal['GA'], val : Union[Variation_1297, Variation_1297_Arg]) -> 'Variation_1301':
        ...

    @overload
    def set_item(self, name : Literal['EM1'], val : Union[Variation_1298, Variation_1298_Arg]) -> 'Variation_1301':
        ...

    @overload
    def set_item(self, name : Literal['TOS'], val : Union[Variation_1299, Variation_1299_Arg]) -> 'Variation_1301':
        ...

    @overload
    def set_item(self, name : Literal['XP'], val : Union[Variation_1300, Variation_1300_Arg]) -> 'Variation_1301':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['SUM']) -> 'Variation_1301':
        ...

    @overload
    def del_item(self, name : Literal['PMN']) -> 'Variation_1301':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1301':
        ...

    @overload
    def del_item(self, name : Literal['GA']) -> 'Variation_1301':
        ...

    @overload
    def del_item(self, name : Literal['EM1']) -> 'Variation_1301':
        ...

    @overload
    def del_item(self, name : Literal['TOS']) -> 'Variation_1301':
        ...

    @overload
    def del_item(self, name : Literal['XP']) -> 'Variation_1301':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['SUM']) -> Variation_1295:
        ...

    @overload
    def get_item(self, name : Literal['PMN']) -> Variation_1296:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_705:
        ...

    @overload
    def get_item(self, name : Literal['GA']) -> Variation_1297:
        ...

    @overload
    def get_item(self, name : Literal['EM1']) -> Variation_1298:
        ...

    @overload
    def get_item(self, name : Literal['TOS']) -> Variation_1299:
        ...

    @overload
    def get_item(self, name : Literal['XP']) -> Variation_1300:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['SUM'], f : Any) -> 'Variation_1301':
        ...

    @overload
    def modify_item(self, name : Literal['PMN'], f : Any) -> 'Variation_1301':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1301':
        ...

    @overload
    def modify_item(self, name : Literal['GA'], f : Any) -> 'Variation_1301':
        ...

    @overload
    def modify_item(self, name : Literal['EM1'], f : Any) -> 'Variation_1301':
        ...

    @overload
    def modify_item(self, name : Literal['TOS'], f : Any) -> 'Variation_1301':
        ...

    @overload
    def modify_item(self, name : Literal['XP'], f : Any) -> 'Variation_1301':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1302_Arg_Group = TypedDict('Variation_1302_Arg_Group', {
    'MODE2': Union[Variation_19, Variation_19_Arg],
})
Variation_1302_Arg : TypeAlias = Union[Raw, Variation_1302_Arg_Group]
class Variation_1302(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        Spare(0, 4),
        ('MODE2', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MODE2': ('Mode-2 Code in Octal Representation', Variation_19, 4, 12),
    }


    @classmethod
    def spec(cls, key : Union[Literal['MODE2']]) -> Union[Type['Variation_19']]:
        if key == 'MODE2':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_1302_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    def get_item(self, name : Literal['MODE2']) -> Any:
        return self._get_item(name)

    def set_item(self, name : Literal['MODE2'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_1302':
        return self._set_item(name, val) # type: ignore

    def modify_item(self, name : Literal['MODE2'], f : Any) -> 'Variation_1302':
        return self._modify_item(name, f) # type: ignore

Variation_1303_Arg_Group_1 = TypedDict('Variation_1303_Arg_Group_1', {
    'MIDENT': Union[Variation_0, Variation_0_Arg],
    'MTRACK': Union[Variation_224, Variation_224_Arg],
})
Variation_1303_Arg_Group_2 = TypedDict('Variation_1303_Arg_Group_2', {
    'MIDENT': Union[Variation_0, Variation_0_Arg],
    'MTRACK': Union[Variation_224, Variation_224_Arg],
    'SIDENT': Union[Variation_0, Variation_0_Arg],
    'STRACK': Union[Variation_224, Variation_224_Arg],
})
Variation_1303_Arg : TypeAlias = Union[
    int,
    Variation_1303_Arg_Group_1,
    Tuple[int],
    Variation_1303_Arg_Group_2,
    Tuple[int,int],
]
class Variation_1303(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        23,
        23,
    ]

    subitems_list = [
        [
            ('MIDENT', Variation_0),
            ('MTRACK', Variation_224),
        ],
        [
            ('SIDENT', Variation_0),
            ('STRACK', Variation_224),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MIDENT': ('Master System Unit Identification', Variation_0, 0, 8),
        'MTRACK': ('Master System Track Number', Variation_224, 8, 15),
        'SIDENT': ('Slave System Unit Identification', Variation_0, 0, 8),
        'STRACK': ('Slave System Track Number', Variation_224, 8, 15),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MIDENT']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MTRACK']) -> Type[Variation_224]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIDENT']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STRACK']) -> Type[Variation_224]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MIDENT'], Literal['MTRACK'], Literal['SIDENT'], Literal['STRACK']]) -> Union[Type['Variation_0'], Type['Variation_224'], Type['Variation_0'], Type['Variation_224']]:
        if key == 'MIDENT':
            return Variation_0
        if key == 'MTRACK':
            return Variation_224
        if key == 'SIDENT':
            return Variation_0
        if key == 'STRACK':
            return Variation_224
        assert_never(key)

    def __init__(self, arg : Variation_1303_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1303_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_1303_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MIDENT']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['MTRACK']) -> Variation_224:
        ...

    @overload
    def get_item(self, name : Literal['SIDENT']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['STRACK']) -> Variation_224:
        ...

    def get_item(self, name : Union[Literal['MIDENT'], Literal['MTRACK'], Literal['SIDENT'], Literal['STRACK']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MIDENT'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1303':
        ...

    @overload
    def set_item(self, name : Literal['MTRACK'], val : Union[Variation_224, Variation_224_Arg]) -> 'Variation_1303':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MIDENT'], f : Any) -> 'Variation_1303':
        ...

    @overload
    def modify_item(self, name : Literal['MTRACK'], f : Any) -> 'Variation_1303':
        ...

    @overload
    def modify_item(self, name : Literal['SIDENT'], f : Any) -> 'Variation_1303':
        ...

    @overload
    def modify_item(self, name : Literal['STRACK'], f : Any) -> 'Variation_1303':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1304_Arg_Group = TypedDict('Variation_1304_Arg_Group', {
    'X': Union[Variation_152, Variation_152_Arg],
    'Y': Union[Variation_152, Variation_152_Arg],
})
Variation_1304_Arg : TypeAlias = Union[Raw, Variation_1304_Arg_Group]
class Variation_1304(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('X', Variation_152),
        ('Y', Variation_152),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('APC (X-Component)', Variation_152, 0, 16),
        'Y': ('APC (Y-Component)', Variation_152, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_152]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_152]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_152'], Type['Variation_152']]:
        if key == 'X':
            return Variation_152
        if key == 'Y':
            return Variation_152
        assert_never(key)

    def __init__(self, arg : Variation_1304_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_152:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_152:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_152, Variation_152_Arg]) -> 'Variation_1304':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_152, Variation_152_Arg]) -> 'Variation_1304':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_1304':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_1304':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1305_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_1305(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 5.364418029785156e-6, '°')

    def __init__(self, arg : Variation_1305_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1306_Arg_Group = TypedDict('Variation_1306_Arg_Group', {
    'LAT': Union[Variation_1305, Variation_1305_Arg],
    'LON': Union[Variation_1305, Variation_1305_Arg],
})
Variation_1306_Arg : TypeAlias = Union[Raw, Variation_1306_Arg_Group]
class Variation_1306(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('LAT', Variation_1305),
        ('LON', Variation_1305),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('APW (Latitude Component)', Variation_1305, 0, 16),
        'LON': ('APW (Longitude Component)', Variation_1305, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_1305]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_1305]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_1305'], Type['Variation_1305']]:
        if key == 'LAT':
            return Variation_1305
        if key == 'LON':
            return Variation_1305
        assert_never(key)

    def __init__(self, arg : Variation_1306_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_1305:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_1305:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_1305, Variation_1305_Arg]) -> 'Variation_1306':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_1305, Variation_1305_Arg]) -> 'Variation_1306':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_1306':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_1306':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1307_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft']]]
class Variation_1307(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 6.25, 'ft')

    def __init__(self, arg : Variation_1307_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1308_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['FL']]]
class Variation_1308(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 0.25, 'FL')

    def __init__(self, arg : Variation_1308_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1309_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s']]]
class Variation_1309(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 0.25, 'm/s')

    def __init__(self, arg : Variation_1309_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1310_Arg_Group = TypedDict('Variation_1310_Arg_Group', {
    'X': Union[Variation_1309, Variation_1309_Arg],
    'Y': Union[Variation_1309, Variation_1309_Arg],
})
Variation_1310_Arg : TypeAlias = Union[Raw, Variation_1310_Arg_Group]
class Variation_1310(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('X', Variation_1309),
        ('Y', Variation_1309),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('ATV (X-Component)', Variation_1309, 0, 8),
        'Y': ('ATV (Y-Component)', Variation_1309, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_1309]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_1309]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_1309'], Type['Variation_1309']]:
        if key == 'X':
            return Variation_1309
        if key == 'Y':
            return Variation_1309
        assert_never(key)

    def __init__(self, arg : Variation_1310_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_1309:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_1309:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_1309, Variation_1309_Arg]) -> 'Variation_1310':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_1309, Variation_1309_Arg]) -> 'Variation_1310':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_1310':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_1310':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1311_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m/s²']]]
class Variation_1311(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 0.25, 'm/s²')

    def __init__(self, arg : Variation_1311_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1312_Arg_Group = TypedDict('Variation_1312_Arg_Group', {
    'X': Union[Variation_1311, Variation_1311_Arg],
    'Y': Union[Variation_1311, Variation_1311_Arg],
})
Variation_1312_Arg : TypeAlias = Union[Raw, Variation_1312_Arg_Group]
class Variation_1312(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('X', Variation_1311),
        ('Y', Variation_1311),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'X': ('AA (X-Component)', Variation_1311, 0, 8),
        'Y': ('AA (Y-Component)', Variation_1311, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['X']) -> Type[Variation_1311]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['Y']) -> Type[Variation_1311]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['X'], Literal['Y']]) -> Union[Type['Variation_1311'], Type['Variation_1311']]:
        if key == 'X':
            return Variation_1311
        if key == 'Y':
            return Variation_1311
        assert_never(key)

    def __init__(self, arg : Variation_1312_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['X']) -> Variation_1311:
        ...

    @overload
    def get_item(self, name : Literal['Y']) -> Variation_1311:
        ...

    def get_item(self, name : Union[Literal['X'], Literal['Y']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['X'], val : Union[Variation_1311, Variation_1311_Arg]) -> 'Variation_1312':
        ...

    @overload
    def set_item(self, name : Literal['Y'], val : Union[Variation_1311, Variation_1311_Arg]) -> 'Variation_1312':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['X'], f : Any) -> 'Variation_1312':
        ...

    @overload
    def modify_item(self, name : Literal['Y'], f : Any) -> 'Variation_1312':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1313_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ft/min']]]
class Variation_1313(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 6.25, 'ft/min')

    def __init__(self, arg : Variation_1313_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1314_Arg = TypedDict('Variation_1314_Arg', {
    'APC': Union[Variation_1304, Variation_1304_Arg],
    'COV': Union[Variation_390, Variation_390_Arg],
    'APW': Union[Variation_1306, Variation_1306_Arg],
    'AGA': Union[Variation_1307, Variation_1307_Arg],
    'ABA': Union[Variation_1308, Variation_1308_Arg],
    'ATV': Union[Variation_1310, Variation_1310_Arg],
    'AA': Union[Variation_1312, Variation_1312_Arg],
    'ARC': Union[Variation_1313, Variation_1313_Arg],
}, total=False)
class Variation_1314(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('APC', Variation_1304),
        ('COV', Variation_390),
        ('APW', Variation_1306),
        ('AGA', Variation_1307),
        ('ABA', Variation_1308),
        ('ATV', Variation_1310),
        ('AA', Variation_1312),
        ('ARC', Variation_1313),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'APC': ('Estimated Accuracy Of Track Position (Cartesian)', Variation_1304, 0x8000),
        'COV': ('XY Covariance Component', Variation_390, 0x4000),
        'APW': ('Estimated Accuracy Of Track Position (WGS-84)', Variation_1306, 0x2000),
        'AGA': ('Estimated Accuracy Of Calculated Track Geometric Altitude', Variation_1307, 0x1000),
        'ABA': ('Estimated Accuracy Of Calculated Track Barometric Altitude', Variation_1308, 0x0800),
        'ATV': ('Estimated Accuracy Of Track Velocity (Cartesian)', Variation_1310, 0x0400),
        'AA': ('Estimated Accuracy Of Acceleration (Cartesian)', Variation_1312, 0x0200),
        'ARC': ('Estimated Accuracy Of Rate Of Climb/Descent', Variation_1313, 0x0180),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['APC']) -> Type[Variation_1304]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COV']) -> Type[Variation_390]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['APW']) -> Type[Variation_1306]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AGA']) -> Type[Variation_1307]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ABA']) -> Type[Variation_1308]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ATV']) -> Type[Variation_1310]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AA']) -> Type[Variation_1312]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_1313]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['APC'], Literal['COV'], Literal['APW'], Literal['AGA'], Literal['ABA'], Literal['ATV'], Literal['AA'], Literal['ARC']]) -> Union[Type['Variation_1304'], Type['Variation_390'], Type['Variation_1306'], Type['Variation_1307'], Type['Variation_1308'], Type['Variation_1310'], Type['Variation_1312'], Type['Variation_1313']]:
        if key == 'APC':
            return Variation_1304
        if key == 'COV':
            return Variation_390
        if key == 'APW':
            return Variation_1306
        if key == 'AGA':
            return Variation_1307
        if key == 'ABA':
            return Variation_1308
        if key == 'ATV':
            return Variation_1310
        if key == 'AA':
            return Variation_1312
        if key == 'ARC':
            return Variation_1313
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1314_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['APC'], val : Union[Variation_1304, Variation_1304_Arg]) -> 'Variation_1314':
        ...

    @overload
    def set_item(self, name : Literal['COV'], val : Union[Variation_390, Variation_390_Arg]) -> 'Variation_1314':
        ...

    @overload
    def set_item(self, name : Literal['APW'], val : Union[Variation_1306, Variation_1306_Arg]) -> 'Variation_1314':
        ...

    @overload
    def set_item(self, name : Literal['AGA'], val : Union[Variation_1307, Variation_1307_Arg]) -> 'Variation_1314':
        ...

    @overload
    def set_item(self, name : Literal['ABA'], val : Union[Variation_1308, Variation_1308_Arg]) -> 'Variation_1314':
        ...

    @overload
    def set_item(self, name : Literal['ATV'], val : Union[Variation_1310, Variation_1310_Arg]) -> 'Variation_1314':
        ...

    @overload
    def set_item(self, name : Literal['AA'], val : Union[Variation_1312, Variation_1312_Arg]) -> 'Variation_1314':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_1313, Variation_1313_Arg]) -> 'Variation_1314':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['APC']) -> 'Variation_1314':
        ...

    @overload
    def del_item(self, name : Literal['COV']) -> 'Variation_1314':
        ...

    @overload
    def del_item(self, name : Literal['APW']) -> 'Variation_1314':
        ...

    @overload
    def del_item(self, name : Literal['AGA']) -> 'Variation_1314':
        ...

    @overload
    def del_item(self, name : Literal['ABA']) -> 'Variation_1314':
        ...

    @overload
    def del_item(self, name : Literal['ATV']) -> 'Variation_1314':
        ...

    @overload
    def del_item(self, name : Literal['AA']) -> 'Variation_1314':
        ...

    @overload
    def del_item(self, name : Literal['ARC']) -> 'Variation_1314':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['APC']) -> Variation_1304:
        ...

    @overload
    def get_item(self, name : Literal['COV']) -> Variation_390:
        ...

    @overload
    def get_item(self, name : Literal['APW']) -> Variation_1306:
        ...

    @overload
    def get_item(self, name : Literal['AGA']) -> Variation_1307:
        ...

    @overload
    def get_item(self, name : Literal['ABA']) -> Variation_1308:
        ...

    @overload
    def get_item(self, name : Literal['ATV']) -> Variation_1310:
        ...

    @overload
    def get_item(self, name : Literal['AA']) -> Variation_1312:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_1313:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['APC'], f : Any) -> 'Variation_1314':
        ...

    @overload
    def modify_item(self, name : Literal['COV'], f : Any) -> 'Variation_1314':
        ...

    @overload
    def modify_item(self, name : Literal['APW'], f : Any) -> 'Variation_1314':
        ...

    @overload
    def modify_item(self, name : Literal['AGA'], f : Any) -> 'Variation_1314':
        ...

    @overload
    def modify_item(self, name : Literal['ABA'], f : Any) -> 'Variation_1314':
        ...

    @overload
    def modify_item(self, name : Literal['ATV'], f : Any) -> 'Variation_1314':
        ...

    @overload
    def modify_item(self, name : Literal['AA'], f : Any) -> 'Variation_1314':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_1314':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1315_Arg_Group = TypedDict('Variation_1315_Arg_Group', {
    'RHO': Union[Variation_594, Variation_594_Arg],
    'THETA': Union[Variation_14, Variation_14_Arg],
})
Variation_1315_Arg : TypeAlias = Union[Raw, Variation_1315_Arg_Group]
class Variation_1315(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('RHO', Variation_594),
        ('THETA', Variation_14),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'RHO': ('Measured Distance', Variation_594, 0, 16),
        'THETA': ('Measured Azimuth', Variation_14, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['RHO']) -> Type[Variation_594]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['THETA']) -> Type[Variation_14]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['RHO'], Literal['THETA']]) -> Union[Type['Variation_594'], Type['Variation_14']]:
        if key == 'RHO':
            return Variation_594
        if key == 'THETA':
            return Variation_14
        assert_never(key)

    def __init__(self, arg : Variation_1315_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['RHO']) -> Variation_594:
        ...

    @overload
    def get_item(self, name : Literal['THETA']) -> Variation_14:
        ...

    def get_item(self, name : Union[Literal['RHO'], Literal['THETA']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['RHO'], val : Union[Variation_594, Variation_594_Arg]) -> 'Variation_1315':
        ...

    @overload
    def set_item(self, name : Literal['THETA'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1315':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['RHO'], f : Any) -> 'Variation_1315':
        ...

    @overload
    def modify_item(self, name : Literal['THETA'], f : Any) -> 'Variation_1315':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1316_Arg_Group = TypedDict('Variation_1316_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'LMC': Union[Variation_21, Variation_21_Arg],
})
Variation_1316_Arg : TypeAlias = Union[Raw, Variation_1316_Arg_Group]
class Variation_1316(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('LMC', Variation_21),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('Validated', Variation_16, 0, 1),
        'G': ('Garbled', Variation_17, 1, 1),
        'LMC': ('Last Measured Mode C Code', Variation_21, 2, 14),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LMC']) -> Type[Variation_21]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['LMC']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_21']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'LMC':
            return Variation_21
        assert_never(key)

    def __init__(self, arg : Variation_1316_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['LMC']) -> Variation_21:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['LMC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_1316':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_1316':
        ...

    @overload
    def set_item(self, name : Literal['LMC'], val : Union[Variation_21, Variation_21_Arg]) -> 'Variation_1316':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_1316':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_1316':
        ...

    @overload
    def modify_item(self, name : Literal['LMC'], f : Any) -> 'Variation_1316':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1317_Arg : TypeAlias = Raw
class Variation_1317(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Mode 3/A code as derived from the reply of the transponder',
        1: 'Mode 3/A code as provided by a sensor local tracker',
    }

    def __init__(self, arg : Variation_1317_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1318_Arg_Group = TypedDict('Variation_1318_Arg_Group', {
    'V': Union[Variation_16, Variation_16_Arg],
    'G': Union[Variation_17, Variation_17_Arg],
    'L': Union[Variation_1317, Variation_1317_Arg],
    'MODE3A': Union[Variation_19, Variation_19_Arg],
})
Variation_1318_Arg : TypeAlias = Union[Raw, Variation_1318_Arg_Group]
class Variation_1318(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('V', Variation_16),
        ('G', Variation_17),
        ('L', Variation_1317),
        Spare(3, 1),
        ('MODE3A', Variation_19),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'V': ('Validated', Variation_16, 0, 1),
        'G': ('Garbled', Variation_17, 1, 1),
        'L': ('', Variation_1317, 2, 1),
        'MODE3A': ('Mode-3/A Reply in Octal Representation', Variation_19, 4, 12),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['V']) -> Type[Variation_16]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['G']) -> Type[Variation_17]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['L']) -> Type[Variation_1317]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MODE3A']) -> Type[Variation_19]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Union[Type['Variation_16'], Type['Variation_17'], Type['Variation_1317'], Type['Variation_19']]:
        if key == 'V':
            return Variation_16
        if key == 'G':
            return Variation_17
        if key == 'L':
            return Variation_1317
        if key == 'MODE3A':
            return Variation_19
        assert_never(key)

    def __init__(self, arg : Variation_1318_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['V']) -> Variation_16:
        ...

    @overload
    def get_item(self, name : Literal['G']) -> Variation_17:
        ...

    @overload
    def get_item(self, name : Literal['L']) -> Variation_1317:
        ...

    @overload
    def get_item(self, name : Literal['MODE3A']) -> Variation_19:
        ...

    def get_item(self, name : Union[Literal['V'], Literal['G'], Literal['L'], Literal['MODE3A']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['V'], val : Union[Variation_16, Variation_16_Arg]) -> 'Variation_1318':
        ...

    @overload
    def set_item(self, name : Literal['G'], val : Union[Variation_17, Variation_17_Arg]) -> 'Variation_1318':
        ...

    @overload
    def set_item(self, name : Literal['L'], val : Union[Variation_1317, Variation_1317_Arg]) -> 'Variation_1318':
        ...

    @overload
    def set_item(self, name : Literal['MODE3A'], val : Union[Variation_19, Variation_19_Arg]) -> 'Variation_1318':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['V'], f : Any) -> 'Variation_1318':
        ...

    @overload
    def modify_item(self, name : Literal['G'], f : Any) -> 'Variation_1318':
        ...

    @overload
    def modify_item(self, name : Literal['L'], f : Any) -> 'Variation_1318':
        ...

    @overload
    def modify_item(self, name : Literal['MODE3A'], f : Any) -> 'Variation_1318':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1319_Arg : TypeAlias = Raw
class Variation_1319(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 3
    table = {
        0: 'No detection',
        1: 'Single PSR detection',
        2: 'Single SSR detection',
        3: 'SSR + PSR detection',
        4: 'Single ModeS All-Call',
        5: 'Single ModeS Roll-Call',
        6: 'ModeS All-Call + PSR',
        7: 'ModeS Roll-Call + PSR',
    }

    def __init__(self, arg : Variation_1319_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1320_Arg : TypeAlias = Raw
class Variation_1320(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'Report from target transponder',
        1: 'Report from field monitor (item transponder)',
    }

    def __init__(self, arg : Variation_1320_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1321_Arg : TypeAlias = Raw
class Variation_1321(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Real target report',
        1: 'Test target report',
    }

    def __init__(self, arg : Variation_1321_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1322_Arg_Group = TypedDict('Variation_1322_Arg_Group', {
    'TYP': Union[Variation_1319, Variation_1319_Arg],
    'SIM': Union[Variation_1113, Variation_1113_Arg],
    'RAB': Union[Variation_1320, Variation_1320_Arg],
    'TST': Union[Variation_1321, Variation_1321_Arg],
})
Variation_1322_Arg : TypeAlias = Union[Raw, Variation_1322_Arg_Group]
class Variation_1322(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('TYP', Variation_1319),
        ('SIM', Variation_1113),
        ('RAB', Variation_1320),
        ('TST', Variation_1321),
        Spare(6, 2),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'TYP': ('Report Type', Variation_1319, 0, 3),
        'SIM': ('', Variation_1113, 3, 1),
        'RAB': ('', Variation_1320, 4, 1),
        'TST': ('', Variation_1321, 5, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_1319]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_1113]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAB']) -> Type[Variation_1320]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TST']) -> Type[Variation_1321]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['TYP'], Literal['SIM'], Literal['RAB'], Literal['TST']]) -> Union[Type['Variation_1319'], Type['Variation_1113'], Type['Variation_1320'], Type['Variation_1321']]:
        if key == 'TYP':
            return Variation_1319
        if key == 'SIM':
            return Variation_1113
        if key == 'RAB':
            return Variation_1320
        if key == 'TST':
            return Variation_1321
        assert_never(key)

    def __init__(self, arg : Variation_1322_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_1319:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_1113:
        ...

    @overload
    def get_item(self, name : Literal['RAB']) -> Variation_1320:
        ...

    @overload
    def get_item(self, name : Literal['TST']) -> Variation_1321:
        ...

    def get_item(self, name : Union[Literal['TYP'], Literal['SIM'], Literal['RAB'], Literal['TST']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_1319, Variation_1319_Arg]) -> 'Variation_1322':
        ...

    @overload
    def set_item(self, name : Literal['SIM'], val : Union[Variation_1113, Variation_1113_Arg]) -> 'Variation_1322':
        ...

    @overload
    def set_item(self, name : Literal['RAB'], val : Union[Variation_1320, Variation_1320_Arg]) -> 'Variation_1322':
        ...

    @overload
    def set_item(self, name : Literal['TST'], val : Union[Variation_1321, Variation_1321_Arg]) -> 'Variation_1322':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1322':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_1322':
        ...

    @overload
    def modify_item(self, name : Literal['RAB'], f : Any) -> 'Variation_1322':
        ...

    @overload
    def modify_item(self, name : Literal['TST'], f : Any) -> 'Variation_1322':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1323_Arg = TypedDict('Variation_1323_Arg', {
    'SID': Union[Variation_1, Variation_1_Arg],
    'POS': Union[Variation_1315, Variation_1315_Arg],
    'HEIGHT': Union[Variation_193, Variation_193_Arg],
    'MDC': Union[Variation_1316, Variation_1316_Arg],
    'MDA': Union[Variation_1318, Variation_1318_Arg],
    'TYP': Union[Variation_1322, Variation_1322_Arg],
}, total=False)
class Variation_1323(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('SID', Variation_1),
        ('POS', Variation_1315),
        ('HEIGHT', Variation_193),
        ('MDC', Variation_1316),
        ('MDA', Variation_1318),
        ('TYP', Variation_1322),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'SID': ('Sensor Identification', Variation_1, 0x80),
        'POS': ('Measured Position', Variation_1315, 0x40),
        'HEIGHT': ('Measured 3-D Height', Variation_193, 0x20),
        'MDC': ('', Variation_1316, 0x10),
        'MDA': ('', Variation_1318, 0x08),
        'TYP': ('', Variation_1322, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SID']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_1315]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HEIGHT']) -> Type[Variation_193]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDC']) -> Type[Variation_1316]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDA']) -> Type[Variation_1318]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_1322]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SID'], Literal['POS'], Literal['HEIGHT'], Literal['MDC'], Literal['MDA'], Literal['TYP']]) -> Union[Type['Variation_1'], Type['Variation_1315'], Type['Variation_193'], Type['Variation_1316'], Type['Variation_1318'], Type['Variation_1322']]:
        if key == 'SID':
            return Variation_1
        if key == 'POS':
            return Variation_1315
        if key == 'HEIGHT':
            return Variation_193
        if key == 'MDC':
            return Variation_1316
        if key == 'MDA':
            return Variation_1318
        if key == 'TYP':
            return Variation_1322
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1323_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['SID'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1323':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_1315, Variation_1315_Arg]) -> 'Variation_1323':
        ...

    @overload
    def set_item(self, name : Literal['HEIGHT'], val : Union[Variation_193, Variation_193_Arg]) -> 'Variation_1323':
        ...

    @overload
    def set_item(self, name : Literal['MDC'], val : Union[Variation_1316, Variation_1316_Arg]) -> 'Variation_1323':
        ...

    @overload
    def set_item(self, name : Literal['MDA'], val : Union[Variation_1318, Variation_1318_Arg]) -> 'Variation_1323':
        ...

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_1322, Variation_1322_Arg]) -> 'Variation_1323':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['SID']) -> 'Variation_1323':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1323':
        ...

    @overload
    def del_item(self, name : Literal['HEIGHT']) -> 'Variation_1323':
        ...

    @overload
    def del_item(self, name : Literal['MDC']) -> 'Variation_1323':
        ...

    @overload
    def del_item(self, name : Literal['MDA']) -> 'Variation_1323':
        ...

    @overload
    def del_item(self, name : Literal['TYP']) -> 'Variation_1323':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['SID']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_1315:
        ...

    @overload
    def get_item(self, name : Literal['HEIGHT']) -> Variation_193:
        ...

    @overload
    def get_item(self, name : Literal['MDC']) -> Variation_1316:
        ...

    @overload
    def get_item(self, name : Literal['MDA']) -> Variation_1318:
        ...

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_1322:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['SID'], f : Any) -> 'Variation_1323':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1323':
        ...

    @overload
    def modify_item(self, name : Literal['HEIGHT'], f : Any) -> 'Variation_1323':
        ...

    @overload
    def modify_item(self, name : Literal['MDC'], f : Any) -> 'Variation_1323':
        ...

    @overload
    def modify_item(self, name : Literal['MDA'], f : Any) -> 'Variation_1323':
        ...

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1323':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1324_Arg = TypedDict('Variation_1324_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '070': Union[Variation_80, Variation_80_Arg],
    '105': Union[Variation_649, Variation_649_Arg],
    '100': Union[Variation_1214, Variation_1214_Arg],
    '185': Union[Variation_1215, Variation_1215_Arg],
    '210': Union[Variation_664, Variation_664_Arg],
    '060': Union[Variation_1217, Variation_1217_Arg],
    '245': Union[Variation_1219, Variation_1219_Arg],
    '380': Union[Variation_1251, Variation_1251_Arg],
    '040': Union[Variation_64, Variation_64_Arg],
    '080': Union[Variation_1273, Variation_1273_Arg],
    '290': Union[Variation_1274, Variation_1274_Arg],
    '200': Union[Variation_1279, Variation_1279_Arg],
    '295': Union[Variation_1280, Variation_1280_Arg],
    '136': Union[Variation_360, Variation_360_Arg],
    '130': Union[Variation_287, Variation_287_Arg],
    '135': Union[Variation_1281, Variation_1281_Arg],
    '220': Union[Variation_364, Variation_364_Arg],
    '390': Union[Variation_1288, Variation_1288_Arg],
    '270': Union[Variation_290, Variation_290_Arg],
    '300': Union[Variation_285, Variation_285_Arg],
    '110': Union[Variation_1301, Variation_1301_Arg],
    '120': Union[Variation_1302, Variation_1302_Arg],
    '510': Union[Variation_1303, Variation_1303_Arg],
    '500': Union[Variation_1314, Variation_1314_Arg],
    '340': Union[Variation_1323, Variation_1323_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1324(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('010', Variation_1),
        None,
        ('015', Variation_0),
        ('070', Variation_80),
        ('105', Variation_649),
        ('100', Variation_1214),
        ('185', Variation_1215),
        ('210', Variation_664),
        ('060', Variation_1217),
        ('245', Variation_1219),
        ('380', Variation_1251),
        ('040', Variation_64),
        ('080', Variation_1273),
        ('290', Variation_1274),
        ('200', Variation_1279),
        ('295', Variation_1280),
        ('136', Variation_360),
        ('130', Variation_287),
        ('135', Variation_1281),
        ('220', Variation_364),
        ('390', Variation_1288),
        ('270', Variation_290),
        ('300', Variation_285),
        ('110', Variation_1301),
        ('120', Variation_1302),
        ('510', Variation_1303),
        ('500', Variation_1314),
        ('340', Variation_1323),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000000000),
        '015': ('Service Identification', Variation_0, 0x2000000000),
        '070': ('Time Of Track Information', Variation_80, 0x1000000000),
        '105': ('Calculated Position In WGS-84 Co-ordinates', Variation_649, 0x0800000000),
        '100': ('Calculated Track Position (Cartesian)', Variation_1214, 0x0400000000),
        '185': ('Calculated Track Velocity (Cartesian)', Variation_1215, 0x0200000000),
        '210': ('Calculated Acceleration (Cartesian)', Variation_664, 0x0180000000),
        '060': ('Track Mode 3/A Code', Variation_1217, 0x0140000000),
        '245': ('Target Identification', Variation_1219, 0x0120000000),
        '380': ('Aircraft Derived Data', Variation_1251, 0x0110000000),
        '040': ('Track Number', Variation_64, 0x0108000000),
        '080': ('Track Status', Variation_1273, 0x0104000000),
        '290': ('System Track Update Ages', Variation_1274, 0x0102000000),
        '200': ('Mode of Movement', Variation_1279, 0x0101800000),
        '295': ('Track Data Ages', Variation_1280, 0x0101400000),
        '136': ('Measured Flight Level', Variation_360, 0x0101200000),
        '130': ('Calculated Track Geometric Altitude', Variation_287, 0x0101100000),
        '135': ('Calculated Track Barometric Altitude', Variation_1281, 0x0101080000),
        '220': ('Calculated Rate of Climb/Descent', Variation_364, 0x0101040000),
        '390': ('Flight Plan Related Data', Variation_1288, 0x0101020000),
        '270': ('Target Size and Orientation', Variation_290, 0x0101018000),
        '300': ('Vehicle Fleet Identification', Variation_285, 0x0101014000),
        '110': ('Mode 5 Data Reports and Extended Mode 1 Code', Variation_1301, 0x0101012000),
        '120': ('Track Mode 2 Code', Variation_1302, 0x0101011000),
        '510': ('Composed Track Number', Variation_1303, 0x0101010800),
        '500': ('Estimated Accuracies', Variation_1314, 0x0101010400),
        '340': ('Measured Information', Variation_1323, 0x0101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x0101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['105']) -> Type[Variation_649]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_1214]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['185']) -> Type[Variation_1215]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_664]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_1217]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['245']) -> Type[Variation_1219]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['380']) -> Type[Variation_1251]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_1273]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['290']) -> Type[Variation_1274]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_1279]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['295']) -> Type[Variation_1280]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['136']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['135']) -> Type[Variation_1281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['390']) -> Type[Variation_1288]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['270']) -> Type[Variation_290]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_285]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1301]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1302]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['510']) -> Type[Variation_1303]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_1314]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['340']) -> Type[Variation_1323]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['015'], Literal['070'], Literal['105'], Literal['100'], Literal['185'], Literal['210'], Literal['060'], Literal['245'], Literal['380'], Literal['040'], Literal['080'], Literal['290'], Literal['200'], Literal['295'], Literal['136'], Literal['130'], Literal['135'], Literal['220'], Literal['390'], Literal['270'], Literal['300'], Literal['110'], Literal['120'], Literal['510'], Literal['500'], Literal['340'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_0'], Type['Variation_80'], Type['Variation_649'], Type['Variation_1214'], Type['Variation_1215'], Type['Variation_664'], Type['Variation_1217'], Type['Variation_1219'], Type['Variation_1251'], Type['Variation_64'], Type['Variation_1273'], Type['Variation_1274'], Type['Variation_1279'], Type['Variation_1280'], Type['Variation_360'], Type['Variation_287'], Type['Variation_1281'], Type['Variation_364'], Type['Variation_1288'], Type['Variation_290'], Type['Variation_285'], Type['Variation_1301'], Type['Variation_1302'], Type['Variation_1303'], Type['Variation_1314'], Type['Variation_1323'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '015':
            return Variation_0
        if key == '070':
            return Variation_80
        if key == '105':
            return Variation_649
        if key == '100':
            return Variation_1214
        if key == '185':
            return Variation_1215
        if key == '210':
            return Variation_664
        if key == '060':
            return Variation_1217
        if key == '245':
            return Variation_1219
        if key == '380':
            return Variation_1251
        if key == '040':
            return Variation_64
        if key == '080':
            return Variation_1273
        if key == '290':
            return Variation_1274
        if key == '200':
            return Variation_1279
        if key == '295':
            return Variation_1280
        if key == '136':
            return Variation_360
        if key == '130':
            return Variation_287
        if key == '135':
            return Variation_1281
        if key == '220':
            return Variation_364
        if key == '390':
            return Variation_1288
        if key == '270':
            return Variation_290
        if key == '300':
            return Variation_285
        if key == '110':
            return Variation_1301
        if key == '120':
            return Variation_1302
        if key == '510':
            return Variation_1303
        if key == '500':
            return Variation_1314
        if key == '340':
            return Variation_1323
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1324_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['105'], val : Union[Variation_649, Variation_649_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_1214, Variation_1214_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['185'], val : Union[Variation_1215, Variation_1215_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_664, Variation_664_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_1217, Variation_1217_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['245'], val : Union[Variation_1219, Variation_1219_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['380'], val : Union[Variation_1251, Variation_1251_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_1273, Variation_1273_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['290'], val : Union[Variation_1274, Variation_1274_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_1279, Variation_1279_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['295'], val : Union[Variation_1280, Variation_1280_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['136'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['135'], val : Union[Variation_1281, Variation_1281_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['390'], val : Union[Variation_1288, Variation_1288_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['270'], val : Union[Variation_290, Variation_290_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_285, Variation_285_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1301, Variation_1301_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1302, Variation_1302_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['510'], val : Union[Variation_1303, Variation_1303_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_1314, Variation_1314_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['340'], val : Union[Variation_1323, Variation_1323_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1324':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1324':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['105']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['185']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['245']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['380']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['290']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['295']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['136']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['135']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['390']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['270']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['510']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['340']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1324':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1324':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['105']) -> Variation_649:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_1214:
        ...

    @overload
    def get_item(self, name : Literal['185']) -> Variation_1215:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_664:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_1217:
        ...

    @overload
    def get_item(self, name : Literal['245']) -> Variation_1219:
        ...

    @overload
    def get_item(self, name : Literal['380']) -> Variation_1251:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_1273:
        ...

    @overload
    def get_item(self, name : Literal['290']) -> Variation_1274:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_1279:
        ...

    @overload
    def get_item(self, name : Literal['295']) -> Variation_1280:
        ...

    @overload
    def get_item(self, name : Literal['136']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['135']) -> Variation_1281:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['390']) -> Variation_1288:
        ...

    @overload
    def get_item(self, name : Literal['270']) -> Variation_290:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_285:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1301:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1302:
        ...

    @overload
    def get_item(self, name : Literal['510']) -> Variation_1303:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_1314:
        ...

    @overload
    def get_item(self, name : Literal['340']) -> Variation_1323:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['105'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['185'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['245'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['380'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['290'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['295'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['136'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['135'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['390'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['270'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['510'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['340'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1324':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1324':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1325_Arg : TypeAlias = Raw
class Variation_1325(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 3
    table = {
        0: 'No alert, no SPI, aircraft airborne',
        1: 'No alert, no SPI, aircraft on ground',
        2: 'Alert, no SPI, aircraft airborne',
        3: 'Alert, no SPI, aircraft on ground',
        4: 'Alert, SPI, aircraft airborne or on ground',
        5: 'No alert, SPI, aircraft airborne or on ground',
        6: 'Not defined',
        7: 'Unknown or not yet extracted',
    }

    def __init__(self, arg : Variation_1325_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1326_Arg_Group = TypedDict('Variation_1326_Arg_Group', {
    'COM': Union[Variation_322, Variation_322_Arg],
    'STAT': Union[Variation_1325, Variation_1325_Arg],
    'SSC': Union[Variation_324, Variation_324_Arg],
    'ARC': Union[Variation_325, Variation_325_Arg],
    'AIC': Union[Variation_326, Variation_326_Arg],
    'B1A': Union[Variation_237, Variation_237_Arg],
    'B1B': Union[Variation_282, Variation_282_Arg],
})
Variation_1326_Arg : TypeAlias = Union[Raw, Variation_1326_Arg_Group]
class Variation_1326(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('COM', Variation_322),
        ('STAT', Variation_1325),
        Spare(6, 2),
        ('SSC', Variation_324),
        ('ARC', Variation_325),
        ('AIC', Variation_326),
        ('B1A', Variation_237),
        ('B1B', Variation_282),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'COM': ('Communications Capability of the Transponder', Variation_322, 0, 3),
        'STAT': ('Flight Status', Variation_1325, 3, 3),
        'SSC': ('Specific Service Capability', Variation_324, 8, 1),
        'ARC': ('Altitude Reporting Capability', Variation_325, 9, 1),
        'AIC': ('Aircraft Identification Capability', Variation_326, 10, 1),
        'B1A': ('BDS 1,0 Bit 16', Variation_237, 11, 1),
        'B1B': ('BDS BDS 1,0 Bits 37/40', Variation_282, 12, 4),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_322]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STAT']) -> Type[Variation_1325]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSC']) -> Type[Variation_324]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ARC']) -> Type[Variation_325]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AIC']) -> Type[Variation_326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1A']) -> Type[Variation_237]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['B1B']) -> Type[Variation_282]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['COM'], Literal['STAT'], Literal['SSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B']]) -> Union[Type['Variation_322'], Type['Variation_1325'], Type['Variation_324'], Type['Variation_325'], Type['Variation_326'], Type['Variation_237'], Type['Variation_282']]:
        if key == 'COM':
            return Variation_322
        if key == 'STAT':
            return Variation_1325
        if key == 'SSC':
            return Variation_324
        if key == 'ARC':
            return Variation_325
        if key == 'AIC':
            return Variation_326
        if key == 'B1A':
            return Variation_237
        if key == 'B1B':
            return Variation_282
        assert_never(key)

    def __init__(self, arg : Variation_1326_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_322:
        ...

    @overload
    def get_item(self, name : Literal['STAT']) -> Variation_1325:
        ...

    @overload
    def get_item(self, name : Literal['SSC']) -> Variation_324:
        ...

    @overload
    def get_item(self, name : Literal['ARC']) -> Variation_325:
        ...

    @overload
    def get_item(self, name : Literal['AIC']) -> Variation_326:
        ...

    @overload
    def get_item(self, name : Literal['B1A']) -> Variation_237:
        ...

    @overload
    def get_item(self, name : Literal['B1B']) -> Variation_282:
        ...

    def get_item(self, name : Union[Literal['COM'], Literal['STAT'], Literal['SSC'], Literal['ARC'], Literal['AIC'], Literal['B1A'], Literal['B1B']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_322, Variation_322_Arg]) -> 'Variation_1326':
        ...

    @overload
    def set_item(self, name : Literal['STAT'], val : Union[Variation_1325, Variation_1325_Arg]) -> 'Variation_1326':
        ...

    @overload
    def set_item(self, name : Literal['SSC'], val : Union[Variation_324, Variation_324_Arg]) -> 'Variation_1326':
        ...

    @overload
    def set_item(self, name : Literal['ARC'], val : Union[Variation_325, Variation_325_Arg]) -> 'Variation_1326':
        ...

    @overload
    def set_item(self, name : Literal['AIC'], val : Union[Variation_326, Variation_326_Arg]) -> 'Variation_1326':
        ...

    @overload
    def set_item(self, name : Literal['B1A'], val : Union[Variation_237, Variation_237_Arg]) -> 'Variation_1326':
        ...

    @overload
    def set_item(self, name : Literal['B1B'], val : Union[Variation_282, Variation_282_Arg]) -> 'Variation_1326':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1326':
        ...

    @overload
    def modify_item(self, name : Literal['STAT'], f : Any) -> 'Variation_1326':
        ...

    @overload
    def modify_item(self, name : Literal['SSC'], f : Any) -> 'Variation_1326':
        ...

    @overload
    def modify_item(self, name : Literal['ARC'], f : Any) -> 'Variation_1326':
        ...

    @overload
    def modify_item(self, name : Literal['AIC'], f : Any) -> 'Variation_1326':
        ...

    @overload
    def modify_item(self, name : Literal['B1A'], f : Any) -> 'Variation_1326':
        ...

    @overload
    def modify_item(self, name : Literal['B1B'], f : Any) -> 'Variation_1326':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1327_Arg = TypedDict('Variation_1327_Arg', {
    'ADR': Union[Variation_278, Variation_278_Arg],
    'ID': Union[Variation_196, Variation_196_Arg],
    'MHG': Union[Variation_14, Variation_14_Arg],
    'IAS': Union[Variation_1221, Variation_1221_Arg],
    'TAS': Union[Variation_720, Variation_720_Arg],
    'SAL': Union[Variation_1224, Variation_1224_Arg],
    'FSS': Union[Variation_1225, Variation_1225_Arg],
    'TIS': Union[Variation_1228, Variation_1228_Arg],
    'TID': Union[Variation_1230, Variation_1230_Arg],
    'COM': Union[Variation_1326, Variation_1326_Arg],
    'SAB': Union[Variation_1238, Variation_1238_Arg],
    'ACS': Union[Variation_281, Variation_281_Arg],
    'BVR': Union[Variation_364, Variation_364_Arg],
    'GVR': Union[Variation_364, Variation_364_Arg],
    'RAN': Union[Variation_717, Variation_717_Arg],
    'TAR': Union[Variation_1239, Variation_1239_Arg],
    'TAN': Union[Variation_14, Variation_14_Arg],
    'GS': Union[Variation_721, Variation_721_Arg],
    'VUN': Union[Variation_0, Variation_0_Arg],
    'MET': Union[Variation_1244, Variation_1244_Arg],
    'EMC': Union[Variation_1245, Variation_1245_Arg],
    'POS': Union[Variation_1246, Variation_1246_Arg],
    'GAL': Union[Variation_287, Variation_287_Arg],
    'PUN': Union[Variation_1247, Variation_1247_Arg],
    'MB': Union[Variation_321, Variation_321_Arg],
    'IAR': Union[Variation_720, Variation_720_Arg],
    'MAC': Union[Variation_1248, Variation_1248_Arg],
    'BPS': Union[Variation_1250, Variation_1250_Arg],
}, total=False)
class Variation_1327(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('ADR', Variation_278),
        ('ID', Variation_196),
        ('MHG', Variation_14),
        ('IAS', Variation_1221),
        ('TAS', Variation_720),
        ('SAL', Variation_1224),
        ('FSS', Variation_1225),
        ('TIS', Variation_1228),
        ('TID', Variation_1230),
        ('COM', Variation_1326),
        ('SAB', Variation_1238),
        ('ACS', Variation_281),
        ('BVR', Variation_364),
        ('GVR', Variation_364),
        ('RAN', Variation_717),
        ('TAR', Variation_1239),
        ('TAN', Variation_14),
        ('GS', Variation_721),
        ('VUN', Variation_0),
        ('MET', Variation_1244),
        ('EMC', Variation_1245),
        ('POS', Variation_1246),
        ('GAL', Variation_287),
        ('PUN', Variation_1247),
        ('MB', Variation_321),
        ('IAR', Variation_720),
        ('MAC', Variation_1248),
        ('BPS', Variation_1250),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'ADR': ('Target Address', Variation_278, 0x80000000),
        'ID': ('Target Identification', Variation_196, 0x40000000),
        'MHG': ('Magnetic Heading', Variation_14, 0x20000000),
        'IAS': ('Indicated Airspeed/Mach No', Variation_1221, 0x10000000),
        'TAS': ('True Airspeed', Variation_720, 0x08000000),
        'SAL': ('Selected Altitude', Variation_1224, 0x04000000),
        'FSS': ('Final State Selected Altitude', Variation_1225, 0x02000000),
        'TIS': ('Trajectory Intent Status', Variation_1228, 0x01800000),
        'TID': ('Trajectory Intent Data', Variation_1230, 0x01400000),
        'COM': ('Communications/ACAS Capability and Flight Status', Variation_1326, 0x01200000),
        'SAB': ('Status Reported by ADS-B', Variation_1238, 0x01100000),
        'ACS': ('ACAS Resolution Advisory Report', Variation_281, 0x01080000),
        'BVR': ('Barometric Vertical Rate', Variation_364, 0x01040000),
        'GVR': ('Geometric Vertical Rate', Variation_364, 0x01020000),
        'RAN': ('Roll Angle', Variation_717, 0x01018000),
        'TAR': ('Track Angle Rate', Variation_1239, 0x01014000),
        'TAN': ('Track Angle', Variation_14, 0x01012000),
        'GS': ('Ground Speed', Variation_721, 0x01011000),
        'VUN': ('Velocity Uncertainty', Variation_0, 0x01010800),
        'MET': ('Meteorological Data', Variation_1244, 0x01010400),
        'EMC': ('Emitter Category', Variation_1245, 0x01010200),
        'POS': ('Position', Variation_1246, 0x01010180),
        'GAL': ('Geometric Altitude', Variation_287, 0x01010140),
        'PUN': ('Position Uncertainty', Variation_1247, 0x01010120),
        'MB': ('MODE S MB DATA', Variation_321, 0x01010110),
        'IAR': ('Indicated Airspeed', Variation_720, 0x01010108),
        'MAC': ('Mach Number', Variation_1248, 0x01010104),
        'BPS': ('Barometric Pressure Setting (derived from Mode S BDS 4,0)', Variation_1250, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ADR']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ID']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MHG']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAS']) -> Type[Variation_1221]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAS']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAL']) -> Type[Variation_1224]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FSS']) -> Type[Variation_1225]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TIS']) -> Type[Variation_1228]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_1230]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_1326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAB']) -> Type[Variation_1238]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ACS']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BVR']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GVR']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAN']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAR']) -> Type[Variation_1239]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAN']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GS']) -> Type[Variation_721]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VUN']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MET']) -> Type[Variation_1244]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EMC']) -> Type[Variation_1245]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_1246]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GAL']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PUN']) -> Type[Variation_1247]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MB']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAR']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAC']) -> Type[Variation_1248]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BPS']) -> Type[Variation_1250]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ADR'], Literal['ID'], Literal['MHG'], Literal['IAS'], Literal['TAS'], Literal['SAL'], Literal['FSS'], Literal['TIS'], Literal['TID'], Literal['COM'], Literal['SAB'], Literal['ACS'], Literal['BVR'], Literal['GVR'], Literal['RAN'], Literal['TAR'], Literal['TAN'], Literal['GS'], Literal['VUN'], Literal['MET'], Literal['EMC'], Literal['POS'], Literal['GAL'], Literal['PUN'], Literal['MB'], Literal['IAR'], Literal['MAC'], Literal['BPS']]) -> Union[Type['Variation_278'], Type['Variation_196'], Type['Variation_14'], Type['Variation_1221'], Type['Variation_720'], Type['Variation_1224'], Type['Variation_1225'], Type['Variation_1228'], Type['Variation_1230'], Type['Variation_1326'], Type['Variation_1238'], Type['Variation_281'], Type['Variation_364'], Type['Variation_364'], Type['Variation_717'], Type['Variation_1239'], Type['Variation_14'], Type['Variation_721'], Type['Variation_0'], Type['Variation_1244'], Type['Variation_1245'], Type['Variation_1246'], Type['Variation_287'], Type['Variation_1247'], Type['Variation_321'], Type['Variation_720'], Type['Variation_1248'], Type['Variation_1250']]:
        if key == 'ADR':
            return Variation_278
        if key == 'ID':
            return Variation_196
        if key == 'MHG':
            return Variation_14
        if key == 'IAS':
            return Variation_1221
        if key == 'TAS':
            return Variation_720
        if key == 'SAL':
            return Variation_1224
        if key == 'FSS':
            return Variation_1225
        if key == 'TIS':
            return Variation_1228
        if key == 'TID':
            return Variation_1230
        if key == 'COM':
            return Variation_1326
        if key == 'SAB':
            return Variation_1238
        if key == 'ACS':
            return Variation_281
        if key == 'BVR':
            return Variation_364
        if key == 'GVR':
            return Variation_364
        if key == 'RAN':
            return Variation_717
        if key == 'TAR':
            return Variation_1239
        if key == 'TAN':
            return Variation_14
        if key == 'GS':
            return Variation_721
        if key == 'VUN':
            return Variation_0
        if key == 'MET':
            return Variation_1244
        if key == 'EMC':
            return Variation_1245
        if key == 'POS':
            return Variation_1246
        if key == 'GAL':
            return Variation_287
        if key == 'PUN':
            return Variation_1247
        if key == 'MB':
            return Variation_321
        if key == 'IAR':
            return Variation_720
        if key == 'MAC':
            return Variation_1248
        if key == 'BPS':
            return Variation_1250
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1327_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['ADR'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['ID'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['MHG'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['IAS'], val : Union[Variation_1221, Variation_1221_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['TAS'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['SAL'], val : Union[Variation_1224, Variation_1224_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['FSS'], val : Union[Variation_1225, Variation_1225_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['TIS'], val : Union[Variation_1228, Variation_1228_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_1230, Variation_1230_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_1326, Variation_1326_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['SAB'], val : Union[Variation_1238, Variation_1238_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['ACS'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['BVR'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['GVR'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['RAN'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['TAR'], val : Union[Variation_1239, Variation_1239_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['TAN'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['GS'], val : Union[Variation_721, Variation_721_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['VUN'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['MET'], val : Union[Variation_1244, Variation_1244_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['EMC'], val : Union[Variation_1245, Variation_1245_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_1246, Variation_1246_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['GAL'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['PUN'], val : Union[Variation_1247, Variation_1247_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['MB'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['IAR'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['MAC'], val : Union[Variation_1248, Variation_1248_Arg]) -> 'Variation_1327':
        ...

    @overload
    def set_item(self, name : Literal['BPS'], val : Union[Variation_1250, Variation_1250_Arg]) -> 'Variation_1327':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['ADR']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['ID']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['MHG']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['IAS']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['TAS']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['SAL']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['FSS']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['TIS']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['TID']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['COM']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['SAB']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['ACS']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['BVR']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['GVR']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['RAN']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['TAR']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['TAN']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['GS']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['VUN']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['MET']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['EMC']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['GAL']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['PUN']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['MB']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['IAR']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['MAC']) -> 'Variation_1327':
        ...

    @overload
    def del_item(self, name : Literal['BPS']) -> 'Variation_1327':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['ADR']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['ID']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['MHG']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['IAS']) -> Variation_1221:
        ...

    @overload
    def get_item(self, name : Literal['TAS']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['SAL']) -> Variation_1224:
        ...

    @overload
    def get_item(self, name : Literal['FSS']) -> Variation_1225:
        ...

    @overload
    def get_item(self, name : Literal['TIS']) -> Variation_1228:
        ...

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_1230:
        ...

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_1326:
        ...

    @overload
    def get_item(self, name : Literal['SAB']) -> Variation_1238:
        ...

    @overload
    def get_item(self, name : Literal['ACS']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['BVR']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['GVR']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['RAN']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['TAR']) -> Variation_1239:
        ...

    @overload
    def get_item(self, name : Literal['TAN']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['GS']) -> Variation_721:
        ...

    @overload
    def get_item(self, name : Literal['VUN']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['MET']) -> Variation_1244:
        ...

    @overload
    def get_item(self, name : Literal['EMC']) -> Variation_1245:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_1246:
        ...

    @overload
    def get_item(self, name : Literal['GAL']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['PUN']) -> Variation_1247:
        ...

    @overload
    def get_item(self, name : Literal['MB']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['IAR']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['MAC']) -> Variation_1248:
        ...

    @overload
    def get_item(self, name : Literal['BPS']) -> Variation_1250:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['ADR'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['ID'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['MHG'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['IAS'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['TAS'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['SAL'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['FSS'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['TIS'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['SAB'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['ACS'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['BVR'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['GVR'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['RAN'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['TAR'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['TAN'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['GS'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['VUN'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['MET'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['EMC'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['GAL'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['PUN'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['MB'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['IAR'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['MAC'], f : Any) -> 'Variation_1327':
        ...

    @overload
    def modify_item(self, name : Literal['BPS'], f : Any) -> 'Variation_1327':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1328_Arg : TypeAlias = Raw
class Variation_1328(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Surface target',
    }

    def __init__(self, arg : Variation_1328_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1329_Arg : TypeAlias = Raw
class Variation_1329(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'No indication',
        1: 'Duplicate Flight-ID',
    }

    def __init__(self, arg : Variation_1329_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1330_Arg : TypeAlias = Raw
class Variation_1330(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Inconsistent Emergency Code',
    }

    def __init__(self, arg : Variation_1330_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1331_Arg_Group_1 = TypedDict('Variation_1331_Arg_Group_1', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
})
Variation_1331_Arg_Group_2 = TypedDict('Variation_1331_Arg_Group_2', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
})
Variation_1331_Arg_Group_3 = TypedDict('Variation_1331_Arg_Group_3', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
})
Variation_1331_Arg_Group_4 = TypedDict('Variation_1331_Arg_Group_4', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
    'CST': Union[Variation_1263, Variation_1263_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_1264, Variation_1264_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_1265, Variation_1265_Arg],
})
Variation_1331_Arg_Group_5 = TypedDict('Variation_1331_Arg_Group_5', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
    'CST': Union[Variation_1263, Variation_1263_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_1264, Variation_1264_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_1265, Variation_1265_Arg],
    'SDS': Union[Variation_1266, Variation_1266_Arg],
    'EMS': Union[Variation_1267, Variation_1267_Arg],
    'PFT': Union[Variation_1268, Variation_1268_Arg],
    'FPLT': Union[Variation_1269, Variation_1269_Arg],
})
Variation_1331_Arg_Group_6 = TypedDict('Variation_1331_Arg_Group_6', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
    'CST': Union[Variation_1263, Variation_1263_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_1264, Variation_1264_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_1265, Variation_1265_Arg],
    'SDS': Union[Variation_1266, Variation_1266_Arg],
    'EMS': Union[Variation_1267, Variation_1267_Arg],
    'PFT': Union[Variation_1268, Variation_1268_Arg],
    'FPLT': Union[Variation_1269, Variation_1269_Arg],
    'DUPT': Union[Variation_1270, Variation_1270_Arg],
    'DUPF': Union[Variation_1271, Variation_1271_Arg],
    'DUPM': Union[Variation_1272, Variation_1272_Arg],
    'SFC': Union[Variation_1328, Variation_1328_Arg],
    'IDD': Union[Variation_1329, Variation_1329_Arg],
    'IEC': Union[Variation_1330, Variation_1330_Arg],
})
Variation_1331_Arg : TypeAlias = Union[
    int,
    Variation_1331_Arg_Group_1,
    Tuple[int],
    Variation_1331_Arg_Group_2,
    Tuple[int,int],
    Variation_1331_Arg_Group_3,
    Tuple[int,int,int],
    Variation_1331_Arg_Group_4,
    Tuple[int,int,int,int],
    Variation_1331_Arg_Group_5,
    Tuple[int,int,int,int,int],
    Variation_1331_Arg_Group_6,
    Tuple[int,int,int,int,int,int],
]
class Variation_1331(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('MON', Variation_1252),
            ('SPI', Variation_351),
            ('MRH', Variation_341),
            ('SRC', Variation_1253),
            ('CNF', Variation_343),
        ],
        [
            ('SIM', Variation_1254),
            ('TSE', Variation_1255),
            ('TSB', Variation_1256),
            ('FPC', Variation_353),
            ('AFF', Variation_354),
            ('STP', Variation_1257),
            ('KOS', Variation_1258),
        ],
        [
            ('AMA', Variation_350),
            ('MD4', Variation_1259),
            ('ME', Variation_1260),
            ('MI', Variation_1261),
            ('MD5', Variation_1262),
        ],
        [
            ('CST', Variation_1263),
            ('PSR', Variation_416),
            ('SSR', Variation_417),
            ('MDS', Variation_418),
            ('ADS', Variation_1264),
            ('SUC', Variation_420),
            ('AAC', Variation_1265),
        ],
        [
            ('SDS', Variation_1266),
            ('EMS', Variation_1267),
            ('PFT', Variation_1268),
            ('FPLT', Variation_1269),
        ],
        [
            ('DUPT', Variation_1270),
            ('DUPF', Variation_1271),
            ('DUPM', Variation_1272),
            ('SFC', Variation_1328),
            ('IDD', Variation_1329),
            ('IEC', Variation_1330),
            Spare(6, 1),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MON': ('', Variation_1252, 0, 1),
        'SPI': ('', Variation_351, 1, 1),
        'MRH': ('Most Reliable Height', Variation_341, 2, 1),
        'SRC': ('Source of Calculated Track Altitude for I062/130', Variation_1253, 3, 3),
        'CNF': ('', Variation_343, 6, 1),
        'SIM': ('', Variation_1254, 0, 1),
        'TSE': ('', Variation_1255, 1, 1),
        'TSB': ('', Variation_1256, 2, 1),
        'FPC': ('', Variation_353, 3, 1),
        'AFF': ('', Variation_354, 4, 1),
        'STP': ('', Variation_1257, 5, 1),
        'KOS': ('', Variation_1258, 6, 1),
        'AMA': ('', Variation_350, 0, 1),
        'MD4': ('', Variation_1259, 1, 2),
        'ME': ('', Variation_1260, 3, 1),
        'MI': ('', Variation_1261, 4, 1),
        'MD5': ('', Variation_1262, 5, 2),
        'CST': ('', Variation_1263, 0, 1),
        'PSR': ('', Variation_416, 1, 1),
        'SSR': ('', Variation_417, 2, 1),
        'MDS': ('', Variation_418, 3, 1),
        'ADS': ('', Variation_1264, 4, 1),
        'SUC': ('', Variation_420, 5, 1),
        'AAC': ('', Variation_1265, 6, 1),
        'SDS': ('', Variation_1266, 0, 2),
        'EMS': ('', Variation_1267, 2, 3),
        'PFT': ('', Variation_1268, 5, 1),
        'FPLT': ('', Variation_1269, 6, 1),
        'DUPT': ('', Variation_1270, 0, 1),
        'DUPF': ('', Variation_1271, 1, 1),
        'DUPM': ('', Variation_1272, 2, 1),
        'SFC': ('', Variation_1328, 3, 1),
        'IDD': ('', Variation_1329, 4, 1),
        'IEC': ('', Variation_1330, 5, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MON']) -> Type[Variation_1252]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_351]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MRH']) -> Type[Variation_341]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRC']) -> Type[Variation_1253]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_343]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_1254]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSE']) -> Type[Variation_1255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSB']) -> Type[Variation_1256]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FPC']) -> Type[Variation_353]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AFF']) -> Type[Variation_354]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STP']) -> Type[Variation_1257]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['KOS']) -> Type[Variation_1258]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AMA']) -> Type[Variation_350]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD4']) -> Type[Variation_1259]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ME']) -> Type[Variation_1260]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MI']) -> Type[Variation_1261]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD5']) -> Type[Variation_1262]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_1263]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_416]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_417]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_418]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADS']) -> Type[Variation_1264]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SUC']) -> Type[Variation_420]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AAC']) -> Type[Variation_1265]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDS']) -> Type[Variation_1266]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EMS']) -> Type[Variation_1267]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PFT']) -> Type[Variation_1268]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FPLT']) -> Type[Variation_1269]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DUPT']) -> Type[Variation_1270]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DUPF']) -> Type[Variation_1271]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DUPM']) -> Type[Variation_1272]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SFC']) -> Type[Variation_1328]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IDD']) -> Type[Variation_1329]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IEC']) -> Type[Variation_1330]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MON'], Literal['SPI'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FPC'], Literal['AFF'], Literal['STP'], Literal['KOS'], Literal['AMA'], Literal['MD4'], Literal['ME'], Literal['MI'], Literal['MD5'], Literal['CST'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['SUC'], Literal['AAC'], Literal['SDS'], Literal['EMS'], Literal['PFT'], Literal['FPLT'], Literal['DUPT'], Literal['DUPF'], Literal['DUPM'], Literal['SFC'], Literal['IDD'], Literal['IEC']]) -> Union[Type['Variation_1252'], Type['Variation_351'], Type['Variation_341'], Type['Variation_1253'], Type['Variation_343'], Type['Variation_1254'], Type['Variation_1255'], Type['Variation_1256'], Type['Variation_353'], Type['Variation_354'], Type['Variation_1257'], Type['Variation_1258'], Type['Variation_350'], Type['Variation_1259'], Type['Variation_1260'], Type['Variation_1261'], Type['Variation_1262'], Type['Variation_1263'], Type['Variation_416'], Type['Variation_417'], Type['Variation_418'], Type['Variation_1264'], Type['Variation_420'], Type['Variation_1265'], Type['Variation_1266'], Type['Variation_1267'], Type['Variation_1268'], Type['Variation_1269'], Type['Variation_1270'], Type['Variation_1271'], Type['Variation_1272'], Type['Variation_1328'], Type['Variation_1329'], Type['Variation_1330']]:
        if key == 'MON':
            return Variation_1252
        if key == 'SPI':
            return Variation_351
        if key == 'MRH':
            return Variation_341
        if key == 'SRC':
            return Variation_1253
        if key == 'CNF':
            return Variation_343
        if key == 'SIM':
            return Variation_1254
        if key == 'TSE':
            return Variation_1255
        if key == 'TSB':
            return Variation_1256
        if key == 'FPC':
            return Variation_353
        if key == 'AFF':
            return Variation_354
        if key == 'STP':
            return Variation_1257
        if key == 'KOS':
            return Variation_1258
        if key == 'AMA':
            return Variation_350
        if key == 'MD4':
            return Variation_1259
        if key == 'ME':
            return Variation_1260
        if key == 'MI':
            return Variation_1261
        if key == 'MD5':
            return Variation_1262
        if key == 'CST':
            return Variation_1263
        if key == 'PSR':
            return Variation_416
        if key == 'SSR':
            return Variation_417
        if key == 'MDS':
            return Variation_418
        if key == 'ADS':
            return Variation_1264
        if key == 'SUC':
            return Variation_420
        if key == 'AAC':
            return Variation_1265
        if key == 'SDS':
            return Variation_1266
        if key == 'EMS':
            return Variation_1267
        if key == 'PFT':
            return Variation_1268
        if key == 'FPLT':
            return Variation_1269
        if key == 'DUPT':
            return Variation_1270
        if key == 'DUPF':
            return Variation_1271
        if key == 'DUPM':
            return Variation_1272
        if key == 'SFC':
            return Variation_1328
        if key == 'IDD':
            return Variation_1329
        if key == 'IEC':
            return Variation_1330
        assert_never(key)

    def __init__(self, arg : Variation_1331_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1331_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_1331_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_1331_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            if Variation_1331_Arg_Group_4.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(4, arg)); return
            if Variation_1331_Arg_Group_5.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(5, arg)); return
            if Variation_1331_Arg_Group_6.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(6, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MON']) -> Variation_1252:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_351:
        ...

    @overload
    def get_item(self, name : Literal['MRH']) -> Variation_341:
        ...

    @overload
    def get_item(self, name : Literal['SRC']) -> Variation_1253:
        ...

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_343:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_1254:
        ...

    @overload
    def get_item(self, name : Literal['TSE']) -> Variation_1255:
        ...

    @overload
    def get_item(self, name : Literal['TSB']) -> Variation_1256:
        ...

    @overload
    def get_item(self, name : Literal['FPC']) -> Variation_353:
        ...

    @overload
    def get_item(self, name : Literal['AFF']) -> Variation_354:
        ...

    @overload
    def get_item(self, name : Literal['STP']) -> Variation_1257:
        ...

    @overload
    def get_item(self, name : Literal['KOS']) -> Variation_1258:
        ...

    @overload
    def get_item(self, name : Literal['AMA']) -> Variation_350:
        ...

    @overload
    def get_item(self, name : Literal['MD4']) -> Variation_1259:
        ...

    @overload
    def get_item(self, name : Literal['ME']) -> Variation_1260:
        ...

    @overload
    def get_item(self, name : Literal['MI']) -> Variation_1261:
        ...

    @overload
    def get_item(self, name : Literal['MD5']) -> Variation_1262:
        ...

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_1263:
        ...

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_416:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_417:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_418:
        ...

    @overload
    def get_item(self, name : Literal['ADS']) -> Variation_1264:
        ...

    @overload
    def get_item(self, name : Literal['SUC']) -> Variation_420:
        ...

    @overload
    def get_item(self, name : Literal['AAC']) -> Variation_1265:
        ...

    @overload
    def get_item(self, name : Literal['SDS']) -> Variation_1266:
        ...

    @overload
    def get_item(self, name : Literal['EMS']) -> Variation_1267:
        ...

    @overload
    def get_item(self, name : Literal['PFT']) -> Variation_1268:
        ...

    @overload
    def get_item(self, name : Literal['FPLT']) -> Variation_1269:
        ...

    @overload
    def get_item(self, name : Literal['DUPT']) -> Variation_1270:
        ...

    @overload
    def get_item(self, name : Literal['DUPF']) -> Variation_1271:
        ...

    @overload
    def get_item(self, name : Literal['DUPM']) -> Variation_1272:
        ...

    @overload
    def get_item(self, name : Literal['SFC']) -> Variation_1328:
        ...

    @overload
    def get_item(self, name : Literal['IDD']) -> Variation_1329:
        ...

    @overload
    def get_item(self, name : Literal['IEC']) -> Variation_1330:
        ...

    def get_item(self, name : Union[Literal['MON'], Literal['SPI'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FPC'], Literal['AFF'], Literal['STP'], Literal['KOS'], Literal['AMA'], Literal['MD4'], Literal['ME'], Literal['MI'], Literal['MD5'], Literal['CST'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['SUC'], Literal['AAC'], Literal['SDS'], Literal['EMS'], Literal['PFT'], Literal['FPLT'], Literal['DUPT'], Literal['DUPF'], Literal['DUPM'], Literal['SFC'], Literal['IDD'], Literal['IEC']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MON'], val : Union[Variation_1252, Variation_1252_Arg]) -> 'Variation_1331':
        ...

    @overload
    def set_item(self, name : Literal['SPI'], val : Union[Variation_351, Variation_351_Arg]) -> 'Variation_1331':
        ...

    @overload
    def set_item(self, name : Literal['MRH'], val : Union[Variation_341, Variation_341_Arg]) -> 'Variation_1331':
        ...

    @overload
    def set_item(self, name : Literal['SRC'], val : Union[Variation_1253, Variation_1253_Arg]) -> 'Variation_1331':
        ...

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_343, Variation_343_Arg]) -> 'Variation_1331':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MON'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['MRH'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['SRC'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['TSE'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['TSB'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['FPC'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['AFF'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['STP'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['KOS'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['AMA'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['MD4'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['ME'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['MI'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['MD5'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['ADS'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['SUC'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['AAC'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['SDS'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['EMS'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['PFT'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['FPLT'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['DUPT'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['DUPF'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['DUPM'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['SFC'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['IDD'], f : Any) -> 'Variation_1331':
        ...

    @overload
    def modify_item(self, name : Literal['IEC'], f : Any) -> 'Variation_1331':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1332_Arg = TypedDict('Variation_1332_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '070': Union[Variation_80, Variation_80_Arg],
    '105': Union[Variation_649, Variation_649_Arg],
    '100': Union[Variation_1214, Variation_1214_Arg],
    '185': Union[Variation_1215, Variation_1215_Arg],
    '210': Union[Variation_664, Variation_664_Arg],
    '060': Union[Variation_1217, Variation_1217_Arg],
    '245': Union[Variation_1219, Variation_1219_Arg],
    '380': Union[Variation_1327, Variation_1327_Arg],
    '040': Union[Variation_64, Variation_64_Arg],
    '080': Union[Variation_1331, Variation_1331_Arg],
    '290': Union[Variation_1274, Variation_1274_Arg],
    '200': Union[Variation_1279, Variation_1279_Arg],
    '295': Union[Variation_1280, Variation_1280_Arg],
    '136': Union[Variation_360, Variation_360_Arg],
    '130': Union[Variation_287, Variation_287_Arg],
    '135': Union[Variation_1281, Variation_1281_Arg],
    '220': Union[Variation_364, Variation_364_Arg],
    '390': Union[Variation_1288, Variation_1288_Arg],
    '270': Union[Variation_290, Variation_290_Arg],
    '300': Union[Variation_285, Variation_285_Arg],
    '110': Union[Variation_1301, Variation_1301_Arg],
    '120': Union[Variation_1302, Variation_1302_Arg],
    '510': Union[Variation_1303, Variation_1303_Arg],
    '500': Union[Variation_1314, Variation_1314_Arg],
    '340': Union[Variation_1323, Variation_1323_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1332(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('010', Variation_1),
        None,
        ('015', Variation_0),
        ('070', Variation_80),
        ('105', Variation_649),
        ('100', Variation_1214),
        ('185', Variation_1215),
        ('210', Variation_664),
        ('060', Variation_1217),
        ('245', Variation_1219),
        ('380', Variation_1327),
        ('040', Variation_64),
        ('080', Variation_1331),
        ('290', Variation_1274),
        ('200', Variation_1279),
        ('295', Variation_1280),
        ('136', Variation_360),
        ('130', Variation_287),
        ('135', Variation_1281),
        ('220', Variation_364),
        ('390', Variation_1288),
        ('270', Variation_290),
        ('300', Variation_285),
        ('110', Variation_1301),
        ('120', Variation_1302),
        ('510', Variation_1303),
        ('500', Variation_1314),
        ('340', Variation_1323),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000000000),
        '015': ('Service Identification', Variation_0, 0x2000000000),
        '070': ('Time Of Track Information', Variation_80, 0x1000000000),
        '105': ('Calculated Position In WGS-84 Co-ordinates', Variation_649, 0x0800000000),
        '100': ('Calculated Track Position (Cartesian)', Variation_1214, 0x0400000000),
        '185': ('Calculated Track Velocity (Cartesian)', Variation_1215, 0x0200000000),
        '210': ('Calculated Acceleration (Cartesian)', Variation_664, 0x0180000000),
        '060': ('Track Mode 3/A Code', Variation_1217, 0x0140000000),
        '245': ('Target Identification', Variation_1219, 0x0120000000),
        '380': ('Aircraft Derived Data', Variation_1327, 0x0110000000),
        '040': ('Track Number', Variation_64, 0x0108000000),
        '080': ('Track Status', Variation_1331, 0x0104000000),
        '290': ('System Track Update Ages', Variation_1274, 0x0102000000),
        '200': ('Mode of Movement', Variation_1279, 0x0101800000),
        '295': ('Track Data Ages', Variation_1280, 0x0101400000),
        '136': ('Measured Flight Level', Variation_360, 0x0101200000),
        '130': ('Calculated Track Geometric Altitude', Variation_287, 0x0101100000),
        '135': ('Calculated Track Barometric Altitude', Variation_1281, 0x0101080000),
        '220': ('Calculated Rate of Climb/Descent', Variation_364, 0x0101040000),
        '390': ('Flight Plan Related Data', Variation_1288, 0x0101020000),
        '270': ('Target Size and Orientation', Variation_290, 0x0101018000),
        '300': ('Vehicle Fleet Identification', Variation_285, 0x0101014000),
        '110': ('Mode 5 Data Reports and Extended Mode 1 Code', Variation_1301, 0x0101012000),
        '120': ('Track Mode 2 Code', Variation_1302, 0x0101011000),
        '510': ('Composed Track Number', Variation_1303, 0x0101010800),
        '500': ('Estimated Accuracies', Variation_1314, 0x0101010400),
        '340': ('Measured Information', Variation_1323, 0x0101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x0101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['105']) -> Type[Variation_649]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_1214]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['185']) -> Type[Variation_1215]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_664]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_1217]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['245']) -> Type[Variation_1219]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['380']) -> Type[Variation_1327]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_1331]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['290']) -> Type[Variation_1274]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_1279]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['295']) -> Type[Variation_1280]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['136']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['135']) -> Type[Variation_1281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['390']) -> Type[Variation_1288]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['270']) -> Type[Variation_290]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_285]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1301]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1302]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['510']) -> Type[Variation_1303]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_1314]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['340']) -> Type[Variation_1323]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['015'], Literal['070'], Literal['105'], Literal['100'], Literal['185'], Literal['210'], Literal['060'], Literal['245'], Literal['380'], Literal['040'], Literal['080'], Literal['290'], Literal['200'], Literal['295'], Literal['136'], Literal['130'], Literal['135'], Literal['220'], Literal['390'], Literal['270'], Literal['300'], Literal['110'], Literal['120'], Literal['510'], Literal['500'], Literal['340'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_0'], Type['Variation_80'], Type['Variation_649'], Type['Variation_1214'], Type['Variation_1215'], Type['Variation_664'], Type['Variation_1217'], Type['Variation_1219'], Type['Variation_1327'], Type['Variation_64'], Type['Variation_1331'], Type['Variation_1274'], Type['Variation_1279'], Type['Variation_1280'], Type['Variation_360'], Type['Variation_287'], Type['Variation_1281'], Type['Variation_364'], Type['Variation_1288'], Type['Variation_290'], Type['Variation_285'], Type['Variation_1301'], Type['Variation_1302'], Type['Variation_1303'], Type['Variation_1314'], Type['Variation_1323'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '015':
            return Variation_0
        if key == '070':
            return Variation_80
        if key == '105':
            return Variation_649
        if key == '100':
            return Variation_1214
        if key == '185':
            return Variation_1215
        if key == '210':
            return Variation_664
        if key == '060':
            return Variation_1217
        if key == '245':
            return Variation_1219
        if key == '380':
            return Variation_1327
        if key == '040':
            return Variation_64
        if key == '080':
            return Variation_1331
        if key == '290':
            return Variation_1274
        if key == '200':
            return Variation_1279
        if key == '295':
            return Variation_1280
        if key == '136':
            return Variation_360
        if key == '130':
            return Variation_287
        if key == '135':
            return Variation_1281
        if key == '220':
            return Variation_364
        if key == '390':
            return Variation_1288
        if key == '270':
            return Variation_290
        if key == '300':
            return Variation_285
        if key == '110':
            return Variation_1301
        if key == '120':
            return Variation_1302
        if key == '510':
            return Variation_1303
        if key == '500':
            return Variation_1314
        if key == '340':
            return Variation_1323
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1332_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['105'], val : Union[Variation_649, Variation_649_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_1214, Variation_1214_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['185'], val : Union[Variation_1215, Variation_1215_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_664, Variation_664_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_1217, Variation_1217_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['245'], val : Union[Variation_1219, Variation_1219_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['380'], val : Union[Variation_1327, Variation_1327_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_1331, Variation_1331_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['290'], val : Union[Variation_1274, Variation_1274_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_1279, Variation_1279_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['295'], val : Union[Variation_1280, Variation_1280_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['136'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['135'], val : Union[Variation_1281, Variation_1281_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['390'], val : Union[Variation_1288, Variation_1288_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['270'], val : Union[Variation_290, Variation_290_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_285, Variation_285_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1301, Variation_1301_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1302, Variation_1302_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['510'], val : Union[Variation_1303, Variation_1303_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_1314, Variation_1314_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['340'], val : Union[Variation_1323, Variation_1323_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1332':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1332':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['105']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['185']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['245']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['380']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['290']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['295']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['136']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['135']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['390']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['270']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['510']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['340']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1332':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1332':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['105']) -> Variation_649:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_1214:
        ...

    @overload
    def get_item(self, name : Literal['185']) -> Variation_1215:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_664:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_1217:
        ...

    @overload
    def get_item(self, name : Literal['245']) -> Variation_1219:
        ...

    @overload
    def get_item(self, name : Literal['380']) -> Variation_1327:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_1331:
        ...

    @overload
    def get_item(self, name : Literal['290']) -> Variation_1274:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_1279:
        ...

    @overload
    def get_item(self, name : Literal['295']) -> Variation_1280:
        ...

    @overload
    def get_item(self, name : Literal['136']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['135']) -> Variation_1281:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['390']) -> Variation_1288:
        ...

    @overload
    def get_item(self, name : Literal['270']) -> Variation_290:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_285:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1301:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1302:
        ...

    @overload
    def get_item(self, name : Literal['510']) -> Variation_1303:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_1314:
        ...

    @overload
    def get_item(self, name : Literal['340']) -> Variation_1323:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['105'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['185'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['245'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['380'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['290'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['295'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['136'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['135'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['390'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['270'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['510'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['340'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1332':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1332':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1333_Arg = TypedDict('Variation_1333_Arg', {
    'ADR': Union[Variation_278, Variation_278_Arg],
    'ID': Union[Variation_196, Variation_196_Arg],
    'MHG': Union[Variation_14, Variation_14_Arg],
    'IAS': Union[Variation_1221, Variation_1221_Arg],
    'TAS': Union[Variation_720, Variation_720_Arg],
    'SAL': Union[Variation_1224, Variation_1224_Arg],
    'FSS': Union[Variation_1225, Variation_1225_Arg],
    'TIS': Union[Variation_1228, Variation_1228_Arg],
    'TID': Union[Variation_1230, Variation_1230_Arg],
    'COM': Union[Variation_1326, Variation_1326_Arg],
    'SAB': Union[Variation_1238, Variation_1238_Arg],
    'ACS': Union[Variation_281, Variation_281_Arg],
    'BVR': Union[Variation_364, Variation_364_Arg],
    'GVR': Union[Variation_364, Variation_364_Arg],
    'RAN': Union[Variation_717, Variation_717_Arg],
    'TAR': Union[Variation_1239, Variation_1239_Arg],
    'TAN': Union[Variation_14, Variation_14_Arg],
    'GS': Union[Variation_721, Variation_721_Arg],
    'VUN': Union[Variation_0, Variation_0_Arg],
    'MET': Union[Variation_1244, Variation_1244_Arg],
    'EMC': Union[Variation_1245, Variation_1245_Arg],
    'POS': Union[Variation_1246, Variation_1246_Arg],
    'GAL': Union[Variation_287, Variation_287_Arg],
    'PUN': Union[Variation_1247, Variation_1247_Arg],
    'MB': Union[Variation_321, Variation_321_Arg],
    'IAR': Union[Variation_720, Variation_720_Arg],
    'MAC': Union[Variation_1248, Variation_1248_Arg],
    'BPS': Union[Variation_1250, Variation_1250_Arg],
}, total=False)
class Variation_1333(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('ADR', Variation_278),
        ('ID', Variation_196),
        ('MHG', Variation_14),
        ('IAS', Variation_1221),
        ('TAS', Variation_720),
        ('SAL', Variation_1224),
        ('FSS', Variation_1225),
        ('TIS', Variation_1228),
        ('TID', Variation_1230),
        ('COM', Variation_1326),
        ('SAB', Variation_1238),
        ('ACS', Variation_281),
        ('BVR', Variation_364),
        ('GVR', Variation_364),
        ('RAN', Variation_717),
        ('TAR', Variation_1239),
        ('TAN', Variation_14),
        ('GS', Variation_721),
        ('VUN', Variation_0),
        ('MET', Variation_1244),
        ('EMC', Variation_1245),
        ('POS', Variation_1246),
        ('GAL', Variation_287),
        ('PUN', Variation_1247),
        ('MB', Variation_321),
        ('IAR', Variation_720),
        ('MAC', Variation_1248),
        ('BPS', Variation_1250),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'ADR': ('Target Address', Variation_278, 0x80000000),
        'ID': ('Target Identification', Variation_196, 0x40000000),
        'MHG': ('Magnetic Heading', Variation_14, 0x20000000),
        'IAS': ('Indicated Airspeed/Mach No', Variation_1221, 0x10000000),
        'TAS': ('True Airspeed', Variation_720, 0x08000000),
        'SAL': ('Selected Altitude', Variation_1224, 0x04000000),
        'FSS': ('Final State Selected Altitude', Variation_1225, 0x02000000),
        'TIS': ('Trajectory Intent Status', Variation_1228, 0x01800000),
        'TID': ('Trajectory Intent Data', Variation_1230, 0x01400000),
        'COM': ('Communications/ACAS Capability and Flight Status', Variation_1326, 0x01200000),
        'SAB': ('Status Reported by ADS-B', Variation_1238, 0x01100000),
        'ACS': ('ACAS Resolution Advisory Report', Variation_281, 0x01080000),
        'BVR': ('Barometric Vertical Rate', Variation_364, 0x01040000),
        'GVR': ('Geometric Vertical Rate', Variation_364, 0x01020000),
        'RAN': ('Roll Angle', Variation_717, 0x01018000),
        'TAR': ('Track Angle Rate', Variation_1239, 0x01014000),
        'TAN': ('Track Angle', Variation_14, 0x01012000),
        'GS': ('Ground Speed', Variation_721, 0x01011000),
        'VUN': ('Velocity Uncertainty', Variation_0, 0x01010800),
        'MET': ('Meteorological Data', Variation_1244, 0x01010400),
        'EMC': ('Emitter Category', Variation_1245, 0x01010200),
        'POS': ('Position', Variation_1246, 0x01010180),
        'GAL': ('Geometric Altitude', Variation_287, 0x01010140),
        'PUN': ('Position Uncertainty', Variation_1247, 0x01010120),
        'MB': ('MODE S MB DATA', Variation_321, 0x01010110),
        'IAR': ('Indicated Airspeed', Variation_720, 0x01010108),
        'MAC': ('Mach Number', Variation_1248, 0x01010104),
        'BPS': ('Barometric Pressure Setting', Variation_1250, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ADR']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ID']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MHG']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAS']) -> Type[Variation_1221]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAS']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAL']) -> Type[Variation_1224]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FSS']) -> Type[Variation_1225]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TIS']) -> Type[Variation_1228]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_1230]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_1326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAB']) -> Type[Variation_1238]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ACS']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BVR']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GVR']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAN']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAR']) -> Type[Variation_1239]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAN']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GS']) -> Type[Variation_721]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VUN']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MET']) -> Type[Variation_1244]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EMC']) -> Type[Variation_1245]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_1246]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GAL']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PUN']) -> Type[Variation_1247]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MB']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAR']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAC']) -> Type[Variation_1248]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BPS']) -> Type[Variation_1250]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ADR'], Literal['ID'], Literal['MHG'], Literal['IAS'], Literal['TAS'], Literal['SAL'], Literal['FSS'], Literal['TIS'], Literal['TID'], Literal['COM'], Literal['SAB'], Literal['ACS'], Literal['BVR'], Literal['GVR'], Literal['RAN'], Literal['TAR'], Literal['TAN'], Literal['GS'], Literal['VUN'], Literal['MET'], Literal['EMC'], Literal['POS'], Literal['GAL'], Literal['PUN'], Literal['MB'], Literal['IAR'], Literal['MAC'], Literal['BPS']]) -> Union[Type['Variation_278'], Type['Variation_196'], Type['Variation_14'], Type['Variation_1221'], Type['Variation_720'], Type['Variation_1224'], Type['Variation_1225'], Type['Variation_1228'], Type['Variation_1230'], Type['Variation_1326'], Type['Variation_1238'], Type['Variation_281'], Type['Variation_364'], Type['Variation_364'], Type['Variation_717'], Type['Variation_1239'], Type['Variation_14'], Type['Variation_721'], Type['Variation_0'], Type['Variation_1244'], Type['Variation_1245'], Type['Variation_1246'], Type['Variation_287'], Type['Variation_1247'], Type['Variation_321'], Type['Variation_720'], Type['Variation_1248'], Type['Variation_1250']]:
        if key == 'ADR':
            return Variation_278
        if key == 'ID':
            return Variation_196
        if key == 'MHG':
            return Variation_14
        if key == 'IAS':
            return Variation_1221
        if key == 'TAS':
            return Variation_720
        if key == 'SAL':
            return Variation_1224
        if key == 'FSS':
            return Variation_1225
        if key == 'TIS':
            return Variation_1228
        if key == 'TID':
            return Variation_1230
        if key == 'COM':
            return Variation_1326
        if key == 'SAB':
            return Variation_1238
        if key == 'ACS':
            return Variation_281
        if key == 'BVR':
            return Variation_364
        if key == 'GVR':
            return Variation_364
        if key == 'RAN':
            return Variation_717
        if key == 'TAR':
            return Variation_1239
        if key == 'TAN':
            return Variation_14
        if key == 'GS':
            return Variation_721
        if key == 'VUN':
            return Variation_0
        if key == 'MET':
            return Variation_1244
        if key == 'EMC':
            return Variation_1245
        if key == 'POS':
            return Variation_1246
        if key == 'GAL':
            return Variation_287
        if key == 'PUN':
            return Variation_1247
        if key == 'MB':
            return Variation_321
        if key == 'IAR':
            return Variation_720
        if key == 'MAC':
            return Variation_1248
        if key == 'BPS':
            return Variation_1250
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1333_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['ADR'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['ID'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['MHG'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['IAS'], val : Union[Variation_1221, Variation_1221_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['TAS'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['SAL'], val : Union[Variation_1224, Variation_1224_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['FSS'], val : Union[Variation_1225, Variation_1225_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['TIS'], val : Union[Variation_1228, Variation_1228_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_1230, Variation_1230_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_1326, Variation_1326_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['SAB'], val : Union[Variation_1238, Variation_1238_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['ACS'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['BVR'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['GVR'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['RAN'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['TAR'], val : Union[Variation_1239, Variation_1239_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['TAN'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['GS'], val : Union[Variation_721, Variation_721_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['VUN'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['MET'], val : Union[Variation_1244, Variation_1244_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['EMC'], val : Union[Variation_1245, Variation_1245_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_1246, Variation_1246_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['GAL'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['PUN'], val : Union[Variation_1247, Variation_1247_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['MB'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['IAR'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['MAC'], val : Union[Variation_1248, Variation_1248_Arg]) -> 'Variation_1333':
        ...

    @overload
    def set_item(self, name : Literal['BPS'], val : Union[Variation_1250, Variation_1250_Arg]) -> 'Variation_1333':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['ADR']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['ID']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['MHG']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['IAS']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['TAS']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['SAL']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['FSS']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['TIS']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['TID']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['COM']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['SAB']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['ACS']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['BVR']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['GVR']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['RAN']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['TAR']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['TAN']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['GS']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['VUN']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['MET']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['EMC']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['GAL']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['PUN']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['MB']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['IAR']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['MAC']) -> 'Variation_1333':
        ...

    @overload
    def del_item(self, name : Literal['BPS']) -> 'Variation_1333':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['ADR']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['ID']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['MHG']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['IAS']) -> Variation_1221:
        ...

    @overload
    def get_item(self, name : Literal['TAS']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['SAL']) -> Variation_1224:
        ...

    @overload
    def get_item(self, name : Literal['FSS']) -> Variation_1225:
        ...

    @overload
    def get_item(self, name : Literal['TIS']) -> Variation_1228:
        ...

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_1230:
        ...

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_1326:
        ...

    @overload
    def get_item(self, name : Literal['SAB']) -> Variation_1238:
        ...

    @overload
    def get_item(self, name : Literal['ACS']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['BVR']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['GVR']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['RAN']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['TAR']) -> Variation_1239:
        ...

    @overload
    def get_item(self, name : Literal['TAN']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['GS']) -> Variation_721:
        ...

    @overload
    def get_item(self, name : Literal['VUN']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['MET']) -> Variation_1244:
        ...

    @overload
    def get_item(self, name : Literal['EMC']) -> Variation_1245:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_1246:
        ...

    @overload
    def get_item(self, name : Literal['GAL']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['PUN']) -> Variation_1247:
        ...

    @overload
    def get_item(self, name : Literal['MB']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['IAR']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['MAC']) -> Variation_1248:
        ...

    @overload
    def get_item(self, name : Literal['BPS']) -> Variation_1250:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['ADR'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['ID'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['MHG'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['IAS'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['TAS'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['SAL'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['FSS'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['TIS'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['SAB'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['ACS'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['BVR'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['GVR'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['RAN'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['TAR'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['TAN'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['GS'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['VUN'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['MET'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['EMC'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['GAL'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['PUN'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['MB'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['IAR'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['MAC'], f : Any) -> 'Variation_1333':
        ...

    @overload
    def modify_item(self, name : Literal['BPS'], f : Any) -> 'Variation_1333':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1334_Arg = TypedDict('Variation_1334_Arg', {
    'SID': Union[Variation_1, Variation_1_Arg],
    'POS': Union[Variation_1315, Variation_1315_Arg],
    'HEIGHT': Union[Variation_148, Variation_148_Arg],
    'MDC': Union[Variation_1316, Variation_1316_Arg],
    'MDA': Union[Variation_1318, Variation_1318_Arg],
    'TYP': Union[Variation_1322, Variation_1322_Arg],
}, total=False)
class Variation_1334(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('SID', Variation_1),
        ('POS', Variation_1315),
        ('HEIGHT', Variation_148),
        ('MDC', Variation_1316),
        ('MDA', Variation_1318),
        ('TYP', Variation_1322),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'SID': ('Sensor Identification', Variation_1, 0x80),
        'POS': ('Measured Position', Variation_1315, 0x40),
        'HEIGHT': ('Measured 3-D Height', Variation_148, 0x20),
        'MDC': ('', Variation_1316, 0x10),
        'MDA': ('', Variation_1318, 0x08),
        'TYP': ('', Variation_1322, 0x04),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SID']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_1315]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['HEIGHT']) -> Type[Variation_148]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDC']) -> Type[Variation_1316]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDA']) -> Type[Variation_1318]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TYP']) -> Type[Variation_1322]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SID'], Literal['POS'], Literal['HEIGHT'], Literal['MDC'], Literal['MDA'], Literal['TYP']]) -> Union[Type['Variation_1'], Type['Variation_1315'], Type['Variation_148'], Type['Variation_1316'], Type['Variation_1318'], Type['Variation_1322']]:
        if key == 'SID':
            return Variation_1
        if key == 'POS':
            return Variation_1315
        if key == 'HEIGHT':
            return Variation_148
        if key == 'MDC':
            return Variation_1316
        if key == 'MDA':
            return Variation_1318
        if key == 'TYP':
            return Variation_1322
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1334_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['SID'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1334':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_1315, Variation_1315_Arg]) -> 'Variation_1334':
        ...

    @overload
    def set_item(self, name : Literal['HEIGHT'], val : Union[Variation_148, Variation_148_Arg]) -> 'Variation_1334':
        ...

    @overload
    def set_item(self, name : Literal['MDC'], val : Union[Variation_1316, Variation_1316_Arg]) -> 'Variation_1334':
        ...

    @overload
    def set_item(self, name : Literal['MDA'], val : Union[Variation_1318, Variation_1318_Arg]) -> 'Variation_1334':
        ...

    @overload
    def set_item(self, name : Literal['TYP'], val : Union[Variation_1322, Variation_1322_Arg]) -> 'Variation_1334':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['SID']) -> 'Variation_1334':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1334':
        ...

    @overload
    def del_item(self, name : Literal['HEIGHT']) -> 'Variation_1334':
        ...

    @overload
    def del_item(self, name : Literal['MDC']) -> 'Variation_1334':
        ...

    @overload
    def del_item(self, name : Literal['MDA']) -> 'Variation_1334':
        ...

    @overload
    def del_item(self, name : Literal['TYP']) -> 'Variation_1334':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['SID']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_1315:
        ...

    @overload
    def get_item(self, name : Literal['HEIGHT']) -> Variation_148:
        ...

    @overload
    def get_item(self, name : Literal['MDC']) -> Variation_1316:
        ...

    @overload
    def get_item(self, name : Literal['MDA']) -> Variation_1318:
        ...

    @overload
    def get_item(self, name : Literal['TYP']) -> Variation_1322:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['SID'], f : Any) -> 'Variation_1334':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1334':
        ...

    @overload
    def modify_item(self, name : Literal['HEIGHT'], f : Any) -> 'Variation_1334':
        ...

    @overload
    def modify_item(self, name : Literal['MDC'], f : Any) -> 'Variation_1334':
        ...

    @overload
    def modify_item(self, name : Literal['MDA'], f : Any) -> 'Variation_1334':
        ...

    @overload
    def modify_item(self, name : Literal['TYP'], f : Any) -> 'Variation_1334':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1335_Arg = TypedDict('Variation_1335_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '070': Union[Variation_80, Variation_80_Arg],
    '105': Union[Variation_649, Variation_649_Arg],
    '100': Union[Variation_1214, Variation_1214_Arg],
    '185': Union[Variation_1215, Variation_1215_Arg],
    '210': Union[Variation_664, Variation_664_Arg],
    '060': Union[Variation_1217, Variation_1217_Arg],
    '245': Union[Variation_1219, Variation_1219_Arg],
    '380': Union[Variation_1333, Variation_1333_Arg],
    '040': Union[Variation_64, Variation_64_Arg],
    '080': Union[Variation_1331, Variation_1331_Arg],
    '290': Union[Variation_1274, Variation_1274_Arg],
    '200': Union[Variation_1279, Variation_1279_Arg],
    '295': Union[Variation_1280, Variation_1280_Arg],
    '136': Union[Variation_360, Variation_360_Arg],
    '130': Union[Variation_287, Variation_287_Arg],
    '135': Union[Variation_1281, Variation_1281_Arg],
    '220': Union[Variation_364, Variation_364_Arg],
    '390': Union[Variation_1288, Variation_1288_Arg],
    '270': Union[Variation_290, Variation_290_Arg],
    '300': Union[Variation_285, Variation_285_Arg],
    '110': Union[Variation_1301, Variation_1301_Arg],
    '120': Union[Variation_1302, Variation_1302_Arg],
    '510': Union[Variation_1303, Variation_1303_Arg],
    '500': Union[Variation_1314, Variation_1314_Arg],
    '340': Union[Variation_1334, Variation_1334_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1335(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('010', Variation_1),
        None,
        ('015', Variation_0),
        ('070', Variation_80),
        ('105', Variation_649),
        ('100', Variation_1214),
        ('185', Variation_1215),
        ('210', Variation_664),
        ('060', Variation_1217),
        ('245', Variation_1219),
        ('380', Variation_1333),
        ('040', Variation_64),
        ('080', Variation_1331),
        ('290', Variation_1274),
        ('200', Variation_1279),
        ('295', Variation_1280),
        ('136', Variation_360),
        ('130', Variation_287),
        ('135', Variation_1281),
        ('220', Variation_364),
        ('390', Variation_1288),
        ('270', Variation_290),
        ('300', Variation_285),
        ('110', Variation_1301),
        ('120', Variation_1302),
        ('510', Variation_1303),
        ('500', Variation_1314),
        ('340', Variation_1334),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000000000),
        '015': ('Service Identification', Variation_0, 0x2000000000),
        '070': ('Time Of Track Information', Variation_80, 0x1000000000),
        '105': ('Calculated Position In WGS-84 Co-ordinates', Variation_649, 0x0800000000),
        '100': ('Calculated Track Position (Cartesian)', Variation_1214, 0x0400000000),
        '185': ('Calculated Track Velocity (Cartesian)', Variation_1215, 0x0200000000),
        '210': ('Calculated Acceleration (Cartesian)', Variation_664, 0x0180000000),
        '060': ('Track Mode 3/A Code', Variation_1217, 0x0140000000),
        '245': ('Target Identification', Variation_1219, 0x0120000000),
        '380': ('Aircraft Derived Data', Variation_1333, 0x0110000000),
        '040': ('Track Number', Variation_64, 0x0108000000),
        '080': ('Track Status', Variation_1331, 0x0104000000),
        '290': ('System Track Update Ages', Variation_1274, 0x0102000000),
        '200': ('Mode of Movement', Variation_1279, 0x0101800000),
        '295': ('Track Data Ages', Variation_1280, 0x0101400000),
        '136': ('Measured Flight Level', Variation_360, 0x0101200000),
        '130': ('Calculated Track Geometric Altitude', Variation_287, 0x0101100000),
        '135': ('Calculated Track Barometric Altitude', Variation_1281, 0x0101080000),
        '220': ('Calculated Rate of Climb/Descent', Variation_364, 0x0101040000),
        '390': ('Flight Plan Related Data', Variation_1288, 0x0101020000),
        '270': ('Target Size and Orientation', Variation_290, 0x0101018000),
        '300': ('Vehicle Fleet Identification', Variation_285, 0x0101014000),
        '110': ('Mode 5 Data Reports and Extended Mode 1 Code', Variation_1301, 0x0101012000),
        '120': ('Track Mode 2 Code', Variation_1302, 0x0101011000),
        '510': ('Composed Track Number', Variation_1303, 0x0101010800),
        '500': ('Estimated Accuracies', Variation_1314, 0x0101010400),
        '340': ('Measured Information', Variation_1334, 0x0101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x0101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['105']) -> Type[Variation_649]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_1214]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['185']) -> Type[Variation_1215]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_664]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_1217]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['245']) -> Type[Variation_1219]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['380']) -> Type[Variation_1333]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_1331]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['290']) -> Type[Variation_1274]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_1279]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['295']) -> Type[Variation_1280]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['136']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['135']) -> Type[Variation_1281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['390']) -> Type[Variation_1288]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['270']) -> Type[Variation_290]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_285]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1301]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1302]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['510']) -> Type[Variation_1303]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_1314]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['340']) -> Type[Variation_1334]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['015'], Literal['070'], Literal['105'], Literal['100'], Literal['185'], Literal['210'], Literal['060'], Literal['245'], Literal['380'], Literal['040'], Literal['080'], Literal['290'], Literal['200'], Literal['295'], Literal['136'], Literal['130'], Literal['135'], Literal['220'], Literal['390'], Literal['270'], Literal['300'], Literal['110'], Literal['120'], Literal['510'], Literal['500'], Literal['340'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_0'], Type['Variation_80'], Type['Variation_649'], Type['Variation_1214'], Type['Variation_1215'], Type['Variation_664'], Type['Variation_1217'], Type['Variation_1219'], Type['Variation_1333'], Type['Variation_64'], Type['Variation_1331'], Type['Variation_1274'], Type['Variation_1279'], Type['Variation_1280'], Type['Variation_360'], Type['Variation_287'], Type['Variation_1281'], Type['Variation_364'], Type['Variation_1288'], Type['Variation_290'], Type['Variation_285'], Type['Variation_1301'], Type['Variation_1302'], Type['Variation_1303'], Type['Variation_1314'], Type['Variation_1334'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '015':
            return Variation_0
        if key == '070':
            return Variation_80
        if key == '105':
            return Variation_649
        if key == '100':
            return Variation_1214
        if key == '185':
            return Variation_1215
        if key == '210':
            return Variation_664
        if key == '060':
            return Variation_1217
        if key == '245':
            return Variation_1219
        if key == '380':
            return Variation_1333
        if key == '040':
            return Variation_64
        if key == '080':
            return Variation_1331
        if key == '290':
            return Variation_1274
        if key == '200':
            return Variation_1279
        if key == '295':
            return Variation_1280
        if key == '136':
            return Variation_360
        if key == '130':
            return Variation_287
        if key == '135':
            return Variation_1281
        if key == '220':
            return Variation_364
        if key == '390':
            return Variation_1288
        if key == '270':
            return Variation_290
        if key == '300':
            return Variation_285
        if key == '110':
            return Variation_1301
        if key == '120':
            return Variation_1302
        if key == '510':
            return Variation_1303
        if key == '500':
            return Variation_1314
        if key == '340':
            return Variation_1334
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1335_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['105'], val : Union[Variation_649, Variation_649_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_1214, Variation_1214_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['185'], val : Union[Variation_1215, Variation_1215_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_664, Variation_664_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_1217, Variation_1217_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['245'], val : Union[Variation_1219, Variation_1219_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['380'], val : Union[Variation_1333, Variation_1333_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_1331, Variation_1331_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['290'], val : Union[Variation_1274, Variation_1274_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_1279, Variation_1279_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['295'], val : Union[Variation_1280, Variation_1280_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['136'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['135'], val : Union[Variation_1281, Variation_1281_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['390'], val : Union[Variation_1288, Variation_1288_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['270'], val : Union[Variation_290, Variation_290_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_285, Variation_285_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1301, Variation_1301_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1302, Variation_1302_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['510'], val : Union[Variation_1303, Variation_1303_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_1314, Variation_1314_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['340'], val : Union[Variation_1334, Variation_1334_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1335':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1335':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['105']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['185']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['245']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['380']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['290']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['295']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['136']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['135']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['390']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['270']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['510']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['340']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1335':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1335':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['105']) -> Variation_649:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_1214:
        ...

    @overload
    def get_item(self, name : Literal['185']) -> Variation_1215:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_664:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_1217:
        ...

    @overload
    def get_item(self, name : Literal['245']) -> Variation_1219:
        ...

    @overload
    def get_item(self, name : Literal['380']) -> Variation_1333:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_1331:
        ...

    @overload
    def get_item(self, name : Literal['290']) -> Variation_1274:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_1279:
        ...

    @overload
    def get_item(self, name : Literal['295']) -> Variation_1280:
        ...

    @overload
    def get_item(self, name : Literal['136']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['135']) -> Variation_1281:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['390']) -> Variation_1288:
        ...

    @overload
    def get_item(self, name : Literal['270']) -> Variation_290:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_285:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1301:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1302:
        ...

    @overload
    def get_item(self, name : Literal['510']) -> Variation_1303:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_1314:
        ...

    @overload
    def get_item(self, name : Literal['340']) -> Variation_1334:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['105'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['185'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['245'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['380'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['290'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['295'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['136'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['135'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['390'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['270'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['510'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['340'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1335':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1335':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1336_Arg = TypedDict('Variation_1336_Arg', {
    'ADR': Union[Variation_278, Variation_278_Arg],
    'ID': Union[Variation_196, Variation_196_Arg],
    'MHG': Union[Variation_14, Variation_14_Arg],
    'IAS': Union[Variation_1221, Variation_1221_Arg],
    'TAS': Union[Variation_720, Variation_720_Arg],
    'SAL': Union[Variation_1224, Variation_1224_Arg],
    'FSS': Union[Variation_1225, Variation_1225_Arg],
    'TIS': Union[Variation_1228, Variation_1228_Arg],
    'TID': Union[Variation_1230, Variation_1230_Arg],
    'COM': Union[Variation_1326, Variation_1326_Arg],
    'SAB': Union[Variation_1238, Variation_1238_Arg],
    'ACS': Union[Variation_281, Variation_281_Arg],
    'BVR': Union[Variation_364, Variation_364_Arg],
    'GVR': Union[Variation_364, Variation_364_Arg],
    'RAN': Union[Variation_717, Variation_717_Arg],
    'TAR': Union[Variation_1239, Variation_1239_Arg],
    'TAN': Union[Variation_14, Variation_14_Arg],
    'GS': Union[Variation_721, Variation_721_Arg],
    'VUN': Union[Variation_0, Variation_0_Arg],
    'MET': Union[Variation_1244, Variation_1244_Arg],
    'EMC': Union[Variation_1245, Variation_1245_Arg],
    'POS': Union[Variation_1246, Variation_1246_Arg],
    'GAL': Union[Variation_287, Variation_287_Arg],
    'PUN': Union[Variation_1247, Variation_1247_Arg],
    'BDSDATA': Union[Variation_321, Variation_321_Arg],
    'IAR': Union[Variation_720, Variation_720_Arg],
    'MAC': Union[Variation_1248, Variation_1248_Arg],
    'BPS': Union[Variation_1250, Variation_1250_Arg],
}, total=False)
class Variation_1336(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('ADR', Variation_278),
        ('ID', Variation_196),
        ('MHG', Variation_14),
        ('IAS', Variation_1221),
        ('TAS', Variation_720),
        ('SAL', Variation_1224),
        ('FSS', Variation_1225),
        ('TIS', Variation_1228),
        ('TID', Variation_1230),
        ('COM', Variation_1326),
        ('SAB', Variation_1238),
        ('ACS', Variation_281),
        ('BVR', Variation_364),
        ('GVR', Variation_364),
        ('RAN', Variation_717),
        ('TAR', Variation_1239),
        ('TAN', Variation_14),
        ('GS', Variation_721),
        ('VUN', Variation_0),
        ('MET', Variation_1244),
        ('EMC', Variation_1245),
        ('POS', Variation_1246),
        ('GAL', Variation_287),
        ('PUN', Variation_1247),
        ('BDSDATA', Variation_321),
        ('IAR', Variation_720),
        ('MAC', Variation_1248),
        ('BPS', Variation_1250),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        'ADR': ('Target Address', Variation_278, 0x80000000),
        'ID': ('Target Identification', Variation_196, 0x40000000),
        'MHG': ('Magnetic Heading', Variation_14, 0x20000000),
        'IAS': ('Indicated Airspeed/Mach No', Variation_1221, 0x10000000),
        'TAS': ('True Airspeed', Variation_720, 0x08000000),
        'SAL': ('Selected Altitude', Variation_1224, 0x04000000),
        'FSS': ('Final State Selected Altitude', Variation_1225, 0x02000000),
        'TIS': ('Trajectory Intent Status', Variation_1228, 0x01800000),
        'TID': ('Trajectory Intent Data', Variation_1230, 0x01400000),
        'COM': ('Communications/ACAS Capability and Flight Status', Variation_1326, 0x01200000),
        'SAB': ('Status Reported by ADS-B', Variation_1238, 0x01100000),
        'ACS': ('ACAS Resolution Advisory Report', Variation_281, 0x01080000),
        'BVR': ('Barometric Vertical Rate', Variation_364, 0x01040000),
        'GVR': ('Geometric Vertical Rate', Variation_364, 0x01020000),
        'RAN': ('Roll Angle', Variation_717, 0x01018000),
        'TAR': ('Track Angle Rate', Variation_1239, 0x01014000),
        'TAN': ('Track Angle', Variation_14, 0x01012000),
        'GS': ('Ground Speed', Variation_721, 0x01011000),
        'VUN': ('Velocity Uncertainty', Variation_0, 0x01010800),
        'MET': ('Meteorological Data', Variation_1244, 0x01010400),
        'EMC': ('Emitter Category', Variation_1245, 0x01010200),
        'POS': ('Position', Variation_1246, 0x01010180),
        'GAL': ('Geometric Altitude', Variation_287, 0x01010140),
        'PUN': ('Position Uncertainty', Variation_1247, 0x01010120),
        'BDSDATA': ('BDS Register DATA', Variation_321, 0x01010110),
        'IAR': ('Indicated Airspeed', Variation_720, 0x01010108),
        'MAC': ('Mach Number', Variation_1248, 0x01010104),
        'BPS': ('Barometric Pressure Setting', Variation_1250, 0x01010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['ADR']) -> Type[Variation_278]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ID']) -> Type[Variation_196]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MHG']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAS']) -> Type[Variation_1221]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAS']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAL']) -> Type[Variation_1224]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FSS']) -> Type[Variation_1225]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TIS']) -> Type[Variation_1228]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TID']) -> Type[Variation_1230]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['COM']) -> Type[Variation_1326]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SAB']) -> Type[Variation_1238]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ACS']) -> Type[Variation_281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BVR']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GVR']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RAN']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAR']) -> Type[Variation_1239]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TAN']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GS']) -> Type[Variation_721]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['VUN']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MET']) -> Type[Variation_1244]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EMC']) -> Type[Variation_1245]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['POS']) -> Type[Variation_1246]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['GAL']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PUN']) -> Type[Variation_1247]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BDSDATA']) -> Type[Variation_321]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IAR']) -> Type[Variation_720]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAC']) -> Type[Variation_1248]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['BPS']) -> Type[Variation_1250]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['ADR'], Literal['ID'], Literal['MHG'], Literal['IAS'], Literal['TAS'], Literal['SAL'], Literal['FSS'], Literal['TIS'], Literal['TID'], Literal['COM'], Literal['SAB'], Literal['ACS'], Literal['BVR'], Literal['GVR'], Literal['RAN'], Literal['TAR'], Literal['TAN'], Literal['GS'], Literal['VUN'], Literal['MET'], Literal['EMC'], Literal['POS'], Literal['GAL'], Literal['PUN'], Literal['BDSDATA'], Literal['IAR'], Literal['MAC'], Literal['BPS']]) -> Union[Type['Variation_278'], Type['Variation_196'], Type['Variation_14'], Type['Variation_1221'], Type['Variation_720'], Type['Variation_1224'], Type['Variation_1225'], Type['Variation_1228'], Type['Variation_1230'], Type['Variation_1326'], Type['Variation_1238'], Type['Variation_281'], Type['Variation_364'], Type['Variation_364'], Type['Variation_717'], Type['Variation_1239'], Type['Variation_14'], Type['Variation_721'], Type['Variation_0'], Type['Variation_1244'], Type['Variation_1245'], Type['Variation_1246'], Type['Variation_287'], Type['Variation_1247'], Type['Variation_321'], Type['Variation_720'], Type['Variation_1248'], Type['Variation_1250']]:
        if key == 'ADR':
            return Variation_278
        if key == 'ID':
            return Variation_196
        if key == 'MHG':
            return Variation_14
        if key == 'IAS':
            return Variation_1221
        if key == 'TAS':
            return Variation_720
        if key == 'SAL':
            return Variation_1224
        if key == 'FSS':
            return Variation_1225
        if key == 'TIS':
            return Variation_1228
        if key == 'TID':
            return Variation_1230
        if key == 'COM':
            return Variation_1326
        if key == 'SAB':
            return Variation_1238
        if key == 'ACS':
            return Variation_281
        if key == 'BVR':
            return Variation_364
        if key == 'GVR':
            return Variation_364
        if key == 'RAN':
            return Variation_717
        if key == 'TAR':
            return Variation_1239
        if key == 'TAN':
            return Variation_14
        if key == 'GS':
            return Variation_721
        if key == 'VUN':
            return Variation_0
        if key == 'MET':
            return Variation_1244
        if key == 'EMC':
            return Variation_1245
        if key == 'POS':
            return Variation_1246
        if key == 'GAL':
            return Variation_287
        if key == 'PUN':
            return Variation_1247
        if key == 'BDSDATA':
            return Variation_321
        if key == 'IAR':
            return Variation_720
        if key == 'MAC':
            return Variation_1248
        if key == 'BPS':
            return Variation_1250
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1336_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['ADR'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['ID'], val : Union[Variation_196, Variation_196_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['MHG'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['IAS'], val : Union[Variation_1221, Variation_1221_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['TAS'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['SAL'], val : Union[Variation_1224, Variation_1224_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['FSS'], val : Union[Variation_1225, Variation_1225_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['TIS'], val : Union[Variation_1228, Variation_1228_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['TID'], val : Union[Variation_1230, Variation_1230_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['COM'], val : Union[Variation_1326, Variation_1326_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['SAB'], val : Union[Variation_1238, Variation_1238_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['ACS'], val : Union[Variation_281, Variation_281_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['BVR'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['GVR'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['RAN'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['TAR'], val : Union[Variation_1239, Variation_1239_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['TAN'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['GS'], val : Union[Variation_721, Variation_721_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['VUN'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['MET'], val : Union[Variation_1244, Variation_1244_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['EMC'], val : Union[Variation_1245, Variation_1245_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['POS'], val : Union[Variation_1246, Variation_1246_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['GAL'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['PUN'], val : Union[Variation_1247, Variation_1247_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['BDSDATA'], val : Union[Variation_321, Variation_321_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['IAR'], val : Union[Variation_720, Variation_720_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['MAC'], val : Union[Variation_1248, Variation_1248_Arg]) -> 'Variation_1336':
        ...

    @overload
    def set_item(self, name : Literal['BPS'], val : Union[Variation_1250, Variation_1250_Arg]) -> 'Variation_1336':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['ADR']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['ID']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['MHG']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['IAS']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['TAS']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['SAL']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['FSS']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['TIS']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['TID']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['COM']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['SAB']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['ACS']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['BVR']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['GVR']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['RAN']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['TAR']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['TAN']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['GS']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['VUN']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['MET']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['EMC']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['POS']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['GAL']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['PUN']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['BDSDATA']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['IAR']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['MAC']) -> 'Variation_1336':
        ...

    @overload
    def del_item(self, name : Literal['BPS']) -> 'Variation_1336':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['ADR']) -> Variation_278:
        ...

    @overload
    def get_item(self, name : Literal['ID']) -> Variation_196:
        ...

    @overload
    def get_item(self, name : Literal['MHG']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['IAS']) -> Variation_1221:
        ...

    @overload
    def get_item(self, name : Literal['TAS']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['SAL']) -> Variation_1224:
        ...

    @overload
    def get_item(self, name : Literal['FSS']) -> Variation_1225:
        ...

    @overload
    def get_item(self, name : Literal['TIS']) -> Variation_1228:
        ...

    @overload
    def get_item(self, name : Literal['TID']) -> Variation_1230:
        ...

    @overload
    def get_item(self, name : Literal['COM']) -> Variation_1326:
        ...

    @overload
    def get_item(self, name : Literal['SAB']) -> Variation_1238:
        ...

    @overload
    def get_item(self, name : Literal['ACS']) -> Variation_281:
        ...

    @overload
    def get_item(self, name : Literal['BVR']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['GVR']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['RAN']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['TAR']) -> Variation_1239:
        ...

    @overload
    def get_item(self, name : Literal['TAN']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['GS']) -> Variation_721:
        ...

    @overload
    def get_item(self, name : Literal['VUN']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['MET']) -> Variation_1244:
        ...

    @overload
    def get_item(self, name : Literal['EMC']) -> Variation_1245:
        ...

    @overload
    def get_item(self, name : Literal['POS']) -> Variation_1246:
        ...

    @overload
    def get_item(self, name : Literal['GAL']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['PUN']) -> Variation_1247:
        ...

    @overload
    def get_item(self, name : Literal['BDSDATA']) -> Variation_321:
        ...

    @overload
    def get_item(self, name : Literal['IAR']) -> Variation_720:
        ...

    @overload
    def get_item(self, name : Literal['MAC']) -> Variation_1248:
        ...

    @overload
    def get_item(self, name : Literal['BPS']) -> Variation_1250:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['ADR'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['ID'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['MHG'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['IAS'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['TAS'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['SAL'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['FSS'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['TIS'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['TID'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['COM'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['SAB'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['ACS'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['BVR'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['GVR'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['RAN'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['TAR'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['TAN'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['GS'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['VUN'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['MET'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['EMC'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['POS'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['GAL'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['PUN'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['BDSDATA'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['IAR'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['MAC'], f : Any) -> 'Variation_1336':
        ...

    @overload
    def modify_item(self, name : Literal['BPS'], f : Any) -> 'Variation_1336':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1337_Arg : TypeAlias = Raw
class Variation_1337(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'Default value',
        1: 'Age of the last received MLAT track updateis higher than system dependent threshold',
    }

    def __init__(self, arg : Variation_1337_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1338_Arg_Group_1 = TypedDict('Variation_1338_Arg_Group_1', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
})
Variation_1338_Arg_Group_2 = TypedDict('Variation_1338_Arg_Group_2', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
})
Variation_1338_Arg_Group_3 = TypedDict('Variation_1338_Arg_Group_3', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
})
Variation_1338_Arg_Group_4 = TypedDict('Variation_1338_Arg_Group_4', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
    'CST': Union[Variation_1263, Variation_1263_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_1264, Variation_1264_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_1265, Variation_1265_Arg],
})
Variation_1338_Arg_Group_5 = TypedDict('Variation_1338_Arg_Group_5', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
    'CST': Union[Variation_1263, Variation_1263_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_1264, Variation_1264_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_1265, Variation_1265_Arg],
    'SDS': Union[Variation_1266, Variation_1266_Arg],
    'EMS': Union[Variation_1267, Variation_1267_Arg],
    'PFT': Union[Variation_1268, Variation_1268_Arg],
    'FPLT': Union[Variation_1269, Variation_1269_Arg],
})
Variation_1338_Arg_Group_6 = TypedDict('Variation_1338_Arg_Group_6', {
    'MON': Union[Variation_1252, Variation_1252_Arg],
    'SPI': Union[Variation_351, Variation_351_Arg],
    'MRH': Union[Variation_341, Variation_341_Arg],
    'SRC': Union[Variation_1253, Variation_1253_Arg],
    'CNF': Union[Variation_343, Variation_343_Arg],
    'SIM': Union[Variation_1254, Variation_1254_Arg],
    'TSE': Union[Variation_1255, Variation_1255_Arg],
    'TSB': Union[Variation_1256, Variation_1256_Arg],
    'FPC': Union[Variation_353, Variation_353_Arg],
    'AFF': Union[Variation_354, Variation_354_Arg],
    'STP': Union[Variation_1257, Variation_1257_Arg],
    'KOS': Union[Variation_1258, Variation_1258_Arg],
    'AMA': Union[Variation_350, Variation_350_Arg],
    'MD4': Union[Variation_1259, Variation_1259_Arg],
    'ME': Union[Variation_1260, Variation_1260_Arg],
    'MI': Union[Variation_1261, Variation_1261_Arg],
    'MD5': Union[Variation_1262, Variation_1262_Arg],
    'CST': Union[Variation_1263, Variation_1263_Arg],
    'PSR': Union[Variation_416, Variation_416_Arg],
    'SSR': Union[Variation_417, Variation_417_Arg],
    'MDS': Union[Variation_418, Variation_418_Arg],
    'ADS': Union[Variation_1264, Variation_1264_Arg],
    'SUC': Union[Variation_420, Variation_420_Arg],
    'AAC': Union[Variation_1265, Variation_1265_Arg],
    'SDS': Union[Variation_1266, Variation_1266_Arg],
    'EMS': Union[Variation_1267, Variation_1267_Arg],
    'PFT': Union[Variation_1268, Variation_1268_Arg],
    'FPLT': Union[Variation_1269, Variation_1269_Arg],
    'DUPT': Union[Variation_1270, Variation_1270_Arg],
    'DUPF': Union[Variation_1271, Variation_1271_Arg],
    'DUPM': Union[Variation_1272, Variation_1272_Arg],
    'SFC': Union[Variation_1328, Variation_1328_Arg],
    'IDD': Union[Variation_1329, Variation_1329_Arg],
    'IEC': Union[Variation_1330, Variation_1330_Arg],
    'MLAT': Union[Variation_1337, Variation_1337_Arg],
})
Variation_1338_Arg : TypeAlias = Union[
    int,
    Variation_1338_Arg_Group_1,
    Tuple[int],
    Variation_1338_Arg_Group_2,
    Tuple[int,int],
    Variation_1338_Arg_Group_3,
    Tuple[int,int,int],
    Variation_1338_Arg_Group_4,
    Tuple[int,int,int,int],
    Variation_1338_Arg_Group_5,
    Tuple[int,int,int,int,int],
    Variation_1338_Arg_Group_6,
    Tuple[int,int,int,int,int,int],
]
class Variation_1338(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
        7,
        7,
        7,
        7,
    ]

    subitems_list = [
        [
            ('MON', Variation_1252),
            ('SPI', Variation_351),
            ('MRH', Variation_341),
            ('SRC', Variation_1253),
            ('CNF', Variation_343),
        ],
        [
            ('SIM', Variation_1254),
            ('TSE', Variation_1255),
            ('TSB', Variation_1256),
            ('FPC', Variation_353),
            ('AFF', Variation_354),
            ('STP', Variation_1257),
            ('KOS', Variation_1258),
        ],
        [
            ('AMA', Variation_350),
            ('MD4', Variation_1259),
            ('ME', Variation_1260),
            ('MI', Variation_1261),
            ('MD5', Variation_1262),
        ],
        [
            ('CST', Variation_1263),
            ('PSR', Variation_416),
            ('SSR', Variation_417),
            ('MDS', Variation_418),
            ('ADS', Variation_1264),
            ('SUC', Variation_420),
            ('AAC', Variation_1265),
        ],
        [
            ('SDS', Variation_1266),
            ('EMS', Variation_1267),
            ('PFT', Variation_1268),
            ('FPLT', Variation_1269),
        ],
        [
            ('DUPT', Variation_1270),
            ('DUPF', Variation_1271),
            ('DUPM', Variation_1272),
            ('SFC', Variation_1328),
            ('IDD', Variation_1329),
            ('IEC', Variation_1330),
            ('MLAT', Variation_1337),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'MON': ('', Variation_1252, 0, 1),
        'SPI': ('', Variation_351, 1, 1),
        'MRH': ('Most Reliable Height', Variation_341, 2, 1),
        'SRC': ('Source of Calculated Track Altitude for I062/130', Variation_1253, 3, 3),
        'CNF': ('', Variation_343, 6, 1),
        'SIM': ('', Variation_1254, 0, 1),
        'TSE': ('', Variation_1255, 1, 1),
        'TSB': ('', Variation_1256, 2, 1),
        'FPC': ('', Variation_353, 3, 1),
        'AFF': ('', Variation_354, 4, 1),
        'STP': ('', Variation_1257, 5, 1),
        'KOS': ('', Variation_1258, 6, 1),
        'AMA': ('', Variation_350, 0, 1),
        'MD4': ('', Variation_1259, 1, 2),
        'ME': ('', Variation_1260, 3, 1),
        'MI': ('', Variation_1261, 4, 1),
        'MD5': ('', Variation_1262, 5, 2),
        'CST': ('', Variation_1263, 0, 1),
        'PSR': ('', Variation_416, 1, 1),
        'SSR': ('', Variation_417, 2, 1),
        'MDS': ('', Variation_418, 3, 1),
        'ADS': ('', Variation_1264, 4, 1),
        'SUC': ('', Variation_420, 5, 1),
        'AAC': ('', Variation_1265, 6, 1),
        'SDS': ('', Variation_1266, 0, 2),
        'EMS': ('', Variation_1267, 2, 3),
        'PFT': ('', Variation_1268, 5, 1),
        'FPLT': ('', Variation_1269, 6, 1),
        'DUPT': ('', Variation_1270, 0, 1),
        'DUPF': ('', Variation_1271, 1, 1),
        'DUPM': ('', Variation_1272, 2, 1),
        'SFC': ('', Variation_1328, 3, 1),
        'IDD': ('', Variation_1329, 4, 1),
        'IEC': ('', Variation_1330, 5, 1),
        'MLAT': ('', Variation_1337, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['MON']) -> Type[Variation_1252]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SPI']) -> Type[Variation_351]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MRH']) -> Type[Variation_341]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRC']) -> Type[Variation_1253]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CNF']) -> Type[Variation_343]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SIM']) -> Type[Variation_1254]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSE']) -> Type[Variation_1255]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSB']) -> Type[Variation_1256]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FPC']) -> Type[Variation_353]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AFF']) -> Type[Variation_354]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STP']) -> Type[Variation_1257]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['KOS']) -> Type[Variation_1258]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AMA']) -> Type[Variation_350]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD4']) -> Type[Variation_1259]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ME']) -> Type[Variation_1260]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MI']) -> Type[Variation_1261]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MD5']) -> Type[Variation_1262]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CST']) -> Type[Variation_1263]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_416]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_417]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_418]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADS']) -> Type[Variation_1264]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SUC']) -> Type[Variation_420]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['AAC']) -> Type[Variation_1265]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SDS']) -> Type[Variation_1266]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['EMS']) -> Type[Variation_1267]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PFT']) -> Type[Variation_1268]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['FPLT']) -> Type[Variation_1269]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DUPT']) -> Type[Variation_1270]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DUPF']) -> Type[Variation_1271]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['DUPM']) -> Type[Variation_1272]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SFC']) -> Type[Variation_1328]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IDD']) -> Type[Variation_1329]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['IEC']) -> Type[Variation_1330]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MLAT']) -> Type[Variation_1337]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['MON'], Literal['SPI'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FPC'], Literal['AFF'], Literal['STP'], Literal['KOS'], Literal['AMA'], Literal['MD4'], Literal['ME'], Literal['MI'], Literal['MD5'], Literal['CST'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['SUC'], Literal['AAC'], Literal['SDS'], Literal['EMS'], Literal['PFT'], Literal['FPLT'], Literal['DUPT'], Literal['DUPF'], Literal['DUPM'], Literal['SFC'], Literal['IDD'], Literal['IEC'], Literal['MLAT']]) -> Union[Type['Variation_1252'], Type['Variation_351'], Type['Variation_341'], Type['Variation_1253'], Type['Variation_343'], Type['Variation_1254'], Type['Variation_1255'], Type['Variation_1256'], Type['Variation_353'], Type['Variation_354'], Type['Variation_1257'], Type['Variation_1258'], Type['Variation_350'], Type['Variation_1259'], Type['Variation_1260'], Type['Variation_1261'], Type['Variation_1262'], Type['Variation_1263'], Type['Variation_416'], Type['Variation_417'], Type['Variation_418'], Type['Variation_1264'], Type['Variation_420'], Type['Variation_1265'], Type['Variation_1266'], Type['Variation_1267'], Type['Variation_1268'], Type['Variation_1269'], Type['Variation_1270'], Type['Variation_1271'], Type['Variation_1272'], Type['Variation_1328'], Type['Variation_1329'], Type['Variation_1330'], Type['Variation_1337']]:
        if key == 'MON':
            return Variation_1252
        if key == 'SPI':
            return Variation_351
        if key == 'MRH':
            return Variation_341
        if key == 'SRC':
            return Variation_1253
        if key == 'CNF':
            return Variation_343
        if key == 'SIM':
            return Variation_1254
        if key == 'TSE':
            return Variation_1255
        if key == 'TSB':
            return Variation_1256
        if key == 'FPC':
            return Variation_353
        if key == 'AFF':
            return Variation_354
        if key == 'STP':
            return Variation_1257
        if key == 'KOS':
            return Variation_1258
        if key == 'AMA':
            return Variation_350
        if key == 'MD4':
            return Variation_1259
        if key == 'ME':
            return Variation_1260
        if key == 'MI':
            return Variation_1261
        if key == 'MD5':
            return Variation_1262
        if key == 'CST':
            return Variation_1263
        if key == 'PSR':
            return Variation_416
        if key == 'SSR':
            return Variation_417
        if key == 'MDS':
            return Variation_418
        if key == 'ADS':
            return Variation_1264
        if key == 'SUC':
            return Variation_420
        if key == 'AAC':
            return Variation_1265
        if key == 'SDS':
            return Variation_1266
        if key == 'EMS':
            return Variation_1267
        if key == 'PFT':
            return Variation_1268
        if key == 'FPLT':
            return Variation_1269
        if key == 'DUPT':
            return Variation_1270
        if key == 'DUPF':
            return Variation_1271
        if key == 'DUPM':
            return Variation_1272
        if key == 'SFC':
            return Variation_1328
        if key == 'IDD':
            return Variation_1329
        if key == 'IEC':
            return Variation_1330
        if key == 'MLAT':
            return Variation_1337
        assert_never(key)

    def __init__(self, arg : Variation_1338_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1338_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_1338_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            if Variation_1338_Arg_Group_3.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(3, arg)); return
            if Variation_1338_Arg_Group_4.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(4, arg)); return
            if Variation_1338_Arg_Group_5.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(5, arg)); return
            if Variation_1338_Arg_Group_6.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(6, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['MON']) -> Variation_1252:
        ...

    @overload
    def get_item(self, name : Literal['SPI']) -> Variation_351:
        ...

    @overload
    def get_item(self, name : Literal['MRH']) -> Variation_341:
        ...

    @overload
    def get_item(self, name : Literal['SRC']) -> Variation_1253:
        ...

    @overload
    def get_item(self, name : Literal['CNF']) -> Variation_343:
        ...

    @overload
    def get_item(self, name : Literal['SIM']) -> Variation_1254:
        ...

    @overload
    def get_item(self, name : Literal['TSE']) -> Variation_1255:
        ...

    @overload
    def get_item(self, name : Literal['TSB']) -> Variation_1256:
        ...

    @overload
    def get_item(self, name : Literal['FPC']) -> Variation_353:
        ...

    @overload
    def get_item(self, name : Literal['AFF']) -> Variation_354:
        ...

    @overload
    def get_item(self, name : Literal['STP']) -> Variation_1257:
        ...

    @overload
    def get_item(self, name : Literal['KOS']) -> Variation_1258:
        ...

    @overload
    def get_item(self, name : Literal['AMA']) -> Variation_350:
        ...

    @overload
    def get_item(self, name : Literal['MD4']) -> Variation_1259:
        ...

    @overload
    def get_item(self, name : Literal['ME']) -> Variation_1260:
        ...

    @overload
    def get_item(self, name : Literal['MI']) -> Variation_1261:
        ...

    @overload
    def get_item(self, name : Literal['MD5']) -> Variation_1262:
        ...

    @overload
    def get_item(self, name : Literal['CST']) -> Variation_1263:
        ...

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_416:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_417:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_418:
        ...

    @overload
    def get_item(self, name : Literal['ADS']) -> Variation_1264:
        ...

    @overload
    def get_item(self, name : Literal['SUC']) -> Variation_420:
        ...

    @overload
    def get_item(self, name : Literal['AAC']) -> Variation_1265:
        ...

    @overload
    def get_item(self, name : Literal['SDS']) -> Variation_1266:
        ...

    @overload
    def get_item(self, name : Literal['EMS']) -> Variation_1267:
        ...

    @overload
    def get_item(self, name : Literal['PFT']) -> Variation_1268:
        ...

    @overload
    def get_item(self, name : Literal['FPLT']) -> Variation_1269:
        ...

    @overload
    def get_item(self, name : Literal['DUPT']) -> Variation_1270:
        ...

    @overload
    def get_item(self, name : Literal['DUPF']) -> Variation_1271:
        ...

    @overload
    def get_item(self, name : Literal['DUPM']) -> Variation_1272:
        ...

    @overload
    def get_item(self, name : Literal['SFC']) -> Variation_1328:
        ...

    @overload
    def get_item(self, name : Literal['IDD']) -> Variation_1329:
        ...

    @overload
    def get_item(self, name : Literal['IEC']) -> Variation_1330:
        ...

    @overload
    def get_item(self, name : Literal['MLAT']) -> Variation_1337:
        ...

    def get_item(self, name : Union[Literal['MON'], Literal['SPI'], Literal['MRH'], Literal['SRC'], Literal['CNF'], Literal['SIM'], Literal['TSE'], Literal['TSB'], Literal['FPC'], Literal['AFF'], Literal['STP'], Literal['KOS'], Literal['AMA'], Literal['MD4'], Literal['ME'], Literal['MI'], Literal['MD5'], Literal['CST'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['SUC'], Literal['AAC'], Literal['SDS'], Literal['EMS'], Literal['PFT'], Literal['FPLT'], Literal['DUPT'], Literal['DUPF'], Literal['DUPM'], Literal['SFC'], Literal['IDD'], Literal['IEC'], Literal['MLAT']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['MON'], val : Union[Variation_1252, Variation_1252_Arg]) -> 'Variation_1338':
        ...

    @overload
    def set_item(self, name : Literal['SPI'], val : Union[Variation_351, Variation_351_Arg]) -> 'Variation_1338':
        ...

    @overload
    def set_item(self, name : Literal['MRH'], val : Union[Variation_341, Variation_341_Arg]) -> 'Variation_1338':
        ...

    @overload
    def set_item(self, name : Literal['SRC'], val : Union[Variation_1253, Variation_1253_Arg]) -> 'Variation_1338':
        ...

    @overload
    def set_item(self, name : Literal['CNF'], val : Union[Variation_343, Variation_343_Arg]) -> 'Variation_1338':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['MON'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['SPI'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['MRH'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['SRC'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['CNF'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['SIM'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['TSE'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['TSB'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['FPC'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['AFF'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['STP'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['KOS'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['AMA'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['MD4'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['ME'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['MI'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['MD5'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['CST'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['ADS'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['SUC'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['AAC'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['SDS'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['EMS'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['PFT'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['FPLT'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['DUPT'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['DUPF'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['DUPM'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['SFC'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['IDD'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['IEC'], f : Any) -> 'Variation_1338':
        ...

    @overload
    def modify_item(self, name : Literal['MLAT'], f : Any) -> 'Variation_1338':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1339_Arg = TypedDict('Variation_1339_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '070': Union[Variation_80, Variation_80_Arg],
    '105': Union[Variation_649, Variation_649_Arg],
    '100': Union[Variation_1214, Variation_1214_Arg],
    '185': Union[Variation_1215, Variation_1215_Arg],
    '210': Union[Variation_664, Variation_664_Arg],
    '060': Union[Variation_1217, Variation_1217_Arg],
    '245': Union[Variation_1219, Variation_1219_Arg],
    '380': Union[Variation_1336, Variation_1336_Arg],
    '040': Union[Variation_64, Variation_64_Arg],
    '080': Union[Variation_1338, Variation_1338_Arg],
    '290': Union[Variation_1274, Variation_1274_Arg],
    '200': Union[Variation_1279, Variation_1279_Arg],
    '295': Union[Variation_1280, Variation_1280_Arg],
    '136': Union[Variation_360, Variation_360_Arg],
    '130': Union[Variation_287, Variation_287_Arg],
    '135': Union[Variation_1281, Variation_1281_Arg],
    '220': Union[Variation_364, Variation_364_Arg],
    '390': Union[Variation_1288, Variation_1288_Arg],
    '270': Union[Variation_290, Variation_290_Arg],
    '300': Union[Variation_285, Variation_285_Arg],
    '110': Union[Variation_1301, Variation_1301_Arg],
    '120': Union[Variation_1302, Variation_1302_Arg],
    '510': Union[Variation_1303, Variation_1303_Arg],
    '500': Union[Variation_1314, Variation_1314_Arg],
    '340': Union[Variation_1334, Variation_1334_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1339(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 5

    subitems_list = [
        ('010', Variation_1),
        None,
        ('015', Variation_0),
        ('070', Variation_80),
        ('105', Variation_649),
        ('100', Variation_1214),
        ('185', Variation_1215),
        ('210', Variation_664),
        ('060', Variation_1217),
        ('245', Variation_1219),
        ('380', Variation_1336),
        ('040', Variation_64),
        ('080', Variation_1338),
        ('290', Variation_1274),
        ('200', Variation_1279),
        ('295', Variation_1280),
        ('136', Variation_360),
        ('130', Variation_287),
        ('135', Variation_1281),
        ('220', Variation_364),
        ('390', Variation_1288),
        ('270', Variation_290),
        ('300', Variation_285),
        ('110', Variation_1301),
        ('120', Variation_1302),
        ('510', Variation_1303),
        ('500', Variation_1314),
        ('340', Variation_1334),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000000000),
        '015': ('Service Identification', Variation_0, 0x2000000000),
        '070': ('Time Of Track Information', Variation_80, 0x1000000000),
        '105': ('Calculated Position In WGS-84 Co-ordinates', Variation_649, 0x0800000000),
        '100': ('Calculated Track Position (Cartesian)', Variation_1214, 0x0400000000),
        '185': ('Calculated Track Velocity (Cartesian)', Variation_1215, 0x0200000000),
        '210': ('Calculated Acceleration (Cartesian)', Variation_664, 0x0180000000),
        '060': ('Track Mode 3/A Code', Variation_1217, 0x0140000000),
        '245': ('Target Identification', Variation_1219, 0x0120000000),
        '380': ('Aircraft Derived Data', Variation_1336, 0x0110000000),
        '040': ('Track Number', Variation_64, 0x0108000000),
        '080': ('Track Status', Variation_1338, 0x0104000000),
        '290': ('System Track Update Ages', Variation_1274, 0x0102000000),
        '200': ('Mode of Movement', Variation_1279, 0x0101800000),
        '295': ('Track Data Ages', Variation_1280, 0x0101400000),
        '136': ('Measured Flight Level', Variation_360, 0x0101200000),
        '130': ('Calculated Track Geometric Altitude', Variation_287, 0x0101100000),
        '135': ('Calculated Track Barometric Altitude', Variation_1281, 0x0101080000),
        '220': ('Calculated Rate of Climb/Descent', Variation_364, 0x0101040000),
        '390': ('Flight Plan Related Data', Variation_1288, 0x0101020000),
        '270': ('Target Size and Orientation', Variation_290, 0x0101018000),
        '300': ('Vehicle Fleet Identification', Variation_285, 0x0101014000),
        '110': ('Mode 5 Data Reports and Extended Mode 1 Code', Variation_1301, 0x0101012000),
        '120': ('Track Mode 2 Code', Variation_1302, 0x0101011000),
        '510': ('Composed Track Number', Variation_1303, 0x0101010800),
        '500': ('Estimated Accuracies', Variation_1314, 0x0101010400),
        '340': ('Measured Information', Variation_1334, 0x0101010200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0101010104),
        'SP': ('Special Purpose Field', Variation_62, 0x0101010102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['105']) -> Type[Variation_649]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_1214]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['185']) -> Type[Variation_1215]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['210']) -> Type[Variation_664]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_1217]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['245']) -> Type[Variation_1219]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['380']) -> Type[Variation_1336]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_1338]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['290']) -> Type[Variation_1274]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_1279]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['295']) -> Type[Variation_1280]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['136']) -> Type[Variation_360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_287]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['135']) -> Type[Variation_1281]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['220']) -> Type[Variation_364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['390']) -> Type[Variation_1288]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['270']) -> Type[Variation_290]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['300']) -> Type[Variation_285]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1301]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1302]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['510']) -> Type[Variation_1303]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['500']) -> Type[Variation_1314]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['340']) -> Type[Variation_1334]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['015'], Literal['070'], Literal['105'], Literal['100'], Literal['185'], Literal['210'], Literal['060'], Literal['245'], Literal['380'], Literal['040'], Literal['080'], Literal['290'], Literal['200'], Literal['295'], Literal['136'], Literal['130'], Literal['135'], Literal['220'], Literal['390'], Literal['270'], Literal['300'], Literal['110'], Literal['120'], Literal['510'], Literal['500'], Literal['340'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_0'], Type['Variation_80'], Type['Variation_649'], Type['Variation_1214'], Type['Variation_1215'], Type['Variation_664'], Type['Variation_1217'], Type['Variation_1219'], Type['Variation_1336'], Type['Variation_64'], Type['Variation_1338'], Type['Variation_1274'], Type['Variation_1279'], Type['Variation_1280'], Type['Variation_360'], Type['Variation_287'], Type['Variation_1281'], Type['Variation_364'], Type['Variation_1288'], Type['Variation_290'], Type['Variation_285'], Type['Variation_1301'], Type['Variation_1302'], Type['Variation_1303'], Type['Variation_1314'], Type['Variation_1334'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '015':
            return Variation_0
        if key == '070':
            return Variation_80
        if key == '105':
            return Variation_649
        if key == '100':
            return Variation_1214
        if key == '185':
            return Variation_1215
        if key == '210':
            return Variation_664
        if key == '060':
            return Variation_1217
        if key == '245':
            return Variation_1219
        if key == '380':
            return Variation_1336
        if key == '040':
            return Variation_64
        if key == '080':
            return Variation_1338
        if key == '290':
            return Variation_1274
        if key == '200':
            return Variation_1279
        if key == '295':
            return Variation_1280
        if key == '136':
            return Variation_360
        if key == '130':
            return Variation_287
        if key == '135':
            return Variation_1281
        if key == '220':
            return Variation_364
        if key == '390':
            return Variation_1288
        if key == '270':
            return Variation_290
        if key == '300':
            return Variation_285
        if key == '110':
            return Variation_1301
        if key == '120':
            return Variation_1302
        if key == '510':
            return Variation_1303
        if key == '500':
            return Variation_1314
        if key == '340':
            return Variation_1334
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1339_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['105'], val : Union[Variation_649, Variation_649_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_1214, Variation_1214_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['185'], val : Union[Variation_1215, Variation_1215_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['210'], val : Union[Variation_664, Variation_664_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_1217, Variation_1217_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['245'], val : Union[Variation_1219, Variation_1219_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['380'], val : Union[Variation_1336, Variation_1336_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_1338, Variation_1338_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['290'], val : Union[Variation_1274, Variation_1274_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_1279, Variation_1279_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['295'], val : Union[Variation_1280, Variation_1280_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['136'], val : Union[Variation_360, Variation_360_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_287, Variation_287_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['135'], val : Union[Variation_1281, Variation_1281_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['220'], val : Union[Variation_364, Variation_364_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['390'], val : Union[Variation_1288, Variation_1288_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['270'], val : Union[Variation_290, Variation_290_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['300'], val : Union[Variation_285, Variation_285_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1301, Variation_1301_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1302, Variation_1302_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['510'], val : Union[Variation_1303, Variation_1303_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['500'], val : Union[Variation_1314, Variation_1314_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['340'], val : Union[Variation_1334, Variation_1334_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1339':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1339':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['105']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['185']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['210']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['245']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['380']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['290']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['295']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['136']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['135']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['220']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['390']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['270']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['300']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['510']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['500']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['340']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1339':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1339':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['105']) -> Variation_649:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_1214:
        ...

    @overload
    def get_item(self, name : Literal['185']) -> Variation_1215:
        ...

    @overload
    def get_item(self, name : Literal['210']) -> Variation_664:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_1217:
        ...

    @overload
    def get_item(self, name : Literal['245']) -> Variation_1219:
        ...

    @overload
    def get_item(self, name : Literal['380']) -> Variation_1336:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_1338:
        ...

    @overload
    def get_item(self, name : Literal['290']) -> Variation_1274:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_1279:
        ...

    @overload
    def get_item(self, name : Literal['295']) -> Variation_1280:
        ...

    @overload
    def get_item(self, name : Literal['136']) -> Variation_360:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_287:
        ...

    @overload
    def get_item(self, name : Literal['135']) -> Variation_1281:
        ...

    @overload
    def get_item(self, name : Literal['220']) -> Variation_364:
        ...

    @overload
    def get_item(self, name : Literal['390']) -> Variation_1288:
        ...

    @overload
    def get_item(self, name : Literal['270']) -> Variation_290:
        ...

    @overload
    def get_item(self, name : Literal['300']) -> Variation_285:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1301:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1302:
        ...

    @overload
    def get_item(self, name : Literal['510']) -> Variation_1303:
        ...

    @overload
    def get_item(self, name : Literal['500']) -> Variation_1314:
        ...

    @overload
    def get_item(self, name : Literal['340']) -> Variation_1334:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['105'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['185'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['210'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['245'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['380'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['290'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['295'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['136'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['135'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['220'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['390'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['270'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['300'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['510'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['500'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['340'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1339':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1339':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1340_Arg : TypeAlias = Raw
class Variation_1340(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Operational',
        1: 'Degraded',
        2: 'Initialization',
        3: 'Not currently connected',
    }

    def __init__(self, arg : Variation_1340_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1341_Arg : TypeAlias = Raw
class Variation_1341(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'PSR GO',
        1: 'PSR NOGO',
    }

    def __init__(self, arg : Variation_1341_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1342_Arg : TypeAlias = Raw
class Variation_1342(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'SSR GO',
        1: 'SSR NOGO',
    }

    def __init__(self, arg : Variation_1342_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1343_Arg : TypeAlias = Raw
class Variation_1343(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 1
    table = {
        0: 'MDS GO',
        1: 'MDS NOGO',
    }

    def __init__(self, arg : Variation_1343_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1344_Arg : TypeAlias = Raw
class Variation_1344(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'ADS GO',
        1: 'ADS NOGO',
    }

    def __init__(self, arg : Variation_1344_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1345_Arg : TypeAlias = Raw
class Variation_1345(Element):
    variation = 'Element'

    bit_offset8 = 6
    bit_size = 1
    table = {
        0: 'MLT GO',
        1: 'MLT NOGO',
    }

    def __init__(self, arg : Variation_1345_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1346_Arg : TypeAlias = Raw
class Variation_1346(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'System is released for operational use',
        1: 'Operational use of System is inhibited',
    }

    def __init__(self, arg : Variation_1346_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1347_Arg : TypeAlias = Raw
class Variation_1347(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Monitoring system connected',
        1: 'Monitoring system disconnected',
    }

    def __init__(self, arg : Variation_1347_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1348_Arg : TypeAlias = Raw
class Variation_1348(Element):
    variation = 'Element'

    bit_offset8 = 5
    bit_size = 1
    table = {
        0: 'Default (no meaning)',
        1: 'No plots being received',
    }

    def __init__(self, arg : Variation_1348_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1349_Arg_Group_1 = TypedDict('Variation_1349_Arg_Group_1', {
    'CON': Union[Variation_1340, Variation_1340_Arg],
    'PSR': Union[Variation_1341, Variation_1341_Arg],
    'SSR': Union[Variation_1342, Variation_1342_Arg],
    'MDS': Union[Variation_1343, Variation_1343_Arg],
    'ADS': Union[Variation_1344, Variation_1344_Arg],
    'MLT': Union[Variation_1345, Variation_1345_Arg],
})
Variation_1349_Arg_Group_2 = TypedDict('Variation_1349_Arg_Group_2', {
    'CON': Union[Variation_1340, Variation_1340_Arg],
    'PSR': Union[Variation_1341, Variation_1341_Arg],
    'SSR': Union[Variation_1342, Variation_1342_Arg],
    'MDS': Union[Variation_1343, Variation_1343_Arg],
    'ADS': Union[Variation_1344, Variation_1344_Arg],
    'MLT': Union[Variation_1345, Variation_1345_Arg],
    'OPS': Union[Variation_1346, Variation_1346_Arg],
    'ODP': Union[Variation_935, Variation_935_Arg],
    'OXT': Union[Variation_936, Variation_936_Arg],
    'MSC': Union[Variation_1347, Variation_1347_Arg],
    'TSV': Union[Variation_938, Variation_938_Arg],
    'NPW': Union[Variation_1348, Variation_1348_Arg],
})
Variation_1349_Arg : TypeAlias = Union[
    int,
    Variation_1349_Arg_Group_1,
    Tuple[int],
    Variation_1349_Arg_Group_2,
    Tuple[int,int],
]
class Variation_1349(Extended):
    variation = 'Extended'

    no_trailing_fx = False
    groups_bit_sizes = [
        7,
        7,
    ]

    subitems_list = [
        [
            ('CON', Variation_1340),
            ('PSR', Variation_1341),
            ('SSR', Variation_1342),
            ('MDS', Variation_1343),
            ('ADS', Variation_1344),
            ('MLT', Variation_1345),
        ],
        [
            ('OPS', Variation_1346),
            ('ODP', Variation_935),
            ('OXT', Variation_936),
            ('MSC', Variation_1347),
            ('TSV', Variation_938),
            ('NPW', Variation_1348),
            Spare(6, 1),
        ],
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CON': ('', Variation_1340, 0, 2),
        'PSR': ('', Variation_1341, 2, 1),
        'SSR': ('', Variation_1342, 3, 1),
        'MDS': ('', Variation_1343, 4, 1),
        'ADS': ('', Variation_1344, 5, 1),
        'MLT': ('', Variation_1345, 6, 1),
        'OPS': ('Operational Release Status of the System', Variation_1346, 0, 1),
        'ODP': ('Data Processor Overload Indicator', Variation_935, 1, 1),
        'OXT': ('Transmission Subsystem Overload Status', Variation_936, 2, 1),
        'MSC': ('Monitoring System Connected Status', Variation_1347, 3, 1),
        'TSV': ('Time Source Validity', Variation_938, 4, 1),
        'NPW': ('No Plot Warning', Variation_1348, 5, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CON']) -> Type[Variation_1340]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSR']) -> Type[Variation_1341]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SSR']) -> Type[Variation_1342]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MDS']) -> Type[Variation_1343]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ADS']) -> Type[Variation_1344]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MLT']) -> Type[Variation_1345]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OPS']) -> Type[Variation_1346]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ODP']) -> Type[Variation_935]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OXT']) -> Type[Variation_936]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MSC']) -> Type[Variation_1347]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSV']) -> Type[Variation_938]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NPW']) -> Type[Variation_1348]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CON'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['MLT'], Literal['OPS'], Literal['ODP'], Literal['OXT'], Literal['MSC'], Literal['TSV'], Literal['NPW']]) -> Union[Type['Variation_1340'], Type['Variation_1341'], Type['Variation_1342'], Type['Variation_1343'], Type['Variation_1344'], Type['Variation_1345'], Type['Variation_1346'], Type['Variation_935'], Type['Variation_936'], Type['Variation_1347'], Type['Variation_938'], Type['Variation_1348']]:
        if key == 'CON':
            return Variation_1340
        if key == 'PSR':
            return Variation_1341
        if key == 'SSR':
            return Variation_1342
        if key == 'MDS':
            return Variation_1343
        if key == 'ADS':
            return Variation_1344
        if key == 'MLT':
            return Variation_1345
        if key == 'OPS':
            return Variation_1346
        if key == 'ODP':
            return Variation_935
        if key == 'OXT':
            return Variation_936
        if key == 'MSC':
            return Variation_1347
        if key == 'TSV':
            return Variation_938
        if key == 'NPW':
            return Variation_1348
        assert_never(key)

    def __init__(self, arg : Variation_1349_Arg) -> None:
        if isinstance(arg, int):
            super().__init__(*self._from_single_int(0, arg, False)); return
        if isinstance(arg, tuple):
            if isinstance(arg[0], Bits):
                super().__init__(*arg); return
            super().__init__(*self._from_tuple_int(arg)); return
        if isinstance(arg, dict):
            if Variation_1349_Arg_Group_1.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(1, arg)); return
            if Variation_1349_Arg_Group_2.__required_keys__ == arg.keys():
                super().__init__(*self._from_dict(2, arg)); return
            raise Exception('internal error: unexpected argument')
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CON']) -> Variation_1340:
        ...

    @overload
    def get_item(self, name : Literal['PSR']) -> Variation_1341:
        ...

    @overload
    def get_item(self, name : Literal['SSR']) -> Variation_1342:
        ...

    @overload
    def get_item(self, name : Literal['MDS']) -> Variation_1343:
        ...

    @overload
    def get_item(self, name : Literal['ADS']) -> Variation_1344:
        ...

    @overload
    def get_item(self, name : Literal['MLT']) -> Variation_1345:
        ...

    @overload
    def get_item(self, name : Literal['OPS']) -> Variation_1346:
        ...

    @overload
    def get_item(self, name : Literal['ODP']) -> Variation_935:
        ...

    @overload
    def get_item(self, name : Literal['OXT']) -> Variation_936:
        ...

    @overload
    def get_item(self, name : Literal['MSC']) -> Variation_1347:
        ...

    @overload
    def get_item(self, name : Literal['TSV']) -> Variation_938:
        ...

    @overload
    def get_item(self, name : Literal['NPW']) -> Variation_1348:
        ...

    def get_item(self, name : Union[Literal['CON'], Literal['PSR'], Literal['SSR'], Literal['MDS'], Literal['ADS'], Literal['MLT'], Literal['OPS'], Literal['ODP'], Literal['OXT'], Literal['MSC'], Literal['TSV'], Literal['NPW']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CON'], val : Union[Variation_1340, Variation_1340_Arg]) -> 'Variation_1349':
        ...

    @overload
    def set_item(self, name : Literal['PSR'], val : Union[Variation_1341, Variation_1341_Arg]) -> 'Variation_1349':
        ...

    @overload
    def set_item(self, name : Literal['SSR'], val : Union[Variation_1342, Variation_1342_Arg]) -> 'Variation_1349':
        ...

    @overload
    def set_item(self, name : Literal['MDS'], val : Union[Variation_1343, Variation_1343_Arg]) -> 'Variation_1349':
        ...

    @overload
    def set_item(self, name : Literal['ADS'], val : Union[Variation_1344, Variation_1344_Arg]) -> 'Variation_1349':
        ...

    @overload
    def set_item(self, name : Literal['MLT'], val : Union[Variation_1345, Variation_1345_Arg]) -> 'Variation_1349':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CON'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['PSR'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['SSR'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['MDS'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['ADS'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['MLT'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['OPS'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['ODP'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['OXT'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['MSC'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['TSV'], f : Any) -> 'Variation_1349':
        ...

    @overload
    def modify_item(self, name : Literal['NPW'], f : Any) -> 'Variation_1349':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1350_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ms']]]
class Variation_1350(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 1.0, 'ms')

    def __init__(self, arg : Variation_1350_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1351_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['']]]
class Variation_1351(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 1.0e-5, '')

    def __init__(self, arg : Variation_1351_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1352_Arg_Group = TypedDict('Variation_1352_Arg_Group', {
    'SRG': Union[Variation_1351, Variation_1351_Arg],
    'SRB': Union[Variation_596, Variation_596_Arg],
})
Variation_1352_Arg : TypeAlias = Union[Raw, Variation_1352_Arg_Group]
class Variation_1352(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('SRG', Variation_1351),
        ('SRB', Variation_596),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'SRG': ('Mode S Range Gain', Variation_1351, 0, 16),
        'SRB': ('Mode S Range Bias', Variation_596, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['SRG']) -> Type[Variation_1351]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SRB']) -> Type[Variation_596]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['SRG'], Literal['SRB']]) -> Union[Type['Variation_1351'], Type['Variation_596']]:
        if key == 'SRG':
            return Variation_1351
        if key == 'SRB':
            return Variation_596
        assert_never(key)

    def __init__(self, arg : Variation_1352_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['SRG']) -> Variation_1351:
        ...

    @overload
    def get_item(self, name : Literal['SRB']) -> Variation_596:
        ...

    def get_item(self, name : Union[Literal['SRG'], Literal['SRB']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['SRG'], val : Union[Variation_1351, Variation_1351_Arg]) -> 'Variation_1352':
        ...

    @overload
    def set_item(self, name : Literal['SRB'], val : Union[Variation_596, Variation_596_Arg]) -> 'Variation_1352':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['SRG'], f : Any) -> 'Variation_1352':
        ...

    @overload
    def modify_item(self, name : Literal['SRB'], f : Any) -> 'Variation_1352':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1353_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_1353(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 5.4931640625e-3, '°')

    def __init__(self, arg : Variation_1353_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1354_Arg_Group = TypedDict('Variation_1354_Arg_Group', {
    'PRG': Union[Variation_1351, Variation_1351_Arg],
    'PRB': Union[Variation_596, Variation_596_Arg],
})
Variation_1354_Arg : TypeAlias = Union[Raw, Variation_1354_Arg_Group]
class Variation_1354(Group):
    variation = 'Group'

    bit_size = 32

    subitems_list = [
        ('PRG', Variation_1351),
        ('PRB', Variation_596),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'PRG': ('PSR Range Gain', Variation_1351, 0, 16),
        'PRB': ('PSR Range Bias', Variation_596, 16, 16),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['PRG']) -> Type[Variation_1351]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PRB']) -> Type[Variation_596]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['PRG'], Literal['PRB']]) -> Union[Type['Variation_1351'], Type['Variation_596']]:
        if key == 'PRG':
            return Variation_1351
        if key == 'PRB':
            return Variation_596
        assert_never(key)

    def __init__(self, arg : Variation_1354_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['PRG']) -> Variation_1351:
        ...

    @overload
    def get_item(self, name : Literal['PRB']) -> Variation_596:
        ...

    def get_item(self, name : Union[Literal['PRG'], Literal['PRB']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['PRG'], val : Union[Variation_1351, Variation_1351_Arg]) -> 'Variation_1354':
        ...

    @overload
    def set_item(self, name : Literal['PRB'], val : Union[Variation_596, Variation_596_Arg]) -> 'Variation_1354':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['PRG'], f : Any) -> 'Variation_1354':
        ...

    @overload
    def modify_item(self, name : Literal['PRB'], f : Any) -> 'Variation_1354':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1355_Arg = TypedDict('Variation_1355_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '050': Union[Variation_1, Variation_1_Arg],
    '060': Union[Variation_1349, Variation_1349_Arg],
    '070': Union[Variation_1350, Variation_1350_Arg],
    '080': Union[Variation_1352, Variation_1352_Arg],
    '081': Union[Variation_1353, Variation_1353_Arg],
    '090': Union[Variation_1354, Variation_1354_Arg],
    '091': Union[Variation_1353, Variation_1353_Arg],
    '092': Union[Variation_1353, Variation_1353_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1355(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('015', Variation_0),
        ('030', Variation_80),
        ('050', Variation_1),
        ('060', Variation_1349),
        ('070', Variation_1350),
        ('080', Variation_1352),
        ('081', Variation_1353),
        ('090', Variation_1354),
        ('091', Variation_1353),
        ('092', Variation_1353),
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '015': ('Service Identification', Variation_0, 0x4000),
        '030': ('Time of Message', Variation_80, 0x2000),
        '050': ('Sensor Identifier', Variation_1, 0x1000),
        '060': ('Sensor Configuration and Status', Variation_1349, 0x0800),
        '070': ('Time Stamping Bias', Variation_1350, 0x0400),
        '080': ('SSR / Mode S Range Gain and Bias', Variation_1352, 0x0200),
        '081': ('SSR Mode S Azimuth Bias', Variation_1353, 0x0180),
        '090': ('PSR Range Gain and Bias', Variation_1354, 0x0140),
        '091': ('PSR Azimuth Bias', Variation_1353, 0x0120),
        '092': ('PSR Elevation Bias', Variation_1353, 0x0110),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0104),
        'SP': ('Special Purpose Field', Variation_62, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_1349]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_1350]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_1352]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['081']) -> Type[Variation_1353]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_1354]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['091']) -> Type[Variation_1353]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['092']) -> Type[Variation_1353]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['015'], Literal['030'], Literal['050'], Literal['060'], Literal['070'], Literal['080'], Literal['081'], Literal['090'], Literal['091'], Literal['092'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_0'], Type['Variation_80'], Type['Variation_1'], Type['Variation_1349'], Type['Variation_1350'], Type['Variation_1352'], Type['Variation_1353'], Type['Variation_1354'], Type['Variation_1353'], Type['Variation_1353'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '015':
            return Variation_0
        if key == '030':
            return Variation_80
        if key == '050':
            return Variation_1
        if key == '060':
            return Variation_1349
        if key == '070':
            return Variation_1350
        if key == '080':
            return Variation_1352
        if key == '081':
            return Variation_1353
        if key == '090':
            return Variation_1354
        if key == '091':
            return Variation_1353
        if key == '092':
            return Variation_1353
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1355_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_1349, Variation_1349_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_1350, Variation_1350_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_1352, Variation_1352_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['081'], val : Union[Variation_1353, Variation_1353_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_1354, Variation_1354_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['091'], val : Union[Variation_1353, Variation_1353_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['092'], val : Union[Variation_1353, Variation_1353_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1355':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1355':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['081']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['091']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['092']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1355':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1355':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_1349:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_1350:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_1352:
        ...

    @overload
    def get_item(self, name : Literal['081']) -> Variation_1353:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_1354:
        ...

    @overload
    def get_item(self, name : Literal['091']) -> Variation_1353:
        ...

    @overload
    def get_item(self, name : Literal['092']) -> Variation_1353:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['081'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['091'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['092'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1355':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1355':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1356_Arg : TypeAlias = Raw
class Variation_1356(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'SDPS Status',
        2: 'End of Batch',
        3: 'Service Status Report',
    }

    def __init__(self, arg : Variation_1356_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1357_Arg : TypeAlias = Raw
class Variation_1357(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2
    table = {
        0: 'Operational',
        1: 'Degraded',
        2: 'Not currently connected',
        3: 'Unknown',
    }

    def __init__(self, arg : Variation_1357_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1358_Arg : TypeAlias = Raw
class Variation_1358(Element):
    variation = 'Element'

    bit_offset8 = 2
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Overload',
    }

    def __init__(self, arg : Variation_1358_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1359_Arg : TypeAlias = Raw
class Variation_1359(Element):
    variation = 'Element'

    bit_offset8 = 3
    bit_size = 1
    table = {
        0: 'Default',
        1: 'Invalid Time Source',
    }

    def __init__(self, arg : Variation_1359_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1360_Arg : TypeAlias = Raw
class Variation_1360(Element):
    variation = 'Element'

    bit_offset8 = 4
    bit_size = 2
    table = {
        0: 'Not applicable',
        1: 'SDPS-1 selected',
        2: 'SDPS-2 selected',
        3: 'SDPS-3 selected',
    }

    def __init__(self, arg : Variation_1360_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1361_Arg_Group = TypedDict('Variation_1361_Arg_Group', {
    'NOGO': Union[Variation_1357, Variation_1357_Arg],
    'OVL': Union[Variation_1358, Variation_1358_Arg],
    'TSV': Union[Variation_1359, Variation_1359_Arg],
    'PSS': Union[Variation_1360, Variation_1360_Arg],
    'STTN': Union[Variation_978, Variation_978_Arg],
})
Variation_1361_Arg : TypeAlias = Union[Raw, Variation_1361_Arg_Group]
class Variation_1361(Group):
    variation = 'Group'

    bit_size = 8

    subitems_list = [
        ('NOGO', Variation_1357),
        ('OVL', Variation_1358),
        ('TSV', Variation_1359),
        ('PSS', Variation_1360),
        ('STTN', Variation_978),
        Spare(7, 1),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NOGO': ('', Variation_1357, 0, 2),
        'OVL': ('', Variation_1358, 2, 1),
        'TSV': ('', Variation_1359, 3, 1),
        'PSS': ('Processing System Status', Variation_1360, 4, 2),
        'STTN': ('Track Re-numbering Indication', Variation_978, 6, 1),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NOGO']) -> Type[Variation_1357]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['OVL']) -> Type[Variation_1358]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['TSV']) -> Type[Variation_1359]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['PSS']) -> Type[Variation_1360]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STTN']) -> Type[Variation_978]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NOGO'], Literal['OVL'], Literal['TSV'], Literal['PSS'], Literal['STTN']]) -> Union[Type['Variation_1357'], Type['Variation_1358'], Type['Variation_1359'], Type['Variation_1360'], Type['Variation_978']]:
        if key == 'NOGO':
            return Variation_1357
        if key == 'OVL':
            return Variation_1358
        if key == 'TSV':
            return Variation_1359
        if key == 'PSS':
            return Variation_1360
        if key == 'STTN':
            return Variation_978
        assert_never(key)

    def __init__(self, arg : Variation_1361_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NOGO']) -> Variation_1357:
        ...

    @overload
    def get_item(self, name : Literal['OVL']) -> Variation_1358:
        ...

    @overload
    def get_item(self, name : Literal['TSV']) -> Variation_1359:
        ...

    @overload
    def get_item(self, name : Literal['PSS']) -> Variation_1360:
        ...

    @overload
    def get_item(self, name : Literal['STTN']) -> Variation_978:
        ...

    def get_item(self, name : Union[Literal['NOGO'], Literal['OVL'], Literal['TSV'], Literal['PSS'], Literal['STTN']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NOGO'], val : Union[Variation_1357, Variation_1357_Arg]) -> 'Variation_1361':
        ...

    @overload
    def set_item(self, name : Literal['OVL'], val : Union[Variation_1358, Variation_1358_Arg]) -> 'Variation_1361':
        ...

    @overload
    def set_item(self, name : Literal['TSV'], val : Union[Variation_1359, Variation_1359_Arg]) -> 'Variation_1361':
        ...

    @overload
    def set_item(self, name : Literal['PSS'], val : Union[Variation_1360, Variation_1360_Arg]) -> 'Variation_1361':
        ...

    @overload
    def set_item(self, name : Literal['STTN'], val : Union[Variation_978, Variation_978_Arg]) -> 'Variation_1361':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NOGO'], f : Any) -> 'Variation_1361':
        ...

    @overload
    def modify_item(self, name : Literal['OVL'], f : Any) -> 'Variation_1361':
        ...

    @overload
    def modify_item(self, name : Literal['TSV'], f : Any) -> 'Variation_1361':
        ...

    @overload
    def modify_item(self, name : Literal['PSS'], f : Any) -> 'Variation_1361':
        ...

    @overload
    def modify_item(self, name : Literal['STTN'], f : Any) -> 'Variation_1361':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1362_Arg : TypeAlias = Raw
class Variation_1362(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Service degradation',
        2: 'Service degradation ended',
        3: 'Main radar out of service',
        4: 'Service interrupted by the operator',
        5: 'Service interrupted due to contingency',
        6: 'Ready for service restart after contingency',
        7: 'Service ended by the operator',
        8: 'Failure of user main radar',
        9: 'Service restarted by the operator',
        10: 'Main radar becoming operational',
        11: 'Main radar becoming degraded',
        12: 'Service continuity interrupted due to disconnection with adjacent unit',
        13: 'Service continuity restarted',
        14: 'Service synchronised on backup radar',
        15: 'Service synchronised on main radar',
        16: 'Main and backup radar, if any, failed',
    }

    def __init__(self, arg : Variation_1362_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1363_Arg = TypedDict('Variation_1363_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_1356, Variation_1356_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '020': Union[Variation_0, Variation_0_Arg],
    '040': Union[Variation_1361, Variation_1361_Arg],
    '050': Union[Variation_1362, Variation_1362_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1363(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_1356),
        ('015', Variation_0),
        ('030', Variation_80),
        ('020', Variation_0),
        ('040', Variation_1361),
        ('050', Variation_1362),
        None,
        None,
        None,
        None,
        None,
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Message Type', Variation_1356, 0x4000),
        '015': ('Service Identification', Variation_0, 0x2000),
        '030': ('Time of Message', Variation_80, 0x1000),
        '020': ('Batch Number', Variation_0, 0x0800),
        '040': ('SDPS Configuration and Status', Variation_1361, 0x0400),
        '050': ('Service Status Report', Variation_1362, 0x0200),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0104),
        'SP': ('Special Purpose Field', Variation_62, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_1356]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_1361]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_1362]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['015'], Literal['030'], Literal['020'], Literal['040'], Literal['050'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_1356'], Type['Variation_0'], Type['Variation_80'], Type['Variation_0'], Type['Variation_1361'], Type['Variation_1362'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_1356
        if key == '015':
            return Variation_0
        if key == '030':
            return Variation_80
        if key == '020':
            return Variation_0
        if key == '040':
            return Variation_1361
        if key == '050':
            return Variation_1362
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1363_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1363':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_1356, Variation_1356_Arg]) -> 'Variation_1363':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1363':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1363':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1363':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_1361, Variation_1361_Arg]) -> 'Variation_1363':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_1362, Variation_1362_Arg]) -> 'Variation_1363':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1363':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1363':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1363':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_1363':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_1363':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1363':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1363':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1363':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1363':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1363':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1363':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_1356:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_1361:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_1362:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1363':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_1363':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_1363':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1363':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1363':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1363':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1363':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1363':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1363':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1364_Arg : TypeAlias = Raw
class Variation_1364(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'System Position Report',
        2: 'System Bearing Report',
        3: 'System Position Report of conflicting transmission',
        4: 'System Detection End Report',
        5: 'Sensor Data Report',
    }

    def __init__(self, arg : Variation_1364_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1365_Arg_Group = TypedDict('Variation_1365_Arg_Group', {
    'LAT': Union[Variation_147, Variation_147_Arg],
    'LON': Union[Variation_147, Variation_147_Arg],
})
Variation_1365_Arg : TypeAlias = Union[Raw, Variation_1365_Arg_Group]
class Variation_1365(Group):
    variation = 'Group'

    bit_size = 64

    subitems_list = [
        ('LAT', Variation_147),
        ('LON', Variation_147),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'LAT': ('Latitude in WGS-84', Variation_147, 0, 32),
        'LON': ('Longitude in WGS-84', Variation_147, 32, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['LAT']) -> Type[Variation_147]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['LON']) -> Type[Variation_147]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['LAT'], Literal['LON']]) -> Union[Type['Variation_147'], Type['Variation_147']]:
        if key == 'LAT':
            return Variation_147
        if key == 'LON':
            return Variation_147
        assert_never(key)

    def __init__(self, arg : Variation_1365_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['LAT']) -> Variation_147:
        ...

    @overload
    def get_item(self, name : Literal['LON']) -> Variation_147:
        ...

    def get_item(self, name : Union[Literal['LAT'], Literal['LON']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['LAT'], val : Union[Variation_147, Variation_147_Arg]) -> 'Variation_1365':
        ...

    @overload
    def set_item(self, name : Literal['LON'], val : Union[Variation_147, Variation_147_Arg]) -> 'Variation_1365':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['LAT'], f : Any) -> 'Variation_1365':
        ...

    @overload
    def modify_item(self, name : Literal['LON'], f : Any) -> 'Variation_1365':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1366_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['°']]]
class Variation_1366(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Unsigned', 1.0e-2, '°')

    def __init__(self, arg : Variation_1366_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1367_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['m']]]
class Variation_1367(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    quantity = Quantity('Unsigned', 100.0, 'm')

    def __init__(self, arg : Variation_1367_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1368_Arg : TypeAlias = Union[Variation_0, Variation_0_Arg]
class Variation_1368(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 8
    variation_type = Variation_0

    @classmethod
    def spec(cls) -> Type[Variation_0]:
        return Variation_0

    def __init__(self, arg : List[Union[Variation_0, Variation_0_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1368':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1368':
        return self._prepend_item(arg) # type: ignore

Variation_1369_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['dBµV']]]
class Variation_1369(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 16
    quantity = Quantity('Signed', 1.0e-2, 'dBµV')

    def __init__(self, arg : Variation_1369_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1370_Arg = TypedDict('Variation_1370_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '000': Union[Variation_1364, Variation_1364_Arg],
    '030': Union[Variation_80, Variation_80_Arg],
    '040': Union[Variation_0, Variation_0_Arg],
    '090': Union[Variation_145, Variation_145_Arg],
    '050': Union[Variation_1365, Variation_1365_Arg],
    '060': Union[Variation_650, Variation_650_Arg],
    '070': Union[Variation_1366, Variation_1366_Arg],
    '080': Union[Variation_1366, Variation_1366_Arg],
    '100': Union[Variation_0, Variation_0_Arg],
    '110': Union[Variation_1367, Variation_1367_Arg],
    '120': Union[Variation_1368, Variation_1368_Arg],
    '130': Union[Variation_1365, Variation_1365_Arg],
    '140': Union[Variation_650, Variation_650_Arg],
    '150': Union[Variation_1367, Variation_1367_Arg],
    '160': Union[Variation_64, Variation_64_Arg],
    '170': Union[Variation_0, Variation_0_Arg],
    '180': Union[Variation_1369, Variation_1369_Arg],
    '190': Union[Variation_0, Variation_0_Arg],
    '200': Union[Variation_717, Variation_717_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1370(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 4

    subitems_list = [
        ('010', Variation_1),
        ('015', Variation_0),
        ('000', Variation_1364),
        ('030', Variation_80),
        ('040', Variation_0),
        ('090', Variation_145),
        ('050', Variation_1365),
        ('060', Variation_650),
        ('070', Variation_1366),
        ('080', Variation_1366),
        ('100', Variation_0),
        ('110', Variation_1367),
        ('120', Variation_1368),
        ('130', Variation_1365),
        ('140', Variation_650),
        ('150', Variation_1367),
        ('160', Variation_64),
        ('170', Variation_0),
        ('180', Variation_1369),
        ('190', Variation_0),
        ('200', Variation_717),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80000000),
        '015': ('Service Identification', Variation_0, 0x40000000),
        '000': ('Message Type', Variation_1364, 0x20000000),
        '030': ('Time of Day', Variation_80, 0x10000000),
        '040': ('Report Number', Variation_0, 0x08000000),
        '090': ('Radio Channel Name', Variation_145, 0x04000000),
        '050': ('Position in WGS-84 Coordinates', Variation_1365, 0x02000000),
        '060': ('Position in Cartesian Coordinates', Variation_650, 0x01800000),
        '070': ('Local Bearing', Variation_1366, 0x01400000),
        '080': ('System Bearing', Variation_1366, 0x01200000),
        '100': ('Quality of Measurement', Variation_0, 0x01100000),
        '110': ('Estimated Uncertainty', Variation_1367, 0x01080000),
        '120': ('Contributing Sensors', Variation_1368, 0x01040000),
        '130': ('Conflicting Transmitter Position in WGS-84 Coordinates', Variation_1365, 0x01020000),
        '140': ('Conflicting Transmitter Position in Cartesian Coordinates', Variation_650, 0x01018000),
        '150': ('Conflicting Transmitter Estimated Uncertainty', Variation_1367, 0x01014000),
        '160': ('Track Number', Variation_64, 0x01012000),
        '170': ('Sensor Identification', Variation_0, 0x01011000),
        '180': ('Signal Level', Variation_1369, 0x01010800),
        '190': ('Signal Quality', Variation_0, 0x01010400),
        '200': ('Signal Elevation', Variation_717, 0x01010200),
        'SP': ('Special Purpose Field', Variation_62, 0x01010180),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_1364]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['090']) -> Type[Variation_145]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_1365]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['060']) -> Type[Variation_650]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['070']) -> Type[Variation_1366]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['080']) -> Type[Variation_1366]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['100']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['110']) -> Type[Variation_1367]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['120']) -> Type[Variation_1368]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['130']) -> Type[Variation_1365]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_650]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['150']) -> Type[Variation_1367]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['160']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['170']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['180']) -> Type[Variation_1369]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['190']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['200']) -> Type[Variation_717]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['015'], Literal['000'], Literal['030'], Literal['040'], Literal['090'], Literal['050'], Literal['060'], Literal['070'], Literal['080'], Literal['100'], Literal['110'], Literal['120'], Literal['130'], Literal['140'], Literal['150'], Literal['160'], Literal['170'], Literal['180'], Literal['190'], Literal['200'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_0'], Type['Variation_1364'], Type['Variation_80'], Type['Variation_0'], Type['Variation_145'], Type['Variation_1365'], Type['Variation_650'], Type['Variation_1366'], Type['Variation_1366'], Type['Variation_0'], Type['Variation_1367'], Type['Variation_1368'], Type['Variation_1365'], Type['Variation_650'], Type['Variation_1367'], Type['Variation_64'], Type['Variation_0'], Type['Variation_1369'], Type['Variation_0'], Type['Variation_717'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '015':
            return Variation_0
        if key == '000':
            return Variation_1364
        if key == '030':
            return Variation_80
        if key == '040':
            return Variation_0
        if key == '090':
            return Variation_145
        if key == '050':
            return Variation_1365
        if key == '060':
            return Variation_650
        if key == '070':
            return Variation_1366
        if key == '080':
            return Variation_1366
        if key == '100':
            return Variation_0
        if key == '110':
            return Variation_1367
        if key == '120':
            return Variation_1368
        if key == '130':
            return Variation_1365
        if key == '140':
            return Variation_650
        if key == '150':
            return Variation_1367
        if key == '160':
            return Variation_64
        if key == '170':
            return Variation_0
        if key == '180':
            return Variation_1369
        if key == '190':
            return Variation_0
        if key == '200':
            return Variation_717
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1370_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_1364, Variation_1364_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['090'], val : Union[Variation_145, Variation_145_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_1365, Variation_1365_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['060'], val : Union[Variation_650, Variation_650_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['070'], val : Union[Variation_1366, Variation_1366_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['080'], val : Union[Variation_1366, Variation_1366_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['100'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['110'], val : Union[Variation_1367, Variation_1367_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['120'], val : Union[Variation_1368, Variation_1368_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['130'], val : Union[Variation_1365, Variation_1365_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_650, Variation_650_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['150'], val : Union[Variation_1367, Variation_1367_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['160'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['170'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['180'], val : Union[Variation_1369, Variation_1369_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['190'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['200'], val : Union[Variation_717, Variation_717_Arg]) -> 'Variation_1370':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1370':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['090']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['060']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['070']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['080']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['100']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['110']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['120']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['130']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['150']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['160']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['170']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['180']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['190']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['200']) -> 'Variation_1370':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1370':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_1364:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['090']) -> Variation_145:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_1365:
        ...

    @overload
    def get_item(self, name : Literal['060']) -> Variation_650:
        ...

    @overload
    def get_item(self, name : Literal['070']) -> Variation_1366:
        ...

    @overload
    def get_item(self, name : Literal['080']) -> Variation_1366:
        ...

    @overload
    def get_item(self, name : Literal['100']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['110']) -> Variation_1367:
        ...

    @overload
    def get_item(self, name : Literal['120']) -> Variation_1368:
        ...

    @overload
    def get_item(self, name : Literal['130']) -> Variation_1365:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_650:
        ...

    @overload
    def get_item(self, name : Literal['150']) -> Variation_1367:
        ...

    @overload
    def get_item(self, name : Literal['160']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['170']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['180']) -> Variation_1369:
        ...

    @overload
    def get_item(self, name : Literal['190']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['200']) -> Variation_717:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['090'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['060'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['070'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['080'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['100'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['110'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['120'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['130'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['150'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['160'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['170'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['180'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['190'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['200'], f : Any) -> 'Variation_1370':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1370':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1371_Arg : TypeAlias = Raw
class Variation_1371(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Video Summary message',
        2: 'Video message',
    }

    def __init__(self, arg : Variation_1371_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1372_Arg : TypeAlias = Union[Variation_990, Variation_990_Arg]
class Variation_1372(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 8
    variation_type = Variation_990

    @classmethod
    def spec(cls) -> Type[Variation_990]:
        return Variation_990

    def __init__(self, arg : List[Union[Variation_990, Variation_990_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_990, Variation_990_Arg]) -> 'Variation_1372':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_990, Variation_990_Arg]) -> 'Variation_1372':
        return self._prepend_item(arg) # type: ignore

Variation_1373_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['ns']]]
class Variation_1373(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 32
    quantity = Quantity('Unsigned', 1.0, 'ns')

    def __init__(self, arg : Variation_1373_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1374_Arg_Group = TypedDict('Variation_1374_Arg_Group', {
    'STARTAZ': Union[Variation_14, Variation_14_Arg],
    'ENDAZ': Union[Variation_14, Variation_14_Arg],
    'STARTRG': Union[Variation_555, Variation_555_Arg],
    'CELLDUR': Union[Variation_1373, Variation_1373_Arg],
})
Variation_1374_Arg : TypeAlias = Union[Raw, Variation_1374_Arg_Group]
class Variation_1374(Group):
    variation = 'Group'

    bit_size = 96

    subitems_list = [
        ('STARTAZ', Variation_14),
        ('ENDAZ', Variation_14),
        ('STARTRG', Variation_555),
        ('CELLDUR', Variation_1373),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STARTAZ': ('Start Azimuth of the Cells Group', Variation_14, 0, 16),
        'ENDAZ': ('End Azimuth of the Cells Group', Variation_14, 16, 16),
        'STARTRG': ('Starting Range of the Cells Group, Expressed in Number of Cells', Variation_555, 32, 32),
        'CELLDUR': ('Video Cell Duration in Nano-seconds', Variation_1373, 64, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['STARTAZ']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ENDAZ']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STARTRG']) -> Type[Variation_555]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CELLDUR']) -> Type[Variation_1373]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['STARTAZ'], Literal['ENDAZ'], Literal['STARTRG'], Literal['CELLDUR']]) -> Union[Type['Variation_14'], Type['Variation_14'], Type['Variation_555'], Type['Variation_1373']]:
        if key == 'STARTAZ':
            return Variation_14
        if key == 'ENDAZ':
            return Variation_14
        if key == 'STARTRG':
            return Variation_555
        if key == 'CELLDUR':
            return Variation_1373
        assert_never(key)

    def __init__(self, arg : Variation_1374_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['STARTAZ']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['ENDAZ']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['STARTRG']) -> Variation_555:
        ...

    @overload
    def get_item(self, name : Literal['CELLDUR']) -> Variation_1373:
        ...

    def get_item(self, name : Union[Literal['STARTAZ'], Literal['ENDAZ'], Literal['STARTRG'], Literal['CELLDUR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['STARTAZ'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1374':
        ...

    @overload
    def set_item(self, name : Literal['ENDAZ'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1374':
        ...

    @overload
    def set_item(self, name : Literal['STARTRG'], val : Union[Variation_555, Variation_555_Arg]) -> 'Variation_1374':
        ...

    @overload
    def set_item(self, name : Literal['CELLDUR'], val : Union[Variation_1373, Variation_1373_Arg]) -> 'Variation_1374':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['STARTAZ'], f : Any) -> 'Variation_1374':
        ...

    @overload
    def modify_item(self, name : Literal['ENDAZ'], f : Any) -> 'Variation_1374':
        ...

    @overload
    def modify_item(self, name : Literal['STARTRG'], f : Any) -> 'Variation_1374':
        ...

    @overload
    def modify_item(self, name : Literal['CELLDUR'], f : Any) -> 'Variation_1374':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1375_Arg : TypeAlias = Union[Raw,float,Tuple[float,Literal['fs']]]
class Variation_1375(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 32
    quantity = Quantity('Unsigned', 1.0, 'fs')

    def __init__(self, arg : Variation_1375_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        if isinstance(arg, float):
            super().__init__(self._from_float(arg)); return
        if isinstance(arg, tuple):
            super().__init__(self._from_float(arg[0])); return
        assert_never(arg)



    def to_quantity(self) -> float:
        return self._to_quantity()

Variation_1376_Arg_Group = TypedDict('Variation_1376_Arg_Group', {
    'STARTAZ': Union[Variation_14, Variation_14_Arg],
    'ENDAZ': Union[Variation_14, Variation_14_Arg],
    'STARTRG': Union[Variation_555, Variation_555_Arg],
    'CELLDUR': Union[Variation_1375, Variation_1375_Arg],
})
Variation_1376_Arg : TypeAlias = Union[Raw, Variation_1376_Arg_Group]
class Variation_1376(Group):
    variation = 'Group'

    bit_size = 96

    subitems_list = [
        ('STARTAZ', Variation_14),
        ('ENDAZ', Variation_14),
        ('STARTRG', Variation_555),
        ('CELLDUR', Variation_1375),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'STARTAZ': ('Start Azimuth of the Cells Group', Variation_14, 0, 16),
        'ENDAZ': ('End Azimuth of the Cells Group', Variation_14, 16, 16),
        'STARTRG': ('Starting Range of the Cells Group, Expressed in Number of Cells', Variation_555, 32, 32),
        'CELLDUR': ('Video Cell Duration in Femto-seconds', Variation_1375, 64, 32),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['STARTAZ']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['ENDAZ']) -> Type[Variation_14]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['STARTRG']) -> Type[Variation_555]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['CELLDUR']) -> Type[Variation_1375]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['STARTAZ'], Literal['ENDAZ'], Literal['STARTRG'], Literal['CELLDUR']]) -> Union[Type['Variation_14'], Type['Variation_14'], Type['Variation_555'], Type['Variation_1375']]:
        if key == 'STARTAZ':
            return Variation_14
        if key == 'ENDAZ':
            return Variation_14
        if key == 'STARTRG':
            return Variation_555
        if key == 'CELLDUR':
            return Variation_1375
        assert_never(key)

    def __init__(self, arg : Variation_1376_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['STARTAZ']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['ENDAZ']) -> Variation_14:
        ...

    @overload
    def get_item(self, name : Literal['STARTRG']) -> Variation_555:
        ...

    @overload
    def get_item(self, name : Literal['CELLDUR']) -> Variation_1375:
        ...

    def get_item(self, name : Union[Literal['STARTAZ'], Literal['ENDAZ'], Literal['STARTRG'], Literal['CELLDUR']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['STARTAZ'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1376':
        ...

    @overload
    def set_item(self, name : Literal['ENDAZ'], val : Union[Variation_14, Variation_14_Arg]) -> 'Variation_1376':
        ...

    @overload
    def set_item(self, name : Literal['STARTRG'], val : Union[Variation_555, Variation_555_Arg]) -> 'Variation_1376':
        ...

    @overload
    def set_item(self, name : Literal['CELLDUR'], val : Union[Variation_1375, Variation_1375_Arg]) -> 'Variation_1376':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['STARTAZ'], f : Any) -> 'Variation_1376':
        ...

    @overload
    def modify_item(self, name : Literal['ENDAZ'], f : Any) -> 'Variation_1376':
        ...

    @overload
    def modify_item(self, name : Literal['STARTRG'], f : Any) -> 'Variation_1376':
        ...

    @overload
    def modify_item(self, name : Literal['CELLDUR'], f : Any) -> 'Variation_1376':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1377_Arg : TypeAlias = Raw
class Variation_1377(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 1
    table = {
        0: 'No compression applied',
        1: 'Compression applied',
    }

    def __init__(self, arg : Variation_1377_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1378_Arg : TypeAlias = Raw
class Variation_1378(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 8
    table = {
        1: 'Monobit Resolution (1 bit)',
        2: 'Low Resolution (2 bits)',
        3: 'Medium Resolution (4 bits)',
        4: 'High Resolution (8 bits)',
        5: 'Very High Resolution (16 bits)',
        6: 'Ultra High Resolution (32 bits)',
    }

    def __init__(self, arg : Variation_1378_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)

    @property
    def table_value(self) -> Optional[str]:
        return self.__class__.table.get(self.to_uinteger())



Variation_1379_Arg_Group = TypedDict('Variation_1379_Arg_Group', {
    'C': Union[Variation_1377, Variation_1377_Arg],
    'RES': Union[Variation_1378, Variation_1378_Arg],
})
Variation_1379_Arg : TypeAlias = Union[Raw, Variation_1379_Arg_Group]
class Variation_1379(Group):
    variation = 'Group'

    bit_size = 16

    subitems_list = [
        ('C', Variation_1377),
        Spare(1, 7),
        ('RES', Variation_1378),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'C': ('Data Compression Indicator', Variation_1377, 0, 1),
        'RES': ('Bit Resolution', Variation_1378, 8, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['C']) -> Type[Variation_1377]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RES']) -> Type[Variation_1378]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['C'], Literal['RES']]) -> Union[Type['Variation_1377'], Type['Variation_1378']]:
        if key == 'C':
            return Variation_1377
        if key == 'RES':
            return Variation_1378
        assert_never(key)

    def __init__(self, arg : Variation_1379_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['C']) -> Variation_1377:
        ...

    @overload
    def get_item(self, name : Literal['RES']) -> Variation_1378:
        ...

    def get_item(self, name : Union[Literal['C'], Literal['RES']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['C'], val : Union[Variation_1377, Variation_1377_Arg]) -> 'Variation_1379':
        ...

    @overload
    def set_item(self, name : Literal['RES'], val : Union[Variation_1378, Variation_1378_Arg]) -> 'Variation_1379':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['C'], f : Any) -> 'Variation_1379':
        ...

    @overload
    def modify_item(self, name : Literal['RES'], f : Any) -> 'Variation_1379':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1380_Arg_Group = TypedDict('Variation_1380_Arg_Group', {
    'NBVB': Union[Variation_64, Variation_64_Arg],
    'NBCELLS': Union[Variation_278, Variation_278_Arg],
})
Variation_1380_Arg : TypeAlias = Union[Raw, Variation_1380_Arg_Group]
class Variation_1380(Group):
    variation = 'Group'

    bit_size = 40

    subitems_list = [
        ('NBVB', Variation_64),
        ('NBCELLS', Variation_278),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'NBVB': ('Number of \'valid\' Octets', Variation_64, 0, 16),
        'NBCELLS': ('Number of \'valid\' Cells', Variation_278, 16, 24),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['NBVB']) -> Type[Variation_64]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['NBCELLS']) -> Type[Variation_278]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['NBVB'], Literal['NBCELLS']]) -> Union[Type['Variation_64'], Type['Variation_278']]:
        if key == 'NBVB':
            return Variation_64
        if key == 'NBCELLS':
            return Variation_278
        assert_never(key)

    def __init__(self, arg : Variation_1380_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['NBVB']) -> Variation_64:
        ...

    @overload
    def get_item(self, name : Literal['NBCELLS']) -> Variation_278:
        ...

    def get_item(self, name : Union[Literal['NBVB'], Literal['NBCELLS']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['NBVB'], val : Union[Variation_64, Variation_64_Arg]) -> 'Variation_1380':
        ...

    @overload
    def set_item(self, name : Literal['NBCELLS'], val : Union[Variation_278, Variation_278_Arg]) -> 'Variation_1380':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['NBVB'], f : Any) -> 'Variation_1380':
        ...

    @overload
    def modify_item(self, name : Literal['NBCELLS'], f : Any) -> 'Variation_1380':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1381_Arg : TypeAlias = Raw
class Variation_1381(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 512

    def __init__(self, arg : Variation_1381_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_1382_Arg : TypeAlias = Union[Variation_1381, Variation_1381_Arg]
class Variation_1382(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 512
    variation_type = Variation_1381

    @classmethod
    def spec(cls) -> Type[Variation_1381]:
        return Variation_1381

    def __init__(self, arg : List[Union[Variation_1381, Variation_1381_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1381, Variation_1381_Arg]) -> 'Variation_1382':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1381, Variation_1381_Arg]) -> 'Variation_1382':
        return self._prepend_item(arg) # type: ignore

Variation_1383_Arg : TypeAlias = Raw
class Variation_1383(Element):
    variation = 'Element'

    bit_offset8 = 0
    bit_size = 2048

    def __init__(self, arg : Variation_1383_Arg) -> None:
        if isinstance(arg, Bits):
            super().__init__(arg); return
        if isinstance(arg, Raw):
            super().__init__(self._from_raw(arg)); return
        assert_never(arg)




Variation_1384_Arg : TypeAlias = Union[Variation_1383, Variation_1383_Arg]
class Variation_1384(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 2048
    variation_type = Variation_1383

    @classmethod
    def spec(cls) -> Type[Variation_1383]:
        return Variation_1383

    def __init__(self, arg : List[Union[Variation_1383, Variation_1383_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1383, Variation_1383_Arg]) -> 'Variation_1384':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1383, Variation_1383_Arg]) -> 'Variation_1384':
        return self._prepend_item(arg) # type: ignore

Variation_1385_Arg = TypedDict('Variation_1385_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '000': Union[Variation_1371, Variation_1371_Arg],
    '020': Union[Variation_555, Variation_555_Arg],
    '030': Union[Variation_1372, Variation_1372_Arg],
    '040': Union[Variation_1374, Variation_1374_Arg],
    '041': Union[Variation_1376, Variation_1376_Arg],
    '048': Union[Variation_1379, Variation_1379_Arg],
    '049': Union[Variation_1380, Variation_1380_Arg],
    '050': Union[Variation_556, Variation_556_Arg],
    '051': Union[Variation_1382, Variation_1382_Arg],
    '052': Union[Variation_1384, Variation_1384_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
}, total=False)
class Variation_1385(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 2

    subitems_list = [
        ('010', Variation_1),
        ('000', Variation_1371),
        ('020', Variation_555),
        ('030', Variation_1372),
        ('040', Variation_1374),
        ('041', Variation_1376),
        ('048', Variation_1379),
        ('049', Variation_1380),
        ('050', Variation_556),
        ('051', Variation_1382),
        ('052', Variation_1384),
        ('140', Variation_80),
        ('RE', Variation_202),
        ('SP', Variation_62),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x8000),
        '000': ('Message Type', Variation_1371, 0x4000),
        '020': ('Video Record Header', Variation_555, 0x2000),
        '030': ('Video Summary', Variation_1372, 0x1000),
        '040': ('Video Header Nano', Variation_1374, 0x0800),
        '041': ('Video Header Femto', Variation_1376, 0x0400),
        '048': ('Video Cells Resolution & Data Compression Indicator', Variation_1379, 0x0200),
        '049': ('Video Octets & Video Cells Counters', Variation_1380, 0x0180),
        '050': ('Video Block Low Data Volume', Variation_556, 0x0140),
        '051': ('Video Block Medium Data Volume', Variation_1382, 0x0120),
        '052': ('Video Block High Data Volume', Variation_1384, 0x0110),
        '140': ('Time of Day', Variation_80, 0x0108),
        'RE': ('Reserved Expansion Field', Variation_202, 0x0104),
        'SP': ('Special Purpose Field', Variation_62, 0x0102),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['000']) -> Type[Variation_1371]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['020']) -> Type[Variation_555]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['030']) -> Type[Variation_1372]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['040']) -> Type[Variation_1374]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['041']) -> Type[Variation_1376]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['048']) -> Type[Variation_1379]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['049']) -> Type[Variation_1380]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['050']) -> Type[Variation_556]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['051']) -> Type[Variation_1382]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['052']) -> Type[Variation_1384]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['000'], Literal['020'], Literal['030'], Literal['040'], Literal['041'], Literal['048'], Literal['049'], Literal['050'], Literal['051'], Literal['052'], Literal['140'], Literal['RE'], Literal['SP']]) -> Union[Type['Variation_1'], Type['Variation_1371'], Type['Variation_555'], Type['Variation_1372'], Type['Variation_1374'], Type['Variation_1376'], Type['Variation_1379'], Type['Variation_1380'], Type['Variation_556'], Type['Variation_1382'], Type['Variation_1384'], Type['Variation_80'], Type['Variation_202'], Type['Variation_62']]:
        if key == '010':
            return Variation_1
        if key == '000':
            return Variation_1371
        if key == '020':
            return Variation_555
        if key == '030':
            return Variation_1372
        if key == '040':
            return Variation_1374
        if key == '041':
            return Variation_1376
        if key == '048':
            return Variation_1379
        if key == '049':
            return Variation_1380
        if key == '050':
            return Variation_556
        if key == '051':
            return Variation_1382
        if key == '052':
            return Variation_1384
        if key == '140':
            return Variation_80
        if key == 'RE':
            return Variation_202
        if key == 'SP':
            return Variation_62
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1385_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['000'], val : Union[Variation_1371, Variation_1371_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['020'], val : Union[Variation_555, Variation_555_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['030'], val : Union[Variation_1372, Variation_1372_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['040'], val : Union[Variation_1374, Variation_1374_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['041'], val : Union[Variation_1376, Variation_1376_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['048'], val : Union[Variation_1379, Variation_1379_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['049'], val : Union[Variation_1380, Variation_1380_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['050'], val : Union[Variation_556, Variation_556_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['051'], val : Union[Variation_1382, Variation_1382_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['052'], val : Union[Variation_1384, Variation_1384_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1385':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1385':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['000']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['020']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['030']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['040']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['041']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['048']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['049']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['050']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['051']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['052']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1385':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1385':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['000']) -> Variation_1371:
        ...

    @overload
    def get_item(self, name : Literal['020']) -> Variation_555:
        ...

    @overload
    def get_item(self, name : Literal['030']) -> Variation_1372:
        ...

    @overload
    def get_item(self, name : Literal['040']) -> Variation_1374:
        ...

    @overload
    def get_item(self, name : Literal['041']) -> Variation_1376:
        ...

    @overload
    def get_item(self, name : Literal['048']) -> Variation_1379:
        ...

    @overload
    def get_item(self, name : Literal['049']) -> Variation_1380:
        ...

    @overload
    def get_item(self, name : Literal['050']) -> Variation_556:
        ...

    @overload
    def get_item(self, name : Literal['051']) -> Variation_1382:
        ...

    @overload
    def get_item(self, name : Literal['052']) -> Variation_1384:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['000'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['020'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['030'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['040'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['041'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['048'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['049'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['050'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['051'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['052'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1385':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1385':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1386_Arg_Group = TypedDict('Variation_1386_Arg_Group', {
    'CAT': Union[Variation_0, Variation_0_Arg],
    'MAIN': Union[Variation_0, Variation_0_Arg],
    'SUB': Union[Variation_0, Variation_0_Arg],
})
Variation_1386_Arg : TypeAlias = Union[Raw, Variation_1386_Arg_Group]
class Variation_1386(Group):
    variation = 'Group'

    bit_size = 24

    subitems_list = [
        ('CAT', Variation_0),
        ('MAIN', Variation_0),
        ('SUB', Variation_0),
    ]

    # name: (title, cls, group_offset, bit_size)
    subitems_dict = {
        'CAT': ('Category', Variation_0, 0, 8),
        'MAIN': ('Main Version Number', Variation_0, 8, 8),
        'SUB': ('Sub Version Number', Variation_0, 16, 8),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['CAT']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['MAIN']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SUB']) -> Type[Variation_0]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['CAT'], Literal['MAIN'], Literal['SUB']]) -> Union[Type['Variation_0'], Type['Variation_0'], Type['Variation_0']]:
        if key == 'CAT':
            return Variation_0
        if key == 'MAIN':
            return Variation_0
        if key == 'SUB':
            return Variation_0
        assert_never(key)

    def __init__(self, arg : Variation_1386_Arg) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, dict):
            super().__init__(*self._from_items(arg)); return
        if isinstance(arg, Raw):
            super().__init__(*self._from_raw(arg)); return
        assert_never(arg)

    @overload
    def get_item(self, name : Literal['CAT']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['MAIN']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['SUB']) -> Variation_0:
        ...

    def get_item(self, name : Union[Literal['CAT'], Literal['MAIN'], Literal['SUB']]) -> Any:
        return self._get_item(name)

    @overload
    def set_item(self, name : Literal['CAT'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1386':
        ...

    @overload
    def set_item(self, name : Literal['MAIN'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1386':
        ...

    @overload
    def set_item(self, name : Literal['SUB'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1386':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def modify_item(self, name : Literal['CAT'], f : Any) -> 'Variation_1386':
        ...

    @overload
    def modify_item(self, name : Literal['MAIN'], f : Any) -> 'Variation_1386':
        ...

    @overload
    def modify_item(self, name : Literal['SUB'], f : Any) -> 'Variation_1386':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

Variation_1387_Arg : TypeAlias = Union[Variation_1386, Variation_1386_Arg]
class Variation_1387(Repetitive):
    variation = 'Repetitive'

    rep_byte_size = 1
    variation_bit_size = 24
    variation_type = Variation_1386

    @classmethod
    def spec(cls) -> Type[Variation_1386]:
        return Variation_1386

    def __init__(self, arg : List[Union[Variation_1386, Variation_1386_Arg]]) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        if isinstance(arg, list):
            super().__init__(*self._from_list(arg)); return
        assert_never(arg)

    def append_item(self, arg : Union[Variation_1386, Variation_1386_Arg]) -> 'Variation_1387':
        return self._append_item(arg) # type: ignore

    def prepend_item(self, arg : Union[Variation_1386, Variation_1386_Arg]) -> 'Variation_1387':
        return self._prepend_item(arg) # type: ignore

Variation_1388_Arg = TypedDict('Variation_1388_Arg', {
    '010': Union[Variation_1, Variation_1_Arg],
    '015': Union[Variation_0, Variation_0_Arg],
    '140': Union[Variation_80, Variation_80_Arg],
    '550': Union[Variation_1387, Variation_1387_Arg],
    'SP': Union[Variation_62, Variation_62_Arg],
    'RE': Union[Variation_202, Variation_202_Arg],
}, total=False)
class Variation_1388(Compound):
    variation = 'Compound'

    fspec_fx = True
    fspec_max_bytes = 1

    subitems_list = [
        ('010', Variation_1),
        ('015', Variation_0),
        ('140', Variation_80),
        ('550', Variation_1387),
        None,
        ('SP', Variation_62),
        ('RE', Variation_202),
    ]

    # name: (title, cls, fspec)
    subitems_dict = {
        '010': ('Data Source Identifier', Variation_1, 0x80),
        '015': ('Service Identification', Variation_0, 0x40),
        '140': ('Time of Day', Variation_80, 0x20),
        '550': ('Category Version Number Report', Variation_1387, 0x10),
        'SP': ('Special Purpose Field', Variation_62, 0x04),
        'RE': ('Reserved Expansion Field', Variation_202, 0x02),
    }

    @overload
    @classmethod
    def spec(cls, key : Literal['010']) -> Type[Variation_1]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['015']) -> Type[Variation_0]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['140']) -> Type[Variation_80]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['550']) -> Type[Variation_1387]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['SP']) -> Type[Variation_62]:
        ...

    @overload
    @classmethod
    def spec(cls, key : Literal['RE']) -> Type[Variation_202]:
        ...

    @classmethod
    def spec(cls, key : Union[Literal['010'], Literal['015'], Literal['140'], Literal['550'], Literal['SP'], Literal['RE']]) -> Union[Type['Variation_1'], Type['Variation_0'], Type['Variation_80'], Type['Variation_1387'], Type['Variation_62'], Type['Variation_202']]:
        if key == '010':
            return Variation_1
        if key == '015':
            return Variation_0
        if key == '140':
            return Variation_80
        if key == '550':
            return Variation_1387
        if key == 'SP':
            return Variation_62
        if key == 'RE':
            return Variation_202
        assert_never(key)

    def __init__(self, arg : Optional[Variation_1388_Arg] = None) -> None:
        if isinstance(arg, tuple):
            super().__init__(*arg); return
        super().__init__()
        if arg is not None: self._update(arg)

    @overload
    def set_item(self, name : Literal['010'], val : Union[Variation_1, Variation_1_Arg]) -> 'Variation_1388':
        ...

    @overload
    def set_item(self, name : Literal['015'], val : Union[Variation_0, Variation_0_Arg]) -> 'Variation_1388':
        ...

    @overload
    def set_item(self, name : Literal['140'], val : Union[Variation_80, Variation_80_Arg]) -> 'Variation_1388':
        ...

    @overload
    def set_item(self, name : Literal['550'], val : Union[Variation_1387, Variation_1387_Arg]) -> 'Variation_1388':
        ...

    @overload
    def set_item(self, name : Literal['SP'], val : Union[Variation_62, Variation_62_Arg]) -> 'Variation_1388':
        ...

    @overload
    def set_item(self, name : Literal['RE'], val : Union[Variation_202, Variation_202_Arg]) -> 'Variation_1388':
        ...

    def set_item(self, name : Any, val : Any) -> Any:
        return self._set_item(name, val)

    @overload
    def del_item(self, name : Literal['010']) -> 'Variation_1388':
        ...

    @overload
    def del_item(self, name : Literal['015']) -> 'Variation_1388':
        ...

    @overload
    def del_item(self, name : Literal['140']) -> 'Variation_1388':
        ...

    @overload
    def del_item(self, name : Literal['550']) -> 'Variation_1388':
        ...

    @overload
    def del_item(self, name : Literal['SP']) -> 'Variation_1388':
        ...

    @overload
    def del_item(self, name : Literal['RE']) -> 'Variation_1388':
        ...

    def del_item(self, name : Any) -> Any:
        return self._del_item(name)

    @overload
    def get_item(self, name : Literal['010']) -> Variation_1:
        ...

    @overload
    def get_item(self, name : Literal['015']) -> Variation_0:
        ...

    @overload
    def get_item(self, name : Literal['140']) -> Variation_80:
        ...

    @overload
    def get_item(self, name : Literal['550']) -> Variation_1387:
        ...

    @overload
    def get_item(self, name : Literal['SP']) -> Variation_62:
        ...

    @overload
    def get_item(self, name : Literal['RE']) -> Variation_202:
        ...

    def get_item(self, name : Any) -> Any:
        return self._get_item(name)

    @overload
    def modify_item(self, name : Literal['010'], f : Any) -> 'Variation_1388':
        ...

    @overload
    def modify_item(self, name : Literal['015'], f : Any) -> 'Variation_1388':
        ...

    @overload
    def modify_item(self, name : Literal['140'], f : Any) -> 'Variation_1388':
        ...

    @overload
    def modify_item(self, name : Literal['550'], f : Any) -> 'Variation_1388':
        ...

    @overload
    def modify_item(self, name : Literal['SP'], f : Any) -> 'Variation_1388':
        ...

    @overload
    def modify_item(self, name : Literal['RE'], f : Any) -> 'Variation_1388':
        ...

    def modify_item(self, name : Any, f : Any) -> Any:
        return self._modify_item(name, f)

class CAT_001_1_2(Basic):
    cat = 1

    uaps = {
        'plot': Variation_63,
        'track': Variation_77,
    }

    uap_selector_item = ["020", "TYP"]

    uap_selector_table = {
        0: 'plot',
        1: 'track',
    }

    @classmethod
    def spec(cls, val : Literal["plot", "track"]) -> Any:
        return cls.uaps[val]

    @overload
    @classmethod
    def make_record_unsafe(cls, uap : Literal['plot'], arg : Variation_63_Arg) -> Variation_63:
        ...
    @overload
    @classmethod
    def make_record_unsafe(cls, uap : Literal['track'], arg : Variation_77_Arg) -> Variation_77:
        ...

    @classmethod
    def make_record_unsafe(cls, uap : Any, arg : Any) -> Any:
        return cls.uaps[uap](arg)

    @classmethod
    def make_datablock(cls, val : Union[Union[Variation_63, Variation_77], List[Union[Variation_63, Variation_77]]]) -> Datablock[Union[Variation_63, Variation_77]]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions, uap : Optional[Literal["plot", "track"]] = None) -> Any:
        return cls._parse(val, opt, uap=uap)

    @classmethod
    def is_valid(cls, arg : Union[Variation_63, Variation_77]) -> bool:
        return cls._is_valid(arg)

class CAT_001_1_3(Basic):
    cat = 1

    uaps = {
        'plot': Variation_63,
        'track': Variation_77,
    }

    uap_selector_item = ["020", "TYP"]

    uap_selector_table = {
        0: 'plot',
        1: 'track',
    }

    @classmethod
    def spec(cls, val : Literal["plot", "track"]) -> Any:
        return cls.uaps[val]

    @overload
    @classmethod
    def make_record_unsafe(cls, uap : Literal['plot'], arg : Variation_63_Arg) -> Variation_63:
        ...
    @overload
    @classmethod
    def make_record_unsafe(cls, uap : Literal['track'], arg : Variation_77_Arg) -> Variation_77:
        ...

    @classmethod
    def make_record_unsafe(cls, uap : Any, arg : Any) -> Any:
        return cls.uaps[uap](arg)

    @classmethod
    def make_datablock(cls, val : Union[Union[Variation_63, Variation_77], List[Union[Variation_63, Variation_77]]]) -> Datablock[Union[Variation_63, Variation_77]]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions, uap : Optional[Literal["plot", "track"]] = None) -> Any:
        return cls._parse(val, opt, uap=uap)

    @classmethod
    def is_valid(cls, arg : Union[Variation_63, Variation_77]) -> bool:
        return cls._is_valid(arg)

class CAT_001_1_4(Basic):
    cat = 1

    uaps = {
        'plot': Variation_63,
        'track': Variation_77,
    }

    uap_selector_item = ["020", "TYP"]

    uap_selector_table = {
        0: 'plot',
        1: 'track',
    }

    @classmethod
    def spec(cls, val : Literal["plot", "track"]) -> Any:
        return cls.uaps[val]

    @overload
    @classmethod
    def make_record_unsafe(cls, uap : Literal['plot'], arg : Variation_63_Arg) -> Variation_63:
        ...
    @overload
    @classmethod
    def make_record_unsafe(cls, uap : Literal['track'], arg : Variation_77_Arg) -> Variation_77:
        ...

    @classmethod
    def make_record_unsafe(cls, uap : Any, arg : Any) -> Any:
        return cls.uaps[uap](arg)

    @classmethod
    def make_datablock(cls, val : Union[Union[Variation_63, Variation_77], List[Union[Variation_63, Variation_77]]]) -> Datablock[Union[Variation_63, Variation_77]]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions, uap : Optional[Literal["plot", "track"]] = None) -> Any:
        return cls._parse(val, opt, uap=uap)

    @classmethod
    def is_valid(cls, arg : Union[Variation_63, Variation_77]) -> bool:
        return cls._is_valid(arg)

class CAT_002_1_0(Basic):
    cat = 2
    variation = Variation_90

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_90_Arg) -> Variation_90:
        return Variation_90(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_90, List[Variation_90]]) -> Datablock[Variation_90]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_90]:
        return cls._parse(val, opt) # type: ignore

class CAT_002_1_1(Basic):
    cat = 2
    variation = Variation_90

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_90_Arg) -> Variation_90:
        return Variation_90(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_90, List[Variation_90]]) -> Datablock[Variation_90]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_90]:
        return cls._parse(val, opt) # type: ignore

class CAT_004_1_12(Basic):
    cat = 4
    variation = Variation_203

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_203_Arg) -> Variation_203:
        return Variation_203(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_203, List[Variation_203]]) -> Datablock[Variation_203]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_203]:
        return cls._parse(val, opt) # type: ignore

class CAT_008_1_2(Basic):
    cat = 8
    variation = Variation_228

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_228_Arg) -> Variation_228:
        return Variation_228(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_228, List[Variation_228]]) -> Datablock[Variation_228]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_228]:
        return cls._parse(val, opt) # type: ignore

class CAT_008_1_3(Basic):
    cat = 8
    variation = Variation_228

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_228_Arg) -> Variation_228:
        return Variation_228(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_228, List[Variation_228]]) -> Datablock[Variation_228]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_228]:
        return cls._parse(val, opt) # type: ignore

class CAT_009_2_1(Basic):
    cat = 9
    variation = Variation_241

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_241_Arg) -> Variation_241:
        return Variation_241(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_241, List[Variation_241]]) -> Datablock[Variation_241]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_241]:
        return cls._parse(val, opt) # type: ignore

class CAT_010_1_1(Basic):
    cat = 10
    variation = Variation_309

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_309_Arg) -> Variation_309:
        return Variation_309(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_309, List[Variation_309]]) -> Datablock[Variation_309]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_309]:
        return cls._parse(val, opt) # type: ignore

class CAT_011_1_2(Basic):
    cat = 11
    variation = Variation_412

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_412_Arg) -> Variation_412:
        return Variation_412(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_412, List[Variation_412]]) -> Datablock[Variation_412]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_412]:
        return cls._parse(val, opt) # type: ignore

class CAT_011_1_3(Basic):
    cat = 11
    variation = Variation_429

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_429_Arg) -> Variation_429:
        return Variation_429(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_429, List[Variation_429]]) -> Datablock[Variation_429]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_429]:
        return cls._parse(val, opt) # type: ignore

class CAT_015_1_0(Basic):
    cat = 15
    variation = Variation_523

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_523_Arg) -> Variation_523:
        return Variation_523(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_523, List[Variation_523]]) -> Datablock[Variation_523]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_523]:
        return cls._parse(val, opt) # type: ignore

class CAT_015_1_1(Basic):
    cat = 15
    variation = Variation_523

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_523_Arg) -> Variation_523:
        return Variation_523(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_523, List[Variation_523]]) -> Datablock[Variation_523]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_523]:
        return cls._parse(val, opt) # type: ignore

class CAT_016_1_0(Basic):
    cat = 16
    variation = Variation_534

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_534_Arg) -> Variation_534:
        return Variation_534(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_534, List[Variation_534]]) -> Datablock[Variation_534]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_534]:
        return cls._parse(val, opt) # type: ignore

class CAT_017_1_3(Basic):
    cat = 17
    variation = Variation_550

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_550_Arg) -> Variation_550:
        return Variation_550(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_550, List[Variation_550]]) -> Datablock[Variation_550]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_550]:
        return cls._parse(val, opt) # type: ignore

class CAT_018_1_7(Basic):
    cat = 18
    variation = Variation_607

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_607_Arg) -> Variation_607:
        return Variation_607(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_607, List[Variation_607]]) -> Datablock[Variation_607]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_607]:
        return cls._parse(val, opt) # type: ignore

class CAT_019_1_3(Basic):
    cat = 19
    variation = Variation_633

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_633_Arg) -> Variation_633:
        return Variation_633(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_633, List[Variation_633]]) -> Datablock[Variation_633]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_633]:
        return cls._parse(val, opt) # type: ignore

class CAT_020_1_9(Basic):
    cat = 20
    variation = Variation_690

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_690_Arg) -> Variation_690:
        return Variation_690(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_690, List[Variation_690]]) -> Datablock[Variation_690]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_690]:
        return cls._parse(val, opt) # type: ignore

class CAT_020_1_10(Basic):
    cat = 20
    variation = Variation_693

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_693_Arg) -> Variation_693:
        return Variation_693(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_693, List[Variation_693]]) -> Datablock[Variation_693]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_693]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_0_23(Basic):
    cat = 21
    variation = Variation_755

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_755_Arg) -> Variation_755:
        return Variation_755(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_755, List[Variation_755]]) -> Datablock[Variation_755]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_755]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_0_24(Basic):
    cat = 21
    variation = Variation_756

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_756_Arg) -> Variation_756:
        return Variation_756(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_756, List[Variation_756]]) -> Datablock[Variation_756]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_756]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_0_25(Basic):
    cat = 21
    variation = Variation_756

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_756_Arg) -> Variation_756:
        return Variation_756(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_756, List[Variation_756]]) -> Datablock[Variation_756]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_756]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_0_26(Basic):
    cat = 21
    variation = Variation_759

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_759_Arg) -> Variation_759:
        return Variation_759(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_759, List[Variation_759]]) -> Datablock[Variation_759]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_759]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_2_1(Basic):
    cat = 21
    variation = Variation_915

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_915_Arg) -> Variation_915:
        return Variation_915(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_915, List[Variation_915]]) -> Datablock[Variation_915]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_915]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_2_2(Basic):
    cat = 21
    variation = Variation_919

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_919_Arg) -> Variation_919:
        return Variation_919(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_919, List[Variation_919]]) -> Datablock[Variation_919]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_919]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_2_3(Basic):
    cat = 21
    variation = Variation_922

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_922_Arg) -> Variation_922:
        return Variation_922(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_922, List[Variation_922]]) -> Datablock[Variation_922]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_922]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_2_4(Basic):
    cat = 21
    variation = Variation_922

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_922_Arg) -> Variation_922:
        return Variation_922(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_922, List[Variation_922]]) -> Datablock[Variation_922]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_922]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_2_5(Basic):
    cat = 21
    variation = Variation_925

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_925_Arg) -> Variation_925:
        return Variation_925(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_925, List[Variation_925]]) -> Datablock[Variation_925]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_925]:
        return cls._parse(val, opt) # type: ignore

class CAT_021_2_6(Basic):
    cat = 21
    variation = Variation_930

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_930_Arg) -> Variation_930:
        return Variation_930(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_930, List[Variation_930]]) -> Datablock[Variation_930]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_930]:
        return cls._parse(val, opt) # type: ignore

class CAT_023_1_2(Basic):
    cat = 23
    variation = Variation_952

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_952_Arg) -> Variation_952:
        return Variation_952(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_952, List[Variation_952]]) -> Datablock[Variation_952]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_952]:
        return cls._parse(val, opt) # type: ignore

class CAT_023_1_3(Basic):
    cat = 23
    variation = Variation_952

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_952_Arg) -> Variation_952:
        return Variation_952(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_952, List[Variation_952]]) -> Datablock[Variation_952]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_952]:
        return cls._parse(val, opt) # type: ignore

class CAT_025_1_5(Basic):
    cat = 25
    variation = Variation_971

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_971_Arg) -> Variation_971:
        return Variation_971(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_971, List[Variation_971]]) -> Datablock[Variation_971]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_971]:
        return cls._parse(val, opt) # type: ignore

class CAT_032_1_1(Basic):
    cat = 32
    variation = Variation_1000

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1000_Arg) -> Variation_1000:
        return Variation_1000(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1000, List[Variation_1000]]) -> Datablock[Variation_1000]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1000]:
        return cls._parse(val, opt) # type: ignore

class CAT_034_1_27(Basic):
    cat = 34
    variation = Variation_1042

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1042_Arg) -> Variation_1042:
        return Variation_1042(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1042, List[Variation_1042]]) -> Datablock[Variation_1042]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1042]:
        return cls._parse(val, opt) # type: ignore

class CAT_034_1_28(Basic):
    cat = 34
    variation = Variation_1047

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1047_Arg) -> Variation_1047:
        return Variation_1047(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1047, List[Variation_1047]]) -> Datablock[Variation_1047]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1047]:
        return cls._parse(val, opt) # type: ignore

class CAT_034_1_29(Basic):
    cat = 34
    variation = Variation_1049

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1049_Arg) -> Variation_1049:
        return Variation_1049(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1049, List[Variation_1049]]) -> Datablock[Variation_1049]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1049]:
        return cls._parse(val, opt) # type: ignore

class CAT_048_1_27(Basic):
    cat = 48
    variation = Variation_1167

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1167_Arg) -> Variation_1167:
        return Variation_1167(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1167, List[Variation_1167]]) -> Datablock[Variation_1167]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1167]:
        return cls._parse(val, opt) # type: ignore

class CAT_048_1_28(Basic):
    cat = 48
    variation = Variation_1170

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1170_Arg) -> Variation_1170:
        return Variation_1170(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1170, List[Variation_1170]]) -> Datablock[Variation_1170]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1170]:
        return cls._parse(val, opt) # type: ignore

class CAT_048_1_29(Basic):
    cat = 48
    variation = Variation_1171

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1171_Arg) -> Variation_1171:
        return Variation_1171(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1171, List[Variation_1171]]) -> Datablock[Variation_1171]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1171]:
        return cls._parse(val, opt) # type: ignore

class CAT_048_1_30(Basic):
    cat = 48
    variation = Variation_1171

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1171_Arg) -> Variation_1171:
        return Variation_1171(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1171, List[Variation_1171]]) -> Datablock[Variation_1171]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1171]:
        return cls._parse(val, opt) # type: ignore

class CAT_048_1_31(Basic):
    cat = 48
    variation = Variation_1184

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1184_Arg) -> Variation_1184:
        return Variation_1184(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1184, List[Variation_1184]]) -> Datablock[Variation_1184]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1184]:
        return cls._parse(val, opt) # type: ignore

class CAT_062_1_17(Basic):
    cat = 62
    variation = Variation_1324

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1324_Arg) -> Variation_1324:
        return Variation_1324(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1324, List[Variation_1324]]) -> Datablock[Variation_1324]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1324]:
        return cls._parse(val, opt) # type: ignore

class CAT_062_1_18(Basic):
    cat = 62
    variation = Variation_1332

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1332_Arg) -> Variation_1332:
        return Variation_1332(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1332, List[Variation_1332]]) -> Datablock[Variation_1332]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1332]:
        return cls._parse(val, opt) # type: ignore

class CAT_062_1_19(Basic):
    cat = 62
    variation = Variation_1335

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1335_Arg) -> Variation_1335:
        return Variation_1335(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1335, List[Variation_1335]]) -> Datablock[Variation_1335]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1335]:
        return cls._parse(val, opt) # type: ignore

class CAT_062_1_20(Basic):
    cat = 62
    variation = Variation_1339

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1339_Arg) -> Variation_1339:
        return Variation_1339(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1339, List[Variation_1339]]) -> Datablock[Variation_1339]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1339]:
        return cls._parse(val, opt) # type: ignore

class CAT_063_1_6(Basic):
    cat = 63
    variation = Variation_1355

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1355_Arg) -> Variation_1355:
        return Variation_1355(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1355, List[Variation_1355]]) -> Datablock[Variation_1355]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1355]:
        return cls._parse(val, opt) # type: ignore

class CAT_065_1_4(Basic):
    cat = 65
    variation = Variation_1363

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1363_Arg) -> Variation_1363:
        return Variation_1363(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1363, List[Variation_1363]]) -> Datablock[Variation_1363]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1363]:
        return cls._parse(val, opt) # type: ignore

class CAT_065_1_5(Basic):
    cat = 65
    variation = Variation_1363

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1363_Arg) -> Variation_1363:
        return Variation_1363(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1363, List[Variation_1363]]) -> Datablock[Variation_1363]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1363]:
        return cls._parse(val, opt) # type: ignore

class CAT_065_1_6(Basic):
    cat = 65
    variation = Variation_1363

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1363_Arg) -> Variation_1363:
        return Variation_1363(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1363, List[Variation_1363]]) -> Datablock[Variation_1363]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1363]:
        return cls._parse(val, opt) # type: ignore

class CAT_205_1_0(Basic):
    cat = 205
    variation = Variation_1370

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1370_Arg) -> Variation_1370:
        return Variation_1370(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1370, List[Variation_1370]]) -> Datablock[Variation_1370]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1370]:
        return cls._parse(val, opt) # type: ignore

class CAT_240_1_3(Basic):
    cat = 240
    variation = Variation_1385

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1385_Arg) -> Variation_1385:
        return Variation_1385(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1385, List[Variation_1385]]) -> Datablock[Variation_1385]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1385]:
        return cls._parse(val, opt) # type: ignore

class CAT_247_1_2(Basic):
    cat = 247
    variation = Variation_1388

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1388_Arg) -> Variation_1388:
        return Variation_1388(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1388, List[Variation_1388]]) -> Datablock[Variation_1388]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1388]:
        return cls._parse(val, opt) # type: ignore

class CAT_247_1_3(Basic):
    cat = 247
    variation = Variation_1388

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_record(cls, val : Variation_1388_Arg) -> Variation_1388:
        return Variation_1388(val)

    @classmethod
    def make_datablock(cls, val : Union[Variation_1388, List[Variation_1388]]) -> Datablock[Variation_1388]:
        return Datablock(cls.cat, val)

    @classmethod
    def parse(cls, val : RawDatablock, opt : ParsingOptions) -> Datablock[Variation_1388]:
        return cls._parse(val, opt) # type: ignore

class REF_021_1_4(Expansion):
    cat = 21
    variation = Variation_805

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_extended(cls, val : Variation_805_Arg) -> Variation_805:
        return Variation_805(val)

    @classmethod
    def parse(cls, val : bytes, opt : ParsingOptions) -> Variation_805:
        s = Bits.from_bytes(val)
        (rec, s2) = Variation_805.parse_bits(s, opt)
        if len(s2) != 0:
            raise AsterixError('unable to parse expansion')
        return rec # type: ignore

class REF_021_1_5(Expansion):
    cat = 21
    variation = Variation_839

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_extended(cls, val : Variation_839_Arg) -> Variation_839:
        return Variation_839(val)

    @classmethod
    def parse(cls, val : bytes, opt : ParsingOptions) -> Variation_839:
        s = Bits.from_bytes(val)
        (rec, s2) = Variation_839.parse_bits(s, opt)
        if len(s2) != 0:
            raise AsterixError('unable to parse expansion')
        return rec # type: ignore

class REF_048_1_11(Expansion):
    cat = 48
    variation = Variation_1111

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_extended(cls, val : Variation_1111_Arg) -> Variation_1111:
        return Variation_1111(val)

    @classmethod
    def parse(cls, val : bytes, opt : ParsingOptions) -> Variation_1111:
        s = Bits.from_bytes(val)
        (rec, s2) = Variation_1111.parse_bits(s, opt)
        if len(s2) != 0:
            raise AsterixError('unable to parse expansion')
        return rec # type: ignore

class REF_062_1_2(Expansion):
    cat = 62
    variation = Variation_1192

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_extended(cls, val : Variation_1192_Arg) -> Variation_1192:
        return Variation_1192(val)

    @classmethod
    def parse(cls, val : bytes, opt : ParsingOptions) -> Variation_1192:
        s = Bits.from_bytes(val)
        (rec, s2) = Variation_1192.parse_bits(s, opt)
        if len(s2) != 0:
            raise AsterixError('unable to parse expansion')
        return rec # type: ignore

class REF_062_1_3(Expansion):
    cat = 62
    variation = Variation_1213

    spec = variation.spec

    parse_bits = variation.parse_bits

    unparse_bits = variation.unparse_bits

    @classmethod
    def make_extended(cls, val : Variation_1213_Arg) -> Variation_1213:
        return Variation_1213(val)

    @classmethod
    def parse(cls, val : bytes, opt : ParsingOptions) -> Variation_1213:
        s = Bits.from_bytes(val)
        (rec, s2) = Variation_1213.parse_bits(s, opt)
        if len(s2) != 0:
            raise AsterixError('unable to parse expansion')
        return rec # type: ignore

manifest = {
    'CATS': {
        1: {
            '1.2': CAT_001_1_2,
            '1.3': CAT_001_1_3,
            '1.4': CAT_001_1_4,
        },
        2: {
            '1.0': CAT_002_1_0,
            '1.1': CAT_002_1_1,
        },
        4: {
            '1.12': CAT_004_1_12,
        },
        8: {
            '1.2': CAT_008_1_2,
            '1.3': CAT_008_1_3,
        },
        9: {
            '2.1': CAT_009_2_1,
        },
        10: {
            '1.1': CAT_010_1_1,
        },
        11: {
            '1.2': CAT_011_1_2,
            '1.3': CAT_011_1_3,
        },
        15: {
            '1.0': CAT_015_1_0,
            '1.1': CAT_015_1_1,
        },
        16: {
            '1.0': CAT_016_1_0,
        },
        17: {
            '1.3': CAT_017_1_3,
        },
        18: {
            '1.7': CAT_018_1_7,
        },
        19: {
            '1.3': CAT_019_1_3,
        },
        20: {
            '1.9': CAT_020_1_9,
            '1.10': CAT_020_1_10,
        },
        21: {
            '0.23': CAT_021_0_23,
            '0.24': CAT_021_0_24,
            '0.25': CAT_021_0_25,
            '0.26': CAT_021_0_26,
            '2.1': CAT_021_2_1,
            '2.2': CAT_021_2_2,
            '2.3': CAT_021_2_3,
            '2.4': CAT_021_2_4,
            '2.5': CAT_021_2_5,
            '2.6': CAT_021_2_6,
        },
        23: {
            '1.2': CAT_023_1_2,
            '1.3': CAT_023_1_3,
        },
        25: {
            '1.5': CAT_025_1_5,
        },
        32: {
            '1.1': CAT_032_1_1,
        },
        34: {
            '1.27': CAT_034_1_27,
            '1.28': CAT_034_1_28,
            '1.29': CAT_034_1_29,
        },
        48: {
            '1.27': CAT_048_1_27,
            '1.28': CAT_048_1_28,
            '1.29': CAT_048_1_29,
            '1.30': CAT_048_1_30,
            '1.31': CAT_048_1_31,
        },
        62: {
            '1.17': CAT_062_1_17,
            '1.18': CAT_062_1_18,
            '1.19': CAT_062_1_19,
            '1.20': CAT_062_1_20,
        },
        63: {
            '1.6': CAT_063_1_6,
        },
        65: {
            '1.4': CAT_065_1_4,
            '1.5': CAT_065_1_5,
            '1.6': CAT_065_1_6,
        },
        205: {
            '1.0': CAT_205_1_0,
        },
        240: {
            '1.3': CAT_240_1_3,
        },
        247: {
            '1.2': CAT_247_1_2,
            '1.3': CAT_247_1_3,
        },
    },
    'REFS': {
        21: {
            '1.4': REF_021_1_4,
            '1.5': REF_021_1_5,
        },
        48: {
            '1.11': REF_048_1_11,
        },
        62: {
            '1.2': REF_062_1_2,
            '1.3': REF_062_1_3,
        },
    },
}

VERSION = '20240324.6939'

REFERENCE = '2dd898ff931d42f1887bf26314765947606f731e'
